@@ -38,23 +38,35 @@ rm qrender
 # This script cleans all sub projects for a neat and compact directory.
 cd ../configurator/; make clean 
 rm Makefile
-rm -r .ui .moc .obj
+rm -r .ui .moc .obj core*
 
 cd ../qdvdauthor/; make clean 
 rm Makefile
 rm i18n/*.qm
 rm CONFIG.h
+rm core*
 
 cd qslideshow/; make clean
 rm Makefile
+rm core*
 
 cd ../qplayer/; make clean
 rm Makefile
 rm MEDIA_CONFIG.h
+rm core
 
 cd ../qrender/; make clean
 rm Makefile
+rm core
 
 cd ..
 rm -r .ui .moc .obj
+rm core* 
+
+cd ..
+sourceFiles=`cat \`find . -name "*.cpp"\` | wc -l`
+sourceHeader=`cat \`find . -name "*.h"\`  | wc -l`
+echo "Source=$sourceFiles + Header=$sourceHeader  => LOC=$(( sourceFiles + sourceHeader ))"
+echo
+
 
