@@ -35,7 +35,8 @@ void Configurator::initMe(QApplication *pApp)
 	// disable VLC support for now.
 //	qsLib = QString ("libvlc.so");
 //	qsLib = QString ("libvlc.a");
-//	if (!checkLibraryExists (qsLib))
+	qsLib = QString ("NoNoNoVLCForBeta1");
+	if (!checkLibraryExists (qsLib))
 		checkVideoVLC->setEnabled(false);
 	qsLib = QString ("mplayer");
 	system ((const char *)QString ("which %1 > /tmp/out.txt 2>/dev/null").arg(qsLib));
@@ -377,7 +378,7 @@ int Configurator::getCompileSteps ()
 	arrayDirs[4] = QString ("../qdvdauthor/.ui");
 	arrayDirs[5] = QString ("../qdvdauthor/.moc");
 	arrayDirs[6] = QString ("../qdvdauthor/.obj");
-	// Next we change into the soiurce directory
+	// Next we change into the source directory
 	QDir theDir ("../qdvdauthor");
 
 	iUIFiles = iHeaderFiles = iObjectHeader = iExtra = 0;
@@ -480,7 +481,7 @@ void Configurator::slotInstall()
 	/////////////////////////////////////////////////////////////////////////////////////////////////
 	uint t;
 	bool bCanWriteToInstallDir;
-	QString qsPassword;
+	QString qsPassword, qsQTDir;
 	QString qsPath = editInstallDir->text();
 	
 	if (m_pNewProcess)	{
@@ -530,12 +531,18 @@ void Configurator::slotInstall()
 	// This does not work since we start out in /root after changing to become root to install
 //	m_pNewProcess->setWorkingDirectory (QDir ("../qdvdauthor/"));
 	// Did not know how to handle this in one line so I create another bash script ...
+	qsQTDir = QString (getenv ("QTDIR"));
+	if ( qsQTDir.isEmpty () )
+	  qsQTDir = searchQTDir ();
+	else
+	  qsQTDir = QString("export QTDIR=%1\n").arg(qsQTDir);
+
 	theDir = QDir::current();
 	theDir.cdUp();
 	file.setName("/tmp/make_install.sh");
 	if ( file.open( IO_WriteOnly ) ) {
 		QTextStream stream( &file );
-		stream << "#!/bin/sh\n\n" << QString ("make -C %1 install").arg(theDir.absPath());
+		stream << "#!/bin/sh\n\n" << qsQTDir << QString ("make -C %1 install").arg(theDir.absPath());
 		file.close();
 	}
 	chmod ("/tmp/make_install.sh", S_IEXEC | S_IRUSR | S_IWRITE);
@@ -651,4 +658,55 @@ void Configurator::slotInfoVLC()
 			QMessageBox::Ok ,  QMessageBox::NoButton);
 }
 
-
+QString Configurator::searchQTDir ()
+{
+  // This function will create a script to search for the missing QTDIR
+  QString qsReturn ("find_qt_dir ()\n"
+      "{\n"
+      "export QTDIR=$(\n"
+      "ls -d1 $1/qt* 2>/dev/null |\n"
+      "(while read dir\n"
+      "do\n"
+      "  if [ -e $dir/bin/moc ];\n"
+      "  then\n"
+      "    export qtVersion=`$dir/bin/moc -v 2>&1 | awk -F\"(\" '{printf $2}' | awk '{print $2}' | awk -F \")\" '{print $1}' | awk -F. '{printf (\"%.2d%.2d%.2d\", $1, $2, $3);}'`;\n"
+      "    if [ $qtVersion -gt 030100 ] && [ $qtVersion -lt 040000 ];\n"
+      "    then\n"
+      "      echo $dir\n"
+      "    fi;\n"
+      "    break;\n"
+      "  fi;\n"
+      "done;\n"
+      "))\n"
+      "}\n"
+      "\n"
+      "check_qt_dir ()\n"
+      "{\n"
+      "if [ -z \"$QTDIR\" ];\n"
+      "then\n"
+      "  find_qt_dir /usr/lib\n"
+      "  if [ -z \"$QTDIR\" ];\n"
+      "  then\n"
+      "    find_qt_dir /usr/lib64\n"
+      "    if [ -z \"$QTDIR\" ];\n"
+      "    then\n"
+      "      find_qt_dir /usr/local/lib\n"
+      "      if [ -z \"$QTDIR\" ];\n"
+      "      then\n"
+      "        find_qt_dir /usr/local/lib64\n"
+      "      fi;\n"
+      "    fi;\n"
+      "  fi;\n"
+      "fi;\n"
+      "if [ ! -z \"$QTDIR\" ] \n"
+      "then\n"
+      "        export PATH=$QTDIR/bin:$PATH\n"
+      "        export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$QTDIR/lib\n"
+      "fi;\n"
+      "}\n"
+      "\n"
+      "check_qt_dir\n"
+      "\n"
+      "\n");
+  return qsReturn;
+}
