@@ -12,10 +12,13 @@
 
 #include <qstring.h>
 #include <qcolor.h>
+#include <qpoint.h>
 
 #define TYPE_COLOR_RED   0
 #define TYPE_COLOR_GREEN 1 
 #define TYPE_COLOR_BLUE  2
+#define TYPE_POSITION_X  3
+#define TYPE_POSITION_Y  4
 
 // Needed to access the function of the stored function pointer to a function of a class
 class CallbackClass
@@ -31,53 +34,72 @@ template <class T>
 class FunctionCallback : public CallbackClass
 {
 public:
-    typedef void (T::*Fn) ( int );
-    typedef bool (T::*Fn2)( const QString & );
+  // define function prototypes ...
+  typedef void   (T::*Fn)        ( int );
+  typedef bool   (T::*Fn2)       ( const QString & );
+  typedef void   (T::*Fn3)       ( QPoint & );
+  typedef QPoint (T::*FnGetPos ) ( );
 
-    FunctionCallback( T& obj, Fn fn )
-	: m_obj( obj ), m_fn( fn ), m_iWhichType ( -1 )
-    {};
-    FunctionCallback( T& obj, Fn2 fn2 )
-	: m_obj( obj ), m_fn2( fn2 ), m_iWhichType ( -1 )
-    {};
-    FunctionCallback( T& obj, int c )
-	: m_obj( obj ), m_iWhichType ( c )
-    {};
-    virtual ~FunctionCallback () 
-    {};
+  FunctionCallback( T& obj, Fn fn )
+    : m_obj( obj ), m_fn( fn ), m_iWhichType ( -1 )
+  {};
+  FunctionCallback( T& obj, Fn2 fn2 )
+    : m_obj( obj ), m_fn2( fn2 ), m_iWhichType ( -1 )
+  {};
+  FunctionCallback( T& obj, Fn3 fn3, FnGetPos fnGetPos, int c )
+    : m_obj( obj ), m_fn3( fn3 ), m_fnGetPos( fnGetPos ), m_iWhichType ( c )
+  {};
+  FunctionCallback( T& obj, int c )
+    : m_obj( obj ), m_iWhichType ( c )
+  {};
+  virtual ~FunctionCallback () 
+  {};
 
-    virtual int operator()( int n )
-    {
-	// call the function on the object
-	if (m_iWhichType == -1)	{
-		(m_obj.*m_fn)( n );
-	}
-	else if ( (m_iWhichType >= TYPE_COLOR_RED) && (m_iWhichType <= TYPE_COLOR_BLUE) )	{// Special handling for QColor
-		QColor &theColor = ((QColor &)m_obj);
-		int r = theColor.red  ();
-		int g = theColor.green();
-		int b = theColor.blue ();
-		switch (m_iWhichType)	{
-		case TYPE_COLOR_RED:   r = n; break;
-		case TYPE_COLOR_GREEN: g = n; break;
-		case TYPE_COLOR_BLUE:  b = n; break;
-		}
-		theColor.setRgb(r, g, b);
-//		(m_obj.*m_colorFn)( n, ((QColor &)m_obj).green(), ((QColor &)m_obj).blue() );
-	}
-	return 0;
+  virtual int operator()( int n )
+  {
+    // call the function on the object
+    if (m_iWhichType == -1)	{
+      (m_obj.*m_fn)( n );
     }
-    virtual void operator()( QString &str )
-    {
-	// call the function on the object
-	(m_obj.*m_fn2)( str );
+    else if ( (m_iWhichType >= TYPE_COLOR_RED) && (m_iWhichType <= TYPE_COLOR_BLUE) )	{// Special handling for QColor
+      QColor &theColor = ((QColor &)m_obj);
+      int r = theColor.red  ();
+      int g = theColor.green();
+      int b = theColor.blue ();
+      switch (m_iWhichType)	{
+      case TYPE_COLOR_RED:   r = n; break;
+      case TYPE_COLOR_GREEN: g = n; break;
+      case TYPE_COLOR_BLUE:  b = n; break;
+      }
+      theColor.setRgb(r, g, b);
+      //		(m_obj.*m_colorFn)( n, ((QColor &)m_obj).green(), ((QColor &)m_obj).blue() );
     }
-
+    else if ( ( m_iWhichType == TYPE_POSITION_X ) || (  m_iWhichType == TYPE_POSITION_Y ) ) {
+      QPoint thePosition = (m_obj.*m_fnGetPos)( );
+      int iX = thePosition.x ( );
+      int iY = thePosition.y ( );
+      if ( m_iWhichType == TYPE_POSITION_X )
+	iX = n;
+      if ( m_iWhichType == TYPE_POSITION_Y )
+	iY = n;
+      thePosition = QPoint ( iX, iY );
+      (m_obj.*m_fn3)( thePosition );
+    }
+    return 0;
+  }
+  virtual void operator()( QString &str )
+  {
+    // call the function on the object
+    (m_obj.*m_fn2)( str );
+  }
+  
 private:
-    T&    m_obj; 	// object reference
-    Fn    m_fn;  	// function pointer
-    Fn2   m_fn2;  	// function pointer
-    int   m_iWhichType;	// which color to set 
+    T&       m_obj; 	   // object reference
+    Fn       m_fn;  	   // function pointer
+    Fn2      m_fn2;  	   // function pointer
+    Fn3      m_fn3;  	   // function pointer
+    FnGetPos m_fnGetPos;   // function to get value
+    int      m_iWhichType; // which color to set 
 }; 
 
 class AnimationAttribute
