@@ -151,30 +151,62 @@ void ButtonObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int
 
 bool ButtonObject::mouseMoveEvent (QMouseEvent *pEvent)
 {
-	if (m_bMoveable)	{
-		// This will move the ButtonObject and all associated objects around and around and around we go ...
-		uint t;
-		QRect theRect = rect();
-		int iX, iY, iWidth, iHeight;
-		iWidth  = rect().width ();
-		iHeight = rect().height();
-		iX = rect().x() - (m_currentMousePos.x() - pEvent->pos().x());
-		iY = rect().y() - (m_currentMousePos.y() - pEvent->pos().y());
-		theRect.setX(iX);
-		theRect.setY(iY);
-		theRect.setWidth(iWidth);
-		theRect.setHeight(iHeight);
-
-		setRect(theRect);
-		for (t=0;t<m_listNormalState.count();t++)
-			m_listNormalState[t]->setRect (theRect);
-		for (t=0;t<m_listSelectedState.count();t++)
-			m_listSelectedState[t]->setRect (theRect);
-		for (t=0;t<m_listHighlightedState.count();t++)
-			m_listHighlightedState[t]->setRect (theRect);
-	}
-	m_currentMousePos = pEvent->pos();
-	return false;
+  if (m_bMoveable)	{
+    switch ( m_objectState )  {	
+    case MenuObject::StateScaleTLXY:
+    case MenuObject::StateScaleTRXY:
+    case MenuObject::StateScaleBLXY:
+    case MenuObject::StateScaleBRXY:
+    case MenuObject::StateScaleLeftX:
+    case MenuObject::StateScaleRightX:
+    case MenuObject::StateScaleTopY:
+    case MenuObject::StateScaleBottomY:
+    case MenuObject::StateRotate: {
+      uint t;
+      Modifiers *pModifiers, *pObjectModifiers;
+      MenuObject::mouseMoveEvent ( pEvent );
+      pModifiers = modifiers ();
+      for (t=0;t<m_listNormalState.count();t++) {
+	pObjectModifiers = m_listNormalState[t]->modifiers ();
+	*pObjectModifiers = *pModifiers;
+      }
+      for (t=0;t<m_listSelectedState.count();t++) {
+	pObjectModifiers = m_listSelectedState[t]->modifiers ();
+	*pObjectModifiers = *pModifiers;
+      }
+      for (t=0;t<m_listHighlightedState.count();t++) {
+	pObjectModifiers = m_listHighlightedState[t]->modifiers ();
+	*pObjectModifiers = *pModifiers;
+      }
+    }
+      break;
+    case MenuObject::StateMoveObject:
+    default: {
+      // This will move the ButtonObject and all associated objects around and around and around we go ...
+      uint t;
+      QRect theRect = rect();
+      int iX, iY, iWidth, iHeight;
+      iWidth  = rect().width ();
+      iHeight = rect().height();
+      iX = rect().x() - (m_currentMousePos.x() - pEvent->pos().x());
+      iY = rect().y() - (m_currentMousePos.y() - pEvent->pos().y());
+      theRect.setX(iX);
+      theRect.setY(iY);
+      theRect.setWidth(iWidth);
+      theRect.setHeight(iHeight);
+      
+      setRect(theRect);
+      for (t=0;t<m_listNormalState.count();t++)
+	m_listNormalState[t]->setRect (theRect);
+      for (t=0;t<m_listSelectedState.count();t++)
+	m_listSelectedState[t]->setRect (theRect);
+      for (t=0;t<m_listHighlightedState.count();t++)
+	m_listHighlightedState[t]->setRect (theRect);
+      }
+    }
+  }
+  m_currentMousePos = pEvent->pos();
+  return false;
 }
 
 bool ButtonObject::mousePressEvent (QMouseEvent *pEvent)
