@@ -33,6 +33,7 @@ ButtonPreview::ButtonPreview(QWidget * parent, const char * name, WFlags f)
 	// Here we have the undo buffer ...
 	m_pUndoBuffer = new UndoBuffer(MAX_UNDO_DEPTH);
 
+	m_iCursorStyle = MousePointerCursor;
 	m_pActiveObject = NULL;
 	m_bMouseEventDone = false;
 	m_bDrawVisibleRegion = false;	// This is set in the derived calss MenuPreview - only ... (No need for the buttonPreview class to play with)
@@ -96,6 +97,7 @@ MenuObject *ButtonPreview::menuObject (uint iNr)
 	else 
 		return NULL;
 }
+
 uint ButtonPreview::objectCount()
 {
 	return m_listMenuObjects.count();
@@ -108,9 +110,50 @@ UndoBuffer *ButtonPreview::undoBuffer()
 
 void ButtonPreview::toTop(MenuObject *pObject)
 {
-	// This function pushes the currently selected child to the top of the stack as to draw it last (on the top).
-	m_listMenuObjects.remove (pObject);
-	m_listMenuObjects.append (pObject);
+  // This function pushes the currently selected child to the top of the stack as to draw it last (on the top).
+  m_listMenuObjects.remove (pObject);
+  m_listMenuObjects.append (pObject);
+}
+
+void ButtonPreview::setObjectCursor ( MenuObject::enState theState )
+{
+  QCursor theCursor;
+  switch ( theState ) {
+  case MenuObject::StateScaleTLXY: // >< - cross
+  case MenuObject::StateScaleBRXY: // >< - cross
+    setMouseCursor ( MouseLZoomCursor );
+    break;
+  case MenuObject::StateScaleTRXY: // >< - cross
+  case MenuObject::StateScaleBLXY: // >< - cross
+    setMouseCursor ( MouseRZoomCursor );
+    break;
+  case MenuObject::StateScaleLeftX: // Horizontal
+  case MenuObject::StateScaleRightX: // Horizontal
+    setMouseCursor ( MouseXResizeCursor );
+    break;
+  case MenuObject::StateScaleTopY: // vertical
+  case MenuObject::StateScaleBottomY: // vertical
+    setMouseCursor ( MouseYResizeCursor );
+    break;
+  case MenuObject::StateMoveObject: // moving
+    setMouseCursor ( MouseMoveCursor    );
+    break;
+  case MenuObject::StateRotate: // 
+    setMouseCursor ( MouseRotateCursor );
+    break;
+
+  default:
+    setMouseCursor ( MousePointerCursor );
+    break;
+  }
+}
+
+void ButtonPreview::setMouseCursor ( enPointerShape iPointerShape )
+{
+  QCursor theCursor;
+  theCursor.setShape ( iPointerShape );
+  setCursor ( theCursor );
+  m_iCursorStyle = iPointerShape;
 }
 
 void ButtonPreview::slotMoveOnStack(MenuObject *pObject, int iHowMany)
@@ -134,36 +177,50 @@ void ButtonPreview::slotMoveOnStack(MenuObject *pObject, int iHowMany)
 
 void ButtonPreview::mousePressEvent (QMouseEvent *pEvent)
 {
-	// Here we check if the mouse click appeared withtin one of the MenuObjects,
-	// in which case the Object will take over the mouse handling ...
-	QPoint thePos  = pEvent->pos();
-	MenuObject *pObject = childContains(thePos);
-	if (pObject != NULL)	{
-		m_bMouseEventDone = pObject->mousePressEvent(pEvent);
-		// Here we protect the action toTop for creation of Buttons, which delete the returned pObject
-		if (!m_bMouseEventDone)	{
-			toTop(pObject);
-			undoBuffer()->push (new DVDMenuUndoObject(DVDMenuUndoObject::MOVED_OBJECT, pObject));
-		}
-	}
-	
+  // Here we check if the mouse click appeared withtin one of the MenuObjects,
+  // in which case the Object will take over the mouse handling ...
+  QPoint thePos  = pEvent->pos();
+  MenuObject *pObject = childContains(thePos);
+  if (pObject != NULL)	{
+    MenuObject::enState currentState = pObject->setObjectState ( thePos );
+    setObjectCursor ( currentState );
+    m_bMouseEventDone = pObject->mousePressEvent ( pEvent );
+    // Here we protect the action toTop for creation of Buttons, which delete the returned pObject
+    if (!m_bMouseEventDone)	{
+      toTop(pObject);
+      undoBuffer()->push (new DVDMenuUndoObject(DVDMenuUndoObject::MOVED_OBJECT, pObject));
+    }
+  }
 }
 
 void ButtonPreview::mouseReleaseEvent (QMouseEvent *pEvent)
 {
-	// Here we check if the mouse click appeared withtin one of the MenuObjects,
-	// in which case the object will take over ...
-	QPoint thePos = pEvent->pos();
-	MenuObject *pObject = childContains(thePos);
-	if (pObject != NULL)	{
-		m_bMouseEventDone = pObject->mouseReleaseEvent(pEvent);
-		// here we get tht last object on the undoBuffer
-		DVDMenuUndoObject *pUndo = (DVDMenuUndoObject *) undoBuffer()->last();
-		if (pUndo && !pUndo->hasMoved())	{
-			undoBuffer()->removeLast();
-			delete pUndo;
-		}
-	}
+  // Here we check if the mouse click appeared withtin one of the MenuObjects,
+  // in which case the object will take over ...
+  //  QPoint thePos = pEvent->pos();
+  //  MenuObject *pObject = childContains(thePos);
+  //  if (pObject != NULL)	{
+  //    pObject->setObjectState ( MenuObject::StateInactive );
+  //    m_bMouseEventDone = pObject->mouseReleaseEvent(pEvent);
+  //    // here we get the last object on the undoBuffer
+  //    DVDMenuUndoObject *pUndo = (DVDMenuUndoObject *) undoBuffer()->last();
+  //    if (pUndo && !pUndo->hasMoved())	{
+  //      undoBuffer()->removeLast();
+  //      delete pUndo;
+  //    }
+  //  }
+  for ( uint t=0; t<m_listMenuObjects.count();t++ ) {
+    if ( m_listMenuObjects.at ( t )->isActive ( ) ) {
+      m_bMouseEventDone = m_listMenuObjects.at ( t )->mouseReleaseEvent(pEvent);
+      // here we get the last object on the undoBuffer
+      DVDMenuUndoObject *pUndo = (DVDMenuUndoObject *) undoBuffer()->last();
+      if (pUndo && !pUndo->hasMoved())	{
+	undoBuffer()->removeLast();
+	delete pUndo;
+      }
+    }
+  }
+  unsetCursor  ( );
 }
 
 void ButtonPreview::mouseDoubleClickEvent	(QMouseEvent *pEvent)
@@ -204,6 +261,7 @@ QPixmap &ButtonPreview::renderMenu (CDVDMenuInterface *pInterface, long iRenderF
 	// Okay here we get the Directory list of the extracted image files from the directory
 	theDir.setPath(qsFullPath);
 	QStringList listFiles = theDir.entryList ("0*.jpg");
+	//QStringList listFiles = theDir.entryList ("rendered_*.png");
 	if (listFiles.count () == 0)	{
 		qsFullPath = QString ("%1/%2/").arg(Global::qsTempPath).arg(Global::qsProjectName);
 		theDir.setPath (qsFullPath);
@@ -360,7 +418,6 @@ void ButtonPreview::setPixmap (const QPixmap &pixmap)
 
 void ButtonPreview::updatePixmap()
 {
-	uint t;
 	if (m_backgroundPixmap.isNull())
 		return;
 	// Set the waiting cursor ...
@@ -368,13 +425,8 @@ void ButtonPreview::updatePixmap()
 	setCursor(myCursor);
 
 	// This is the function, which updates the background Pixmap
-	QPixmap thePixmap(m_backgroundPixmap);
-	QPainter thePainter(&thePixmap);
-	// First lets imprint the visibleRegionR - rect (if neccesarry).
-	drawVisibleRegion (&thePainter);
-	// And here we draw the objects ...
-	for (t=0;t<m_listMenuObjects.count();t++)
-		m_listMenuObjects.at(t)->drawContents (&thePainter);
+	QPixmap thePixmap;
+	drawBackground ( thePixmap );
 
 	// This will check if we load the transparent background (extensions are much smaller)
 	if ( (thePixmap.width() < 100) || (thePixmap.height() < 100) )
@@ -382,14 +434,29 @@ void ButtonPreview::updatePixmap()
 	else	// Otherwise we set the original image size.
 		setFixedSize(thePixmap.width(), thePixmap.height());
 
-	// This change might affect some areas I am not currently considering. (2004 Oct 20)
-	if (parentWidget()->parentWidget()->name () == QString ("usingScrollView"))
-		setPaletteBackgroundPixmap (thePixmap);
-	else
-		QLabel::setPixmap (thePixmap);
-
+	setBackground ( thePixmap );
 	// re-set the cursor ...
 	myCursor = QCursor(QCursor::ArrowCursor);
 	setCursor(myCursor);
 }
 
+void ButtonPreview::setBackground ( QPixmap &thePixmap )
+{
+  // This change might affect some areas I am not currently considering. (2004 Oct 20)
+  if ( parentWidget ( )->parentWidget ( )->name ( ) == QString ( "usingScrollView" ) )
+    setPaletteBackgroundPixmap ( thePixmap );
+  else
+    QLabel::setPixmap ( thePixmap );
+}
+
+void ButtonPreview::drawBackground ( QPixmap &thePixmap )
+{
+  uint t;
+  thePixmap = QPixmap ( m_backgroundPixmap );
+  QPainter thePainter ( &thePixmap  );
+  // First lets imprint the visibleRegionR - rect (if neccesarry).
+  drawVisibleRegion   ( &thePainter );
+  // And here we draw the objects ...
+  for (t=0;t<m_listMenuObjects.count();t++)
+    m_listMenuObjects.at(t)->drawContents (&thePainter);
+}
