@@ -7,6 +7,7 @@
 **
 ****************************************************************************/
 
+#include <qmessagebox.h>
 #include <qtextedit.h>
 #include <qcombobox.h>
 #include <qspinbox.h>
@@ -30,8 +31,9 @@ void DialogAnimation::initMe ( QString qsAnimation, long iFrames, float fFPS, in
 {
 	char *standardProperties[] = {"rect", "visibleFromTo", "transparency", "rotate", "zoom", "scale", "shear"}; // index 0-14
 	char *frameProperties [] = {"color", "frameWidth", "frameStyle", "frameJoin"}; // index 15-26
-	char *imageProperties [] = {"backgroundFileName", "showBackground", "startPos", "res", "aspectRatio", "blendColor", "brightness" }; // index 15-26
-	char *movieProperties [] = {"frameNo"}; // index 28
+	//	char *imageProperties [] = {"backgroundFileName", "showBackground", "startPos", "res", "aspectRatio", "blendColor", "brightness" }; // index 15-26
+	char *imageProperties [] = {"backgroundFileName", "showBackground", "startPos", "pos", "blendColor", "brightness" }; // index 15-24
+	char *movieProperties [] = {"frameNo"}; // index 26
 	char *textProperties  [] = {"text", "font", "textAlign", "foregroundColor", "backgroundColor"}; // index 15-27
 	// Note we have to synch those entries when we make the changes. I.e. 
 	// standard properties.rect has 6 variables, index 0-5 (x1, y1, x2, y2, width, height)
@@ -84,6 +86,7 @@ void DialogAnimation::initMe ( QString qsAnimation, long iFrames, float fFPS, in
 	m_pSpinBoxPosition->setMaxValue ( iFrames );
 
 	connect (m_pButtonAdd,       SIGNAL (clicked ()), this, SLOT(slotAddAttribute ()));
+	connect (m_pButtonHelp,      SIGNAL (clicked ()), this, SLOT(slotHelp ()));
 	connect (m_pSliderPosition,  SIGNAL (valueChanged(int)), this, SLOT (slotValueChanged(int)));
 	connect (m_pSpinBoxPosition, SIGNAL (valueChanged(int)), this, SLOT (slotValueChanged (int)));
 	connect (m_pComboAttributes, SIGNAL (activated (const QString &)), this, SLOT(slotAttribute (const QString &)));
@@ -102,6 +105,22 @@ void DialogAnimation::setFontName (QString qsFontName )
 	m_qsFontName = qsFontName;
 }
 
+void DialogAnimation::slotHelp ()
+{
+  QMessageBox::information ( NULL, tr("Animation Dialog"), tr(
+"This dialog will allow you to modify an objects properties over time (I.e. animate the object).\n"
+" You will be offered the available properties for the object you selected.\n\n"
+" The generated output is in the format:\n"
+" FrameNumber::object-property=value\n\n"
+
+" E.g. to move an object diagonal over the screen (NTSC) within 100 frames you could use this little script.\n"
+" for ((t=0;t<100;t++))\n"
+" {\n"
+"   echo \"$t::rect.x1=$(($t/100 * 720))\"\n"
+"   echo \"$t::rect.y1=$(($t/100 * 480))\"\n"
+" }\n"), QMessageBox::Ok, QMessageBox::NoButton );
+}
+
 void DialogAnimation::slotValueChanged ( int iNewValue )
 {
 	static bool bChanging = false;
@@ -166,7 +185,7 @@ void DialogAnimation::slotAttribute (const QString &newText)
 		m_pComboAttributeSub->insertItem ( "startFrame" );
 		m_pComboAttributeSub->insertItem ( "stopFrame" );
 	}
-	else if ( ( newText == "startPos" ) || ( newText == "res" ) || ( newText == "scale" ) || ( newText == "shear" ) )	{
+	else if ( ( newText == "startPos" ) || ( newText == "pos" )|| ( newText == "res" ) || ( newText == "scale" ) || ( newText == "shear" ) )	{
 		m_pComboAttributeSub->insertItem ( "x" );
 		m_pComboAttributeSub->insertItem ( "y" );
 	}
