@@ -23,11 +23,11 @@
 #include <qlayout.h>
 #include <qframe.h>
 #include <qfileinfo.h>
-#include <qmessagebox.h>
 
 #include "global.h"
 #include "dialogbutton.h"
 #include "menuobject.h"
+#include "messagebox.h"
 #include "buttonobject.h"
 #include "buttonpreview.h"
 #include "sourcefileentry.h"
@@ -552,7 +552,7 @@ void DialogButton::slotChapters2(int)
 
 void DialogButton::slotHelpAction()
 {
-	QMessageBox::warning(this, tr("Action - tag"), tr("If you make manual changes here they will be kept.\n"
+	MessageBox::warning(this, tr("Action - tag"), tr("If you make manual changes here they will be kept.\n"
 		"If this is the case then the background color will change to orange.\n"
 		"You can reverse these changes by using the drop down boxes above.\n"
 		"This is an advanced feature and should be used with care.\n\n"
@@ -562,7 +562,7 @@ void DialogButton::slotHelpAction()
 
 void DialogButton::slotHelpGoto()
 {
-	QMessageBox::warning(this, tr("Goto - attributes"), 
+	MessageBox::warning(this, tr("Goto - attributes"), 
 		tr("Here you can specify the button to goto when the user pushes\n"
 		"the up/down/right/left buttons on the remote control.\n\n"
 		"Note: dvdauthor will choose a logical default value for each of those cases."), 
@@ -571,7 +571,7 @@ void DialogButton::slotHelpGoto()
 
 void DialogButton::slotHelp()
 {
-	QMessageBox::warning(this, "ButtonDialog", "Cool you got a button !!!\n", 
+	MessageBox::warning(this, "ButtonDialog", "Cool you got a button !!!\n", 
 		QMessageBox::Ok, QMessageBox::NoButton);
 }
 
@@ -674,6 +674,8 @@ void DialogButton::slotOkay()
 			parent(), SLOT(slotDeleteObject(MenuObject *)));
 		connect (pObject, SIGNAL(signalDefineAsButton(MenuObject *)),
 			parent(), SLOT(slotDefineAsButton(MenuObject *)));
+		connect (pObject, SIGNAL(signalShadowMe(MenuObject *)),
+			parent(), SLOT(slotAddShadow(MenuObject *)));
 		connect (pObject, SIGNAL(signalUpdateStructure()),
 			parent(), SLOT(slotUpdateStructure()));
 		connect (pObject, SIGNAL(signalUpdatePixmap()),
