@@ -19,22 +19,22 @@ class DialogCommandEditor : public uiDialogCommandEditor
 {
 	Q_OBJECT
 public:
-	 DialogCommandEditor (QWidget * parent, const char * name = 0, WFlags f = 0 );
-	~DialogCommandEditor ();
+	 DialogCommandEditor ( QWidget *, const char *n=0, WFlags f=0 );
+	~DialogCommandEditor ( );
 
-	void initMe (QDVDAuthorInit::MenuBlock::Block *, uint);
-	void initMe (QDVDAuthorInit::MenuBlock::Block *, uint, QStringList);
+	void initMe ( QDVDAuthorInit::MenuBlock::Block *, uint );
+	void initMe ( QDVDAuthorInit::MenuBlock::Block *, uint, QStringList, uint i=0 );
 
 private slots:
-	virtual void slotAddCommand ();
-	virtual void slotAddToCommand ();
-	virtual void slotDeleteCommand ();
-	virtual void slotCheckDefault ();
+	virtual void slotAddCommand    ( );
+	virtual void slotAddToCommand  ( );
+	virtual void slotDeleteCommand ( );
+	virtual void slotCheckDefault  ( );
 
 private:
-	virtual void accept ();
+	virtual void accept ( );
 
-	void addCommandTab(QString);
+	void addCommandTab( QString );
 
 private:
 	QDVDAuthorInit::MenuBlock::Block *m_pCommandBlock;
