@@ -30,7 +30,7 @@
 #include "dialogman.h"
 #include "qdvdauthorinit.h"
 #include "dialogcommandeditor.h"
-
+#include "messagebox.h"
 
 DialogExecute::DialogExecute(QValueList<ExecuteInterface *> listExecuteBlocks, bool bShowDialog )
     : QDialog( )
@@ -49,6 +49,17 @@ DialogExecute::DialogExecute(QValueList<ExecuteInterface *> listExecuteBlocks, b
 //	for (t=0;t<listExecuteBlocks.count();t++)	// Lets get the default commands ...
 //		for (i=0;i<listExecuteBlocks[t]->listCommandList.count();i++)	// Lets get the default commands ...
 //			commandList.append(listExecuteBlocks[t]->listCommandList[i][listExecuteBlocks[t]->listDefaults[t]]);
+/* debugging the output.
+for (t=0;t<listExecuteBlocks.count();t++)  {
+for (int i=0;i<listExecuteBlocks[t]->listCommandList.count ();i++)  {
+QStringList qsCommandList = listExecuteBlocks[t]->listCommandList[i];
+for (int j=0;j<qsCommandList.count();j++)  {
+printf ( "DialogExecute::DialogExecute <%d><%d><%d> = <%s>\n", t, i, j, qsCommandList[j].ascii() );
+}
+}
+}
+printf ("\n\n");
+*/
 
 	// In case the user does not want to display a execute Dialog but instead prefers the default settings.
 	if (!bShowDialog)
@@ -113,9 +124,10 @@ void DialogExecute::createMainForm ()
 	m_pTabWidget->setEnabled( TRUE );
 
 		// signals and slots connections
-	connect( buttonOk     , SIGNAL( clicked() ), this, SLOT( slotOkay() ) );
-	connect( buttonCancel , SIGNAL( clicked() ), this, SLOT( reject() ) );
+	connect( buttonOk     , SIGNAL( clicked() ), this, SLOT( slotOkay  () ) );
+	connect( buttonCancel , SIGNAL( clicked() ), this, SLOT( reject    () ) );
 	connect( buttonExport , SIGNAL( clicked() ), this, SLOT( slotExport() ) );
+	connect( buttonHelp ,   SIGNAL( clicked() ), this, SLOT( slotHelp  () ) );
 	connect( m_pTabWidget , SIGNAL( currentChanged  (QWidget*)), this, SLOT(slotTabChanged(QWidget *)));
 	connect(&m_doSomething, SIGNAL( signalRenderMenu(QString )), this, SLOT(slotRenderMenu(QString  )));
 }
@@ -470,6 +482,22 @@ void DialogExecute::languageChange()
     m_pTabWidget->changeTab( m_pTabExpert, tr( "Authoring" ) );
 }
 
+void DialogExecute::slotHelp ()
+{
+  MessageBox::warning (NULL, tr ("Help"), 
+    tr ("In this dialog you see all commands that are going to get executed to create the DVD.\n\n"
+	"[Export] Allows you to export all those commands to a script and execute one it fomr the command line.\n"
+	"         Note: You can execute one command at a time. E.g. script.sh 1; script.sh 2 etc.\n"
+	"[Help]   Displays this message.\n"
+	"[e]      Opens the CommandEditorDialog. Using this button allows you to modify (and store) the command.\n"
+	"[d]      Will set the current selected choice in the combo box as the default command.\n"
+	"[man]    Will open a new dialog, which displays the man pages of all toools used in this command line.\n"
+	"         Note: You can easily search for text through this dialog.\n"
+	"[X]      (checkbox) this will enable / disable the commands for the whole selected command block.\n"
+     ), QMessageBox::Ok , QMessageBox::NoButton );
+  raise ();
+}
+
 void DialogExecute::slotManButtonClicked()
 {
 	QStringList listOfCommandsUsed;
