@@ -96,8 +96,54 @@ void DialogMatrix::slotSliderReleased()
 
 void DialogMatrix::slotDeleteObject( MenuObject * )
 {
-printf ("Kill me ...\n");
-	accept();
+  accept();
 }
 
+void DialogMatrix::slotZoomChanged()
+{
+  bool  bOk    = false;
+  float fValue = m_pEditZoom->text().toFloat ( &bOk );
+  if ( bOk ) {
+    m_pParent->modifiers()->fScaleX = fValue;
+    m_pParent->modifiers()->fScaleY = fValue;
+    m_pParent->update();
+    
+    if (fValue > 1.0)
+        fValue = fValue * 2.0 - 1.0;
 
+    m_pSliderZoom->setValue ( (int) ( fValue * 1000.0  ) );
+  }
+}
+
+void DialogMatrix::slotRotateChanged()
+{
+  bool  bOk    = false;
+  float fValue = m_pEditRotate->text().toFloat ( &bOk );
+  if ( bOk ) {
+    m_pParent->modifiers()->fRotate = fValue;
+    m_pParent->update();    
+    m_pSliderRotate->setValue ( (int) ( fValue * 10.0 ) );
+  }
+}
+
+void DialogMatrix::slotShearXChanged()
+{
+  bool  bOk    = false;
+  float fValue = m_pEditShearX->text().toFloat ( &bOk );
+  if ( bOk ) {
+    m_pParent->modifiers()->fShearX = fValue;
+    m_pParent->update();
+    m_pSliderShearX->setValue ( (int) ( fValue * 1000.0 ) );
+  }
+}
+
+void DialogMatrix::slotShearYChanged()
+{
+  bool  bOk    = false;
+  float fValue = m_pEditShearY->text().toFloat ( &bOk );
+  if ( bOk ) {
+    m_pParent->modifiers()->fShearX = fValue;
+    m_pParent->update();
+    m_pSliderShearY->setValue ( (int) ( fValue * 1000.0 ) );
+  }
+}
