@@ -9,6 +9,7 @@
 #include <qlabel.h>
 #include <qimage.h>
 #include <qtimer.h>
+#include <qregexp.h>
 #include <qpixmap.h>
 #include <qlayout.h>
 #include <qlistbox.h>
@@ -21,7 +22,6 @@
 #include <qgroupbox.h>
 #include <qcombobox.h>
 #include <qpushbutton.h>
-#include <qmessagebox.h>
 #include <qcolordialog.h>
 
 #ifndef QPLAYER_ONLY
@@ -33,9 +33,11 @@
 #include "qplayer/startstopcontrol.h"
 #include "qplayer/engines/mediainterface.h"
 
+#include "messagebox.h"
 #include "movieobject.h"
 #include "dialogmovie.h"
 #include "dialoganimation.h"
+#include "dialogmediainfo.h"
 
 #define PROPERTIES_TAB  0
 #define CHAPTERS_TAB    1
@@ -78,12 +80,14 @@ DialogMovie::DialogMovie(QWidget * parent, const char * name, WFlags f)
 	connect (m_pButtonStop,      SIGNAL(clicked   ()), this, SLOT (slotStop           ()));
 	connect (m_pButtonStart,     SIGNAL(clicked   ()), this, SLOT (slotStart          ()));
 	connect (m_pButtonEnd,       SIGNAL(clicked   ()), this, SLOT (slotEnd            ()));
+	connect (m_pButtonThumbnail, SIGNAL(clicked   ()), this, SLOT (slotSetThumbnail   ()));
 	connect (m_pButtonTranscode, SIGNAL(clicked   ()), this, SLOT (slotTranscode      ()));
 	connect (m_pButtonEncodeNow, SIGNAL(clicked   ()), this, SLOT (slotEncodeNow      ()));
 	connect (m_pButtonAnimation, SIGNAL(clicked   ()), this, SLOT (slotAnimation      ()));
 	connect (m_pButtonAddCK,     SIGNAL(clicked   ()), this, SLOT (slotAddColorKey    ()));
 	connect (m_pButtonDelCK,     SIGNAL(clicked   ()), this, SLOT (slotDelColorKey    ()));
 	connect (m_pButtonCK,        SIGNAL(clicked   ()), this, SLOT (slotBrowseColorKey ()));
+	connect (m_pButtonEdit,      SIGNAL(clicked   ()), this, SLOT (slotEditMediaInfo  ()));
 }
 
 DialogMovie::~DialogMovie()
@@ -165,6 +169,7 @@ void DialogMovie::initMe(DVDMenu *pMenu)
 		// And finally we hide the play buttons etc.
 		delete m_pButtonPlay;
 		delete m_pButtonStop;
+		delete m_pButtonThumbnail;
 		delete m_pButtonStart;
 		delete m_pButtonEnd;
 		delete m_pSliderVolume;
@@ -212,6 +217,7 @@ void DialogMovie::initMe(SourceFileEntry *pSourceFileEntry)
 	delete m_pMediaPreview;
 	delete m_pButtonPlay;
 	delete m_pButtonStop;
+	delete m_pButtonThumbnail;
 	delete m_pButtonStart;
 	delete m_pButtonEnd;
 	delete m_pSliderVolume;
@@ -279,18 +285,19 @@ void DialogMovie::initMe(SourceFileInfo *pInfo, const void *pExistingMediaEngine
 	m_pMediaInterface->initMediaEngine();
 
 	m_qsFileName = m_sourceFileInfo.qsFileName;
-	m_pMediaInterface->openMRL (m_qsFileName);
-	m_pMediaInterface->getScreenshot  ();
+	m_pMediaInterface->openMRL  ( m_qsFileName );
+	m_pMediaInterface->getScreenshot ( );
 
 	// This is the new version, where I have a new WidgetControl.
-	QGridLayout *pLayout = new QGridLayout( m_pFrameControl, 1, 1, 2, 2, "pLayout");
-	m_pStartStopControl = new StartStopControl ( m_pFrameControl );
+	QGridLayout *pLayout = new QGridLayout      ( m_pFrameControl, 1, 1, 2, 2, "pLayout");
+	m_pStartStopControl  = new StartStopControl ( m_pFrameControl );
 	m_pStartStopControl->initMe (m_sourceFileInfo.qsFileName, iThumbnailSize, iLength);
-	connect (m_pStartStopControl, (SIGNAL (signalSliderValues (float, float))), this, SLOT(slotSliderValues(float, float)));
+	connect (m_pStartStopControl, SIGNAL (signalSliderValues   ( float, float ) ), this, SLOT ( slotSliderValues   ( float, float ) ) );
+	connect (m_pStartStopControl, SIGNAL (signalSliderReleased ( bool ) ),         this, SLOT ( slotSliderReleased ( bool ) ) );
 
 	m_iMovieLength = iLength;
-	if (m_iMovieLength < 1)
-		m_iMovieLength = 1;
+	if ( m_iMovieLength < 1 )
+	     m_iMovieLength = 1;
 	pLayout->addWidget( m_pStartStopControl, 0, 0 );
 
 	if (m_sourceFileInfo.pTranscodeInterface)	{
@@ -298,8 +305,8 @@ void DialogMovie::initMe(SourceFileInfo *pInfo, const void *pExistingMediaEngine
 			m_sourceFileInfo.pTranscodeInterface->iEndingAt = m_iMovieLength;
 		QString qsFormat = QString ("hh:mm:ss.zzz");
 		QTime endingTime, startingTime;
-		startingTime.addMSecs (m_sourceFileInfo.pTranscodeInterface->iStartingAt);
-		endingTime.addMSecs   (m_sourceFileInfo.pTranscodeInterface->iEndingAt);
+		startingTime = startingTime.addMSecs ( m_sourceFileInfo.pTranscodeInterface->iStartingAt );
+		endingTime   = endingTime.addMSecs   ( m_sourceFileInfo.pTranscodeInterface->iEndingAt   );
 		m_pEditStarting1->setText (startingTime.toString(qsFormat));
 		m_pEditEnding1  ->setText (endingTime.toString  (qsFormat));
 	}
@@ -313,18 +320,28 @@ void DialogMovie::initMe(SourceFileInfo *pInfo, const void *pExistingMediaEngine
 		pMediaInfo->setFileName (m_qsFileName);
 	}
 
+	//	m_pLabelVideoFormat->setText (QString ("%1(%2) %3Hz")
+	//.arg (pMediaInfo->getFormat(true))
+	//.arg (pMediaInfo->getResolutionString())
+	//.arg (pMediaInfo->getFPS())
+	//);
 	m_pLabelVideoFormat->setText (QString ("%1(%2) %3Hz")
-		.arg (pMediaInfo->getFormat(true))
-		.arg (pMediaInfo->getResolutionString())
-		.arg (pMediaInfo->getFPS())
+		.arg ( pInfo->qsVideoFormat )
+		.arg ( pInfo->qsResolution  )
+		.arg ( pInfo->qsFPS         )
 	);
 
 	m_pLabelVideoCodec->setText (pMediaInfo->getCodec(true));
-	
+
+	//	m_pLabelAudioFormat->setText(QString ("%1 %2bit %3")
+	//.arg(pMediaInfo->getFormat(false))
+	//.arg(pMediaInfo->getBits())
+	//.arg(pMediaInfo->getSampleString())
+	//);
 	m_pLabelAudioFormat->setText(QString ("%1 %2bit %3")
-		.arg(pMediaInfo->getFormat(false))
-		.arg(pMediaInfo->getBits())
-		.arg(pMediaInfo->getSampleString())
+		.arg( pInfo->qsAudioFormat )
+		.arg( pInfo->qsBits        )
+		.arg( pInfo->qsSample      )
 	);
 
 	m_pLabelAudioCodec->setText (pMediaInfo->getCodec (false) );  // Stereo 2.0
@@ -335,10 +352,10 @@ void DialogMovie::initMe(SourceFileInfo *pInfo, const void *pExistingMediaEngine
 	m_pTabWidget->setCurrentPage (0);
 
 	// And finally here are the callback functions ...
-	connect (m_pButtonAdd,            SIGNAL(clicked ()), this, SLOT (slotAddChapter()));
-	connect (m_pButtonDel,            SIGNAL(clicked ()), this, SLOT (slotDelChapters()));
-	connect (m_pButtonAuto,           SIGNAL(clicked ()), this, SLOT (slotAutoChapters()));
-	connect (m_pListBoxChapters,      SIGNAL(currentChanged (QListBoxItem *)), this, SLOT (slotCurrentChanged(QListBoxItem *)));
+	connect (m_pButtonAdd,            SIGNAL( clicked ()), this, SLOT (slotAddChapter()));
+	connect (m_pButtonDel,            SIGNAL( clicked ()), this, SLOT (slotDelChapters()));
+	connect (m_pButtonAuto,           SIGNAL( clicked ()), this, SLOT (slotAutoChapters()));
+	connect (m_pListBoxChapters,      SIGNAL( currentChanged (QListBoxItem *)), this, SLOT (slotCurrentChanged(QListBoxItem *)));
 
 	connect (m_pComboVideoOut,        SIGNAL( activated(const QString &)), this, SLOT (slotVideoOutChanged(const QString &)));
 	connect (m_pComboVideoResolution, SIGNAL( activated(const QString &)), this, SLOT (slotVideoResolutionChanged(const QString &)));
@@ -346,7 +363,7 @@ void DialogMovie::initMe(SourceFileInfo *pInfo, const void *pExistingMediaEngine
 	connect (m_pComboVideoType,       SIGNAL( activated(const QString &)), this, SLOT (slotVideoTypeChanged(const QString &)));
 	connect (m_pComboVideoAspect,     SIGNAL( activated(const QString &)), this, SLOT (slotVideoAspectChanged(const QString &)));
 	connect (m_pComboVideoBitrate,    SIGNAL( activated(const QString &)), this, SLOT (slotVideoBitrateChanged(const QString &)));
-	connect (m_pSliderVolume,         SIGNAL(valueChanged (int)),          this, SLOT (slotNewVolume (int)));
+	connect (m_pSliderVolume,         SIGNAL( valueChanged (int)),         this, SLOT (slotNewVolume (int)));
 
 	QTimer::singleShot (50, this, SLOT(slotSetStartStop()));
 }
@@ -462,15 +479,17 @@ void DialogMovie::initMediaInterface(DVDMenu *pDVDMenu)
 	if (m_iMovieLength < 1)
 		m_iMovieLength = 1;
 
-	QGridLayout *pLayout = new QGridLayout( m_pFrameControl, 1, 1, 2, 2, "pLayout");
-	m_pStartStopControl = new StartStopControl ( m_pFrameControl );
+	QGridLayout *pLayout = new QGridLayout      ( m_pFrameControl, 1, 1, 2, 2, "pLayout");
+	m_pStartStopControl  = new StartStopControl ( m_pFrameControl );
 	m_pStartStopControl->initMe (m_qsFileName, iThumbnailSize, m_iMovieLength);
 	pLayout->addWidget( m_pStartStopControl, 0, 0 );
 
 	// next is to set the satrting / ending points ...
 	QTimer::singleShot (50, this, SLOT(slotSetStartStop()));
-	connect (m_pStartStopControl, SIGNAL (signalSliderValues (float, float)), this, SLOT(slotSliderValues(float, float)));
-	connect (m_pSliderVolume,     SIGNAL (valueChanged (int)),                this, SLOT(slotNewVolume   (int)));
+	connect (m_pStartStopControl, SIGNAL (signalSliderValues   ( float, float)), this, SLOT ( slotSliderValues   ( float, float ) ) );
+
+	connect (m_pStartStopControl, SIGNAL (signalSliderReleased ( bool ) ),       this, SLOT ( slotSliderReleased ( bool ) ) );
+	connect (m_pSliderVolume,     SIGNAL (valueChanged         ( int  ) ),       this, SLOT ( slotNewVolume      ( int ) ) );
 }
 
 void DialogMovie::slotSetStartStop ()
@@ -496,6 +515,34 @@ void DialogMovie::slotSetStartStop ()
 	m_pStartStopControl->setEnd   ((float) iEnding   / m_iMovieLength);
 }
 
+void DialogMovie::slotEditMediaInfo ()
+{
+  // This will open the media info dialog, where the user can modify the auto detected values (through Xine, VLC or MPlayer)
+  DialogMediaInfo theDialog ( this );
+  theDialog.initMe ( &m_sourceFileInfo );
+  
+  if ( theDialog.exec () == QDialog::Accepted ) {
+    m_sourceFileInfo.qsRatio       = theDialog.m_pEditVideoAspect->text ( );
+    m_sourceFileInfo.qsFPS         = theDialog.m_pEditVideoFPS->text    ( );
+    m_sourceFileInfo.qsLength      = theDialog.m_pEditVideoLength->text ( );
+    m_sourceFileInfo.qsVideoFormat = theDialog.m_pEditVideoFormat->text ( );
+    m_sourceFileInfo.qsAudioFormat = theDialog.m_pEditAudioFormat->text ( );
+    m_sourceFileInfo.qsBits        = theDialog.m_pEditAudioBits->text   ( );
+    m_sourceFileInfo.qsBPS         = theDialog.m_pEditAudioBPS->text    ( );
+    m_sourceFileInfo.qsSample      = theDialog.m_pEditAudioSample->text ( );
+    m_pLabelVideoFormat->setText (QString ("%1(%2) %3Hz")
+	          .arg ( m_sourceFileInfo.qsVideoFormat )
+	          .arg ( m_sourceFileInfo.qsResolution  )
+                  .arg ( m_sourceFileInfo.qsFPS         )
+    );
+    m_pLabelAudioFormat->setText(QString ("%1 %2bit %3")
+		 .arg ( m_sourceFileInfo.qsAudioFormat )
+		 .arg ( m_sourceFileInfo.qsBits        )
+		 .arg ( m_sourceFileInfo.qsSample      )
+    );
+  }
+}
+
 SourceFileInfo *DialogMovie::sourceFileInfo ()
 {
 	return &m_sourceFileInfo;
@@ -708,9 +755,11 @@ void DialogMovie::slotAutoChapters ()
 	iEnding    = theUtil.getMsFromString (m_pEditEnding1->text());
 	iDeltaStep = theUtil.getMsFromString (m_pEditEvery->text());
 	iTotalLength = (int)(iEnding - iStarting);
-	// a DeltaStep of 0 woudl generate infinite number of chapters
-	if (iDeltaStep < 1)
-		return;
+	// a DeltaStep of 0 would generate infinite number of chapters
+	if ( ( iDeltaStep < 1 ) || ( iTotalLength < 1 ) ) {
+	  delete []pArrayExistingChapters;
+	  return;
+	}
 	if (iDeltaStep > (uint) iTotalLength)
 		iDeltaStep = iTotalLength;
 	iNumberOfNewChapters = (int)((float)iTotalLength / (float)iDeltaStep) + 1;
@@ -879,7 +928,7 @@ void DialogMovie::slotTranscode ()
 
 void DialogMovie::slotEncodeNow ()
 {
-	QMessageBox::warning (NULL, tr("Warning"), tr("Not yet implemented"), QMessageBox::Ok, QMessageBox::NoButton);
+	MessageBox::warning (NULL, tr("Warning"), tr("Not yet implemented"), QMessageBox::Ok, QMessageBox::NoButton);
 }
 
 void DialogMovie::slotWidth()
@@ -931,6 +980,19 @@ void DialogMovie::slotStop  ()
 	}
 }
 
+void DialogMovie::slotSetThumbnail ()
+{
+  // The user presses SetAsThumbnail ...
+  Utils theUtils;
+  QRegExp rx ( "<[^>]*>" );
+  QString qsCurrentTime =  m_pLabelCurrentPos->text ( );
+  qsCurrentTime.replace ( rx, "" ); // = rx.cap ( 0 );
+
+  long  iMSecOffset     = theUtils.getMsFromString ( qsCurrentTime );
+  if  ( m_pEditStarting1 ) // indicates that we are coming from the Sourcetoolbar-SourceFileInfo
+    emit ( signalSetThumbnail ( iMSecOffset ) ); // calls SourceToolbar::slotSetThumbnail ( long )
+}
+
 void DialogMovie::slotStart ()
 {
 	// This function will set the Start offset of the video clip
@@ -976,10 +1038,28 @@ void DialogMovie::setStartStop (bool bStart)
 	}
 }
 
+void DialogMovie::slotSliderReleased ( bool bStartSlider )
+{
+  // if the start slider was released AND the MediaEngine is NOT playing, then we 
+  // should create a new preview in the MediaInterface - window.
+  if ( bStartSlider ) {
+    if ( ! m_pMediaInterface->isPlaying ( ) ) {
+      m_pLabelCurrentPos->setText ( m_pEditStarting1->text ( ) );
+      // The user presses SetAsThumbnail ...
+      Utils theUtils;
+      QRegExp rx ( "<[^>]*>" );
+      QString qsCurrentTime =  m_pLabelCurrentPos->text ( );
+      qsCurrentTime.replace ( rx, "" );
+      
+      long  iMSecOffset     = theUtils.getMsFromString ( qsCurrentTime );
+      m_pMediaInterface->setScreenshot ( iMSecOffset );
+    }
+  }
+}
+
 void DialogMovie::slotSliderValues (float fStart, float fEnd)
 {
 	// This function is called when the user uses the slider controls (values in percentage)
-	QTime zeroTime;
 	QTime startTime;
 	QTime endTime;
 	QString qsFormat ("hh:mm:ss.zzz");
@@ -1071,6 +1151,7 @@ void DialogMovie::accept ()
 	long iBitrate;
 	long iTemp;
 	float fTemp;
+	QFileInfo fileInfo;
 	QString qsTemp;
 	QString qsFormat ("hh:mm:ss.zzz");
 	QTime startingTime, endingTime, duration, zeroTime;
@@ -1118,13 +1199,17 @@ void DialogMovie::accept ()
 		m_sourceFileInfo.qsPreCommand  = m_pComboPreCommand->currentText ();
 		m_sourceFileInfo.qsPostCommand = m_pComboPostCommand->currentText ();
 		m_sourceFileInfo.iPause        = m_pSpinBoxPause->value ();
+		m_sourceFileInfo.bAutotranscode= false; // once the user clicks ok we don't want to change any transcoding settings any more.
 
 		if (transcodeEnabled ())	{
+		        Utils theUtils;
 			if (!m_sourceFileInfo.pTranscodeInterface)
 				m_sourceFileInfo.pTranscodeInterface = new TranscodeInterface;
 			m_sourceFileInfo.pTranscodeInterface->qsVideoFormat = m_pComboVideoOut->currentText        ();
 			m_sourceFileInfo.pTranscodeInterface->qsVideoType   = m_pComboVideoType->currentText       ();
 			m_sourceFileInfo.pTranscodeInterface->qsResolution  = m_pComboVideoResolution->currentText ();
+			fileInfo.setFile ( m_sourceFileInfo.qsFileName );
+			m_sourceFileInfo.pTranscodeInterface->qsTempFile = QString ( "%1/%2.mpeg2" ).arg (theUtils.getTempPath ( fileInfo.baseName () ) ).arg(fileInfo.baseName () );
 			qsTemp = m_pComboVideoBitrate->currentText ();
 			if ( qsTemp.contains ("Keep "))	{
 				qsTemp.remove ("Keep ");
@@ -1176,6 +1261,7 @@ void DialogMovie::accept ()
 			m_sourceFileInfo.listChapters.append(m_pListBoxChapters->text (t));
 	}
 	else {	// Or if we are coming from the transcodeAll context menu
+	        m_sourceFileInfo.bAutotranscode = false;
 		if (!m_sourceFileInfo.pTranscodeInterface)
 			m_sourceFileInfo.pTranscodeInterface = new TranscodeInterface;
 		m_sourceFileInfo.pTranscodeInterface->qsVideoFormat = m_pComboVideoOut->currentText        ( );
