@@ -50,28 +50,30 @@ public:
 	SourceFileInfo *sourceFileInfo ();
 
 protected slots:
-	virtual void slotNewVolume (int);
-	virtual void accept        ();
-	virtual void slotBlink     ();
-	virtual void slotWidth     ();
-	virtual void slotHeight    ();
-	virtual void slotPlay      ();
-	virtual void slotStop      ();
-	virtual void slotStart     ();
-	virtual void slotEnd       ();
-	virtual void slotTranscode ();
-	virtual void slotEncodeNow ();
-
-	virtual void slotAddChapter   ();
-	virtual void slotDelChapters  ();
-	virtual void slotAutoChapters ();
-	virtual void slotAnimation    ();
-	virtual void slotSizeDialog   ();
-	virtual void slotCurrentChanged (QListBoxItem *);
+	virtual void slotNewVolume    ( int );
+	virtual void accept           ( );
+	virtual void slotBlink        ( );
+	virtual void slotWidth        ( );
+	virtual void slotHeight       ( );
+	virtual void slotPlay         ( );
+	virtual void slotStop         ( );
+	virtual void slotSetThumbnail ( );
+	virtual void slotStart        ( );
+	virtual void slotEnd          ( );
+	virtual void slotTranscode    ( );
+	virtual void slotEncodeNow    ( );
 
+	virtual void slotAddChapter   ( );
+	virtual void slotDelChapters  ( );
+	virtual void slotAutoChapters ( );
+	virtual void slotAnimation    ( );
+	virtual void slotSizeDialog   ( );
+	virtual void slotEditMediaInfo( );
+	virtual void slotCurrentChanged ( QListBoxItem *);
 	
-	virtual void slotNewPosition(int, const QString&);
-	virtual void slotSliderValues (float, float);
+	virtual void slotNewPosition    ( int, const QString &);
+	virtual void slotSliderValues   ( float, float );
+	virtual void slotSliderReleased ( bool );
 
 	virtual void slotVideoOutChanged        (const QString &);
 	virtual void slotVideoResolutionChanged (const QString &);
@@ -88,6 +90,9 @@ protected slots:
 	virtual void slotDelColorKey ();
 	virtual void slotBrowseColorKey ();
 
+signals:
+	void signalSetThumbnail ( long );
+
 private:
 	long normToLong ( QString qsInput );
 	QString longToNorm  ( long iInput );
