@@ -20,6 +20,7 @@
 #include <qslider.h>
 #include <qlineedit.h>
 #include <qlabel.h>
+#include <qgroupbox.h>
 
 #include "global.h"
 #include "dialogtextfont.h"
@@ -35,7 +36,7 @@ QColor  DialogTextFont::m_previousForeground = QColor  ( 0, 0, 0 );
 DialogTextFont::DialogTextFont(QWidget * parent, const char * name, WFlags f)
 	: uiDialogTextFont (parent, name, f)
 {
-	initMe();
+  initMe();
 }
 
 DialogTextFont::~DialogTextFont()
@@ -43,7 +44,7 @@ DialogTextFont::~DialogTextFont()
 
 }
 
-void DialogTextFont::setFont(QFont &newFont)
+void DialogTextFont::setFont ( const QFont &newFont )
 {
 	m_qfFont = newFont;
 	// Here we set the fields ...
@@ -298,21 +299,17 @@ void DialogTextFont::initMe()
 	m_pComboScript->insertStringList(listScripts);
 	m_pComboScript->setCurrentItem(1);
 
-	// Here we handle the bad expansion of TextEdit. Keep it in line ...
-	show ();
-
-	QSize size = m_pTextEdit->size();
-	m_pTextEdit->setFixedSize (size);
 	//Finally we set the font of the TextEdit window ...
 	setFont            ( m_previousFont       );
 	setText            ( m_previousText       );
 	setTextAlign       ( m_previousTextAlign  );
 	setBackgroundColor ( m_previousBackground );
 	setForegroundColor ( m_previousForeground );
-	QPainter thePainter (m_pFrameBackgroundColor);
-	thePainter.drawLine(0, 0, m_pFrameBackgroundColor->width(), m_pFrameFontColor->height());
 
-	m_pTextEdit->setTextFormat(PlainText);
+	QPainter thePainter ( m_pFrameBackgroundColor );
+	thePainter.drawLine ( 0, 0, m_pFrameBackgroundColor->width ( ), m_pFrameFontColor->height ( ) );
+
+	m_pTextEdit->setTextFormat (PlainText);
 
 	// Finally we set up the callback routines ...
 	connect (m_pListFonts, SIGNAL(highlighted (int)), this, SLOT(slotFontFamilyChanged(int)));
@@ -339,10 +336,27 @@ void DialogTextFont::initMe()
 	updateButtons();
 }
 
+void DialogTextFont::resizeEvent ( QResizeEvent *pEvent )
+{
+  uiDialogTextFont::resizeEvent ( pEvent );
+
+  // Here we handle the bad expansion of TextEdit. Keep it in line ...
+  // NOte, when changing font size the TextEdit would resize the complete frame ... 
+  QSize size  = m_pGroupText->size ( );
+  int iWidth  = size.width  ( ) -20;
+  int iHeight = size.height ( ) -30;
+  if ( ( iWidth < 1 ) || ( iHeight < 1 ) )
+    return;
+  size.setWidth  ( iWidth );
+  size.setHeight ( iHeight );
+  m_pTextEdit->setFixedSize ( size );
+}
+
 void DialogTextFont::paintEvent (QPaintEvent *pPaint)
 {
 	// first we call the main function
 	QWidget::paintEvent(pPaint);
+
 	// and here we do  our little do ...
 	QColor transparentColor = QColor(TRANSPARENT_COLOR);
 	if (transparentColor.rgb() ==  m_backgroundColor.rgb())	{	//m_pFrameBackgroundColor->paletteForegroundColor())	{
@@ -390,12 +404,15 @@ void DialogTextFont::slotFontStyleChanged(int)
 
 void DialogTextFont::slotFontSizeChanged(int)
 {
-	updateFont(2);
+  QSize size = m_pTextEdit->size ( );
+  m_pTextEdit->setFixedSize ( size );
+  updateFont(2);
+  //  m_pTextEdit->resize ( size );
 }
 
 void DialogTextFont::slotFontSizeChanged( const QString & )
 {
-	updateFont(2);
+  updateFont(2);
 }
 
 void DialogTextFont::slotScriptChanged(int)
@@ -567,7 +584,7 @@ QColor &DialogTextFont::getForegroundColor ()
 	return m_foregroundColor;
 }
 
-void DialogTextFont::setBackgroundColor (QColor &newColor)
+void DialogTextFont::setBackgroundColor ( const QColor &newColor )
 {
 	// Check if the user pressed cancel ...
 	if (!newColor.isValid())
