@@ -342,12 +342,16 @@ MyDialog::MyDialog( QWidget* parent, const char* name, bool modal, WFlags fl )
 	connect( buttonCancel, SIGNAL( clicked() ),     this, SLOT( reject() ) );
 	connect( checkKeepOpen,SIGNAL( toggled(bool) ), this, SLOT( slotKeepOpen(bool) ) );
 
+	char *pCheckClosed = getenv ( "QDVD_KEEPDLGOPEN" );
+	if (  pCheckClosed )
+	  checkKeepOpen->setChecked ( true );
+
 	m_bDoneProcessing = false;
 	m_pTimer = NULL;
 	QValueList<int> listSizes;
-	listSizes.append (50);
-	listSizes.append (1000);
-	splitter1->setSizes (listSizes);
+	listSizes.append    (    50     );
+	listSizes.append    (   1000    );
+	splitter1->setSizes ( listSizes );
 }
 
 MyDialog::~MyDialog()
@@ -469,7 +473,9 @@ void MyDialog::slotKeepOpen (bool bKeepOpen)
 
 void MyDialog::slotPlay ()
 {
-	system (QString ("%1 dvd:/%2/VIDEO_TS/ &").arg(Global::qsExternalPlayer).arg(Global::qsProjectPath));
+	if ( system (QString ("%1 dvd:/%2/VIDEO_TS/ &").arg(Global::qsExternalPlayer).arg(Global::qsProjectPath)) == -1 )
+		return; // error
+	
 }
 
 void MyDialog::slotExport ()
