@@ -134,16 +134,22 @@ bool DVDAuthor::populateListOfTitlesets ()
   DVDMenu         *pMenu;
   QString          qsFormat;
   int              iTitleset;
-  ExportTitleset  *pTitleset;
+  ExportTitleset  *pTitleset = NULL;
   SourceFileInfo  *pInfo;
   SourceFileEntry *pEntry;
-  QValueList<SourceFileEntry *> listButtonMovies;
+  QValueList<SourceFileEntry *> listTempButtonMovies, listButtonMovies;
 
   for (iMenu=0;iMenu<m_listOfAllMenus.count();iMenu++)  {
     pMenu = m_listOfAllMenus[iMenu];
     //    qsFormat = QString ("%1x%2x%3").arg(pMenu->getInterface()->iWidth).arg(pMenu->getInterface()->iHeight).arg(pMenu->fps());
     //    listButtonMovies = pMenu->getSourceFileInfos ();
-    listButtonMovies = pMenu->getSourceFileEntries ();
+    listTempButtonMovies = pMenu->getSourceFileEntries ();
+    // Next we want to make sure we do not modify the orig SourceFIleEntries ...
+    for (t=0;t<listTempButtonMovies.count();t++) {
+      pEntry = listTempButtonMovies[t]->flatClone ();
+      listButtonMovies.append ( pEntry );
+      m_listNewEntries.append ( pEntry );
+    }
     // clean Up will ensure that each SourceFileEntry only holds same format movies (WidthxHeightxFPS)
     cleanUpSourceFileEntries ( listButtonMovies );
 
@@ -402,6 +408,8 @@ bool DVDAuthor::createDVDAuthorXml ( QString &qsFileName )
 
   // Next we should take care of all sub-menus ...
   iMaxTitlesetNumber = getHighestTitlesetNumber ();
+  if ( iMaxTitlesetNumber < 0 )
+       iMaxTitlesetNumber = 0;
   for (t=1;t<=(uint)iMaxTitlesetNumber;t++) {
     pExpTitleset = findTitleset ( t );
     pXMLTitleset = xmlDvdauthor.m_dvdauthor.addTitleset();
@@ -509,13 +517,13 @@ bool DVDAuthor::addToTitleset ( CXmlDVDAuthor::titleset_struct *pXMLTitleset, So
 
 bool DVDAuthor::addToTitleset ( CXmlDVDAuthor::titles_struct *pTitle, SourceFileEntry *pEntry )
 {
-  CXmlDVDAuthor::pgc_struct *pPgc;
+  CXmlDVDAuthor::pgc_struct *pPgc = NULL;
   ExportTitleset temp;
   // There are two ways to do this.
 
   // The first way is if none of the info's has and post or pre
   // command. All videos are stored in one title ( pgc )
-  if ( ! temp.checkForPrePostCommands ( pEntry ) ) {
+  if ( ! temp.checkForPrePostCommands ( pEntry, true ) ) { // true == the fist pPgc can can have a pre and the last is allowed to have a post command
     pPgc = pTitle->addPgc ( );
     return addToTitleset  ( pPgc, pEntry );
   }
@@ -528,6 +536,10 @@ bool DVDAuthor::addToTitleset ( CXmlDVDAuthor::titles_struct *pTitle, SourceFile
     pPgc = pTitle->addPgc ();
     addToTitleset ( pPgc, pEntry->listFileInfos[i] );
   }
+  // just in case to ensure something is happening afterwards.
+  if ( pPgc && pPgc->post.value.isEmpty () )
+    pPgc->post.value = QString (" { g2 = 0; call vmgm menu entry title; } ");
+
   return true;
 }
 
@@ -556,6 +568,9 @@ bool DVDAuthor::addToTitleset ( CXmlDVDAuthor::pgc_struct *pPgc, SourceFileEntry
   
   pPgc->pre.value  = pEntry->qsPre;
   pPgc->post.value = pEntry->qsPost; //QString (" { g2 = 0; call vmgm menu entry title; } ");
+  if ( pEntry->qsPost.isEmpty () )
+    pPgc->post.value = QString (" { g2 = 0; call vmgm menu entry title; } ");
+    
   if ( pEntry->iPause == -1 )
     pPgc->pause = QString ("inf");
   else
@@ -579,7 +594,7 @@ bool DVDAuthor::addToMenu ( CXmlDVDAuthor::titleset_struct *pXMLTitleset, Export
     // Note there ought to be only one <menus> - tag.
     // my mistake for not understanding the dvdauthor-XML-spec
     if ( ! pXMLTitleset->ppArrayMenus )
-      pXMLMenu = pXMLTitleset->addMenus ();
+      pXMLTitleset->addMenus ();
     pXMLMenu = pXMLTitleset->ppArrayMenus[0];
     
     return addToMenu ( pXMLMenu, pExpTitleset );
@@ -650,7 +665,7 @@ bool DVDAuthor::addToMenu ( CXmlDVDAuthor::titleset_struct *pXMLTitleset, DVDMen
     return true;
 
   if ( ! pXMLTitleset->ppArrayMenus )
-    pXMLMenu = pXMLTitleset->addMenus();
+    pXMLTitleset->addMenus();
   pXMLMenu = pXMLTitleset->ppArrayMenus[0];
   return addToMenu ( pXMLMenu, pMenu );
 }
@@ -675,6 +690,14 @@ bool DVDAuthor::addToMenu ( CXmlDVDAuthor::pgc_struct *pPgc, DVDMenu *pMenu )
   JumpTable *pJumpTable;
   Utils theUtils;
 
+  // VAROL
+  CDVDMenuInterface *pInterface   = pMenu->getInterface ( );
+  for (t=0;t<pInterface->listIntroVobs.count ( );t++ ) {
+    pVob = pPgc->addVob ( );
+    pVob->file  = pInterface->listIntroVobs[t]->file;
+    pVob->pause = QString ( "0" );
+  }
+  
   //  pPgc->entry = QString ("title");  
   //  pPgc->pre.value = QString (" { g1=1; g2=1024; g3=2; } ");
   pVob = pPgc->addVob ();
@@ -683,6 +706,12 @@ bool DVDAuthor::addToMenu ( CXmlDVDAuthor::pgc_struct *pPgc, DVDMenu *pMenu )
   // FIXME:
   // Only one problem yet unresolved is that the selection does reset after a loop.
   // This can be fixed through using e.g. the g-register of the virtual machine.
+  for (t=0;t<pInterface->listExtroVobs.count ( );t++ ) {
+    pVob = pPgc->addVob ( );
+    pVob->file  = pInterface->listExtroVobs[t]->file;
+    pVob->pause = QString ( "0" );
+  }
+
   if (pMenu->isMovieMenu ())
     pVob->pause = QString ("0");
   else
@@ -704,15 +733,19 @@ bool DVDAuthor::addToMenu ( CXmlDVDAuthor::pgc_struct *pPgc, DVDMenu *pMenu )
 
 bool DVDAuthor::addToVideo ( CXmlDVDAuthor::video_struct *pVideo, QString &qsResolution, QString &qsAspect )
 {
-  if (qsAspect.isEmpty () ) 
-    qsAspect = "4:3";
+  QString qsSupportedAspect;
+  // Currently dvdauthor only supports those two aspect ratios
+  if ( qsAspect == "16:9" )
+    qsSupportedAspect = "16:9";
+  else if ( qsAspect == "4:3" )
+    qsSupportedAspect = "4:3";
   QString qsRes = qsResolution;
   int iWidth, iHeight, iIdx = qsRes.find ( "x" );
   iWidth  = qsRes.left ( iIdx ).toInt();
   iHeight = qsRes.right( qsRes.length() - iIdx - 1 ).toInt();
   if ( ( iWidth < 1 ) || ( iHeight < 1 ) )
     return false;
-  return addToVideo ( pVideo, iWidth, iHeight, qsAspect );
+  return addToVideo ( pVideo, iWidth, iHeight, qsSupportedAspect );
 }
 
 bool DVDAuthor::addToVideo ( CXmlDVDAuthor::video_struct *pXMLVideo, int iWidth, int iHeight, QString &qsAspect)
@@ -906,7 +939,6 @@ bool DVDAuthor::cleanUpSourceFileEntries ( QValueList<SourceFileEntry *> &listEn
 	  pNewEntry->listFileInfos.append ( pInfo1 );
 	  m_listNewEntries.append (pNewEntry);
 	}
-
       }
     }
   }
@@ -959,14 +991,19 @@ bool Spumux::createXml (DVDMenu *pMenu)
 		// Need to figure this one out ...
 //	pSpu->outlinewidth	= 5;
 	QValueList<ButtonObject *> listButtons;
+	QValueList<QRect>          listButtonRect;
 	QValueList<CXmlSpumux::button_struct *> listXmlButtons;
-	listButtons = pMenu->getButtons();
-	for (t=0;t<listButtons.count ();t++)	{
+	listButtons    = pMenu->getButtons();
+	// First thing is to ensure we have a 1:1 relationship between rect and ButtonObjects.
+	for (t=0;t<listButtons.count();t++)
+	  listButtonRect.append   ( listButtons[t]->boundingRect ( ) );
+	correctOverlappingButtons ( listButtonRect, pMenu->getInterface()->iWidth, pMenu->getInterface()->iHeight );
+	for (t=0;t<listButtons.count();t++)	{
 		pXmlButton = pSpu->addButton();
-		pXmlButton->x0 = listButtons[t]->boundingRect().left();
-		pXmlButton->y0 = listButtons[t]->boundingRect().top();
-		pXmlButton->x1 = listButtons[t]->boundingRect().right();
-		pXmlButton->y1 = listButtons[t]->boundingRect().bottom();
+		pXmlButton->x0 = listButtonRect[t].left   ( ); // boundingRect ( )
+		pXmlButton->y0 = listButtonRect[t].top    ( );
+		pXmlButton->x1 = listButtonRect[t].right  ( );
+		pXmlButton->y1 = listButtonRect[t].bottom ( );
 		//		pXmlButton->label=QString ("%1").arg(t+1);
 		qsButtonName = listButtons[t]->name ();
 		qsButtonName.replace (" ", "_");
@@ -1012,6 +1049,69 @@ bool Spumux::createXml (DVDMenu *pMenu)
 	return true;
 }
 
+bool Spumux::correctOverlappingButtons ( QValueList<QRect> &listOfRect, int iWidth, int iHeight )
+{
+  uint   t, i;
+  int    iDelta;
+  QRect *pRect1, *pRect2, intersection;
+  
+  // None or only one button, return empty 
+  if ( listOfRect.count() < 1 )
+    return false;
+
+  for (t=0;t < listOfRect.count();t++) {
+    pRect1 = & listOfRect[t];
+    // First we check out-of-bounds
+    if ( pRect1->top    () < 0 )
+         pRect1->setTop    ( 1 );
+    if ( pRect1->left   () < 0 )
+         pRect1->setLeft   ( 1 );
+    if ( ( iWidth  > 1 ) && ( pRect1->right  () > iWidth ) )
+         pRect1->setRight  ( iWidth  - 1 );
+    if ( ( iHeight > 1 ) && ( pRect1->bottom () > iHeight ) )
+         pRect1->setBottom ( iHeight - 1 );
+
+    for (i=t+1;i < listOfRect.count ();i++) {
+      pRect2  =  & listOfRect[i];
+
+      if ( pRect1->intersects ( *pRect2 ) ) {
+	intersection = pRect1->intersect ( *pRect2 );
+	
+	// here we determine if the intersection is more long than tall
+	if ( intersection.width ( ) > intersection.height ( ) ) {
+	  // we subtract the delta from the top / bottom of the intersection rectangles.
+	  iDelta = (int) ( ( intersection.height ( ) + 1 ) / 2.0 );
+	  // ensure that the button which is higher to be rect1
+	  if ( pRect1->top ( ) > pRect2->top ( ) ) {
+	    pRect1 = & listOfRect [ i ];
+	    pRect2 = & listOfRect [ t ];
+	  }
+	  // Now we subtract the delta from button1's bounding Rect ...
+	  pRect1->setBottom ( pRect1->bottom ( ) - iDelta );
+	  pRect2->setTop    ( pRect2->top    ( ) + iDelta );
+	}
+	else {
+	  // we subtract the delta from the left / right of the intersection rectangles.
+	  iDelta = (int) ( ( intersection.width ( ) + 1 ) / 2.0 );
+	  // ensure that the button which is closer to the left button1
+	  if ( pRect1->left () > pRect2->left ( ) ) {
+	    pRect1 = & listOfRect [ i ];
+	    pRect2 = & listOfRect [ t ];
+	  }
+	  
+	  pRect1->setRight ( pRect1->right ( ) - iDelta );
+	  pRect2->setLeft  ( pRect2->left  ( ) + iDelta );
+	}
+      }
+      // Ensure pRect1 is the button we expect it to be.
+      pRect1 = & listOfRect [ t ];
+    }
+  }
+
+  return true;
+}
+
+
 // The following function takes care of creating the spumux file for subtitles.
 //<subpictures>
 //   <stream>
@@ -1232,12 +1332,32 @@ int ExportTitleset::getTotalChapters ( SourceFileInfo *pSourceFileInfo )
   return 0;
 }
 
-bool ExportTitleset::checkForPrePostCommands ( SourceFileEntry *pEntry )
+bool ExportTitleset::checkForPrePostCommands ( SourceFileEntry *pEntry, bool bIgnoreFirstLast )
 {
   uint i;
-  for (i=0;i<pEntry->listFileInfos.count();i++) {
-    if ( ( ! pEntry->listFileInfos[i]->qsPreCommand.isEmpty  () ) || 
-	 ( ! pEntry->listFileInfos[i]->qsPostCommand.isEmpty () ) )
+  // bIgnoreFirstLast will ignore the pre for the first SourceFileInfo
+  // and the post command for the last SourceFileInfo.
+
+  // if we ignore first pre and last post AND there is only one SourceFileInfo in the list then ...
+  if ( ( bIgnoreFirstLast ) && ( pEntry->listFileInfos.count() < 1 ) )
+    return false;
+  
+  uint iCount = pEntry->listFileInfos.count();
+  for (i=0;i<iCount;i++) {
+    if ( bIgnoreFirstLast )  {
+      // check first SourceFileInfo
+      if ( ( i == 0 ) && ( ! pEntry->listFileInfos[i]->qsPostCommand.isEmpty () ) )
+	return true;
+      // check last SourceFileInfo
+      else if ( ( i == iCount - 1 ) && ( ! pEntry->listFileInfos[i]->qsPreCommand.isEmpty  () ) )
+	return true;
+      else if ( ( i != 0 ) && ( i != iCount-1 ) && (
+		( ! pEntry->listFileInfos[i]->qsPreCommand.isEmpty  () ) || 
+		( ! pEntry->listFileInfos[i]->qsPostCommand.isEmpty () ) ) )
+	return true;
+    } // if first and last are not to be ignored
+    else if ( ( ! pEntry->listFileInfos[i]->qsPreCommand.isEmpty  () ) || 
+	      ( ! pEntry->listFileInfos[i]->qsPostCommand.isEmpty () ) )
       return true;
   }
 
