@@ -124,3 +124,21 @@ void CFormMain::slotEditAddSlideshow()
 }
 
 
+
+
+void CFormMain::toolsVisibleRegion()
+{
+
+}
+
+
+void CFormMain::slotVisibleRegion()
+{
+
+}
+
+
+void CFormMain::slotVisibleRegion( bool )
+{
+
+}
