@@ -1,10 +1,9 @@
 /****************************************************************************
-** Class Utils implementation ...
+** Class Global implementation ...
 **
 ** Created: Wed Sep 09 07:53:05 2004
 **
-** Here we have some misc functions which are needed by a few classes 
-** but can not really be assigned to any of those classes.
+** Here we have a few global variables.
 **
 ****************************************************************************/
 
@@ -21,6 +20,7 @@ QString Global::qsExternalPlayer     = QString ("qplayer");
 uint    Global::iMaxRunningThreads   = 4;
 int     Global::iChildThreadPriority = 0;
 int     Global::iDeleteTempOlderThan = 30;
+QEventLoop Global::eventLoop;
 
 Global::Global()
 {
