@@ -9,7 +9,6 @@
 ** AN ImageObject is a visible object in a DVD Menu.
 **
 ****************************************************************************/
-#include <qmessagebox.h>
 #include <qpushbutton.h>
 #include <qpopupmenu.h>
 #include <qfileinfo.h>
@@ -26,6 +25,7 @@
 #include "frameobject.h"
 #include "imageobject.h"
 #include "dialogmovie.h"
+#include "messagebox.h"
 #include "dialogmatrix.h"
 #include "dialoggeometry.h"
 #include "dialoganimation.h"
@@ -62,25 +62,31 @@ void ImageObject::setFile (QString fileName)
 
 void ImageObject::setZoom (float fZoom)
 {
-	// For the purpose of this class the Zoom is alreaduy incorporated into m_pixmap ...
-	m_imageManipulator.fZoom = fZoom;
+  // For the purpose of this class the Zoom is alreaduy incorporated into m_pixmap ...
+  m_imageManipulator.fZoom = fZoom;
 }
 
 void ImageObject::setManipulator(ImageManipulator &theOther)
 {
-	m_imageManipulator = theOther;
+  m_imageManipulator = theOther;
+}
+
+void ImageObject::setModifiers ( Modifiers &theOther )
+{
+  Modifiers *pModifier = (Modifiers *)&m_imageManipulator;
+  *pModifier = theOther;
 }
 
 ImageManipulator &ImageObject::manipulator()
 {
-	return m_imageManipulator;
+  return m_imageManipulator;
 }
 
 Modifiers *ImageObject::modifiers()
 {
-	// Return the base class only ...
-	// Note: this is needed to use the same MatrixDialog for text and images.
-	return (Modifiers *) &m_imageManipulator;
+  // Return the base class only ...
+  // Note: this is needed to use the same MatrixDialog for text and images.
+  return (Modifiers *) &m_imageManipulator;
 }
 
 QString &ImageObject::fileName()
@@ -100,6 +106,7 @@ float ImageObject::zoom()
 
 void ImageObject::drawContents (QPainter *painter)
 {
+  //  printf ( "%s::%s::%d rotate=<%0.4f>\n", __FILE__, __FUNCTION__, __LINE__, manipulator().fRotate );
 	QWMatrix theMatrix;
 	// Here we calculate the center point of gravity (rotation)
 	QPoint centerPos;
@@ -123,19 +130,21 @@ void ImageObject::drawContents (QPainter *painter)
 	//. then we apply the other modifications ...
 //	theMatrix.scale  (manipulator().fZoom, manipulator().fZoom);
 	theMatrix.scale  (modifiers()->fScaleX, modifiers()->fScaleY);
-	theMatrix.rotate (manipulator().fRotate);
 	theMatrix.shear  (manipulator().fShearX, manipulator().fShearY);
+	theMatrix.rotate (manipulator().fRotate);
 
 	// Here we get the rect that encompasses the button for this object.
 	m_boundingRect = theMatrix.mapRect(theRect);
-	if (m_bDrawRect)
-		painter->drawRect(m_boundingRect);
+	if (m_bDrawRect) {
+	  drawActiveFrame ( painter );
+	  //painter->drawRect(m_boundingRect);
+	}
 
 	painter->setWorldMatrix(theMatrix);
 
 	// Here we re-set the world matrix and translate the newly drawn ... thing ...
-	if (m_bDrawRect)
-		painter->drawRect(theRect);
+	if ( isActive () )
+	  painter->drawRect(theRect);
 	
 	theMatrix.reset();
 	painter->setWorldMatrix(theMatrix);
@@ -145,6 +154,9 @@ void ImageObject::drawContents (QPainter *painter)
 		return;
 
 	if (!m_bDrawRect)	{
+                if ( m_pShadow )
+	             m_pShadow->drawContents ( painter );
+
 		int t, x, y;
 		QRgb thePixel;
 		int iSourceHeight = pixmap().height();
@@ -246,11 +258,15 @@ void ImageObject::drawContents (QPainter *painter)
 
 void ImageObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int)
 {
-	// Next is to set the AnimationAttributes
-	for (uint t=0;t<m_listAnimationAttributes.count();t++)
-		m_listAnimationAttributes[t]->setValue (iRenderFrameNumber);
-	// And then we can go ahead and draw the contents with the newly set attributes.
-	drawContents (pPainter);
+  // Next is to set the AnimationAttributes
+  for (uint t=0;t<m_listAnimationAttributes.count();t++)
+    m_listAnimationAttributes[t]->setValue (iRenderFrameNumber);
+
+  // And then we ought to refresh the pixmap ...
+  if ( m_listAnimationAttributes.count () > 0 )
+    updatePixmap ( );
+  // before we can go ahead and draw the contents with the newly set attributes.
+  drawContents (pPainter);
 }
 
 // This function checks if pColor is within the min/max of one of the color keys.
@@ -337,8 +353,8 @@ void ImageObject::updatePixmap()
 	// Next we re-set the matrix ...
 	theMatrix.reset ();
 	// and plug in the remaining operations ...
-	theMatrix.rotate (manipulator().fRotate);
 	theMatrix.shear  (manipulator().fShearX, manipulator().fShearY);
+	theMatrix.rotate (manipulator().fRotate);
 	theImage = imageColored.xForm( theMatrix );
 	m_pixmap.convertFromImage(theImage);
 	emit (signalUpdatePixmap());
@@ -393,31 +409,14 @@ void ImageObject::createStructure (QListViewItem *pParentItem)
 	pButtonItem->setExpandable (TRUE);
 
 	manipulator ().createStructure (pButtonItem);
+	if ( m_pShadow )
+	     m_pShadow->createStructure ( pButtonItem );
 
 	new StructureItem(this, pButtonItem, QString ("Geometry"),
 		QString ("%1, %2, %3, %4").
 		arg(rect().x()).arg(rect().y()).arg(rect().width()).arg(rect().height()));
 }
 
-bool ImageObject::mouseMoveEvent (QMouseEvent *pEvent)
-{
-	// This will move the textObject around and around and around we go ...
-	QRect theRect = rect();
-	int iX, iY, iWidth, iHeight;
-	iWidth  = rect().width ();
-	iHeight = rect().height();
-	iX = rect().x() - (m_currentMousePos.x() - pEvent->pos().x());
-	iY = rect().y() - (m_currentMousePos.y() - pEvent->pos().y());
-	theRect.setX(iX);
-	theRect.setY(iY);
-	theRect.setWidth(iWidth);
-	theRect.setHeight(iHeight);
-
-	setRect(theRect);
-	m_currentMousePos = pEvent->pos();
-	return false;
-}
-
 bool ImageObject::mousePressEvent (QMouseEvent *pEvent)
 {
 	m_currentMousePos = pEvent->pos();
@@ -425,8 +424,25 @@ bool ImageObject::mousePressEvent (QMouseEvent *pEvent)
 		QPoint globalPos = pEvent->globalPos();
 		return createContextMenu ( globalPos );
 	}
-	else
+	else {
 		m_bDrawRect = true;
+	}
+	return false;
+}
+
+bool ImageObject::mouseReleaseEvent (QMouseEvent *)
+{
+	m_bDrawRect = false;
+	updatePixmap ();
+	emit (signalUpdatePixmap());
+	emit (signalUpdateStructure());
+	return false;
+}
+
+bool ImageObject::mouseDoubleClickEvent (QMouseEvent *)
+{
+	// Back to the MenuPreview - class, where I can handle this request ...
+	emit (signalModifyMe(this));
 	return false;
 }
 
@@ -442,17 +458,18 @@ bool ImageObject::createContextMenu ( QPoint globalPos )
 	if (m_pContextMenu)
 		delete m_pContextMenu;
 	m_pContextMenu = new QPopupMenu(m_pParent);
-	m_pContextMenu->insertItem ( tr ("Edit ...")      , this, SLOT(slotEdit()));
-	m_pContextMenu->insertItem ( tr ("Properties ..."), this, SLOT(slotProperties()));
-	m_pContextMenu->insertItem ( tr ("Matrix ...")    , this, SLOT(slotMatrix()));
-	m_pContextMenu->insertItem ( tr ("Delete")        , this, SLOT(slotDelete()));
+	m_pContextMenu->insertItem ( tr ("Edit ...")      , this, SLOT(slotEdit      ( ) ) );
+	m_pContextMenu->insertItem ( tr ("Properties ..."), this, SLOT(slotProperties( ) ) );
+	m_pContextMenu->insertItem ( tr ("Matrix ...")    , this, SLOT(slotMatrix    ( ) ) );
+	m_pContextMenu->insertItem ( tr ("Delete")        , this, SLOT(slotDelete    ( ) ) );
 	m_pContextMenu->insertSeparator();
-	m_pContextMenu->insertItem ( tr ("Rotate 90")     , this, SLOT(slotRotate90 ()));
-	m_pContextMenu->insertItem ( tr ("Rotate 180")    , this, SLOT(slotRotate180()));
-	m_pContextMenu->insertItem ( tr ("Rotate 270")    , this, SLOT(slotRotate270()));
+	m_pContextMenu->insertItem ( tr ("Rotate 90")     , this, SLOT(slotRotate90  ( ) ) );
+	m_pContextMenu->insertItem ( tr ("Rotate 180")    , this, SLOT(slotRotate180 ( ) ) );
+	m_pContextMenu->insertItem ( tr ("Rotate 270")    , this, SLOT(slotRotate270 ( ) ) );
 	m_pContextMenu->insertSeparator();
-	m_pContextMenu->insertItem ( tr ("Add Frame")     , this, SLOT(slotAddFrame()));
-	m_pContextMenu->insertItem ( tr ("Add Text")      , this, SLOT(slotAddText()));
+	m_pContextMenu->insertItem ( tr ("Add Shadow")    , this, SLOT(slotAddShadow ( ) ) );
+	m_pContextMenu->insertItem ( tr ("Add Frame")     , this, SLOT(slotAddFrame  ( ) ) );
+	m_pContextMenu->insertItem ( tr ("Add Text")      , this, SLOT(slotAddText   ( ) ) );
 	m_pContextMenu->insertSeparator();
 	m_pContextMenu->insertItem ( tr ("Define as Button") , this, SLOT(slotDefineAsButton()));
 	// Blocking call.
@@ -464,20 +481,57 @@ bool ImageObject::createContextMenu ( QPoint globalPos )
 	return true;
 }
 
-bool ImageObject::mouseReleaseEvent (QMouseEvent *)
+bool ImageObject::mouseMoveEvent (QMouseEvent *pEvent)
 {
-	m_bDrawRect = false;
-	emit (signalUpdatePixmap());
-	emit (signalUpdateStructure());
-	return false;
+  // Slightly different behaviour for images.
+  // if we stretch X and/or Y separately we'll mess rotation up
+  // this is why we have to prevent this. 
+  // So the stretch will be reset and ShearX will be used instead ScaleX if rotated.
+  int iPos = 0;
+
+  switch ( m_objectState ) {
+  case MenuObject::StateScaleLeftX: 
+  case MenuObject::StateScaleRightX: {
+    iPos = pEvent->pos().x() - m_currentMousePos.x();
+    double fZoom   = (double)( iPos / 100.0 );
+    if (fZoom > 1.0)
+      fZoom = fZoom * 2.0 - 1.0;
+
+    if ( m_objectState == MenuObject::StateScaleLeftX )
+      fZoom *= -1;
+    if ( modifiers()->fRotate == 0.0 )
+      modifiers( )->fScaleX *= ( 1.0 + fZoom );
+    else
+      modifiers( )->fShearX -= fZoom;
+    update   ( );
+  }
+  break;
+  case MenuObject::StateScaleTopY:
+  case MenuObject::StateScaleBottomY: {
+    iPos = pEvent->pos().y() - m_currentMousePos.y();
+    double fZoom   = (double)( iPos / 100.0 );
+    if (fZoom > 1.0)
+      fZoom = fZoom * 2.0 - 1.0;
+    
+    if ( m_objectState == MenuObject::StateScaleTopY )
+      fZoom *= -1;
+    if ( modifiers()->fRotate == 0.0 )
+      modifiers( )->fScaleY *= ( 1.0 + fZoom );
+    else
+      modifiers( )->fShearY += fZoom;
+    update   ( );
+  }
+  break;
+  case MenuObject::StateRotate:
+    modifiers()->fScaleX = 1.0;
+    modifiers()->fScaleY = 1.0;    
+  default:
+    return MenuObject::mouseMoveEvent ( pEvent );
+  }
+  m_currentMousePos = pEvent->pos();
+  return false;
 }
 
-bool ImageObject::mouseDoubleClickEvent (QMouseEvent *)
-{
-	// Back to the MenuPreview - class, where I can handle this request ...
-	emit (signalModifyMe(this));
-	return false;
-}
 
 void ImageObject::slotEdit()
 {
@@ -522,7 +576,8 @@ void ImageObject::slotProperties()
 			}
 		}
 		setRect (rect);
-		updatePixmap ();
+		updatePixmap ( );
+		updateShadow ( );
 		emit (signalUpdatePixmap());
 	}
 	delete pGeometry;
@@ -577,29 +632,27 @@ void ImageObject::rotate(float fRot)
 
 void ImageObject::slotMatrix()
 {
-	QMessageBox::warning (NULL, QString ("Warning"), QString ("This Dialog is very instabel ...\n"), QMessageBox::Ok,  QMessageBox::NoButton);
-
-	DialogMatrix *pDialog = new DialogMatrix(MenuObject::parent());
-	pDialog->initMe(this);
-	connect (this, SIGNAL(signalDeleteMe(MenuObject *)), pDialog, SLOT(slotDeleteObject(MenuObject *)));
-	pDialog->show();
+  DialogMatrix *pDialog = new DialogMatrix(MenuObject::parent());
+  pDialog->initMe(this);
+  connect (this, SIGNAL(signalDeleteMe(MenuObject *)), pDialog, SLOT(slotDeleteObject(MenuObject *)));
+  pDialog->show();
 }
 
 void ImageObject::slotAddFrame()
 {
-	QMessageBox::warning (NULL, QString ("Not Implemented yet."), QString ("Not Implemented yet."),
+	MessageBox::warning (NULL, QString ("Not Implemented yet."), QString ("Not Implemented yet."),
 		QMessageBox::Ok ,  QMessageBox::Cancel);
 }
 
 void ImageObject::slotAddText()
 {
-	QMessageBox::warning (NULL, QString ("Not Implemented yet."), QString ("Not Implemented yet."),
+	MessageBox::warning (NULL, QString ("Not Implemented yet."), QString ("Not Implemented yet."),
 		QMessageBox::Ok ,  QMessageBox::Cancel);
 }
 
 void ImageObject::slotDefineAsButton()
 {
-	emit (signalDefineAsButton(this));
+	emit ( signalDefineAsButton ( this ) );
 }
 
 MenuObject *ImageObject::clone()
@@ -613,10 +666,15 @@ MenuObject *ImageObject::clone()
 	pNewObject->setRect(rect());
 	pNewObject->setManipulator(manipulator());
 
+	MenuObject *pShadow = shadow ( );
+	if ( pShadow )
+	  pShadow = pShadow->clone ( pNewObject );
+	pNewObject->setShadow      (  pShadow   );
+
 	return pNewObject;
 }
 
-// Called from xyz, when creating the AnimationAttribute objects, which hold the list of valuers for the attribute to be set.
+// Called from xyz, when creating the AnimationAttribute objects, which hold the list of values for the attribute to be set.
 // Note: only those AnimationAttribute objects are created which are modified during the animation (Menu - video).
 AnimationAttribute *ImageObject::getSpecificAttributes (long iMaxNumberOfFrames, QString qsProperty)
 {
