@@ -23,35 +23,35 @@ public:
 	// Public functions needed for the abstract base class.
 	ImageObject (QWidget *pParent = 0);
 	virtual ~ImageObject();
-	virtual void drawContents(QPainter *);
-	virtual void drawContents(QPainter *, int, int);
-	virtual bool mouseMoveEvent        (QMouseEvent *);
-	virtual bool mousePressEvent       (QMouseEvent *);
-	virtual bool mouseReleaseEvent     (QMouseEvent *);
-	virtual bool mouseDoubleClickEvent (QMouseEvent *);
+	virtual void drawContents          ( QPainter    *  );
+	virtual void drawContents          ( QPainter    *, int, int);
+	virtual bool mousePressEvent       ( QMouseEvent *  );
+	virtual bool mouseReleaseEvent     ( QMouseEvent *  );
+	virtual bool mouseMoveEvent        ( QMouseEvent *  );
+	virtual bool mouseDoubleClickEvent ( QMouseEvent *  );
 
-	virtual bool readProjectFile       (QDomNode &);
-	virtual bool writeProjectFile      (QDomElement &);
-	virtual void createStructure       (QListViewItem *);
-	virtual bool createContextMenu     (QPoint);
+	virtual bool readProjectFile       ( QDomNode &     );
+	virtual bool writeProjectFile      ( QDomElement &  );
+	virtual void createStructure       ( QListViewItem *);
+	virtual bool createContextMenu     ( QPoint         );
 	virtual MenuObject *clone();
 
 public:
 	// Further public functions not dervied from the base class.
-	virtual void setPixmap(QPixmap &);
-	virtual void updatePixmap();
-	void setManipulator(ImageManipulator &);
-	void setFile (QString);
-	void setZoom (float);
-	QPixmap &pixmap ();
-	QString &fileName();
-	float    zoom ();
-	virtual Modifiers *modifiers();
-	ImageManipulator &manipulator();
+	virtual void setPixmap        ( QPixmap & );
+	virtual void updatePixmap     ( );
+	virtual void setManipulator   ( ImageManipulator & );
+	virtual void setModifiers     ( Modifiers & );
+	void setFile                  ( QString );
+	void setZoom                  ( float );
+	QPixmap &pixmap               ( );
+	QString &fileName             ( );
+	float    zoom                 ( );
+	virtual Modifiers *modifiers  ( );
+	ImageManipulator &manipulator ( );
 
 signals:
-	void signalModifyMe(MenuObject *);
-
+	void signalModifyMe ( MenuObject * );
 	
 protected:
 	virtual AnimationAttribute *getSpecificAttributes (long, QString);
