@@ -56,16 +56,6 @@ Keyword::~Keyword ()
 	delete pEntry;
     }
   }
-  //  for (t=0;t<count ( TransKeys );t++) {
-  //    pEntry = m_listOfPair[ TransKeys ][ t ];
-  //    if ( pEntry )
-  //      delete pEntry;
-  //  }
-  //  for (t=0;t<count ( SubKeys );t++) {
-  //    pEntry = m_listOfPair[ SubKeys   ][ t ];
-  //    if ( pEntry )
-  //      delete pEntry;
-  //  }
 }
 
 QString Keyword::value ( int iWhichKeyset, int iWhichKey )
@@ -146,6 +136,7 @@ bool Keyword::setValue ( int iWhichKeyset, int iWhichKey, QString qsValue )
     return false;
 
   m_listOfPair[iWhichKeyset][iWhichKey]->qsValue = qsValue;
+  m_listOfPair[iWhichKeyset][iWhichKey]->iIndex  = iWhichKey;
 
   return true;
 }
@@ -230,3 +221,15 @@ QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
   return qsOutput;
 }
 
+void Keyword::printf ( int iWhichKeyset )
+{
+  int    t;
+  Entry *pEntry;
+  if ( iWhichKeyset >= BaseLast )
+    iWhichKeyset = Keys;
+  
+  for (t=0;t<(int)m_listOfPair[iWhichKeyset].count();t++) {
+    pEntry = m_listOfPair[iWhichKeyset][t];
+    ::printf ("%d > index=<%d> : Key=<%s> value=<%s>\n", t, pEntry->iIndex, pEntry->qsKey.ascii(), pEntry->qsValue.ascii() );
+  }  
+}
