@@ -13,7 +13,6 @@
 ** And yet another Icon could indicate the (intended) Format of the Movie.
 **
 *****************************************************************************/
-#include <qmessagebox.h>
 #include <qfileinfo.h>
 #include <qlistview.h>
 #include <qpainter.h>
@@ -21,6 +20,7 @@
 #include <qimage.h>
 
 #include "global.h"
+#include "messagebox.h"
 #include "sourcefileentry.h"
 #include "listviewitemmedia.h"
 
@@ -55,78 +55,103 @@ ListViewItemMedia::~ListViewItemMedia ()
 {
 }
 
-void ListViewItemMedia::initMe (SourceFileEntry *pEntry, const QColor &theColor)
+void ListViewItemMedia::initMe (SourceFileEntry *pEntry, const QColor &theBaseColor)
 {
-	// Here we create the sub items according to the SourceFileEntry -> listFileInfos
-	int t;
-	QFileInfo fileInfo;
-	m_backgroundColor  = theColor;
-	m_pSourceFileEntry = pEntry;
-	m_pSourceFileInfo  = NULL;
-	m_iButtonState     = StateStop;
-	m_iPreviousButtonState = 1000;
+  // Here we create the sub items according to the SourceFileEntry -> listFileInfos
+  int t;
+  QColor              theColor;
+  QFileInfo           fileInfo;
+  SourceFileInfo     *pInfo;
+  m_backgroundColor  = theBaseColor;
+  m_pSourceFileEntry = pEntry;
+  m_pSourceFileInfo  = NULL;
+  m_iButtonState     = StateStop;
+  m_iPreviousButtonState = 1000;
+  
+  sortChildItems (-1, false);
+  setOpen (true);
+  setDragEnabled (true);
+  setDropEnabled (true);
+  for(t=pEntry->listFileInfos.count()-1;t>=0;t--)	{
+    pInfo = pEntry->listFileInfos[t];
+    if ( ! pInfo )
+      continue;
+    if ( pInfo->pTranscodeInterface )
+      theColor = QColor ( COLOR_MOVIE_TRANSCODE );
+    else
+      theColor = theBaseColor;
+    fileInfo.setFile ( pInfo->qsFileName );
+    
+    QString qsInfo (fileInfo.fileName () + QString ("\n") + pInfo->qsLength);
+    ListViewItemMedia *pItem = new ListViewItemMedia (this, pInfo, theColor, QString(), qsInfo, QString());
+    pItem->setOpen (true);
+    pItem->setDragEnabled (true);
+    pItem->setDropEnabled (true);
+    if (pInfo->pPreview)	{
+      QPixmap thePixmap;
+      QImage scaledImage (pInfo->pPreview->smoothScale (pEntry->sizeThumbnail, QImage::ScaleMin));
+      if (pEntry->bSoundSource)	// No buttons for a sound - SourceFileEntry ...
+	thePixmap = QPixmap (scaledImage);
+      else
+	thePixmap = pItem->attachButtons (scaledImage, pEntry->sizeThumbnail);
+      pItem->setPixmap (0, thePixmap);
+    }
+    pItem->setDragEnabled (true);
+  }
+}
 
-	sortChildItems (-1, false);
-	setOpen (true);
-	setDragEnabled (true);
-	setDropEnabled (true);
-	for(t=pEntry->listFileInfos.count()-1;t>=0;t--)	{
-		fileInfo.setFile (pEntry->listFileInfos[t]->qsFileName);
-		QString qsInfo (fileInfo.fileName () + QString ("\n") + pEntry->listFileInfos[t]->qsLength);
-		ListViewItemMedia *pItem = new ListViewItemMedia (this, pEntry->listFileInfos[t], theColor, QString(), qsInfo, QString());
-		pItem->setOpen (true);
-		pItem->setDragEnabled (true);
-		pItem->setDropEnabled (true);
-		if (pEntry->listFileInfos[t]->pPreview)	{
-			QPixmap thePixmap;
-			QImage scaledImage (pEntry->listFileInfos[t]->pPreview->smoothScale (pEntry->sizeThumbnail, QImage::ScaleMin));
-			if (pEntry->bSoundSource)	// No buttons for a sound - SourceFileEntry ...
-				thePixmap = QPixmap (scaledImage);
-			else
-				thePixmap = pItem->attachButtons (scaledImage, pEntry->sizeThumbnail);
-			pItem->setPixmap (0, thePixmap);
-		}
-		pItem->setDragEnabled (true);
-	}
+void ListViewItemMedia::updateItem ()
+{
+  SourceFileInfo *pInfo = sourceFileInfo ();
+  if ( ! pInfo )
+    return;
+
+  m_backgroundColor   = QColor (COLOR_MOVIE_FILES_OK);
+  if ( pInfo->pTranscodeInterface )
+    m_backgroundColor = QColor (COLOR_MOVIE_TRANSCODE);
+  else if (pInfo->qsStatus != QString ("Ok"))
+    m_backgroundColor = QColor (COLOR_MOVIE_FILES_BAD);
 }
 
 void ListViewItemMedia::replaceInfo (SourceFileInfo *pInfo)
 {
-	SourceFileEntry *pEntry = NULL;
-	if (sourceFileInfo() == pInfo)	{
-		pEntry = ((ListViewItemMedia *)parent())->sourceFileEntry();
-		if (!pEntry)
-			return;
-
-		QImage scaledImage (pInfo->pPreview->smoothScale (pEntry->sizeThumbnail, QImage::ScaleMin));
-		QFileInfo fileInfo (pInfo->qsFileName );
-		QString   qsInfo   (fileInfo.fileName () + QString ("\n") + pInfo->qsLength);
-		setText (1, qsInfo);
-		m_backgroundColor = QColor (COLOR_MOVIE_FILES_OK);
-		if (pInfo->qsStatus != QString ("Ok"))
-			m_backgroundColor = QColor (COLOR_MOVIE_FILES_BAD);
-
-		// attach the buttons and force a repaint of the buttons ...
-		m_iPreviousButtonState = StateUndef;
-		QPixmap thePixmap = attachButtons (scaledImage, pEntry->sizeThumbnail);
-	}
-	else if (sourceFileEntry ())	{
-		pEntry = sourceFileEntry();
-		ListViewItemMedia *pChild = (ListViewItemMedia *)firstChild ();
-		while (pChild)	{
-			pChild->replaceInfo (pInfo);
-			pChild = (ListViewItemMedia *)pChild->nextSibling ();
-		}
-		// Here we check for the color of the header ... onlyu if all status's are Ok do we give
-		// the Ok color to the header too .
-		m_backgroundColor = QColor (COLOR_MOVIE_FILES_OK);
-		for (uint t=0; t<pEntry->listFileInfos.count ();t++)	{
-			if (pEntry->listFileInfos[t]->qsStatus != QString ("Ok"))	{
-				m_backgroundColor = QColor (COLOR_MOVIE_FILES_BAD);
-				break;
-			}
-		}
-	}
+  SourceFileEntry *pEntry = NULL;
+  if (sourceFileInfo() == pInfo)	{
+    pEntry = ((ListViewItemMedia *)parent())->sourceFileEntry();
+    if (!pEntry)
+      return;
+    
+    QImage scaledImage ( pInfo->pPreview->smoothScale (pEntry->sizeThumbnail, QImage::ScaleMin ) );
+    QFileInfo fileInfo ( pInfo->qsFileName );
+    QString   qsInfo   ( fileInfo.fileName () + QString ("\n") + pInfo->qsLength );
+    setText (1, qsInfo);
+    m_backgroundColor   = QColor (COLOR_MOVIE_FILES_OK);
+    if ( pInfo->pTranscodeInterface )
+      m_backgroundColor = QColor (COLOR_MOVIE_TRANSCODE);
+    else if (pInfo->qsStatus != QString ("Ok"))
+      m_backgroundColor = QColor (COLOR_MOVIE_FILES_BAD);
+    
+    // attach the buttons and force a repaint of the buttons ...
+    m_iPreviousButtonState = StateUndef;
+    QPixmap thePixmap = attachButtons (scaledImage, pEntry->sizeThumbnail);
+  }
+  else if (sourceFileEntry ())	{
+    pEntry = sourceFileEntry();
+    ListViewItemMedia *pChild = (ListViewItemMedia *)firstChild ();
+    while (pChild)	{
+      pChild->replaceInfo (pInfo);
+      pChild = (ListViewItemMedia *)pChild->nextSibling ();
+    }
+    // Here we check for the color of the header ... only if all status's are Ok do we give
+    // the Ok color to the header too .
+    m_backgroundColor     = QColor (COLOR_MOVIE_FILES_OK);
+    for (uint t=0; t<pEntry->listFileInfos.count ();t++)	{
+      if (pEntry->listFileInfos[t]->qsStatus != QString ("Ok"))	{
+	m_backgroundColor = QColor (COLOR_MOVIE_FILES_BAD);
+	break;
+      }
+    }
+  }
 }
 
 QPixmap &ListViewItemMedia::attachButtons (QImage &theImage, QSize sizeThumbnail)
@@ -265,7 +290,7 @@ void ListViewItemMedia::itemClicked(QPoint &thePoint)
 			qsState = QString ("Back");
 		QString qsMessage;
 		qsMessage = QString("%1 %2 not yet implemented.").arg(qsState).arg(fileInfo.fileName());
-		QMessageBox::warning (NULL, "Not implemented", qsMessage, QMessageBox::Ok, QMessageBox::NoButton);
+		MessageBox::warning (NULL, "Not implemented", qsMessage, QMessageBox::Ok, QMessageBox::NoButton);
 //		ListViewMedia *pListView = (ListViewMedia *)listView();
 	}
 	drawButtonState ((QPixmap *)pixmap(0));
