@@ -1,3 +1,4 @@
+ 
 /****************************************************************************
 ** MenuOject class
 **
@@ -18,6 +19,7 @@
 
 #include "xml_dvd.h"
 #include "menuobject.h"
+#include "shadowobject.h"
 
 MenuObject::MenuObject (QWidget *pParent)
 	: QObject (pParent)
@@ -26,6 +28,8 @@ MenuObject::MenuObject (QWidget *pParent)
 	m_pParent      = pParent;
 	m_bDrawRect    = false;
 	m_pContextMenu = NULL;
+	m_pShadow      = NULL;
+	m_objectState  = StateUnknown;
 }
 
 MenuObject::~MenuObject ()
@@ -38,14 +42,8 @@ MenuObject::~MenuObject ()
 		delete m_listAnimationAttributes[t];
 	}
 	m_listAnimationAttributes.clear();
-}
-
-// Need to take m_rectPreview into accoutn ...
-bool MenuObject::contains (QPoint &pos)
-{
-	if (!m_boundingRect.contains(pos))
-		return false;
-	return true;
+	if ( m_pShadow )
+	  delete m_pShadow;
 }
 
 bool MenuObject::readProjectFile  (QDomNode &theNode)
@@ -53,6 +51,16 @@ bool MenuObject::readProjectFile  (QDomNode &theNode)
 	// Here we read in the base class ...
 	QDomNode subNode;
 	QDomNode xmlMenuObject = theNode.firstChild();
+	
+	{ // clean up the current object attributes.
+	  // if we have a shadowObject, the we should get rid of it.
+	  Modifiers emptyModifiers;
+	  if ( m_pShadow )
+	    delete m_pShadow;
+	  m_pShadow = NULL;
+	  m_qsAnimation = QString ( );
+	  *modifiers () = emptyModifiers;
+	}
 
 	while ( !xmlMenuObject.isNull () )	{
 		// Okay, here we retain the stored data from the xml file.
@@ -145,6 +153,11 @@ bool MenuObject::readProjectFile  (QDomNode &theNode)
 				subNode = subNode.nextSibling ();
 			}
 		}
+		else if (tagName == SHADOW_OBJECT)	{
+		  m_pShadow = new ShadowObject ( this );
+		  if ( ! m_pShadow->readProjectFile ( xmlMenuObject ) ) 
+		    return false;
+		}
 		// So lets get the next sibling ... until we hit hte end of DVDMenu ...
 		xmlMenuObject = xmlMenuObject.nextSibling();
 	}
@@ -206,6 +219,10 @@ bool MenuObject::writeProjectFile (QDomElement &theElement)
 		animationNode.appendChild ( text );
 		objectNode.appendChild ( animationNode );
 	}
+	if ( m_pShadow ) {
+	  if ( ! m_pShadow->writeProjectFile ( theElement ) )
+	    return false;
+	}
 	theElement.appendChild( objectNode );
 	return true;
 }
@@ -256,9 +273,220 @@ QPoint   &MenuObject::currentMousePos()
 	return m_currentMousePos;
 }
 
+// Need to take m_rectPreview into accoutn ...
+bool MenuObject::contains (QPoint &pos)
+{
+	if (!m_boundingRect.contains(pos))
+		return false;
+	return true;
+}
+
+bool MenuObject::mouseMoveEvent (QMouseEvent *pEvent)
+{
+  // This will move, scale rotatae or share the Object ...
+  QRect theRect = rect();
+  int iX, iY, iWidth, iHeight;
+
+  int iPos = pEvent->pos().x() - m_currentMousePos.x();
+  switch ( m_objectState ) {
+  case MenuObject::StateScaleTLXY: 
+  case MenuObject::StateScaleTRXY: 
+  case MenuObject::StateScaleBLXY: 
+  case MenuObject::StateScaleBRXY: {
+    double fZoom   = (double)( iPos / 100.0 );
+    if (fZoom > 1.0)
+      fZoom = fZoom * 2.0 - 1.0;
+    
+    if ( ( m_objectState == MenuObject::StateScaleTLXY ) || 
+	 ( m_objectState == MenuObject::StateScaleBLXY )  )
+      fZoom *= -1;
+    modifiers( )->fScaleX *= (1.0 + fZoom);
+    modifiers( )->fScaleY *= (1.0 + fZoom);
+    update   ( );
+  }
+  break;
+  case MenuObject::StateScaleLeftX: 
+  case MenuObject::StateScaleRightX: {
+    double fZoom   = (double)( iPos / 100.0 );
+    if (fZoom > 1.0)
+      fZoom = fZoom * 2.0 - 1.0;
+
+    if ( m_objectState == MenuObject::StateScaleLeftX )
+      fZoom *= -1;
+
+    modifiers( )->fScaleX *= (1.0 + fZoom);
+    update   ( );
+  }
+  break;
+  case MenuObject::StateScaleTopY:
+  case MenuObject::StateScaleBottomY: {
+    iPos = pEvent->pos().y() - m_currentMousePos.y();
+    double fZoom   = (double)( iPos / 100.0 );
+    if (fZoom > 1.0)
+      fZoom = fZoom * 2.0 - 1.0;
+    
+    if ( m_objectState == MenuObject::StateScaleTopY )
+      fZoom *= -1;
+    modifiers( )->fScaleY *= (1.0 + fZoom);
+    update   ( );
+  }
+  break;
+  case MenuObject::StateRotate: {
+    double fRotate = (double)iPos;
+    modifiers( )->fRotate += fRotate;
+    update   ( );
+  }
+  break;
+  case MenuObject::StateMoveObject:
+  default:
+    iX = rect().x() - (m_currentMousePos.x() - pEvent->pos().x());
+    iY = rect().y() - (m_currentMousePos.y() - pEvent->pos().y());
+    iWidth  = rect( ).width  ( );
+    iHeight = rect( ).height ( );
+    theRect.setX  ( iX );
+    theRect.setY  ( iY );
+    theRect.setWidth  ( iWidth  );
+    theRect.setHeight ( iHeight );
+    
+    setRect(theRect);
+    break;
+  }
+  m_currentMousePos = pEvent->pos();
+
+  //  char arrayState[][30] = { "StateUnknown", "StateInactive", "StateMoveObject", "StateScaleTLXY", "StateScaleTRXY", "StateScaleBLXY", "StateScaleBRXY", "StateScaleLeftX", "StateScaleRightX", "StateScaleTopY", "StateScaleBottomY", "StateRotate" };
+  //  printf ( "MenuObject::mouseMoveEvent objState<%s>\n", arrayState[m_objectState] );
+  return false;
+}
+
+void MenuObject::setObjectState ( enState newState )
+{
+  m_objectState = newState;
+}
+
+// the state of the mouse operation.
+// This function checks wether the mouse was pressed above a hot spot 
+// Resize / rotate etc. or not.
+MenuObject::enState MenuObject::setObjectState ( QPoint &pos )
+{
+  m_objectState = StateMoveObject;
+  int iHeight2, iWidth2, iX, iY;
+  QRect theRect = m_boundingRect;
+
+  iX = pos.x( );
+  iY = pos.y( );
+  iWidth2  = theRect.x( ) + (int)((float) theRect.width  ( )  / 2.0 );
+  iHeight2 = theRect.y( ) + (int)((float) theRect.height ( )  / 2.0 );
+  if ( iX < theRect.x() + HANDLE_WIDTH ) { // left side
+    if ( iY < theRect.y() + HANDLE_HEIGHT )
+      m_objectState = StateScaleTLXY; // upper left corner
+    else if ( iY > theRect.y( ) + theRect.height ( ) - HANDLE_HEIGHT )
+      m_objectState = StateScaleBLXY; // lower left corner
+    else if ( ( iY > iHeight2 - HANDLE_HEIGHT ) && 
+	      ( iY < iHeight2 + HANDLE_HEIGHT )  )
+      m_objectState = StateScaleLeftX;  // left side center handle
+  }
+  else if ( iX > theRect.x( ) + theRect.width () - HANDLE_WIDTH ) { // right side
+    if ( iY < theRect.y( ) + HANDLE_HEIGHT )
+      m_objectState = StateScaleTRXY; // upper right corner
+    else if ( iY > theRect.y( ) + theRect.height ( ) - HANDLE_HEIGHT )
+      m_objectState = StateScaleBRXY; // lower right corner
+    else if ( ( iY > iHeight2 - HANDLE_HEIGHT ) && 
+	      ( iY < iHeight2 + HANDLE_HEIGHT )  )
+      m_objectState = StateScaleRightX;  // right side center handle
+  }
+  else if ( iY < theRect.y() + HANDLE_HEIGHT ) {  // upper handle in the center
+    if ( ( iX > iWidth2 - HANDLE_WIDTH ) && ( iX < iWidth2 + HANDLE_WIDTH ) )
+      m_objectState = StateScaleTopY;
+  }
+  else if ( iY > theRect.y() + theRect.height() - HANDLE_HEIGHT ) { // lower handle in the center
+    if ( ( iX > iWidth2 - HANDLE_WIDTH ) && ( iX < iWidth2 + HANDLE_WIDTH ) )
+      m_objectState = StateScaleBottomY;
+  }
+  else if ( ( iX > iWidth2  - HANDLE_WIDTH  ) && ( iX < iWidth2  + HANDLE_WIDTH  ) &&
+	    ( iY > iHeight2 - HANDLE_HEIGHT ) && ( iY < iHeight2 + HANDLE_HEIGHT ) ) {
+    m_objectState = StateRotate;
+  }
+  return m_objectState;
+}
+
+void MenuObject::drawActiveFrame ( QPainter *pPainter )
+{
+  QBrush theBrush ( yellow );
+  QRect theRect = m_boundingRect;
+  int iHeight2, iWidth2, iRight, iBottom;
+  
+  iWidth2  = theRect.x( ) + (int)((float) theRect.width  ( )  / 2.0 );
+  iHeight2 = theRect.y( ) + (int)((float) theRect.height ( )  / 2.0 );
+  iRight   = theRect.x( ) + theRect.width  ( ) - HANDLE_WIDTH;
+  iBottom  = theRect.y( ) + theRect.height ( ) - HANDLE_HEIGHT;
+
+  pPainter->drawRect ( theRect ); // the full rect
+  // top left
+  pPainter->fillRect ( theRect.x(), theRect.y(), HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );
+  // top right
+  pPainter->fillRect ( iRight, theRect.y(), HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );
+  // top center
+  pPainter->fillRect ( iWidth2 - (int)(HANDLE_WIDTH / 2.0), theRect.y(), HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );
+
+  // bottom left
+  pPainter->fillRect ( theRect.x(), iBottom, HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );
+  // bottom right
+  pPainter->fillRect ( iRight, iBottom, HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );
+  // bottom center
+  pPainter->fillRect ( iWidth2 - (int)(HANDLE_WIDTH / 2.0), iBottom, HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );
+
+  // left center
+  pPainter->fillRect ( theRect.x(), iHeight2 - (int)(HANDLE_HEIGHT / 2.0), HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );
+  // right center
+  pPainter->fillRect ( iRight, iHeight2 - (int)(HANDLE_HEIGHT / 2.0), HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );
+
+  // center
+  //  pPainter->fillRect ( iWidth2 - (int)(HANDLE_WIDTH / 2.0), iHeight2 - (int)(HANDLE_HEIGHT / 2.0), HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );
+  pPainter->drawEllipse ( iWidth2 - (int)(HANDLE_WIDTH / 2.0), iHeight2 - (int)(HANDLE_HEIGHT / 2.0), HANDLE_WIDTH, HANDLE_HEIGHT );
+}
+
+// called from ButtonPreview::releaseMouseEvent, to reset active object.
+bool MenuObject::isActive ()
+{
+  return m_bDrawRect;
+}
+
+void MenuObject::setActive ( bool bActive )
+{
+  m_bDrawRect = bActive;
+}
+
+MenuObject *MenuObject::shadow ( ) 
+{
+  return m_pShadow;
+}
+
+void MenuObject::setShadow ( MenuObject *pShadow )
+{
+  if ( m_pShadow )
+    delete m_pShadow;
+
+  m_pShadow = pShadow;
+}
+
+void MenuObject::updateShadow ( )
+{
+  if ( m_pShadow )
+       m_pShadow->updateShadow ( );
+}
+
 QRect   &MenuObject::rect()
 {
-	return m_rect;
+  return m_rect;
+}
+
+QPoint MenuObject::position ( )
+{
+  // returns the centered position ...
+  QPoint thePosition;
+  thePosition.setX ( m_rect.x ( ) + (int) ( (float)m_rect.width  ( ) / 2.0 ) );
+  thePosition.setY ( m_rect.y ( ) + (int) ( (float)m_rect.height ( ) / 2.0 ) );
+  return thePosition;
 }
 
 QRect   &MenuObject::boundingRect()
@@ -268,9 +496,24 @@ QRect   &MenuObject::boundingRect()
 
 void MenuObject::setRect(QRect &rect)
 {
-	m_rect = rect;
-	// The bounding rect is set by drawContents.
-	m_boundingRect = rect;
+  m_rect = rect;
+  // The bounding rect is set by drawContents.
+  m_boundingRect = rect;
+}
+
+void MenuObject::setPosition ( QPoint &position )
+{
+  int iWidth  = m_rect.width  ( );
+  int iHeight = m_rect.height ( );
+  int iX =  position.x () - (int)( (float) iWidth  / 2.0 );
+  int iY =  position.y () - (int)( (float) iHeight / 2.0 );
+  m_rect = QRect ( iX, iY, iWidth, iHeight );
+
+  iWidth  = m_boundingRect.width  ( );
+  iHeight = m_boundingRect.height ( );
+  iX =  position.x () - (int)( (float) iWidth  / 2.0 );
+  iY =  position.y () - (int)( (float) iHeight / 2.0 );
+  m_boundingRect = QRect ( iX, iY, iWidth, iHeight );
 }
 
 void MenuObject::setCurrentMousePos(QPoint &pos)
@@ -294,7 +537,12 @@ bool    MenuObject::drawRect()
 }
 
 MenuObject *MenuObject::clone()
-{
+{  
+	return NULL;
+}
+
+MenuObject *MenuObject::clone( MenuObject * )
+{  
 	return NULL;
 }
 
@@ -318,6 +566,12 @@ void MenuObject::slotDelete ()
 	emit (signalDeleteMe(this));
 }
 
+void MenuObject::slotAddShadow ( ) 
+{
+  // Send request back to be handled in MenuPreview ..
+  emit ( signalShadowMe ( this ) );
+}
+
 void MenuObject::slotToFront ()
 {
 	// Send it all the way to the front
@@ -394,7 +648,7 @@ void MenuObject::loadAnimationData (QString &qsFileName, long iMaxNumberOfFrames
 			qsValue = QString ("%1").arg(Qt::BevelJoin);
 		else if (qsValue == "RoundJoin")
 			qsValue = QString ("%1").arg(Qt::RoundJoin);
-//		printf ("load <%d> <%s>=<%s>\n", iFrameNumber, (const char *)qsProperty, (const char *)qsValue);
+		//printf ("MenuObject::loadAnimationData - load <%d> <%s>=<%s>\n", iFrameNumber, (const char *)qsProperty, (const char *)qsValue);
 
 		// This loop will check if this property is already taken care of and we have a array of values waiting.
 		for (t=0;t<m_listAnimationAttributes.count ();t++)	{
@@ -411,7 +665,15 @@ void MenuObject::loadAnimationData (QString &qsFileName, long iMaxNumberOfFrames
 			// (I.e. text for TextObject etc. )
 			pAnimAttr = getSpecificAttributes (iMaxNumberOfFrames, qsProperty);
 			if ( ! pAnimAttr )	{
-				if (qsProperty == QString("rect.x1"))	{
+				if (qsProperty == QString("pos.x"))	{
+				        FunctionCallback<MenuObject> *callMeBack = new FunctionCallback<MenuObject>(*this, &MenuObject::setPosition, &MenuObject::position, TYPE_POSITION_X );
+					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, position().x(), callMeBack);
+				}
+				else if (qsProperty == QString("pos.y"))	{
+				        FunctionCallback<MenuObject> *callMeBack = new FunctionCallback<MenuObject>(*this, &MenuObject::setPosition, &MenuObject::position, TYPE_POSITION_Y );
+					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, position().y(), callMeBack);
+				}
+				else if (qsProperty == QString("rect.x1"))	{
 					FunctionCallback<QRect> *callMeBack = new FunctionCallback<QRect>(m_rect, &QRect::setX);
 					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_rect.x(), callMeBack);
 				}
@@ -457,7 +719,7 @@ void MenuObject::loadAnimationData (QString &qsFileName, long iMaxNumberOfFrames
 			if (pAnimAttr)
 				m_listAnimationAttributes.append ( pAnimAttr );
 		}
-		if (pAnimAttr)
+		if ( ( pAnimAttr ) && ( ! bFound ) )
 			pAnimAttr->append (iFrameNumber, qsValue);
 	}
 	file.close();
