@@ -19,10 +19,10 @@
 #include <stdlib.h>
 
 #include <qfiledialog.h>
-#include <qmessagebox.h>
 #include <qdragobject.h>
 #include <qpopupmenu.h>
 #include <qlineedit.h>
+#include <qcheckbox.h>
 #include <qtextedit.h>
 #include <qpainter.h>
 #include <qcursor.h>
@@ -48,6 +48,9 @@
 #include "objectcollection.h"
 #include "listviewmedia.h"
 #include "dialogresize.h"
+#include "dialogshadow.h"
+#include "messagebox.h"
+#include "filepreviewdialog.h"
 #include "qplayer/engines/dummywidget.h"
 #include "qplayer/mediacreator.h"
 #include "qplayer/mediainfo.h"
@@ -66,16 +69,17 @@ MenuPreview::~MenuPreview()
 
 void MenuPreview::initMe (QColor *pColors)
 {
-	m_iCursorStyle       = Qt::ArrowCursor;
-	m_bActiveCursor      = false;
-	m_iCreateObjectStyle = TypeNone;
-	m_pActiveObject      = NULL;
-	m_pDialogButton      = NULL;
-	m_bIsSubMenu         = false;
-	m_bIsMovieMenu       = false;
-	m_pPgcColors         = NULL;
-	m_bImageButton       = true;
-	m_pPgcColors         = pColors;
+  m_iCreateObjectStyle = TypeNone;
+  m_iPointerState      = StateNormal;
+  m_pActiveObject      = NULL;
+  m_pDialogButton      = NULL;
+  m_bIsSubMenu         = false;
+  m_bIsMovieMenu       = false;
+  m_pPgcColors         = NULL;
+  m_bImageButton       = true;
+  m_pPgcColors         = pColors;
+
+  connect ( &m_selectionObject, SIGNAL ( signalMoveOnStack ( MenuObject *, int ) ), this, SLOT ( slotMoveOnStack ( MenuObject *, int ) ) );
 }
 
 void MenuPreview::clear (QColor *pColors)
@@ -116,44 +120,6 @@ void MenuPreview::setImageButton  (bool bImageButton)
 	m_bImageButton = bImageButton;
 }
 
-void MenuPreview::mousePressEvent (QMouseEvent *pEvent)
-{
-	// First we let the base class have it ...
-	m_bMouseEventDone = false;
-	ButtonPreview::mousePressEvent(pEvent);
-	// Here we check if the mouse click appeared withtin one of the MenuObjects,
-	// in which case the Object will take over the mouse handling ...
-	if (m_bMouseEventDone)
-		return;
-	QPoint thePos = pEvent->pos();
-	MenuObject *pObject = childContains(thePos);
-	if (pObject != NULL)	{
-		m_pActiveObject = pObject;
-		update();
-		return;
-	}
-	// Okay the user actually clicked in the MenuPreview ...
-	// The left mouse button was clicked.
-	// If the user is in creation mode, then we handle this one
-	if (pEvent->button () == LeftButton) 	{
-		// otherwise we simply return.
-		if (m_iCursorStyle == Qt::ArrowCursor)
-			return;
-		// Okay, at this point we know the user is creating an object.
-		m_bActiveCursor = true;
-		m_rectCurrentObject.setX(pEvent->pos().x());
-		m_rectCurrentObject.setY(pEvent->pos().y());
-		return;
-	}
-	// The right mousebutton was pressed means that we should display the context drop down menu.
-	m_iCursorStyle = Qt::ArrowCursor;
-	QCursor myCursor (m_iCursorStyle);
-	setCursor(myCursor);
-	m_bActiveCursor = false;
-
-	createContextMenu ( pEvent->globalPos () );
-}
-
 bool MenuPreview::createContextMenu ( QPoint globalPos )
 {
 	QPopupMenu *pMenu = new QPopupMenu (this);
@@ -177,54 +143,6 @@ bool MenuPreview::createContextMenu ( QPoint globalPos )
 	return true;
 }
 
-void MenuPreview::mouseReleaseEvent (QMouseEvent *pEvent)
-{
-	// First we let the base class have it ...
-	m_bMouseEventDone = false;
-	ButtonPreview::mouseReleaseEvent(pEvent);
-	// Here we check if the mouse click appeared withtin one of the MenuObjects,
-	// in which case the Object will take over the mouse handling ...
-	if (m_bMouseEventDone)
-		return;
-	if (childContains((QPoint &)pEvent->pos()) != NULL)	{
-		m_pActiveObject = NULL;
-//		updatePixmap();	taken care of in the child deja ...
-		update();
-		return;
-	}
-	m_pActiveObject = NULL;
-	// The user actually released the mousebutton in the MenuPreview - class.
-	// The left mouse button was released.
-	if (pEvent->button () == LeftButton) 	{
-		// If the user is not drawing a button, we'll return.
-		if (m_iCursorStyle == Qt::ArrowCursor)
-			return;
-		// The user is drawing a Button. Let us activate the drawing algol.
-		m_rectCurrentObject.setRight (pEvent->pos().x());
-		m_rectCurrentObject.setBottom (pEvent->pos().y());
-		m_iCursorStyle = Qt::ArrowCursor;
-		QCursor myCursor (m_iCursorStyle);
-		setCursor(myCursor);
-		m_bActiveCursor = false;
-		// Here we create the chosen object ...
-		switch (m_iCreateObjectStyle)	{
-		case MenuPreview::FrameType :
-			createFrameObject ();
-		break;
-		case MenuPreview::TextType :
-			createTextObject();
-		break;
-		case MenuPreview::ImageType :
-			createImageObject();
-		break;
-		case MenuPreview::MovieType :
-			createMovieObject ();
-		break;
-		}
-		update ();
-	}
-}
-
 void MenuPreview::mouseDoubleClickEvent	(QMouseEvent *pEvent)
 {
 	m_pActiveObject = NULL;
@@ -232,64 +150,253 @@ void MenuPreview::mouseDoubleClickEvent	(QMouseEvent *pEvent)
 	ButtonPreview::mouseDoubleClickEvent(pEvent);
 }
 
+void MenuPreview::mousePressEvent (QMouseEvent *pEvent)
+{
+  // First we let the base class have it ...
+  m_bMouseEventDone = false;
+  if ( m_selectionObject.mousePressEvent ( pEvent ) )
+    return;
+  ButtonPreview::mousePressEvent(pEvent);
+  // Here we check if the mouse click appeared withtin one of the MenuObjects,
+  // in which case the Object will take over the mouse handling ...
+  if (m_bMouseEventDone) {
+    m_iPointerState = StateNormal; // added to change state after Add Shadow was selected from ContextMenu...
+    return;
+  }
+
+  //  char arrayState[][30]={ "StateUnknown", "StateNormal", "StateMoveSelected", "StateReadyToCreate", "StateCreating", "StateSelecting", "StateSelected" };
+  //  printf ("MenuPreview::mousePressEvent pointerState<%s>\n", arrayState[m_iPointerState]);
+
+  QPoint      thePos  = pEvent->pos ( );
+  MenuObject *pObject = childContains ( thePos );
+
+  if ( ( pObject != NULL ) && ( m_iPointerState != StateSelected ) )	{
+    m_pActiveObject = pObject;
+    update();
+    return;
+  }
+  // Okay the user actually clicked in the MenuPreview ...
+  // The left mouse button was clicked.
+  // If the user is in creation mode, then we handle this one
+  if (pEvent->button () == LeftButton) {
+    // if the state is not StateReadyToCreate then we want to select
+    if ( m_iPointerState == StateReadyToCreate ) {
+      m_iPointerState = StateCreating;
+      drawBackground   ( m_doubleBuffer );
+      setMouseTracking ( true );
+    }
+    else if ( m_iPointerState == StateSelected ) {
+      if ( m_selectionObject.mouseOver ( pEvent->pos () ) ) {
+	m_iPointerState = StateMoveSelected;
+	m_selectionObject.setMoveState ( false );
+	m_selectionObject.setCurrentMousePos ( (QPoint &) pEvent->pos ( ) );
+	drawBackground   ( m_doubleBuffer );
+	setMouseTracking ( true );
+      }
+    }
+    else  {
+      if ( m_backgroundPixmap.isNull () )
+	return;
+      m_iPointerState = StateSelecting; 
+      setMouseCursor ( MouseCrossCursor );	// signals to be awaiting the next mouse click
+      // which will then generate the rectangle for this text button.
+      m_selectionObject.clear ( );
+      m_pActiveObject = &m_selectionObject;
+      drawBackground   ( m_doubleBuffer );
+    }
+    // Okay, at this point we know the user is creating an object.
+    m_rectCurrentObject.setX(pEvent->pos().x());
+    m_rectCurrentObject.setY(pEvent->pos().y());
+    return;
+  }
+  // The right mousebutton was pressed means that we should display the context drop down menu.
+  setMouseCursor ( MousePointerCursor );
+  m_iPointerState = StateNormal;
+  
+  createContextMenu ( pEvent->globalPos  ( ) );
+}
+
+void MenuPreview::mouseReleaseEvent (QMouseEvent *pEvent)
+{
+  // The user is doing something. Let us activate the drawing algol.
+  m_rectCurrentObject.setRight  ( pEvent->pos( ).x ( ) );
+  m_rectCurrentObject.setBottom ( pEvent->pos( ).y ( ) );
+
+  //  char arrayState[][30]={ "StateUnknown", "StateNormal", "StateMoveSelected", "StateReadyToCreate", "StateCreating", "StateSelecting", "StateSelected" };
+  //  printf ("MenuPreview::mouseReleaseEvent pointerState<%s>\n", arrayState[m_iPointerState]);
+
+  if (pEvent->button () == LeftButton) 	{
+    m_doubleBuffer = QPixmap ( );
+    switch ( m_iPointerState ) {
+    case StateMoveSelected: {
+      m_iPointerState = StateSelected;
+      m_selectionObject.setMoveState ( false );
+      updatePixmap ();
+      return;
+    }
+    case StateCreating: {
+      // First we let the base class have it ...
+      m_bMouseEventDone = false;
+      ButtonPreview::mouseReleaseEvent(pEvent);
+      // Here we check if the mouse click appeared withtin one of the MenuObjects,
+      // in which case the Object will take over the mouse handling ...
+      if ( m_bMouseEventDone ) 
+	setMouseTracking ( false );
+
+      m_pActiveObject = NULL;
+      switch ( m_iCreateObjectStyle )	{
+      case FrameType :
+        createFrameObject ();
+	break;
+      case TextType :
+	createTextObject();
+	break;
+      case ImageType :
+        createImageObject();
+      break;
+      case MovieType :
+        createMovieObject ();
+	break;
+      } // switch createObjectStyle
+      m_iPointerState = StateNormal;
+      return;
+    } // end of case StateCreating
+    case StateSelected: {
+      m_pActiveObject = NULL;
+      m_iPointerState = StateNormal;
+      m_selectionObject.setMoveState ( false );
+      update ( );
+      return;
+    }
+    case StateSelecting: {
+      if ( m_selectionObject.getCount () > 0 ) {
+	m_iPointerState = StateSelected;
+	setMouseTracking ( true );
+      }
+      else
+	m_iPointerState = StateNormal;
+      setMouseCursor ( MousePointerCursor );
+      update ();
+      return;
+    }
+    case StateNormal:        // nothing to do if we are in Normal Mouse Mode
+    case StateReadyToCreate: // Should neve happen ...
+    case StateUnknown:       // Something went wrong ...
+    default:                 // should never get here
+      if ( m_pActiveObject )
+	m_pActiveObject->mouseReleaseEvent ( pEvent ); // will call updatePixmap
+      else
+	updatePixmap ( );
+      m_pActiveObject = NULL;
+      return;
+    }
+  } //  end if LeftButton
+}
+
 void MenuPreview::mouseMoveEvent (QMouseEvent *pEvent)
 {
-	// This part will move the active object around ...
-	if (m_pActiveObject)	{
-		m_pActiveObject->mouseMoveEvent(pEvent);
-		update ();
-		return;
-	}
-	if (!m_bActiveCursor)
-		return;
-	// Okay at this point we have m_rectCurrentObject.x, and .y set
-	// Here we draw the dynamicly changing size of the rect.
+  //  char arrayState[][30]={ "StateUnknown", "StateNormal", "StateMoveSelected", "StateReadyToCreate", "StateCreating", "StateSelecting", "StateSelected" };
+  //  printf ("MenuPreview::mouseReleaseEvent pointerState<%s>\n", arrayState[m_iPointerState]);
 
-	// First we clear the contents of the previous rectangle
-	//	repaint(m_rectCurrentObject, FALSE);
-	int iX, iY, iX1, iY1, iX2, iY2;
-	iX  = pEvent->pos ( ).x ( );
-	iY  = pEvent->pos ( ).y ( );
-	iX1 = m_rectCurrentObject.x();
-	iY1 = m_rectCurrentObject.y();
-	
-	if ( iX1 > iX ) {
-	  iX2 = iX1 + 50;
-	  iX1 = iX  - 5;
-	}
-	else
-	  iX2 = iX  + 50;
-	if ( iY1 > iY ) {
-	  iY2 = iY1 + 20;
-	  iY1 = iY  - 5;
-	}
-	else
-	  iY2 = iY  + 20;
-	// give some extra space to be erased ...
-	iX1 -= 20;
-	iY1 -= 20;
-	iX2 += 50;
-	iY2 += 20;
-	// ensure it is within the boundaries ...
-	iX1 = ( iX1 < 0 ) ? 0 : iX1;
-	iY1 = ( iY1 < 0 ) ? 0 : iY1;
-	iX2 = ( iX2 > width  () ) ? width  () : iX2;
-	iY2 = ( iY2 > height () ) ? height () : iY2;
-	repaint ( iX1, iY1, iX + 50, iY + 20, FALSE ); 
-	//	repaint( FALSE );
-	QPainter thePainter (this);
-	QPen thePen (QColor (255, 30,30), 2, Qt::DashDotLine);
-	thePainter.setPen( thePen );
-	
-	m_rectCurrentObject.setRight  ( iX );
-	m_rectCurrentObject.setBottom ( iY );
-	thePainter.drawRect (m_rectCurrentObject);
-	thePainter.drawText ( iX+5, iY+15, QString ( "%1 : %2" ).arg( m_rectCurrentObject.width ( ) ).arg( m_rectCurrentObject.height ( ) ) );
+  switch ( m_iPointerState ) {
+  // The one state I dont need to care ...
+  case StateReadyToCreate:
+    return;
+  case StateMoveSelected:
+    m_selectionObject.mouseMoveEvent ( pEvent );
+    { // doubleBuffer does move the objecs as well, which I don't want
+      // I simply want to get rid of the flicker ...
+      QPixmap temp ( m_doubleBuffer );
+      QPainter thePainter;
+      thePainter.begin ( &temp, this );
+      m_selectionObject.drawSelected ( &thePainter );
+      thePainter.end ( );
+      bitBlt ( this, 0, 0, &temp );
+    }
+  break;
+  case StateSelected: {
+    // this case will take care of the state when multile objects have been selected
+    // and now the user is aboout to move those selected objects around.
+    // for this in-between-state, we want to display the mouse move cursor
+    // if inside one of the selected objects.
+    //    if ( m_selectionObject.mouseOver ( pEvent->pos () ) )
+    bool bMouseOver =  m_selectionObject.mouseOver ( pEvent->pos () );
+    //    printf ( "MenuPreview::mouseMoveEvent mouseOver<%s> - <%dx%d>\n", bMouseOver ? "true" : "false", pEvent->pos().x(), pEvent->pos().y() );
+    if ( bMouseOver )
+      setMouseCursor ( MouseMoveCursor    );
+    else 
+      setMouseCursor ( MousePointerCursor );
+    //    m_selectionObject.mouseMoveEvent ( pEvent );
+    //update ( );
+    return;
+  }
+  case StateSelecting:
+  case StateCreating: {
+    // Okay at this point we have m_rectCurrentObject.x, and .y set
+    // Here we draw the dynamicly changing size of the rect.
+    
+    // First we clear the contents of the previous rectangle
+    int iX, iY;
+    iX  = pEvent->pos ( ).x ( );
+    iY  = pEvent->pos ( ).y ( );
+    m_rectCurrentObject.setRight  ( iX );
+    m_rectCurrentObject.setBottom ( iY );
+    
+    // Double buffering ...
+    QPen     thePen   ( QColor ( 255,  30,  30 ), 2, Qt::DashDotLine );
+    QBrush   theBrush ( QColor ( 100, 255, 100 ),  Qt::Dense6Pattern );
+    QPainter thePainter;
+    QPixmap  doubleBuffer ( m_doubleBuffer );
+
+    thePainter.begin  ( &doubleBuffer, this );
+    
+    if ( m_iPointerState  == StateSelecting ) {
+      thePen = QPen  ( QColor ( 100, 255, 100 ), 1, Qt::SolidLine );
+      thePainter.setBrush ( theBrush );
+      checkSelection ( ); // Any objects added to m_selectionObject ?
+    }
+    else
+      thePen = QPen (QColor (255, 30,30), 2, Qt::DashDotLine);
+
+    thePainter.setPen   ( thePen );
+    m_selectionObject.drawSelected ( &thePainter );
+    thePainter.drawRect ( m_rectCurrentObject    );
+    thePainter.drawText ( iX+5, iY+15, QString   ( "%1 : %2" ).arg( m_rectCurrentObject.width ( ) ).arg( m_rectCurrentObject.height ( ) ) );
+    thePainter.end ( );
+
+    bitBlt ( this, 0, 0, &doubleBuffer );
+  }
+  break;
+  case StateUnknown:
+  case StateNormal:
+  default:
+    // This part will move the active object(s) around ...
+    //  if ( m_pActiveObject && m_iPointerState != StateSelecting ) {
+    if ( m_pActiveObject ) {
+      m_pActiveObject->mouseMoveEvent(pEvent);
+      update ( );
+      return;
+    }
+  }
+}
+
+void MenuPreview::checkSelection ()
+{
+  // Check if any object has been captured by the selection box.
+  uint t;
+  m_selectionObject.clear ( );
+  QRect rect = m_rectCurrentObject.normalize ();
+  for ( t=0;t<m_listMenuObjects.count ( );t++) {
+    if ( rect.intersects ( m_listMenuObjects.at ( t )->boundingRect ( ) ) ) {
+      MenuObject *pObject = m_listMenuObjects.at ( t );
+      m_selectionObject.append ( pObject, false );
+    }
+  }
 }
 
 void MenuPreview::slotEditTimeline ()
 {
-	emit (signalEditTimeline ());
+  emit (signalEditTimeline ());
 }
 
 void MenuPreview::dropEvent (QDropEvent *pDropEvent)
@@ -340,15 +447,15 @@ MenuObject *MenuPreview::insertDraggedObject (QDropEvent *pDropEvent, QImage &th
 	MenuObject *pMenuObject = NULL;
 	// The first thing to check is if this drop was initiated in the Toolbar
 	if ( pDropEvent->source() && (QString("m_pListViewAllSources") == pDropEvent->source()->name()) )	{
-		ListViewMedia *pListViewMedia = (ListViewMedia *)pDropEvent->source();
+		ListViewMedia   *pListViewMedia   = (ListViewMedia *)pDropEvent->source();
 		SourceFileEntry *pSourceFileEntry = pListViewMedia->draggingSourceFileEntry();
 		SourceFileInfo  *pSourceFileInfo  = pListViewMedia->draggingSourceFileInfo();
 		if ( pSourceFileEntry->bSoundSource )  {	// No adding of a sound source !
-			QMessageBox::warning (NULL, tr("Can not add."), tr ("This is a sound source.\nI can currently not add this type of source.\n"), QMessageBox::Ok, QMessageBox::NoButton);
+			MessageBox::warning (NULL, tr("Can not add."), tr ("This is a sound source.\nI can currently not add this type of source.\n"), QMessageBox::Ok, QMessageBox::NoButton);
 			return NULL;
 		}
 		if ( pSourceFileEntry->bIsSlideshow )	{
-			QMessageBox::warning (NULL, tr("Can not add."), tr ("The slideshow is still beeing created.\nI can not add it at this moment.\n"), QMessageBox::Ok, QMessageBox::NoButton);
+			MessageBox::warning (NULL, tr("Can not add."), tr ("The slideshow is still beeing created.\nI can not add it at this moment.\n"), QMessageBox::Ok, QMessageBox::NoButton);
 			return NULL;
 		}
 		if ( pSourceFileInfo)	// Okay here we split between adding one button
@@ -413,7 +520,7 @@ MenuObject *MenuPreview::insertDraggedSourceInfo(QDropEvent *pDropEvent, QImage
 	if (m_bImageButton)
 		pMenuObject = insertDraggedImage (pDropEvent, theImage);
 	else	{
-		pMenuObject = insertDraggedMovie (pDropEvent, theImage);
+	        pMenuObject = insertDraggedMovie (pDropEvent, theImage, pSourceFileInfo->iMSecPreview );
 		// Here we set the real name of the Movie file and not the one of the screenshot.
 		((MovieObject *)pMenuObject)->setFile (pSourceFileInfo->qsFileName);
 	}
@@ -545,7 +652,7 @@ MenuObject *MenuPreview::insertDraggedImage (QDropEvent *pDropEvent, QImage &the
 	return pImageObject;
 }
 
-MenuObject *MenuPreview::insertDraggedMovie (QDropEvent *pDropEvent, QImage &theImage)
+MenuObject *MenuPreview::insertDraggedMovie (QDropEvent *pDropEvent, QImage &theImage, long iMSecPreviewOffset )
 {
 	QPixmap thePixmap;
 	QRect   theRect;
@@ -573,11 +680,12 @@ MenuObject *MenuPreview::insertDraggedMovie (QDropEvent *pDropEvent, QImage &the
 		thePixmap.convertFromImage (theImage);
 	theRect   = QRect(thePoint.x(), thePoint.y(), iWidth, iHeight);
 	MovieObject *pMovieObject = new MovieObject (this);
-	pMovieObject->setZoom      (1.0f);
-	pMovieObject->setRect      (theRect);
-	pMovieObject->setPixmap    (thePixmap);
-//	pMovieObject->setFile      (qsFileName);
-	pMovieObject->setMovieSize (theSize);
+	pMovieObject->setZoom        ( 1.0f );
+	pMovieObject->setRect        ( theRect );
+	pMovieObject->setPixmap      ( thePixmap );
+	pMovieObject->setMSecPreview ( iMSecPreviewOffset );
+//	pMovieObject->setFile        ( qsFileName );
+	pMovieObject->setMovieSize   ( theSize );
 	m_pActiveObject = pMovieObject;
 	emit (signalCreatedMovieObject (pMovieObject, true));	// registerToRender
 
@@ -686,50 +794,45 @@ bool MenuPreview::writeProjectFile (QDomElement &theElement)
 	return true;
 }
 
-// The following three slots will add a button to the Menu.
+// The following slots will add a button to the Menu.
 void MenuPreview::slotAddFrameObject()
 {
-	m_iCursorStyle = Qt::CrossCursor;	// signals to be awaiting the next mouse click
-		// which will then generate the rectangle for this text button.
-	m_iCreateObjectStyle = MenuPreview::FrameType;
-	QCursor myCursor(m_iCursorStyle);
-	setCursor(myCursor);
+  setMouseCursor ( MouseCrossCursor );	// signals to be awaiting the next mouse click
+  // which will then generate the rectangle for this text button.
+  m_iCreateObjectStyle = FrameType;
+  m_iPointerState      = StateReadyToCreate;
 }
 
 void MenuPreview::slotAddTextObject()
 {
-	m_iCursorStyle = Qt::CrossCursor;	// signals to be awaiting the next mouse click
-		// which will then generate the rectangle for this text button.
-	m_iCreateObjectStyle = MenuPreview::TextType;
-	QCursor myCursor(m_iCursorStyle);
-	setCursor(myCursor);
+  setMouseCursor ( MouseCrossCursor );	// signals to be awaiting the next mouse click
+  // which will then generate the rectangle for this text button.
+  m_iCreateObjectStyle = TextType;
+  m_iPointerState      = StateReadyToCreate;
 }
 
 void MenuPreview::slotAddImageObject ()
 {
-	m_iCursorStyle = Qt::CrossCursor;	// signals to be awaiting the next mouse click
-		// which will then generate the rectangle for this text button.
-	m_iCreateObjectStyle = MenuPreview::ImageType;
-	QCursor myCursor(m_iCursorStyle);
-	setCursor(myCursor);
+  setMouseCursor ( MouseCrossCursor );	// signals to be awaiting the next mouse click
+  // which will then generate the rectangle for this text button.
+  m_iCreateObjectStyle = ImageType;
+  m_iPointerState      = StateReadyToCreate;
 }
 
 void MenuPreview::slotAddMovieObject ()
 {
-	m_iCursorStyle = Qt::CrossCursor;	// signals to be awaiting the next mouse click
-		// which will then generate the rectangle for this text button.
-	m_iCreateObjectStyle = MenuPreview::MovieType;
-	QCursor myCursor(m_iCursorStyle);
-	setCursor(myCursor);
+  setMouseCursor ( MouseCrossCursor );	// signals to be awaiting the next mouse click
+  // which will then generate the rectangle for this text button.
+  m_iCreateObjectStyle = MovieType;
+  m_iPointerState      = StateReadyToCreate;
 }
 
 void MenuPreview::slotAddCollection()
 {
-	m_iCursorStyle = Qt::CrossCursor;	// signals to be awaiting the next mouse click
-		// which will then generate the rectangle for this text button.
-	m_iCreateObjectStyle = MenuPreview::CollectionType;
-	QCursor myCursor(m_iCursorStyle);
-	setCursor(myCursor);
+  setMouseCursor ( MouseCrossCursor );	// signals to be awaiting the next mouse click
+  // which will then generate the rectangle for this text button.
+  m_iCreateObjectStyle = CollectionType;
+  m_iPointerState      = StateReadyToCreate;
 }
 
 void MenuPreview::createAnimationData (QString &qsMenuName, long iMaxFrames)
@@ -764,7 +867,8 @@ void MenuPreview::createAnimationData (QString &qsMenuName, long iMaxFrames)
 		chmod (qsFileName+QString(".sh"), 0777);// S_IEXEC | S_IRUSR | S_IWRITE);
 		qsCommand = QString ("\"%1.sh\" 2>/dev/null > \"%2.dat\"").arg (qsFileName).arg(qsFileName);
 //printf ("MenuPreview::createAnimationData <%s>\n", (const char *)qsCommand);
-		system ( qsCommand );
+		if ( system ( qsCommand ) == -1 )
+			return;
 		qsFileName += QString (".dat");
 		// Check if the file has some size to it ...
 		fileInfo.setFile (qsFileName);
@@ -778,17 +882,17 @@ void MenuPreview::createAnimationData (QString &qsMenuName, long iMaxFrames)
 
 MenuObject *MenuPreview::createFrameObject(bool bShowDialog)
 {
-	FrameObject *pFrameObject = new FrameObject (this);
-	pFrameObject->setRect		(m_rectCurrentObject);
-	pFrameObject->setFrameWidth  (4);
- 	pFrameObject->setFrameColor (QColor (START_FRAME_COLOR));
+	FrameObject *pFrameObject = new FrameObject ( this );
+	pFrameObject->setRect        ( m_rectCurrentObject );
+	pFrameObject->setFrameWidth  ( 4 );
+ 	pFrameObject->setFrameColor  ( QColor ( START_FRAME_COLOR ) );
 	if (bShowDialog)	{
-		m_listMenuObjects.append (pFrameObject);
-		emit (signalUpdateStructure());
-		updatePixmap();
+		m_listMenuObjects.append ( pFrameObject );
+		emit ( signalUpdateStructure ( ) );
+		updatePixmap ( );
 	}
 	// Here we connect the signal to the slot ...
-	connectStdSlots (pFrameObject);
+	connectStdSlots ( pFrameObject );
 
 	return pFrameObject;
 }
@@ -838,45 +942,48 @@ MenuObject *MenuPreview::createImageObject(bool bShowDialog)
 	ImageObject *pImageObject = NULL;
 
 	if (bShowDialog)	{
-		// The first step is to get the image name
-		QString qsImageName = QFileDialog::getOpenFileName(Global::qsCurrentPath, tr("Image Files (*.jpg *.jpeg *.png *.xbm *.bmp *.JPG *.JPEG *.PNG *.XBM *.BMP)"), this,
-		tr("Select image"), tr("Select a image object."));
-		if (qsImageName.isNull())
-			return NULL;
+	  // The first step is to get the image name
+	  QString qsImageFilter      = "*.jpg *.jpeg *.png *.xbm *.bmp *.JPG *.JPEG *.PNG *.XBM *.BMP";
 
-		QFileInfo fileInfo  (qsImageName);
-		Global::qsCurrentPath = fileInfo.filePath();
+	  //	  QString qsImageName = QFileDialog::getOpenFileName(Global::qsCurrentPath, tr("Image Files (*.jpg *.jpeg *.png *.xbm *.bmp *.JPG *.JPEG *.PNG *.XBM *.BMP)"), this,
+	  QString qsImageName = FilePreviewDialog::getOpenFileName ( NULL, Global::qsCurrentPath, QString ("Images ( ") + qsImageFilter + QString (" );;All ( * )"), this, 
+	      tr("Select image"), tr("Select a image object."));
+	  if (qsImageName.isNull())
+	    return NULL;
+	  
+	  QFileInfo fileInfo  (qsImageName);
+	  Global::qsCurrentPath = fileInfo.filePath();
 
-		// Here we create the Pixmap in the right scale
-		QImage theImage (qsImageName);
-		int iWidth, iHeight;
-		float fZoom;
-		// Keep aspect ratio
-		iWidth  = m_rectCurrentObject.width();
-		iHeight = (int)((float)theImage.height()/theImage.width()*m_rectCurrentObject.width());
-		fZoom = ((float)m_rectCurrentObject.width() / theImage.width());
-		// Convert the image and generate the Pixmap
-		theImage = theImage.smoothScale (iWidth, iHeight);	//, QImage::ScaleMin);
-		QPixmap thePixmap;
-		thePixmap.convertFromImage(theImage);
-		// Clear memory ...
-		theImage = QImage ();
-		// And here we adopt the rect the user has drawn.
-		m_rectCurrentObject.setHeight(iHeight);
-		// Finally we create the ImageObject
-		pImageObject = new ImageObject (this);
-		pImageObject->setRect (m_rectCurrentObject);
-		pImageObject->setZoom (fZoom);	// We want to say Zoom = 1.0 even if the original size is already zoomed.
-		pImageObject->setFile(qsImageName);
-		pImageObject->setPixmap(thePixmap);
+	  // Here we create the Pixmap in the right scale
+	  QImage theImage (qsImageName);
+	  int iWidth, iHeight;
+	  float fZoom;
+	  // Keep aspect ratio
+	  iWidth  = m_rectCurrentObject.width();
+	  iHeight = (int)((float)theImage.height()/theImage.width()*m_rectCurrentObject.width());
+	  fZoom = ((float)m_rectCurrentObject.width() / theImage.width());
+	  // Convert the image and generate the Pixmap
+	  theImage = theImage.smoothScale (iWidth, iHeight);	//, QImage::ScaleMin);
+	  QPixmap thePixmap;
+	  thePixmap.convertFromImage(theImage);
+	  // Clear memory ...
+	  theImage = QImage ();
+	  // And here we adopt the rect the user has drawn.
+	  m_rectCurrentObject.setHeight(iHeight);
+	  // Finally we create the ImageObject
+	  pImageObject = new ImageObject (this);
+	  pImageObject->setRect (m_rectCurrentObject);
+	  pImageObject->setZoom (fZoom);	// We want to say Zoom = 1.0 even if the original size is already zoomed.
+	  pImageObject->setFile(qsImageName);
+	  pImageObject->setPixmap(thePixmap);
 
-		m_listMenuObjects.append (pImageObject);
-		emit (signalUpdateStructure());
-		updatePixmap();
+	  m_listMenuObjects.append (pImageObject);
+	  emit (signalUpdateStructure());
+	  updatePixmap();
 	}
 	else
-		pImageObject = new ImageObject (this);
-
+	  pImageObject = new ImageObject (this);
+	
 	// And last we connect the signals
 	connectStdSlots (pImageObject);
 	connect (pImageObject, SIGNAL(signalModifyMe(MenuObject *)), this, SLOT(slotModifyObject(MenuObject *)));
@@ -894,8 +1001,12 @@ MenuObject *MenuPreview::createMovieObject(bool bShowDialog)
 		// to speed things up we create a dummyMediaInfo first
 		MediaInfo *pMediaInfo = (MediaInfo *) new DummyInfo ();
 		QString qsFilter = tr ("Movie Files (%1)").arg(pMediaInfo->getExtensions (true));
-		QString qsMovieName = QFileDialog::getOpenFileName(Global::qsCurrentPath, qsFilter, this,
-		tr("Select movie"), tr("Select a movie object."));
+
+
+		//QString qsMovieName = QFileDialog::getOpenFileName(Global::qsCurrentPath, qsFilter, this, 
+		//	tr("Select movie"), tr("Select a movie object."));
+		QString qsMovieName = FilePreviewDialog::getOpenFileName ( NULL, Global::qsCurrentPath, QString ("Movies ( ") + qsFilter + QString (" );;All ( * )"), this, 
+			tr("Select image"), tr("Select a image object."));
 		if (qsMovieName.isNull())
 			return NULL;
 		QCursor myCursor (QCursor::WaitCursor);
@@ -1045,7 +1156,7 @@ MenuObject *MenuPreview::createButtonObject(bool bShowDialog)
 
 MenuObject *MenuPreview::createObjectCollection(bool)
 {
-	QMessageBox::warning (NULL, tr ("Not Implemented yet."), tr ("createObjectCollection : Not Implemented yet."),
+	MessageBox::warning (NULL, tr ("Not Implemented yet."), tr ("createObjectCollection : Not Implemented yet."),
 		QMessageBox::Ok ,  QMessageBox::Cancel);
 	updatePixmap();
 	return NULL;
@@ -1057,23 +1168,23 @@ void MenuPreview::setVisibleRegion (bool bVisibleOn)
 	updatePixmap ();
 }
 
-void MenuPreview::slotDefineAsButton(MenuObject *pTheObject)
+void MenuPreview::slotDefineAsButton ( MenuObject *pTheObject )
 {
 	// This is interesting ...
 	// first we need to create a ButtonObject,
 	// which we then furnish with three copies of this TextObject
 	// Namely: Normal, Selected, and Highlighted ...
-	m_listMenuObjects.remove (pTheObject);
-	ButtonObject *pButtonObject = new ButtonObject (this);
+	m_listMenuObjects.remove ( pTheObject );
+	ButtonObject *pButtonObject = new ButtonObject ( this );
 	// Now we generate two copies ...
 	MenuObject *pNewSelected, *pNewHighlighted;
 	TextObject  textObject;
 	FrameObject frameObject;
 
-	QColor colorTransparent (TRANSPARENT_COLOR);
- 	QColor colorHighlighted (START_HIGHLIGHTED_COLOR);
-	QColor colorSelected    (START_SELECTED_COLOR);
-	QColor colorSpare       (TRANSPARENT_COLOR);
+	QColor colorTransparent ( TRANSPARENT_COLOR       );
+ 	QColor colorHighlighted ( START_HIGHLIGHTED_COLOR );
+	QColor colorSelected    ( START_SELECTED_COLOR    );
+	QColor colorSpare       ( TRANSPARENT_COLOR       );
 	if (m_pPgcColors)	{
 		colorTransparent = m_pPgcColors[0];
  		colorHighlighted = m_pPgcColors[1];
@@ -1082,9 +1193,12 @@ void MenuPreview::slotDefineAsButton(MenuObject *pTheObject)
 	}
 
 	pNewSelected = pNewHighlighted = NULL;
-	if (pTheObject->objectType() == textObject.objectType())	{
-		pNewSelected = pTheObject->clone();
-		pNewHighlighted = pTheObject->clone();
+	if ( pTheObject->objectType ( ) == textObject.objectType ( ) )  {
+		pNewSelected    = pTheObject->clone ( );
+		pNewHighlighted = pTheObject->clone ( );
+		// Only the 'normal' object should have a shadow
+		pNewSelected   ->setShadow ( NULL );
+		pNewHighlighted->setShadow ( NULL );
 		// Next we give some color differences for the different states (TextObjects)
 		((TextObject *)(pNewSelected))   ->setForegroundColor (colorSelected);
 		((TextObject *)(pNewHighlighted))->setForegroundColor (colorHighlighted);
@@ -1102,45 +1216,45 @@ void MenuPreview::slotDefineAsButton(MenuObject *pTheObject)
 	else	{	// All but Text Objects get a frame for starters
 		// Okay we want 1:1 for FrameObjects
 		if (pTheObject->objectType() == frameObject.objectType())	{
-			pNewSelected = pTheObject->clone();
+			pNewSelected    = pTheObject->clone();
 			pNewHighlighted = pTheObject->clone();
 		}
 		else	{	// for ImageObject, and MovieObject a standard frame
-			pNewSelected = new FrameObject;
+			pNewSelected    = new FrameObject;
 			pNewHighlighted = new FrameObject;
-			pNewSelected->setRect(pTheObject->rect());
-			pNewHighlighted->setRect(pTheObject->rect());
-			pNewSelected->setModifiers(*pTheObject->modifiers());
-			pNewHighlighted->setModifiers(*pTheObject->modifiers());
-			((FrameObject *)(pNewSelected))->setFrameWidth(10);
-			((FrameObject *)(pNewHighlighted))->setFrameWidth(10);
+			pNewSelected->setRect        (  pTheObject->rect      ( ) );
+			pNewHighlighted->setRect     (  pTheObject->rect      ( ) );
+			pNewSelected->setModifiers   ( *pTheObject->modifiers ( ) );
+			pNewHighlighted->setModifiers( *pTheObject->modifiers ( ) );
+			((FrameObject *)(pNewSelected))->setFrameWidth       ( 10 );
+			((FrameObject *)(pNewHighlighted))->setFrameWidth    ( 10 );
 		}
 		// Next we give some color the the diffenrent states
-		((FrameObject *)(pNewSelected))   ->setFrameColor (colorSelected);
-		((FrameObject *)(pNewHighlighted))->setFrameColor (colorHighlighted);
+		((FrameObject *)(pNewSelected))   ->setFrameColor ( colorSelected    );
+		((FrameObject *)(pNewHighlighted))->setFrameColor ( colorHighlighted );
 	}
-	pButtonObject->appendNormal (pTheObject);
-	pButtonObject->appendSelected (pNewSelected);
-	pButtonObject->appendHighlighted (pNewHighlighted);
+	pButtonObject->appendNormal      ( pTheObject      );
+	pButtonObject->appendSelected    ( pNewSelected    );
+	pButtonObject->appendHighlighted ( pNewHighlighted );
 
-	pButtonObject->setName(newButtonName());
+	pButtonObject->setName ( newButtonName ( ) );
 	// Next we should give the button the same attributes as the NormalState ...
 	// rect and boundingRect are taken care of in drawContent
-	pButtonObject->setModifiers(*pTheObject->modifiers());
+	pButtonObject->setModifiers ( *pTheObject->modifiers ( ) );
 
 	// and here we append the button object as a new item in the MenuObject list.
-	m_listMenuObjects.append(pButtonObject);
+	m_listMenuObjects.append ( pButtonObject );
 	m_pActiveObject = NULL;
 	// Create the buttonDialog, so the user can change things around ...
-	slotCreateButtonDialog(pButtonObject);
-	if (m_pDialogButton)
-		m_pDialogButton->setButtonCreation(true);
+	slotCreateButtonDialog ( pButtonObject );
+	if ( m_pDialogButton )
+	     m_pDialogButton->setButtonCreation ( true );
 	// And finally we connect everything ...
 	connectStdSlots (pButtonObject);
-	connect (pNewSelected,    SIGNAL(signalDeleteMe(MenuObject *)), this, SLOT(slotDeleteObject(MenuObject *)));
-	connect (pNewHighlighted, SIGNAL(signalDeleteMe(MenuObject *)), this, SLOT(slotDeleteObject(MenuObject *)));
-	connect (pButtonObject,   SIGNAL(signalUnbuttonMe(ButtonObject *)),        this, SLOT(slotUnbutton          (ButtonObject *)));
-	connect (pButtonObject,   SIGNAL(signalCreateButtonDialog(ButtonObject *)),this, SLOT(slotCreateButtonDialog(ButtonObject *)));
+	connect ( pNewSelected,    SIGNAL(signalDeleteMe   ( MenuObject *   ) ), this, SLOT ( slotDeleteObject ( MenuObject   * ) ) );
+	connect ( pNewHighlighted, SIGNAL(signalDeleteMe   ( MenuObject *   ) ), this, SLOT ( slotDeleteObject ( MenuObject   * ) ) );
+	connect ( pButtonObject,   SIGNAL(signalUnbuttonMe ( ButtonObject * ) ), this, SLOT ( slotUnbutton     ( ButtonObject * ) ) );
+	connect ( pButtonObject,   SIGNAL(signalCreateButtonDialog ( ButtonObject * ) ), this, SLOT ( slotCreateButtonDialog ( ButtonObject * ) ) );
 }
 
 void MenuPreview::slotCreateButtonDialog(ButtonObject *pButtonObject)
@@ -1233,6 +1347,28 @@ void MenuPreview::slotDeleteObject(MenuObject *pObject)
 	emit (signalUpdateStructure());
 }
 
+void MenuPreview::slotAddShadow ( MenuObject *pObject ) 
+{
+  QPixmap thePixmap ( m_backgroundPixmap );
+  if ( m_backgroundPixmap.isNull ( ) )
+    thePixmap = QPixmap ( 720, 480 );
+
+  // Here we create the background without the current object
+  // (we want to move that one around right ?)
+  QPainter thePainter(&thePixmap);
+  for ( uint t=0; t<m_listMenuObjects.count ( ); t++ )  {
+    if ( m_listMenuObjects.at ( t ) != pObject)
+      m_listMenuObjects.at ( t )->drawContents ( &thePainter );
+  }
+
+  DialogShadow dialog ( this );
+  dialog.initMe       ( pObject,    &thePixmap );
+  if ( dialog.exec    ( ) == QDialog::Rejected )
+    return;
+
+  updatePixmap ( );
+}
+
 // This is the slow version but 100% functional, I will correct this some time soon.
 void MenuPreview::slotModifyObject(MenuObject *pObject)
 {
@@ -1265,7 +1401,7 @@ void MenuPreview::slotModifyObject(MenuObject *pObject)
 	pManipulator->fStartY = ((float)pImage->rect().y() / height());
 //	pManipulator->backgroundFileName = qsBackgroundImage;
 
-	DialogImage imageDialog(this);
+	DialogImage imageDialog ( this );
 	// Before we initialize this we need to look at the modifiers of this ImageObject.
 
 	imageDialog.initMe ((void *)&theImageStruct, qsBackgroundImage);
@@ -1283,6 +1419,11 @@ void MenuPreview::slotModifyObject(MenuObject *pObject)
 				m_listMenuObjects.at(t)->drawContents (&thePainter);
 		}
 		pPreview->setBackground(thePixmap, false);
+		//imageDialog.slotBackgroundToggled ( true );
+		pPreview->toggleBackground ( true );
+		imageDialog.m_pCheckBackground->setChecked  ( true  );
+		imageDialog.m_pCheckBackground->setEnabled  ( false );
+		imageDialog.m_pButtonBackground->setEnabled ( false );
 	}
 	pPreview->refreshPreview();
 	if (imageDialog.exec() == QDialog::Rejected)
@@ -1294,6 +1435,7 @@ void MenuPreview::slotModifyObject(MenuObject *pObject)
 	QRect newRect = pPreview->getRect();
 	// Next we need to compensate for the ImageObjects drawing offset (rect/2)
 	pImage->setRect(newRect);
+	//	pImage->updateShadow ( );
 	updatePixmap();
 }
 
@@ -1376,22 +1518,30 @@ void MenuPreview::slotUnbutton(ButtonObject *pButton)
 {
 	uint t=0;
 	MenuObject *pObject;
+	ImageObject tempImage;
+	MovieObject tempMovie;
 	m_listMenuObjects.remove(pButton);
 
 	for (t=0;t<pButton->getNormalCount();t++)	{
 		pObject = pButton->getNormal(t);
 		pObject->setCurrentMousePos (pButton->currentMousePos());
 		m_listMenuObjects.append (pObject);
+		connectStdSlots ( pObject );
+		if ( ( pObject->objectType ( ) == tempImage.objectType ( ) ) || 
+		     ( pObject->objectType ( ) == tempMovie.objectType ( ) ) )
+		  connect ( pObject, SIGNAL(signalModifyMe(MenuObject *)), this, SLOT(slotModifyObject(MenuObject *)));
 	}
 	for (t=0;t<pButton->getHighlightedCount();t++)	{
 		pObject = pButton->getHighlighted(t);
-		pObject->setCurrentMousePos (pButton->currentMousePos());
-		m_listMenuObjects.append (pObject);
+		delete pObject;
+		//pObject->setCurrentMousePos (pButton->currentMousePos());
+		//m_listMenuObjects.append (pObject);
 	}
 	for (t=0;t<pButton->getSelectedCount();t++)	{
 		pObject = pButton->getSelected(t);
-		pObject->setCurrentMousePos (pButton->currentMousePos());
-		m_listMenuObjects.append (pObject);
+		delete pObject;
+		//pObject->setCurrentMousePos (pButton->currentMousePos());
+		//m_listMenuObjects.append (pObject);
 	}
 	delete pButton;
 	emit (signalUpdateStructure());
@@ -1443,10 +1593,10 @@ QString &MenuPreview::newButtonName()
 
 void MenuPreview::connectStdSlots (MenuObject *pObject)
 {
-	connect (pObject, SIGNAL(signalDefineAsButton(MenuObject *)), this, SLOT(slotDefineAsButton(MenuObject *)));
-	connect (pObject, SIGNAL(signalDeleteMe(MenuObject *)), this, SLOT(slotDeleteObject(MenuObject *)));
-	connect (pObject, SIGNAL(signalUpdateStructure()), this, SLOT(slotUpdateStructure()));
-	connect (pObject, SIGNAL(signalUpdatePixmap()), this, SLOT(slotUpdatePixmap()));
-	connect (pObject, SIGNAL(signalMoveOnStack(MenuObject *, int)),   
-		this, SLOT(slotMoveOnStack(MenuObject *, int)));
+	connect (pObject, SIGNAL ( signalUpdateStructure( ) ),              this, SLOT ( slotUpdateStructure( ) ) );
+	connect (pObject, SIGNAL ( signalUpdatePixmap   ( ) ),              this, SLOT ( slotUpdatePixmap   ( ) ) );
+	connect (pObject, SIGNAL ( signalDefineAsButton ( MenuObject * ) ), this, SLOT ( slotDefineAsButton ( MenuObject * ) ) );
+	connect (pObject, SIGNAL ( signalDeleteMe       ( MenuObject * ) ), this, SLOT ( slotDeleteObject   ( MenuObject * ) ) );
+	connect (pObject, SIGNAL ( signalShadowMe       ( MenuObject * ) ), this, SLOT ( slotAddShadow      ( MenuObject * ) ) );
+	connect (pObject, SIGNAL ( signalMoveOnStack( MenuObject *, int) ), this, SLOT ( slotMoveOnStack    ( MenuObject *, int ) ) );
 }
