@@ -13,7 +13,6 @@
 ****************************************************************************/
 #include <stdlib.h>
 
-#include <qmessagebox.h>
 #include <qfileinfo.h>
 #include <qlineedit.h>
 #include <qpainter.h>
@@ -27,6 +26,7 @@
 #include "dragndropcontainer.h"
 #include "structuretoolbar.h"
 #include "dialogmovie.h"
+#include "messagebox.h"
 #include "qplayer/mediacreator.h"
 #include "qrender/startmenurender.h"
 
@@ -35,8 +35,9 @@ MovieObject::MovieObject (QWidget *pParent)
 {
 	m_qsObjectType  = QString (MOVIE_OBJECT);
 	m_pConvertTimer = NULL;
-	m_pDVDMenu = NULL;
-	m_bExtracted = false;
+	m_pDVDMenu      = NULL;
+	m_bExtracted    = false;
+	m_iMSecPreview  = 0;
 }
 
 MovieObject::~MovieObject ()
@@ -60,6 +61,11 @@ void MovieObject::setDuration (QTime &timeDuration)
 	m_timeDuration = timeDuration;
 }
 
+void MovieObject::setMSecPreview ( long iMSecPreview )
+{
+	m_iMSecPreview = iMSecPreview;
+}
+
 QTime &MovieObject::offset    ()
 {
 	return m_timeOffset;
@@ -70,6 +76,11 @@ QTime &MovieObject::duration  ()
 	return m_timeDuration;
 }
 
+long MovieObject::msecPreview  ()
+{
+	return m_iMSecPreview;
+}
+
 void MovieObject::setMovieSize (QSize &sizeMovie)
 {
 	m_sizeOriginalMovieSize = sizeMovie;
@@ -132,7 +143,13 @@ void MovieObject::setPixmap(QPixmap &thePixmap)
 
 	updatePixmap (); 
 
-	MediaCreator::registerWithMediaScanner (this, qsFileName, &m_imagePreview);
+	MediaCreator::registerWithMediaScanner (this, qsFileName, &m_imagePreview, m_iMSecPreview );
+}
+
+void MovieObject::slotSetThumbnail ( long iMSecPreview )
+{
+  m_iMSecPreview = iMSecPreview;
+  MediaCreator::registerWithMediaScanner (this, m_qsFileName, &m_imagePreview, m_iMSecPreview );
 }
 
 void MovieObject::timerEvent(QTimerEvent *pTimerEvent)
@@ -242,6 +259,7 @@ void MovieObject::slotProperties ()
 		m_pConvertTimer->stop();
 
 	DialogMovie movieDialog (NULL);
+	connect ( &movieDialog, SIGNAL ( signalSetThumbnail ( long ) ), this, SLOT ( slotSetThumbnail ( long ) ) );
 	movieDialog.initMe(this); 
 	if (movieDialog.exec() == QDialog::Accepted)	{
 		int iX, iY, iWidth, iHeight;
@@ -268,6 +286,7 @@ void MovieObject::slotProperties ()
 		emit (signalUpdatePixmap());
 		updatePixmap ();
 	}
+	disconnect ( &movieDialog, SIGNAL ( signalSetThumbnail ( long ) ), this, SLOT ( slotSetThumbnail ( long ) ) );
 
 	// And finally we re-start the timer (or start a new time to extract the propper images.
 	// Note: this can be done bacause I will check a status file first before extracting the frames, 
@@ -302,7 +321,7 @@ void MovieObject::slotStartConverting ()
 	}
 	// first we check if we have valid data.
 	if ( duration () == zeroTime )	{
-		QMessageBox::warning(NULL, tr("No time left."), tr("Warning I found a length of 0 for MovieButton <%1>.\nFrom Offset %2 with a duration of %3\n\nPlease adjust Offset or Duration for this Object.").arg(fileName()).arg(offset().toString (qsFormat)).arg(duration().toString(qsFormat)), QMessageBox::Ok, QMessageBox::NoButton);
+		MessageBox::warning(NULL, tr("No time left."), tr("Warning I found a length of 0 for MovieButton <%1>.\nFrom Offset %2 with a duration of %3\n\nPlease adjust Offset or Duration for this Object.").arg(fileName()).arg(offset().toString (qsFormat)).arg(duration().toString(qsFormat)), QMessageBox::Ok, QMessageBox::NoButton);
 		return;
 	}
 	// Next we create the directory neccesary ...
@@ -315,11 +334,12 @@ void MovieObject::slotStartConverting ()
 
 	qsFullPath = QString ("%1/%2/%3/%4").arg(Global::qsTempPath).arg(Global::qsProjectName).arg(qsMenuName).arg(extractionPath());
 	qsCommand  = QString ("mkdir -p '%1'").arg (qsFullPath);
-	system ((const char *)qsCommand);
+	if ( system ((const char *)qsCommand) == -1 )
+		return;
 	// and now we check that the path has been created succesfully
 	theTempDir.setPath (qsFullPath);
 	if (!theTempDir.exists())	{
-		QMessageBox::warning(NULL, tr("Could not create Path"), tr("Could not create Path \n%1").arg(qsFullPath), QMessageBox::Ok, QMessageBox::NoButton);
+		MessageBox::warning(NULL, tr("Could not create Path"), tr("Could not create Path \n%1").arg(qsFullPath), QMessageBox::Ok, QMessageBox::NoButton);
 		return;
 	}
 
@@ -352,7 +372,10 @@ bool MovieObject::readProjectFile  (QDomNode &theNode)
 {
 	QDomElement theElement = theNode.toElement();
 	// The video node has only attributes and nothing else.
-	QDomAttr attribute = theElement.attributeNode ( MOVIE_OBJECT_FILE_NAME );
+	QDomAttr attribute =  theElement.attributeNode ( MOVIE_OBJECT_MSEC_PREVIEW );
+	if ( !attribute.isNull ( ) )
+	  setMSecPreview ( attribute.value ( ).toLong ( ) );
+	attribute = theElement.attributeNode ( MOVIE_OBJECT_FILE_NAME );
 	if (!attribute.isNull())	{
 		setFile ( attribute.value() );
 		QPixmap nullPixmap;
@@ -409,6 +432,7 @@ bool MovieObject::writeProjectFile (QDomElement &theElement)
 		movieNode.setAttribute( MOVIE_OBJECT_FILE_NAME, m_qsFileName );
 	movieNode.setAttribute( MOVIE_OBJECT_OFFSET,   m_timeOffset.toString   (qsFormat) );
 	movieNode.setAttribute( MOVIE_OBJECT_DURATION, m_timeDuration.toString (qsFormat) );
+	movieNode.setAttribute( MOVIE_OBJECT_MSEC_PREVIEW, QString ( "%1" ).arg ( m_iMSecPreview ) );
 	movieNode.setAttribute( MOVIE_OBJECT_SIZE, QString("%1x%2").arg(movieSize().width()).arg(movieSize().height()) );
 
 	// Store the ImageManipulator - variables (if neccesarry) ...
@@ -438,6 +462,8 @@ void MovieObject::createStructure (QListViewItem *pParentItem)
 	ImageObject initialValues;
 	// And finally we create the modifiers info ...
 	manipulator().createStructure (pButtonItem);
+	if ( m_pShadow )
+	     m_pShadow->createStructure ( pButtonItem );
 
 	new StructureItem(this, pButtonItem, QString ("Geometry"),
 		QString ("%1, %2, %3, %4").
@@ -447,12 +473,13 @@ void MovieObject::createStructure (QListViewItem *pParentItem)
 	new StructureItem(this, pButtonItem, QString ("Offset"),   m_timeOffset.toString   ());
 }
 
-MenuObject *MovieObject::clone()
+MenuObject *MovieObject::clone ( )
 {
 	MovieObject *pNewObject = new MovieObject (MenuObject::parent());
-	pNewObject->setPixmap     (pixmap());
-	pNewObject->setFile       (fileName());
-	pNewObject->setZoom       (zoom());
+	pNewObject->setPixmap      ( pixmap   ( ) );
+	pNewObject->setFile        ( fileName ( ) );
+	pNewObject->setZoom        ( zoom     ( ) );
+	pNewObject->setMSecPreview ( msecPreview ( ) );
 	// The following two are not really needed, since we get those
 	// informations solely from the Normal State - objects ...
 	pNewObject->setRect       (rect());
@@ -468,6 +495,11 @@ MenuObject *MovieObject::clone()
 //	QImage  m_imagePreview;	// used to create a preview in a background task.
 //	QTimer *m_pConvertTimer;
 
+	MenuObject *pShadow = shadow ( );
+	if ( pShadow )
+	  pShadow = pShadow->clone ( pNewObject );
+	pNewObject->setShadow      (  pShadow   );
+
 	return pNewObject;
 }
 
