@@ -15,7 +15,6 @@
 #include <qapplication.h>
 #include <qprogressbar.h>
 #include <qinputdialog.h>
-#include <qmessagebox.h>
 #include <qtranslator.h>
 #include <qfiledialog.h>
 #include <qtextcodec.h>
@@ -35,12 +34,14 @@
 #include "CONFIG.h"
 
 #include "global.h"
+#include "utils.h"
 #include "sourcefileentry.h"
 #include "uidialogabout.h"
 #include "uinewwizard.h"
 #include "templatewizard.h"
 #include "dialogtemp.h"
 #include "uidialogrenderpreview.h"
+#include "messagebox.h"
 #include "dialogsetup.h"
 #include "dialogslide.h"
 #include "qdvdauthor.h"
@@ -64,18 +65,16 @@
 #include "importdvdauthor.h"
 #include "exportdvdauthor.h"
 #include "subtitlesgui.h"
+#include "templatedownload.h"
 
-#include <X11/Xlib.h>
+#define TEMP_SUBTITLES_COLOR0 0x00FEFFFE
+#define TEMP_SUBTITLES_COLOR1 0xFFFFFFFF
+#define TEMP_SUBTITLES_COLOR2 0xFFFFFFFE
+#define TEMP_SUBTITLES_COLOR3 0xFFFFFEFF
 
 QDVDAuthor::QDVDAuthor ()
 {
-	// One of the first things we ought to do is to ensure threating is turned on ...
-	if (!XInitThreads ())	{
-		QApplication::beep();
-		QMessageBox::warning(NULL, tr ("XInitThreads failed!"), tr ("XInitThreads failed!"), QMessageBox::Ok, QMessageBox::NoButton);
-		return;
-	}
-
+        Utils theUtils;
 	// Init the variables
 	m_bAutosaving          = false;
 	m_bModified            = false;
@@ -89,18 +88,18 @@ QDVDAuthor::QDVDAuthor ()
 	m_pSubtitlesGui        = NULL;
 	m_iAutosave            = 60;	// autosave every minute ...
 	m_iMaxHistoryFiles     = 10;
-	m_qsStyle              = QString ("Default");
+	m_qsStyle              = theUtils.currentStyleName ( ); //QString ("Default");
 	m_qsLanguage           = QString ("en");
 
+	// Next we load init files and init the callbacks and GUI parts.
+	initMe();
+
 	// And disabling the Undo/Redo/Cut/Copy/Paste - option because nothing is selected and undo is empty
 	editUndoAction->setEnabled(false);
 	editRedoAction->setEnabled(false);
 	editCutAction->setEnabled(false);
 	editCopyAction->setEnabled(false);
 	editPasteAction->setEnabled(false);
-
-	// Next we init the callbacks and GUI parts.
-	initMe();
 }
 
 QDVDAuthor::~QDVDAuthor ()
@@ -171,6 +170,7 @@ void QDVDAuthor::initMe()
 	connect (m_pActionUndoStack,       SIGNAL(activated()),   this, SLOT(slotUndoStack()));
 	connect (m_pActionFeedback,        SIGNAL(activated()),   this, SLOT(slotFeedback()));
 	connect (m_pActionTempSpace,       SIGNAL(activated()),   this, SLOT(slotDialogTemp()));
+	connect (m_pActionTemplateDownload,SIGNAL(activated()),   this, SLOT(slotTemplateDownload()));
 	connect (m_pActionImportDvdauthor, SIGNAL(activated()),   this, SLOT(slotImportDvdauthor()));
 	connect (m_pActionImportKino,      SIGNAL(activated()),   this, SLOT(slotImportKino()));
 	connect (m_pMenuHistory,           SIGNAL(activated(int)),this, SLOT(slotChangeHistory(int) ) );
@@ -186,10 +186,10 @@ void QDVDAuthor::postInit ( bool bSkipCheck )
 	QFile autosaveFile(qsAutosaveFile);
 	if ( autosaveFile.exists () && ! bSkipCheck )	{
 		setAutosave (false);
-		if (QMessageBox::information (this, tr("Found recover file"), tr(""
-		"Attention, I found a recovery file.\n"
-		"This usually indicates that 'Q'DVD-Author crashed.\n\n"
-		"Do you want to recover the previous contents ?"), QMessageBox::Yes, QMessageBox::No) == QMessageBox::Yes)	{
+		if (MessageBox::information (this, tr("Found recover file"), 
+		  tr("Attention, I found a recovery file.\n"
+		     "This usually indicates that 'Q'DVD-Author crashed.\n\n"
+		     "Do you want to recover the previous contents ?"), QMessageBox::Yes, QMessageBox::No) == QMessageBox::Yes)	{
 			fileOpen (qsAutosaveFile);
 			fileSaveAs ();
 		}
@@ -573,7 +573,7 @@ void QDVDAuthor::slotRenameCurrentSubMenu ()
 	bool bOkay;
 	DVDMenu *pMenu = getCurrentSubMenu ();
 	if (pMenu == m_pVMGMenu)	{
-		QMessageBox::information (NULL, tr ("Can not change VMGM name"),
+		MessageBox::information (NULL, tr ("Can not change VMGM name"),
 		tr ("I can not change the name of the VMGM\n"), QMessageBox::Ok);
 		return;
 	}
@@ -600,13 +600,13 @@ void QDVDAuthor::slotRemoveCurrentSubMenu ()
 	qsSubMenuName = m_pTabWidgetMain->tabLabel(m_pTabWidgetMain->currentPage());
 	DVDMenu *pMenu = getCurrentSubMenu ();
 	if (pMenu == m_pVMGMenu)	{
-		QMessageBox::information (NULL, tr ("Can not remove VMGM"),
+		MessageBox::information (NULL, tr ("Can not remove VMGM"),
 		tr ("I can not remove the main VMGM\n"), QMessageBox::Ok);
 		return;
 	}
-	int iReturn = QMessageBox::warning (NULL, tr ("Warning, deleting Sub Menu"),
+	int iReturn = MessageBox::warning (NULL, tr ("Warning, deleting Sub Menu"),
 		tr ("Are you sure you want to remove this sub-menu ?\n"
-		"All data will be lost permanently."), QMessageBox::Yes ,  QMessageBox::No);
+		    "All data will be lost permanently."), QMessageBox::Yes|QMessageBox::Default,  QMessageBox::No|QMessageBox::Escape);
 		if (iReturn == QMessageBox::Yes)
 			m_pTabWidgetMain->removePage(m_pTabWidgetMain->currentPage());
 
@@ -647,12 +647,13 @@ void QDVDAuthor::slotDeleteTempOlderThan ()
 	// First we check if there was some old data found ...
 	if (listToBeDeleted.count () > 0)	{
 		// Next we ask the user if he wants to delete the data.
-		if (QMessageBox::warning (NULL, tr("Deleting temp data."), tr("Attention, I found some temp data which exceeds the timeframe\n") +
+		if (MessageBox::warning (NULL, tr("Deleting temp data."), tr("Attention, I found some temp data which exceeds the timeframe\n") +
 			tr ("you have set in the SetupDialog (Tools->Setup ...)\n\n") +
 			listToBeDeleted.join ("\n") +
-			tr ("\n\nDo you want to delete the temp data ?"), QMessageBox::Yes, QMessageBox::No) == QMessageBox::Yes)	{
+			tr ("\n\nDo you want to delete the temp data ?"), 
+					 QMessageBox::Yes|QMessageBox::Default, QMessageBox::No|QMessageBox::Escape) == QMessageBox::Yes)	{
 			for (t=0;t<listToBeDeleted.count ();t++)
-				theUtils.recRmdir (qsProjectTemp, "draggedImage");
+				theUtils.recRmdir (listToBeDeleted[t], "draggedImage");
 		}
 	}
 }
@@ -700,6 +701,20 @@ void QDVDAuthor::slotTabChanged (QWidget *pWidget)
   }
 }
 
+void QDVDAuthor::slotAboutToShowMenu ( )
+{
+  DVDMenu *pCurrentMenu;
+  VMGMenu *pVMG = (VMGMenu *)m_pVMGMenu;
+  QPopupMenu *pMenu = pVMG->getPopupMenu ( );
+  pCurrentMenu = getCurrentSubMenu ( );
+  if ( ! pCurrentMenu )
+    return;
+  if ( pCurrentMenu->getInterface ()->qsBackgroundFileName.isEmpty () )
+    pMenu->setItemEnabled ( pMenu->idAt ( 2 ), false );
+  else
+    pMenu->setItemEnabled ( pMenu->idAt ( 2 ), true );
+}
+
 void QDVDAuthor::slotImportKino ()
 {
   // import Kino's smil format. This will generate only a single
@@ -791,7 +806,7 @@ void QDVDAuthor::slotFeedback ()
     feedbackDir.mkdir (feedbackDir.absPath(), TRUE);
 
   if (!feedbackDir.exists())	{
-    QMessageBox::information (NULL, tr ("Error creating directory"),
+    MessageBox::information (NULL, tr ("Error creating directory"),
 	tr ("\nCould not create direcory :\n"
 	    "%1\n"
 	    "Please check access rights etc.").arg(feedbackDir.absPath()), QMessageBox::Ok, QMessageBox::NoButton);
@@ -818,7 +833,7 @@ void QDVDAuthor::slotFeedback ()
     bashFile.close();
   }
   else	{
-    QMessageBox::information (NULL, tr ("Error creating script file"),
+    MessageBox::information (NULL, tr ("Error creating script file"),
         tr ("\nCould not create script file :\n"
 	    "%1\n"
 	    "Please check access rights etc.").arg(qsBashName), QMessageBox::Ok, QMessageBox::NoButton);
@@ -828,8 +843,9 @@ void QDVDAuthor::slotFeedback ()
   chmod ((const char *)qsBashName, S_IEXEC | S_IRUSR | S_IWRITE);
   
   // And now execute the script ...
-  system (qsBashName);
-  QMessageBox::information (NULL, tr ("Collected Feedback Data"),
+  if ( system (qsBashName) == -1 )
+	return;
+  MessageBox::information (NULL, tr ("Collected Feedback Data"),
       tr ("\nWhen sending feedback, please attach the file :\n"
 	  "%1/%2/feedback.tar.gz\n").arg(Global::qsTempPath).arg(Global::qsProjectName), QMessageBox::Ok, QMessageBox::NoButton);
 }
@@ -851,7 +867,7 @@ void QDVDAuthor::slotStructureClicked(QListViewItem *pItem)
 
 void QDVDAuthor::filePrint()
 {
-	QMessageBox::warning (this, tr("Warning"), tr ("Not implemented Yet"), (int)QMessageBox::Ok, (int)QMessageBox::NoButton);
+	MessageBox::warning (this, tr("Warning"), tr ("Not implemented Yet"), (int)QMessageBox::Ok, (int)QMessageBox::NoButton);
 }
 
 void QDVDAuthor::fileExit()
@@ -921,7 +937,7 @@ void QDVDAuthor::slotAddFromTemplate ()
 	if ( ! m_pTemplateWizard )
 		return;
 	// Note we use show here in order to have DragNDrop working.
-	m_pTemplateWizard->show ();
+	m_pTemplateWizard->showDialog ( );
 }
 
 void QDVDAuthor::slotDeleteTemplateWizard()
@@ -1296,14 +1312,14 @@ void QDVDAuthor::updateHistoryPix ()
 ///////////////////////////////////////////////////////////////////////////////////////////
 void QDVDAuthor::slotCreateSVCD()
 {
-	QMessageBox::information (NULL, tr ("Not implemented yet"),
+	MessageBox::information (NULL, tr ("Not implemented yet"),
 		tr ("This function is not yet implemented.\n"), QMessageBox::Ok);
 		return;
 }
 
 void QDVDAuthor::slotCreateVCD()
 {
-	QMessageBox::information (NULL, tr ("Not implemented yet"),
+	MessageBox::information (NULL, tr ("Not implemented yet"),
 		tr ("This function is not yet implemented.\n"), QMessageBox::Ok);
 }
 
@@ -1316,7 +1332,7 @@ void QDVDAuthor::slotCreateDVD()
 	// invoke spumux -> output to dialog
 	// invoke dvdauthor, but use dummy vob files rather then the original (hiuge) ones.
 
-  m_pSubtitlesGui->releaseSourceFileInfo ();
+        m_pSubtitlesGui->releaseSourceFileInfo ();
 	// This command will generate the Project path under the temp directory. This'll ensure the directory is present and writable for the temp data
 	createTempDirStructure ();
 	QString qsTempPath = getTempFile (QString());
@@ -1484,7 +1500,11 @@ void QDVDAuthor::renderSubtitles ( SourceFileInfo *pInfo )
   QFileInfo fileInfo   ( pInfo->qsFileName );
   Subtitles::entry *pEntry;
   // Okay the subtitles should be named like $TMP/$PROJ/BASE_NAME/sub_<start>.png
-  qsThePath = theUtils.getTempFile( fileInfo.baseName () ) + QString ("/sub_");
+  qsThePath = theUtils.getTempFile( fileInfo.baseName () );
+  QDir tempDir (qsThePath);
+  if ( ! tempDir.exists ( ) )
+    tempDir.mkdir ( qsThePath );
+  qsThePath += QString ("/sub_");
 
   // get the rect of the video ...
   iWidth  = theUtils.getWHFromResolution ( pInfo->qsResolution, true  );
@@ -1507,6 +1527,11 @@ void QDVDAuthor::renderSubtitles ( SourceFileInfo *pInfo )
   colors[2] |= 0xff000000; // make the text opaque
   colors[3] |= 0xff000000; // make the text opaque
   
+  //colors[0] = TEMP_SUBTITLES_COLOR0 | (pSubtitles->iTransparency << 24);
+  //colors[1] = TEMP_SUBTITLES_COLOR1;
+  //colors[2] = TEMP_SUBTITLES_COLOR2;
+  //colors[3] = TEMP_SUBTITLES_COLOR3;
+
   // The most basic progressbar ...
   QProgressBar progress ( this );
   QRect boundingRect;
@@ -1540,13 +1565,33 @@ void QDVDAuthor::renderSubtitles ( SourceFileInfo *pInfo )
       
       // create new dimensioned pixmap
       QPixmap thePixmap = QPixmap ( pEntry->rect.width(), pEntry->rect.height () );
+#if ( QT_VERSION > 0x0301FF )
       copyBlt ( &thePixmap, 0, 0, &theDrawingBoard,  pEntry->rect.x(),  pEntry->rect.y(),  pEntry->rect.width(),  pEntry->rect.height());
+#else
+      bitBlt ( &thePixmap, 0, 0, &theDrawingBoard,  pEntry->rect.x(),  pEntry->rect.y(),  pEntry->rect.width(),  pEntry->rect.height(), Qt::CopyROP);      
+#endif
       theImage = thePixmap.convertToImage ();
     }  thePainter.end ();
     //    if ( pSubtitles->iTransparency > 1 )
-      theImage.setAlphaBuffer ( true );
+    theImage.setAlphaBuffer ( true );
     // and finally we save the rendered image and show some progress ...
     theUtils.reduceColors ( theImage, 4, (QRgb *)&colors );
+
+    //    QRgb theColor;
+    //    int i;
+    //    // Finally we replace the color entries with the original colors ...
+    //    for (t=0;t<MAX_MASK_COLORS;t++) {
+    //      for (i=t;i<MAX_MASK_COLORS;i++) {
+    //	if ( theImage.color ( i ) == theImage.color ( t ) ) {
+    //	  theColor = pSubtitles->subColors[t].rgb() & 0x00FFFFFF;
+    //	  if ( t == 0 )
+    //	    theColor |= ( pSubtitles->iTransparency << 24 );
+    //	  else
+    //	    theColor |= 0xff000000;
+    //	  theImage.setColor ( t, theColor);
+    //	}
+    //      }
+    //    }    
     theImage.save ( qsFileName, "PNG", 100);  // 100%== No compression. png image
 
     progress.setProgress ( (int)((float)t / iTotalCount * 100.0) );
@@ -1575,11 +1620,11 @@ bool QDVDAuthor::checkHealth ()
 	// o  There is enough space on the defined temp - path.
 	//    - approximately by adding all sizes together.
 	// o  And the temp drive should be writeable.
-
+        uint t;
 	CDVDMenuInterface *pInterface = m_pVMGMenu->getInterface();
 	// primary implementation only checks for Background, and mask images.
 	if (Global::qsTempPath.isEmpty())	{
-		QMessageBox::warning ( this, tr ("Error, missing temp path."),
+		MessageBox::warning ( this, tr ("Error, missing temp path."),
 			tr ("You forgot to specify a temp path.\n"
 				"I can not build this DVD without temp path.\n"
 				"Please define the missing temp path first.\n"),
@@ -1590,7 +1635,7 @@ bool QDVDAuthor::checkHealth ()
 		// Check if we can write to the temp path.
 		QFile file( Global::qsTempPath + QString ("/test_file") );
 		if ( !file.open( IO_WriteOnly ) )	{
-			QMessageBox::warning ( this, tr ("Error, can't write to temp."),
+			MessageBox::warning ( this, tr ("Error, can't write to temp."),
 				tr ("I can not write to the specified temp directory.\n%1\n"
 					"Please verify the temp path and try again.\n").arg(Global::qsTempPath),
 					QMessageBox::Ok, QMessageBox::NoButton);
@@ -1602,7 +1647,7 @@ bool QDVDAuthor::checkHealth ()
 		}
 	}
 	if (Global::qsProjectPath.isEmpty())	{
-		if (QMessageBox::warning ( this, tr ("Error, missing DVD path."),
+		if (MessageBox::warning ( this, tr ("Error, missing DVD path."),
 			tr ("You forgot to specify the DVD path.\n"
 				"I can not build this DVD without a DVD path.\n"
 				"Do you want to define the missing DVD path now ?\n"),
@@ -1614,7 +1659,7 @@ bool QDVDAuthor::checkHealth ()
 		// Check if we can write to the projectPath.
 		QFile file( Global::qsProjectPath + QString ("/test_file") );
 		if ( !file.open( IO_WriteOnly ) )	{
-			if (QMessageBox::warning ( this, tr ("Error, can't write to project path."),
+			if (MessageBox::warning ( this, tr ("Error, can't write to project path."),
 				tr ("I can not write to the specified Project directory.\n%1\n"
 					 "Do you want to change the specified path now ?\n").arg(Global::qsProjectPath),
 					QMessageBox::Yes, QMessageBox::No) == QMessageBox::Yes)
@@ -1627,7 +1672,7 @@ bool QDVDAuthor::checkHealth ()
 		}
 	}
 	if (pInterface->qsBackgroundFileName.isEmpty())	{
-		if (QMessageBox::warning ( this, tr ("No background defined."),
+		if (MessageBox::warning ( this, tr ("No background defined."),
 			tr ("You did not define a background image.\n"
 				"Do you want to create a VideoDVD without Menu ?\n"),
 				QMessageBox::Yes, QMessageBox::No) == QMessageBox::Yes)	{
@@ -1640,20 +1685,35 @@ bool QDVDAuthor::checkHealth ()
 
 	QValueList<ButtonObject *> listButtons;
 	listButtons = m_pVMGMenu->getButtons();
-	if ( (pInterface->qsHighlightedMaskFileName.isEmpty()) && (pInterface->qsSelectedMaskFileName.isEmpty()) &&
-		(listButtons.count() == 0) )	{
-		if (QMessageBox::warning ( this, tr ("No button masks defined."),
-			tr ("You did not define any buttons.\n"
-				"Do you want to create a VideoDVD without Menu ?\n"),
-				QMessageBox::Yes, QMessageBox::No) == QMessageBox::Yes)	{
-			// Here we create a Video DVD without a menu
-		}
-		// otherwise we abort here.
-		else
-			return false;
+	if ( ( pInterface->qsHighlightedMaskFileName.isEmpty ( ) ) && 
+	     ( pInterface->qsSelectedMaskFileName.isEmpty    ( ) ) &&
+	     ( listButtons.count ( ) == 0) )	{
+	  if ( MessageBox::warning ( this, tr ("No button masks defined."),
+				     tr ("You did not define any buttons.\n"
+					 "Do you want to create a VideoDVD without Menu ?\n"),
+				     QMessageBox::Yes, QMessageBox::No) == QMessageBox::Yes)	{
+	    // Here we create a Video DVD without a menu
+	  }
+	  // otherwise we abort here.
+	  else
+	    return false;
 	}
+
+	// Check if buttons are overlapping each other ...
+	QString qsOverlappingButtons;
+	qsOverlappingButtons = m_pVMGMenu->checkButtonsOverlapping ( );
+	for (t=0;t<m_listDVDMenus.count ();t++)
+	  qsOverlappingButtons += m_listDVDMenus[t]->checkButtonsOverlapping ( );
+	
+	if ( qsOverlappingButtons.length () > 1 ) {
+	  qsOverlappingButtons  = tr ( "Found buttons overlapping.<BR>I will correct these but the buttons might not look exactly the way you positioned them.<BR>" ) + qsOverlappingButtons;
+	  qsOverlappingButtons += tr ( "<BR>Do you want to manually correct the buttons positions ?" );
+	  if ( MessageBox::html ( this, tr( "Found Buttons overlapping." ), qsOverlappingButtons, QMessageBox::Yes, QMessageBox::No ) == QMessageBox::Yes )
+	    return false;
+	}
+
 	if (m_pSourceToolbar->sourceFileCount() < 1)	{
-		if (QMessageBox::warning ( this, tr ("No movies defined."),
+		if (MessageBox::warning ( this, tr ("No movies defined."),
 			tr ("You did not select any movies.\n"
 				"Do you want to create a DVD with Menu and no movies ?\n"),
 				QMessageBox::Yes, QMessageBox::No) == QMessageBox::Yes)	{
@@ -1664,7 +1724,6 @@ bool QDVDAuthor::checkHealth ()
 			return false;
 	}
 	// Here we check if there is already a dvd in place where the new one should be
-	uint t;
 	QDir projectDir (Global::qsProjectPath + QString ("/VIDEO_TS/"));
 	QStringList listFiles = projectDir.entryList ("*");
 	if (listFiles.count() > 2)	{	// the two standard directories . and ..
@@ -1674,7 +1733,7 @@ bool QDVDAuthor::checkHealth ()
 				continue;
 			stringFiles += QString ("%1\n").arg(listFiles[t]);
 		}
-		if (QMessageBox::warning ( this, tr ("DVD files found."),
+		if (MessageBox::warning ( this, tr ("DVD files found."),
 			tr ("I found DVD files most likely from a previous run.\n%1"
 				"Do you want to remove those files first ?\n").arg(stringFiles),
 				QMessageBox::Yes, QMessageBox::No) == QMessageBox::Yes)	{
@@ -1757,7 +1816,7 @@ void QDVDAuthor::createTempDirStructure ()
 	// this test is done only once 'cause if we can create this directory the we should have no problems 
 	// creating sub directories ...
 	if (!tempDir.exists())	{
-		QMessageBox::warning ( NULL, QObject::tr ("Could not create temp directory"),
+		MessageBox::warning ( NULL, QObject::tr ("Could not create temp directory"),
 		QObject::tr ("Failed to create temp directory\n"
 			"%1").arg (qsTempDir),
 			QMessageBox::Ok, QMessageBox::NoButton);
@@ -1948,6 +2007,13 @@ void QDVDAuthor::slotDialogTemp ()
 	delete pDialog;
 }
 
+void QDVDAuthor::slotTemplateDownload ( )
+{
+  TemplateDownload theDialog ( this );
+
+  theDialog.exec ( );
+}
+
 void QDVDAuthor::slotVisibleRegion(bool)
 {
 	// This signal is intercepted from all DVDMenu's which in turn 
@@ -1978,6 +2044,7 @@ void QDVDAuthor::newWizard ()
 	Global::qsProjectName = pWizard->m_pEditProjectName->text(); // QString ( PROJECT_FILENAME );
 	Global::qsProjectPath = pWizard->m_pEditDVDPath    ->text(); // QString ("");
 	Global::qsTempPath    = pWizard->m_pEditTempPath   ->text(); // QString ("./");
+	addHistory (Global::qsProjectFileName);
 	delete pWizard;
 }
 
@@ -1987,14 +2054,14 @@ bool QDVDAuthor::cleanUp()
 	uint t;
 	int iReturn;
 	// First we should check back if that is what the user wants ...
-//	iReturn = QMessageBox::warning ( this, QString ("Closing current Session."),
+//	iReturn = MessageBox::warning ( this, QString ("Closing current Session."),
 //		QString ("This will close the current Project.\nAre you sure ?"),
 //		QMessageBox::Yes, QMessageBox::No);
 //	if (iReturn == QMessageBox::No)
 //		return false;
 	if ( (m_pVMGMenu->getInterface()->bModified) || (m_bModified) )	{
 		// Now we see if there is something to loose which might be worth saving ...
-		iReturn = QMessageBox::warning ( this, tr ("File not saved"),
+		iReturn = MessageBox::warning ( this, tr ("File not saved"),
 			tr ("The current modifications have not been save to the file. \nDo you want to save the project now ?"),
 			QMessageBox::Yes, QMessageBox::No, QMessageBox::Cancel);
 		if (iReturn == QMessageBox::Yes)
@@ -2058,7 +2125,7 @@ void QDVDAuthor::fileOpen (QString qsProjectFileName)
 	if (!xmlDoc.setContent (&projectFile))	{
 		// Error handling ...
 		projectFile.close();
-		int iReturn = QMessageBox::warning ( this, tr ("xml project file seems to be defective."),
+		int iReturn = MessageBox::warning ( this, tr ("xml project file seems to be defective."),
 			tr ("Do you want to try to load another project file ?"),
 			QMessageBox::Yes, QMessageBox::No);
 		if (iReturn == QMessageBox::Yes)
@@ -2096,7 +2163,7 @@ void QDVDAuthor::fileOpen (QString qsProjectFileName)
 	}
 	projectFile.close();
 	if (bError)	{
-		QMessageBox::warning ( this, tr ("Error occured reading project file."),
+		MessageBox::warning ( this, tr ("Error occured reading project file."),
 			tr ("An unknow error occured when trying to read teh project xml file."),
 			QMessageBox::Ok, QMessageBox::NoButton);
 		return;
@@ -2297,10 +2364,10 @@ QString QDVDAuthor::getImageFilter ()
 
 QString QDVDAuthor::getMovieFilter ()
 {
-	return QString ("*.mpg *.mpeg *.avi *.mwa *.mov *.wma *.vro *.vob *.dv *.wmv *.mjpeg *.mve *.asf *.asx *.MPG *.MPEG *.AVI *.MWA *.MOV *.WMA *.VRO *.VOB *.DV *.WMV *.MJPEG *.MVE *.ASF *.ASX");
+	return QString ("*.mpg *.mpeg *.avi *.mwa *.mov *.wma *.vro *.vob *.m2v *.dv *.wmv *.mjpeg *.mve *.asf *.asx *.MPG *.MPEG *.AVI *.MWA *.MOV *.WMA *.VRO *.VOB *.M2V *.DV *.WMV *.MJPEG *.MVE *.ASF *.ASX");
 }
 
 QString QDVDAuthor::getSoundFilter ()
 {
-	return QString("*.wav *.mp3 *.mp2 *.mpa *.mpega *.ogg *.WAV *.MP3 *.MP2 *.MPA *.MPEGA *.OGG");
+	return QString("*.wav *.mp3 *.mp2 *.mpa *.mpega *.ogg *.ac3 *.WAV *.MP3 *.MP2 *.MPA *.MPEGA *.OGG *.AC3");
 }
