@@ -12,15 +12,16 @@
 **
 ****************************************************************************/
 
-#include <qmessagebox.h>
-
+#include "utils.h"
 #include "execute.h"
 #include "qdvdauthorinit.h"
+#include "messagebox.h"
 #include "sourcefileentry.h"
 #include "dragndropcontainer.h"
 #include "qplayer/mediainfo.h"
 #include "qplayer/mediacreator.h"
-
+#include "qplayer/MEDIA_CONFIG.h"
+ 
 QDVDAuthorInit::MenuBlock::MenuBlock ()
 { 
 	bValid  = false;
@@ -46,6 +47,8 @@ QDVDAuthorInit::MenuBlock::MenuBlock ()
 QDVDAuthorInit::QDVDAuthorInit()
 {
 	initMe();
+	m_pDragNDropContainer    = new DragNDropContainer;
+	m_bOwnDragNDropContainer = true;
 	readIniFile();
 }
 
@@ -84,6 +87,7 @@ QDVDAuthorInit::~QDVDAuthorInit()
     // If this flag is not set means that some other object (QDVDAuthor e.g.) is the master of these.
     for (t=0;t<(int)m_listHistoryPix.count();t++)
       delete m_listHistoryPix[t];
+    m_listHistoryPix.clear ( );
   }
   // Note: Since we clear the list every time getToolsPaths list is called we can delete 
   //       All objects which are at this time still in the list. 
@@ -93,12 +97,18 @@ QDVDAuthorInit::~QDVDAuthorInit()
       for (t=0;t<iCount;t++)
 	delete m_listToolsPaths[t];
     }
+    m_listToolsPaths.clear ( );
   }
+  if ( m_bOwnDragNDropContainer )
+    delete m_pDragNDropContainer;
+  m_pDragNDropContainer = NULL;
+  m_bOwnDragNDropContainer = false;
 }
 
 bool QDVDAuthorInit::initMe()
 {
 	int t;
+	Utils theUtils;
 	m_iMaxHistoryFiles     = 10;
 	m_bOwnerOfHistoryPix   = true;
 	m_iAutosave            = 300;
@@ -106,14 +116,16 @@ bool QDVDAuthorInit::initMe()
 	m_iCurrentBlockID      = 0;	// To uniquely identify each block of commands ...
 	m_bProtectToolsObjects = false;
 	m_bVisibleRegion       = false;
-	m_qsStyle              = QString ("Default");
+	m_qsStyle              = theUtils.currentStyleName ( );
 	m_qsLanguage           = QString ("en");
 
 	m_qsTempPath           = Global::qsTempPath + QString ("/") + Global::qsProjectName;
 	m_qsProjectPath        = Global::qsProjectPath;
 	m_qsDvdauthorFile      = m_qsTempPath + QString ("/") + QString(DVDAUTHOR_XML);
 	m_pDragNDropContainer  = NULL;
+	m_bOwnDragNDropContainer = false;
 
+	m_bFirstApplicationStart       = false;
 	m_convertMenuBlock.qsMenuTag   = QString (TAG_CONVERT);
 	m_convertMenuBlock.iKeyset     = Keyword::TransKeys;
 	m_subtitlesMenuBlock.qsMenuTag = QString (TAG_SUBTITLES);
@@ -266,6 +278,26 @@ QString QDVDAuthorInit::getLanguage ()
 	return m_qsLanguage;
 }
 
+void QDVDAuthorInit::setTemplateAuthor ( QString &qsAuthor )
+{
+  m_qsTemplateAuthor = qsAuthor;
+}
+
+QString &QDVDAuthorInit::getTemplateAuthor ( )
+{
+  return m_qsTemplateAuthor;
+}
+
+void QDVDAuthorInit::setTemplateContact ( QString &qsContact )
+{
+  m_qsTemplateContact = qsContact;
+}
+
+QString &QDVDAuthorInit::getTemplateContact ( )
+{
+  return m_qsTemplateContact;
+}
+
 int QDVDAuthorInit::getAutosave ()
 {
 	return m_iAutosave;
@@ -276,6 +308,11 @@ void QDVDAuthorInit::setAutosave (int iAutosave)
 	m_iAutosave = iAutosave;
 }
 
+bool QDVDAuthorInit::firstApplicationStart ( ) 
+{
+  return m_bFirstApplicationStart;
+}
+
 void QDVDAuthorInit::setVisibleRegion (bool bVisibleRegion)
 {
 	m_bVisibleRegion = bVisibleRegion;
@@ -313,9 +350,10 @@ bool QDVDAuthorInit::readIniFile ()
 	if (!xmlDoc.setContent (&initFile))	{
 		// Error handling ...
 		initFile.close();
-		iReturn = QMessageBox::warning ( NULL, QObject::tr ("QDVDAuthor - init file seems to be defective."),
-			QObject::tr ("The file %1%2 seems  to have a problem. Do you want to reset this file ?").arg(INIT_DIR_NAME).arg(INIT_FILE_NAME),
-			QMessageBox::Yes, QMessageBox::No);
+
+		iReturn = MessageBox::warning ( NULL, QObject::tr ("QDVDAuthor - init file seems to be defective."),
+			   QObject::tr ("The file %1%2 seems  to have a problem. Do you want to reset this file ?").arg(INIT_DIR_NAME).arg(INIT_FILE_NAME),
+			   QMessageBox::Yes|QMessageBox::Default, QMessageBox::No|QMessageBox::Escape );
 		if (iReturn == QMessageBox::Yes)	{
 			resetInitFile ();
 			return initMe ();
@@ -335,6 +373,9 @@ bool QDVDAuthorInit::readIniFile ()
 	a = docElem.attributeNode ( ATTRIB_LANGUAGE );
 	if (!a.value().isEmpty())
 		m_qsLanguage = a.value();
+	a = docElem.attributeNode ( ATTRIB_FIRST_START );
+	if (!a.value().isEmpty())
+	  m_bFirstApplicationStart = (bool) a.value().toInt ();
 	a = docElem.attributeNode ( ATTRIB_VISIBLE_REGION );
 	m_bVisibleRegion = false;
 	if (a.value() == QString ("true"))
@@ -351,7 +392,7 @@ bool QDVDAuthorInit::readIniFile ()
 	if (a.value().toInt() > 0)
 		m_iAutosave = a.value().toInt();
 	if (fStoredVersion > (float)INIT_VERSION)	{
-		iReturn = QMessageBox::warning ( NULL, QObject::tr ("QDVDAuthor - init file is newer than the current version of 'Q' DVD-Author."),
+		iReturn = MessageBox::warning ( NULL, QObject::tr ("QDVDAuthor - init file is newer than the current version of 'Q' DVD-Author."),
 			QObject::tr ("The file %1%2 was created with a more recent version.\nThis could lead to problems.\nDo you want to reset this file ?").arg(INIT_DIR_NAME).arg(INIT_FILE_NAME),
 			QMessageBox::Yes, QMessageBox::No);
 		if (iReturn == QMessageBox::Yes)	{
@@ -361,7 +402,7 @@ bool QDVDAuthorInit::readIniFile ()
 	}
 	else if (fStoredVersion < (float)INIT_VERSION)	{
 		// Here we tell the user and then reset the initfile.
-		iReturn = QMessageBox::warning ( NULL, QObject::tr ("QDVDAuthor - init file is outdated."),
+		iReturn = MessageBox::warning ( NULL, QObject::tr ("QDVDAuthor - init file is outdated."),
 			QObject::tr ("The file %1%2 was created with an older version of 'Q' DVD-Author.\nThis could lead to problems.\n\nDo you want to reset this file ?").arg(INIT_DIR_NAME).arg(INIT_FILE_NAME),
 			QMessageBox::Yes, QMessageBox::No);
 		if (iReturn == QMessageBox::Yes)	{
@@ -424,6 +465,10 @@ bool QDVDAuthorInit::readIniFile ()
 		}
 		else if (qsChildTag == QString(TAG_PREFERRED_ENGINE))
 			m_qsPreferredEngine = childElem.text();
+		else if (qsChildTag == QString(TAG_TEMPLATE_AUTHOR))
+			m_qsTemplateAuthor = childElem.text();
+		else if (qsChildTag == QString(TAG_TEMPLATE_CONTACT))
+			m_qsTemplateContact = childElem.text();
 		else if (qsChildTag == QString(TAG_EXTERNAL_PLAYER))
 			Global::qsExternalPlayer = childElem.text();
 		else if (qsChildTag == QString(TAG_COLOR))	{
@@ -593,6 +638,8 @@ bool QDVDAuthorInit::saveIniFile ()
 	rootInit.setAttribute( ATTRIB_VERSION, QString ("%1").arg((float)INIT_VERSION));
 	rootInit.setAttribute( ATTRIB_STYLE, m_qsStyle);
 	rootInit.setAttribute( ATTRIB_LANGUAGE, m_qsLanguage);
+	if ( m_bFirstApplicationStart )
+	  rootInit.setAttribute( ATTRIB_FIRST_START, (int)m_bFirstApplicationStart);
 	QString qsVisibleRegion ("false");
 	if (m_bVisibleRegion)
 		qsVisibleRegion = QString("true");
@@ -614,6 +661,16 @@ bool QDVDAuthorInit::saveIniFile ()
 	externalElement.appendChild( domText );
 	rootInit.appendChild ( externalElement );
 
+	QDomElement templateAuthor = xmlDoc.createElement( TAG_TEMPLATE_AUTHOR );	// <TemplateAuthor>
+	domText = xmlDoc.createTextNode ( m_qsTemplateAuthor );
+	templateAuthor.appendChild( domText );
+	rootInit.appendChild ( templateAuthor );
+	
+	QDomElement templateContact = xmlDoc.createElement( TAG_TEMPLATE_CONTACT );	// <TemplateContact>
+	domText = xmlDoc.createTextNode ( m_qsTemplateContact );
+	templateContact.appendChild( domText );
+	rootInit.appendChild ( templateContact );
+	
 	// First things first ... the color table ...
 	for (t=0;t<m_arrayColors.count();t++)	{
 		QDomElement colorElement = xmlDoc.createElement( TAG_COLOR );	// <Color>
@@ -649,23 +706,25 @@ bool QDVDAuthorInit::saveIniFile ()
 	}
 	// Here we add the DragNDrop - stuff to the init - file ...
 	DragNDropContainer *p = m_pDragNDropContainer;
-	QDomElement dndElement  = xmlDoc.createElement( TAG_DRAGNDROP );  // <DragNDrop>
-	QDomElement fontElement = xmlDoc.createElement( TAG_FONT );       // <Font>
-	domText = xmlDoc.createTextNode (p->font.toString());
-	dndElement.setAttribute( ATTRIB_DND_THUMBNAIL  , QString ("%1x%2").arg(p->sizeThumbnail.width()).arg(p->sizeThumbnail.height()));
-	dndElement.setAttribute( ATTRIB_DND_BUTTON     , QString ("%1x%2").arg(p->sizeButton.width()).arg(p->sizeButton.height()));
-	dndElement.setAttribute( ATTRIB_DND_BUTTON_TYPE, QString ("%1").arg(p->bImageButton));
-	dndElement.setAttribute( ATTRIB_DND_WITH_TEXT  , QString ("%1").arg(p->bWithText));
-	dndElement.setAttribute( ATTRIB_DND_TEXT_POS   , QString ("%1").arg(p->iTextPosition));
-	dndElement.setAttribute( ATTRIB_DND_START      , QString ("%1").arg(p->timeStartOffset.toString(Qt::TextDate)));
-	dndElement.setAttribute( ATTRIB_DND_DURATION   , QString ("%1").arg(p->timeDuration.toString(Qt::TextDate)));
-	dndElement.setAttribute( ATTRIB_DND_COLOR      , QString ("%1").arg(p->colorForeground.name()));
-	dndElement.setAttribute( ATTRIB_DND_START_WHEN , QString ("%1").arg(p->bStartAfterDropEvent ? "true" : "false"));
-	dndElement.setAttribute( ATTRIB_DND_NICE       , QString ("%1").arg(p->iHowNiceShouldIBe));
-	
-	fontElement.appendChild( domText );
-	dndElement.appendChild ( fontElement );
-	rootInit.appendChild   ( dndElement );
+	if ( p ) {
+	  QDomElement dndElement  = xmlDoc.createElement( TAG_DRAGNDROP );  // <DragNDrop>
+	  QDomElement fontElement = xmlDoc.createElement( TAG_FONT );       // <Font>
+	  domText = xmlDoc.createTextNode (p->font.toString());
+	  dndElement.setAttribute( ATTRIB_DND_THUMBNAIL  , QString ("%1x%2").arg(p->sizeThumbnail.width()).arg(p->sizeThumbnail.height()));
+	  dndElement.setAttribute( ATTRIB_DND_BUTTON     , QString ("%1x%2").arg(p->sizeButton.width()).arg(p->sizeButton.height()));
+	  dndElement.setAttribute( ATTRIB_DND_BUTTON_TYPE, QString ("%1").arg(p->bImageButton));
+	  dndElement.setAttribute( ATTRIB_DND_WITH_TEXT  , QString ("%1").arg(p->bWithText));
+	  dndElement.setAttribute( ATTRIB_DND_TEXT_POS   , QString ("%1").arg(p->iTextPosition));
+	  dndElement.setAttribute( ATTRIB_DND_START      , QString ("%1").arg(p->timeStartOffset.toString(Qt::TextDate)));
+	  dndElement.setAttribute( ATTRIB_DND_DURATION   , QString ("%1").arg(p->timeDuration.toString(Qt::TextDate)));
+	  dndElement.setAttribute( ATTRIB_DND_COLOR      , QString ("%1").arg(p->colorForeground.name()));
+	  dndElement.setAttribute( ATTRIB_DND_START_WHEN , QString ("%1").arg(p->bStartAfterDropEvent ? "true" : "false"));
+	  dndElement.setAttribute( ATTRIB_DND_NICE       , QString ("%1").arg(p->iHowNiceShouldIBe));
+
+	  fontElement.appendChild( domText );
+	  dndElement.appendChild ( fontElement );
+	  rootInit.appendChild   ( dndElement );
+	}
 
 	// Next are the ExecuteInterface's The convert goes first bien sur ...
 	QDomElement convertElement = xmlDoc.createElement( TAG_EXECUTE );	// <ExecuteInterface>
@@ -849,6 +908,7 @@ bool QDVDAuthorInit::saveMenuBlock (MenuBlock *pMenuBlock, QDomElement *pElement
 		// Print some status infos to check. Man unit testing is boring.
 //		printBlock(&pMenuBlock->blockMovieBackground, 0);
 		saveBlock (&pMenuBlock->blockMovieBackground, &systemElement); // Handling the movie conversion 
+		saveBlock (&pMenuBlock->blockImageBackground, &systemElement); // Handling the movie conversion 
 		saveBlock (&pMenuBlock->blockEmptySound, &systemElement);      // Handling the sound conversion
 	}
 	else if ( (pMenuBlock->qsMenuTag == QString (TAG_PAL)) || (pMenuBlock->qsMenuTag == QString (TAG_NTSC)) )	{
@@ -972,7 +1032,7 @@ bool QDVDAuthorInit::saveSubBlock (MenuBlock::SubBlock *pSubBlock, QDomElement *
 	if ( (!pSubBlock->qsName.isEmpty()) && (!pSubBlock->qsName.isNull()) )
 		subBlockElement.setAttribute ( ATTRIB_NAME, pSubBlock->qsName );
 	subBlockElement.setAttribute ( ATTRIB_NUMBER, pSubBlock->iNumber );
-	
+
 	for (t=0;t<pSubBlock->listBlocks.count();t++)	{
 		if (!saveBlock(pSubBlock->listBlocks[t] , &subBlockElement) )
 			return false;
@@ -983,8 +1043,22 @@ bool QDVDAuthorInit::saveSubBlock (MenuBlock::SubBlock *pSubBlock, QDomElement *
 	return true;
 }
 
+void QDVDAuthorInit::printCommandList( char *pFrom )
+{
+	printf ("%s =-> printCommandList \n", pFrom);
+	for (uint t=0;t<m_listExecute.count();t++)  {
+		for (uint i=0;i<m_listExecute[t]->listCommandList.count ();i++)  {
+			QStringList qsCommandList = m_listExecute[t]->listCommandList[i];
+			for (uint j=0;j<qsCommandList.count();j++)  {
+				printf ( "QDVDAuthorInit::printCommandList <%d><%d><%d> = <%s>\n", t, i, j, qsCommandList[j].ascii() );
+			}
+		}
+	}
+}
+
 QValueList <ExecuteInterface *>&QDVDAuthorInit::getList()
 {
+
 	return m_listExecute;
 }
 
@@ -1004,10 +1078,10 @@ void QDVDAuthorInit::setDefault(int iBlockID, uint iDefaultCommand)
 
 QDVDAuthorInit::MenuBlock::Block *QDVDAuthorInit::getBlock (int iBlockID, int *piKeyset )
 {
-  uint t, i, j;
+  uint t, i, j, k;
   MenuBlock *arrayMenuBlocks[] = {&m_palMenuBlock, &m_ntscMenuBlock, &m_convertMenuBlock, &m_subtitlesMenuBlock, &m_dvdauthorMenuBlock, &m_burningMenuBlock};
   MenuBlock *pMenuBlock;
-  MenuBlock::Block *pSubSubBlock, *pReturn = NULL;
+  MenuBlock::Block *pBlock, *pSubSubBlock, *pReturn = NULL;
   MenuBlock::SubBlock *pSubBlock;
   for (t=0;t<sizeof ( arrayMenuBlocks ) /  sizeof (MenuBlock *);t++)	{
     pMenuBlock = arrayMenuBlocks[t];
@@ -1026,25 +1100,21 @@ QDVDAuthorInit::MenuBlock::Block *QDVDAuthorInit::getBlock (int iBlockID, int *p
     else if (pMenuBlock->blockOthers.iBlockID     == iBlockID)
       pReturn = &pMenuBlock->blockOthers;
     else 	{	// No luck finding the block, let us check in the subBlocks of the MovieBackground - block 
-      for (i=0;i<pMenuBlock->blockMovieBackground.listSubBlocks.count();i++)	{
-	pSubBlock = pMenuBlock->blockMovieBackground.listSubBlocks[i];
-	for (j=0;j<pSubBlock->listBlocks.count();j++)	{
-	  pSubSubBlock = pSubBlock->listBlocks[j];
-	  if (pSubSubBlock->iBlockID == iBlockID)	{
-	    return  pSubSubBlock;
+      pBlock = &pMenuBlock->blockMovieBackground;
+      for (k=0;k<3;k++) {
+	if ( k == 1 )
+	  pBlock = &pMenuBlock->blockImageBackground;
+	else if ( k == 2 )
+	  pBlock = &pMenuBlock->blockOthers;
+	for (i=0;i<pBlock->listSubBlocks.count();i++)	{
+	  pSubBlock = pBlock->listSubBlocks[i];
+	  for (j=0;j<pSubBlock->listBlocks.count();j++)	{
+	    pSubSubBlock = pSubBlock->listBlocks[j];
+	    if (pSubSubBlock->iBlockID == iBlockID)	{
+	      return  pSubSubBlock;
+	    }
 	  }
-	  
-	}
-      }  // And since I also use now the blockOthers to store sub-Blocks ...
-      for (i=0;i<pMenuBlock->blockOthers.listSubBlocks.count();i++)	{
-	pSubBlock = pMenuBlock->blockOthers.listSubBlocks[i];
-	for (j=0;j<pSubBlock->listBlocks.count();j++)	{
-	  pSubSubBlock = pSubBlock->listBlocks[j];
-	  if (pSubSubBlock->iBlockID == iBlockID)	{
-	    return  pSubSubBlock;
-	  }
-	  
-	}
+	}  
       }
     }
     if (pReturn)
@@ -1054,6 +1124,26 @@ QDVDAuthorInit::MenuBlock::Block *QDVDAuthorInit::getBlock (int iBlockID, int *p
       *piKeyset = Keyword::Keys;
   return NULL;
 }
+/*
+      for (i=0;i<pMenuBlock->blockMovieBackground.listSubBlocks.count();i++)	{
+	pSubBlock = pMenuBlock->blockMovieBackground.listSubBlocks[i];
+	for (j=0;j<pSubBlock->listBlocks.count();j++)	{
+	  pSubSubBlock = pSubBlock->listBlocks[j];
+	  if (pSubSubBlock->iBlockID == iBlockID)	{
+	    return  pSubSubBlock;
+	  }
+	}
+      }  // And since I also use now the blockOthers to store sub-Blocks ...
+      for (i=0;i<pMenuBlock->blockOthers.listSubBlocks.count();i++)	{
+	pSubBlock = pMenuBlock->blockOthers.listSubBlocks[i];
+	for (j=0;j<pSubBlock->listBlocks.count();j++)	{
+	  pSubSubBlock = pSubBlock->listBlocks[j];
+	  if (pSubSubBlock->iBlockID == iBlockID)	{
+	    return  pSubSubBlock;
+	  }	  
+	}
+      }
+*/
 
 void QDVDAuthorInit::appendPreProcessing ()
 {
@@ -1071,13 +1161,14 @@ void QDVDAuthorInit::appendPreProcessing ()
 	// Then we append pre processing (movie conversion if neccesary).
 	// Prep the convertInterface for Movie / Audio conversion ...
 	m_listExecute.append(&m_convertInterface);
+	//printCommandList ("appendPreProcessing");
 }
 
 void QDVDAuthorInit::appendConvert (SourceFileEntry *pEntry)
 {
   uint t, i, j, k;
   int iXPos, iSplitPos;
-  QString qsWidth, qsHeight, qsBaseName;
+  QString qsResolution, qsVideoFormat, qsRatio, qsWidth, qsHeight, qsBaseName;
 
   TranscodeInterface *pInterface = NULL;
   Subtitles          *pSubtitles = NULL;
@@ -1096,7 +1187,6 @@ void QDVDAuthorInit::appendConvert (SourceFileEntry *pEntry)
     pSubtitles = pInfo->pSubtitles;
     // The user wants this one to get converted.
     if ( pInterface ) {
-
       // It seems that the file is currently beeing transcoded.
       if ( pInterface->bTranscoding )
 	continue;
@@ -1123,21 +1213,37 @@ void QDVDAuthorInit::appendConvert (SourceFileEntry *pEntry)
       listCommands.clear ();
       if (!pEntry->bSoundSource)	{ // here we handle the video sources.
 	pBlock = &(m_convertMenuBlock.blockMovieBackground);
+	if ( pInterface->bRemuxOnly )
+	  pBlock = &(m_convertMenuBlock.blockImageBackground);
 	// Note the following line is kept out bc it represents the 
 	// Transcode/MEncoder selectionDropDown and not used for conversion itself
 	// pExecute->listBlockIDs.append (pBlock->iBlockID);
-	iXPos = pInterface->qsResolution.find ("x");
-	qsWidth  = pInterface->qsResolution.left (iXPos);
-	qsHeight = pInterface->qsResolution.right(iXPos);
+	qsResolution = pInterface->qsResolution;
+	if ( qsResolution.isNull () )
+	  qsResolution = pInfo->qsResolution;
+	iXPos    = qsResolution.find   ( "x" );
+	qsWidth  = qsResolution.left  ( iXPos );
+	qsHeight = qsResolution.right ( iXPos );
+
+	qsVideoFormat = "ntsc";
+	if ( ( pInterface->qsVideoFormat == "pal" ) || ( pInterface->qsVideoFormat == "PAL" ) )
+	  qsVideoFormat = "pal";
+	qsRatio = "4:3";
+	if ( ! pInterface->qsRatio.isEmpty () )
+	  qsRatio = pInterface->qsRatio;
+	else if ( pInfo->qsRatio.isEmpty () )
+	  qsRatio = pInfo->qsRatio;
 	
-	m_keyword.setValue ( Keyword::TransKeys, Keyword::TransWidth,        qsWidth                   );
-	m_keyword.setValue ( Keyword::TransKeys, Keyword::TransHeight,       qsHeight                  );
-	m_keyword.setValue ( Keyword::TransKeys, Keyword::TransVideoFormat,  pInterface->qsVideoFormat );
-	m_keyword.setValue ( Keyword::TransKeys, Keyword::TransVideoType,    pInterface->qsVideoType   );
+	m_keyword.setValue ( Keyword::TransKeys, Keyword::TransWidth,        qsWidth                 );
+	m_keyword.setValue ( Keyword::TransKeys, Keyword::TransHeight,       qsHeight                );
+	m_keyword.setValue ( Keyword::TransKeys, Keyword::TransVideoFormat,  qsVideoFormat           );
+	m_keyword.setValue ( Keyword::TransKeys, Keyword::TransVideoType,    pInterface->qsVideoType );
 	m_keyword.setValue ( Keyword::TransKeys, Keyword::TransVideoBitrate, QString ("%1").arg(pInterface->iVideoBitrate ) );
 	m_keyword.setValue ( Keyword::TransKeys, Keyword::TransFrameRate,    QString ("%1").arg(pInterface->fFrameRate    ) );
-	m_keyword.setValue ( Keyword::TransKeys, Keyword::TransRatio,        pInterface->qsRatio       );
+	m_keyword.setValue ( Keyword::TransKeys, Keyword::TransRatio,        qsRatio                 );
 	
+	// m_keyword.printf ( Keyword::TransKeys );
+
 	for (j=0;j<pBlock->listSubBlocks.count ();j++)	{
 	  pSubBlock = pBlock->listSubBlocks[j];
 	  for (k=0;k<pSubBlock->listBlocks.count ();k++)	{
@@ -1158,9 +1264,8 @@ void QDVDAuthorInit::appendConvert (SourceFileEntry *pEntry)
 	  pSubBlock = pBlock->listSubBlocks[j];
 	  for (k=0;k<pSubBlock->listBlocks.count();k++)	{
 	    pSubSubBlock = pSubBlock->listBlocks[k];
-	    for (i=0;i<pSubSubBlock->listCommands.count();i++)	{
+	    for (i=0;i<pSubSubBlock->listCommands.count();i++)
 	      listCommands.append( m_keyword.resolvConvert( pSubSubBlock->listCommands[i], pSubBlock->qsName ) );
-	    }
 	    iSplitPos ++;
 	    pExecute->listCommandList.append ( listCommands );
 	    pExecute->listBlockIDs.append    ( pSubSubBlock->iBlockID );
@@ -1210,7 +1315,7 @@ void QDVDAuthorInit::appendConvert (SourceFileEntry *pEntry)
       pExecute->qsBlockName = m_keyword.resolvString ( Keyword::SubKeys, m_subtitlesMenuBlock.qsBlockName );
       pExecute->backgroundColor = m_subtitlesMenuBlock.colorBackground;
       if (m_arrayColors.count() > 0)
-	pExecute->backgroundColor = *m_arrayColors[m_iColorCounter++%m_arrayColors.count()];
+	pExecute->backgroundColor = *m_arrayColors[++m_iColorCounter%m_arrayColors.count()];
       else
 	pExecute->backgroundColor.setNamedColor("#9EEE81");
       //      if (m_iColorCounter > (int)m_arrayColors.count())
@@ -1230,7 +1335,7 @@ void QDVDAuthorInit::appendConvert (SourceFileEntry *pEntry)
       m_listToBeDeleted.append (pExecute);
     }
   }
-
+  //printCommandList ("appendConvert");
 }
 
 void QDVDAuthorInit::appendMenu (DVDMenu *pMenu, QString qsMenuName, QString qsBackgroundFileName)
@@ -1280,7 +1385,7 @@ void QDVDAuthorInit::appendMenu (DVDMenu *pMenu, QString qsMenuName, QString qsB
 	pInterface->qsBlockName = m_keyword.resolvString ( Keyword::Keys, pMenuBlock->qsBlockName);
 //	pInterface->backgroundColor = pMenuBlock->colorBackground;
 	if (m_arrayColors.count() > 0)
-		pInterface->backgroundColor = *m_arrayColors[m_iColorCounter++];
+		pInterface->backgroundColor = *m_arrayColors[++m_iColorCounter%m_arrayColors.count()];
 	else
 		pInterface->backgroundColor.setNamedColor("#9EEE81");
 
@@ -1407,16 +1512,28 @@ QString QDVDAuthorInit::convertSoundFile (QString qsOriginalSoundFile)
  */
 void QDVDAuthorInit::resetInitFile ()
 {
-	QString qsInitFile = QDir::homeDirPath();
-	qsInitFile.append(INIT_DIR_NAME);
-	qsInitFile.append(INIT_FILE_NAME);
-	
-	QFile initFile(qsInitFile);
-	if ( initFile.open( IO_WriteOnly ) )	{
-		QTextStream stream( &initFile );
-		QString qsResetInitFile = QString ("<QDVDAuthorInitFile version=\"%1\" delete_older_than=\"30\" >\n").arg((float)INIT_VERSION);
-		qsResetInitFile += QString (
-" <PreferredEngine>QMPlayerWidget</PreferredEngine>\n"
+  
+  QString qsPreferedMediaEngine = "QMPlayerWidget";
+#ifndef MPLAYER_SUPPORT
+  qsPreferedMediaEngine = "KXineWidget";
+  #ifndef XINE_SUPPORT
+    qsPreferedMediaEngine = "QVLCWidget";
+    #ifndef VLC_SUPPORT
+      qsPreferedMediaEngine = "DummyWidget";
+    #endif
+  #endif
+#endif
+
+  QString qsInitFile = QDir::homeDirPath();
+  qsInitFile.append(INIT_DIR_NAME);
+  qsInitFile.append(INIT_FILE_NAME);
+  
+  QFile initFile(qsInitFile);
+  if ( initFile.open( IO_WriteOnly ) )	{
+    QTextStream stream( &initFile );
+    QString qsResetInitFile = QString ("<QDVDAuthorInitFile version=\"%1\" delete_older_than=\"30\" first_start=\"1\" >\n").arg((float)INIT_VERSION);
+    qsResetInitFile += QString (
+" <PreferredEngine>"+qsPreferedMediaEngine+"</PreferredEngine>\n"
 "  <Color number=\"0\">#9EEE81</Color>\n"
 "  <Color number=\"1\">#8FEED3</Color>\n"
 "  <Color number=\"2\">#E0EE8F</Color>\n"
@@ -1435,6 +1552,7 @@ void QDVDAuthorInit::resetInitFile ()
 " <Path name=\"mplex\" ></Path>\n"
 " <Path name=\"arecord\" ></Path>\n"
 " <Path name=\"transcode\" ></Path>\n"
+" <Path name=\"movie-to-dvd\" ></Path>\n"
 " <Path name=\"png2yuv\" ></Path>\n"
 " <Path name=\"oggdec\" ></Path>\n"
 " <Path name=\"mp2enc\" ></Path>\n"
@@ -1464,29 +1582,81 @@ void QDVDAuthorInit::resetInitFile ()
 "  <Convert color=\"#f92f5e\" blockname=\"Conversion Block\" >\n"
 "   <Block editable=\"false\" hidden=\"0\" name=\"MOVIE_BACKGROUND\" >\n"
 "    <Comment>Choose Conversion Tool.</Comment>\n"
-"    <Command default=\"true\" >"CONVERT_TRANSCODE" +INPUT_NAME+</Command>\n"
+"    <Command default=\"true\" >"CONVERT_VIDEOTRANS" +INPUT_NAME+</Command>\n"
+"    <Command>"CONVERT_TRANSCODE" +INPUT_NAME+</Command>\n"
 "    <Command>"CONVERT_MENCODER" +INPUT_NAME+</Command>\n"
 "    <Command>+BASE_NAME+.+FILE_EXT+</Command>\n"
+"    <SubBlock number=\"0\" name=\"VideoTrans\" >\n"
+"     <Block editable=\"false\" hidden=\"0\" name=\"VideoTrans1\" >\n"
+"      <Comment>First extract and scale the video to the propper values.</Comment>\n"
+"      <Command default=\"true\" >movie-to-dvd -M -a +RATIO+ -f audio -m +VIDEO_FORMAT+ -o \"+TEMP_PATH+/+BASE_NAME+/\" \"+INPUT_NAME+\" &amp;&amp; mv \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.vob\" \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mpeg2\"</Command>\n"
+"     </Block>\n"
+"    </SubBlock>\n"
 "    <SubBlock number=\"0\" name=\"Transcode\" >\n"
 "     <Block editable=\"false\" hidden=\"1\" name=\"Transcode\" >\n"
 "      <Comment>This will convert the input movie file from DV - format into DVD conform material.</Comment>\n"
 "      <Comment>This will convert the input movie file from mpeg1 - format into DVD conform material.</Comment>\n"
-"      <Command>transcode -i \"+INPUT_NAME+\" -x ffmpeg -V -w +VIDEO_BITRATE+ --encode_fields b --export_asr +RATIO+ -F \"8,-c -q 6 -4 2 -2 1 -N 0.5 -E -10\" -K tmpgenc -R 2 -y mpeg2enc,mp2enc -b +AUDIO_BITRATE+ -m \"+TEMP_PATH+/+BASE_NAME+.mp2\" -o \"+TEMP_PATH+/+BASE_NAME+.mpg\" --print_status 10</Command>\n"
-"      <Command default=\"true\" >transcode -i \"+INPUT_NAME+\" --export_prof dvd -o \"+TEMP_PATH+/+BASE_NAME+.mpg\"</Command>\n"
+"      <Command>transcode -i \"+INPUT_NAME+\" -x ffmpeg -V -w +VIDEO_BITRATE+ --encode_fields b --export_asr +RATIO+ -F \"8,-c -q 6 -4 2 -2 1 -N 0.5 -E -10\" -K tmpgenc -R 2 -y mpeg2enc,mp2enc -b +AUDIO_BITRATE+ -m \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mpa\" -o \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.m2v\" --print_status 10</Command>\n"
+"      <Command default=\"true\" >transcode -i \"+INPUT_NAME+\" --export_prof dvd -o \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+\"</Command>\n"
+"     </Block>\n"
+"     <Block editable=\"false\" hidden=\"0\" name=\"Transcode2\" >\n"
+"      <Comment>And then we multiplexing the audio and video stream into one file.</Comment>\n"
+"      <Command default=\"true\" >mplex -f 8 -o \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mpeg2\" \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.m2v\" \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mpa\"</Command>\n"
 "     </Block>\n"
 "    </SubBlock>\n"
-"    <SubBlock number=\"0\" name=\"MEncoder3\" >\n"
+"    <SubBlock number=\"0\" name=\"MEncoder\" >\n"
 "     <Block editable=\"false\" hidden=\"0\" name=\"MEncoder1\" >\n"
 "      <Comment>First extract and scale the video to the propper values.</Comment>\n"
-"      <Command default=\"true\" >mencoder -oac copy -nosound -ovc lavc -ss +STARTING_AT+ -endpos +ENDING_AT+ -lavcopts vcodec=mpeg2video:mbd=1:vbitrate=+VIDEO_BITRATE+ -vf scale=+WIDTH+:+HEIGHT+ -ofps +FRAME_RATE+ -o \"+TEMP_PATH+/+BASE_NAME+.avi\" \"+INPUT_NAME+\"</Command>\n"
+"      <Command default=\"true\" >mencoder -oac copy -nosound -ovc lavc -ss +STARTING_AT+ -endpos +ENDING_AT+ -lavcopts vcodec=mpeg2video:mbd=1:vbitrate=+VIDEO_BITRATE+ -vf scale=+WIDTH+:+HEIGHT+ -ofps +FRAME_RATE+ -o \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mpg\" \"+INPUT_NAME+\"</Command>\n"
 "     </Block>\n"
 "     <Block editable=\"false\" hidden=\"0\" name=\"MEncoder2\" >\n"
 "      <Comment>Next we get the audio file from the input movie.</Comment>\n"
-"      <Command default=\"true\" >mplayer -ao pcm -af resample=+SAMPLE_RATE+:16:8 -srate +SAMPLE_RATE+ -vo null -vc null \"+INPUT_NAME+\" -aofile /dev/stdout | mp2enc  -b +AUDIO_BITRATE+ -r +SAMPLE_RATE+ -o \"+TEMP_PATH+/+BASE_NAME+.mp2\"</Command>\n"
+"      <Command default=\"true\" >mplayer -ao pcm -af resample=+SAMPLE_RATE+:16:8 -srate +SAMPLE_RATE+ -vo null -vc null \"+INPUT_NAME+\" -aofile /dev/stdout | mp2enc  -b +AUDIO_BITRATE+ -r +SAMPLE_RATE+ -o \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mp2\"</Command>\n"
 "     </Block>\n"
 "     <Block editable=\"false\" hidden=\"0\" name=\"MEncoder3\" >\n"
 "      <Comment>And then we multiplexing the audio and video stream into one file.</Comment>\n"
-"      <Command default=\"true\" >mplex -f 8 -o \"+TEMP_PATH+/+BASE_NAME+.vob\" \"+TEMP_PATH+/+BASE_NAME+.mpg\" \"+TEMP_PATH+/+BASE_NAME+.mp2\"</Command>\n"
+"      <Command default=\"true\" >mplex -f 8 -o \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mpeg2\" \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mpg\" \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mp2\"</Command>\n"
+"     </Block>\n"
+"    </SubBlock>\n"
+"   </Block>\n"
+"   <Block editable=\"false\" hidden=\"0\" name=\"IMAGE_BACKGROUND\" >\n"
+"    <Comment>Choose Conversion Tool.</Comment>\n"
+"    <Command default=\"true\" >"CONVERT_VIDEOTRANS" +INPUT_NAME+</Command>\n"
+"    <Command>"CONVERT_TRANSCODE" +INPUT_NAME+</Command>\n"
+"    <Command>"CONVERT_MENCODER" +INPUT_NAME+</Command>\n"
+"    <Command>+BASE_NAME+.+FILE_EXT+</Command>\n"
+"    <SubBlock number=\"0\" name=\"VideoTrans\" >\n"
+"     <Block editable=\"false\" hidden=\"0\" name=\"VideoTrans1\" >\n"
+"      <Comment>This command will convert the input video into the propper VOB format.</Comment>\n"
+"      <Command default=\"true\" >movie-to-dvd -M -a +RATIO+ -f audio -m +VIDEO_FORMAT+ -o \"+TEMP_PATH+/+BASE_NAME+/\" \"+INPUT_NAME+\" &amp;&amp; mv \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.vob\" \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mpeg2\"</Command>\n"
+"     </Block>\n"
+"    </SubBlock>\n"
+"    <SubBlock number=\"0\" name=\"Transcode\" >\n"
+"     <Block editable=\"false\" hidden=\"1\" name=\"Transcode\" >\n"
+"      <Comment>These commands will re-multiplex the mpeg2 video to include VOBUs.</Comment>\n"
+"      <Command default=\"true\" >transcode -i \"+INPUT_NAME+\" --export_prof dvd -o \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+\"</Command>\n"
+"      <Command>transcode -i \"+INPUT_NAME+\" -x ffmpeg -V -w +VIDEO_BITRATE+ --encode_fields b --export_asr +RATIO+ -F \"8,-c -q 6 -4 2 -2 1 -N 0.5 -E -10\" -K tmpgenc -R 2 -y mpeg2enc,mp2enc -b +AUDIO_BITRATE+ -m \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mpa\" -o \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.m2v\" --print_status 10</Command>\n"
+"     </Block>\n"
+"     <Block editable=\"false\" hidden=\"0\" name=\"Transcode2\" >\n"
+"      <Comment>And then we multiplexing the audio and video stream into one file.</Comment>\n"
+"      <Command default=\"true\" >mplex -f 8 -o \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mpeg2\" \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.m2v\" \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mpa\"</Command>\n"
+"     </Block>\n"
+"    </SubBlock>\n"
+"    <SubBlock number=\"0\" name=\"MEncoder\" >\n"
+"     <Block editable=\"false\" hidden=\"0\" name=\"MEncoder1\" >\n"
+"      <Comment>These commands will re-multiplex the mpeg2 video to include VOBUs.</Comment>\n"
+"      <Command default=\"true\" >mplayer -dumpfile \"+INPUT_NAME+\" -dumpaudio \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mpa\" </Command>\n"
+"      <Command>mencoder -oac copy -nosound -ovc lavc -ss +STARTING_AT+ -endpos +ENDING_AT+ -lavcopts vcodec=mpeg2video:mbd=1:vbitrate=+VIDEO_BITRATE+ -vf scale=+WIDTH+:+HEIGHT+ -ofps +FRAME_RATE+ -o \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mpg\" \"+INPUT_NAME+\"</Command>\n"
+"     </Block>\n"
+"     <Block editable=\"false\" hidden=\"0\" name=\"MEncoder2\" >\n"
+"      <Comment>Next we get the video file from the input movie.</Comment>\n"
+"      <Command default=\"true\" >mplayer -dumpfile \"+INPUT_NAME+\" -dumpvideo \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.m2v\" </Command>\n"
+"      <Command>mencoder -oac copy -nosound -ovc lavc -ss +STARTING_AT+ -endpos +ENDING_AT+ -lavcopts vcodec=mpeg2video:mbd=1:vbitrate=+VIDEO_BITRATE+ -vf scale=+WIDTH+:+HEIGHT+ -ofps +FRAME_RATE+ -o \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mpg\" \"+INPUT_NAME+\"</Command>\n"
+"     </Block>\n"
+"     <Block editable=\"false\" hidden=\"0\" name=\"MEncoder3\" >\n"
+"      <Comment>And then we multiplexing the audio and video stream into one file.</Comment>\n"
+"      <Command default=\"true\" >mplex -f 8 -o \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mpeg2\" \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.m2v\" \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mpa\"</Command>\n"
+"      <Command default=\"true\" >mplex -f 8 -o \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mpeg2\" \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.m2v\" \"+TEMP_PATH+/+BASE_NAME+/+BASE_NAME+.mp2\"</Command>\n"
 "     </Block>\n"
 "    </SubBlock>\n"
 "   </Block>\n"
@@ -1554,7 +1724,7 @@ void QDVDAuthorInit::resetInitFile ()
 "      </Block>\n"
 "      <Block name=\"IMAGE_BACKGROUND\">\n"
 "        <Comment>&lt;p align=\"center\"&gt;This line of command will convert the background image&lt;BR&gt;into a MPEG2 stream in PAL format +WIDTH+x+HEIGHT+&lt;/p&gt;</Comment>\n"
-"        <Command default=\"true\" >jpegtopnm \"+BACKGROUND_FULL_NAME+\" | ppmtoy4m -n 1 -F25:1 -A59:54 -I t -L | mpeg2enc -f 8 -n p -o \"+TEMP_PATH+/+MENU_NAME+/menu.m2v\"</Command>\n"
+"        <Command default=\"true\" >jpegtopnm \"+BACKGROUND_FULL_NAME+\" | ppmtoy4m -n 50 -r -S 420mpeg2 -F25:1 -A59:54 -I t -L | mpeg2enc -f 8 -n p -o \"+TEMP_PATH+/+MENU_NAME+/menu.m2v\"</Command>\n"
 "        <Command>jpeg2yuv -n 50 -I p -f 25 -j \"+BACKGROUND_FULL_NAME+\" | mpeg2enc -n p -f 8 -o \"+TEMP_PATH+/+MENU_NAME+/menu.m2v\"</Command>\n"
 "      </Block>\n"
 "      <Block name=\"EMPTY_SOUND\">\n"
@@ -1562,7 +1732,7 @@ void QDVDAuthorInit::resetInitFile ()
 "        <Command>arecord -f dat -twav -d 1 | mp2enc -r 48000 -o \"+TEMP_PATH+/+MENU_NAME+/menu.mp2\"</Command>\n"
 "        <Command>arecord -S -M -t 1 -w /dev/stdout | mp2enc -r 48000 -o \"+TEMP_PATH+/+MENU_NAME+/menu.mp2\"</Command>\n"
 "        <Command>sox -t raw -s -w -c 2 -r 48000 /dev/zero -t wav -c 2 -r 48000 /dev/stdout trim 0 1 | mp2enc -r 48000 -o \"+TEMP_PATH+/+MENU_NAME+/menu.mp2\"</Command>\n"
-"        <Command default=\"true\">dd if=/dev/zero bs=4 count=1920 | toolame -b128 -s 48 /dev/stdin \"+TEMP_PATH+/+MENU_NAME+/menu.mp2\"</Command>\n"
+"        <Command default=\"true\">dd if=/dev/zero bs=4 count=1920 | toolame -b128 -s 48000 /dev/stdin \"+TEMP_PATH+/+MENU_NAME+/menu.mp2\"</Command>\n"
 "      </Block>\n"
 "      <Block name=\"MPLEX\">\n"
 "        <Comment>&lt;p align=\"center\"&gt;The following command will multiplex the sound file into the menu-movie.&lt;/p&gt;</Comment>\n"
@@ -1621,7 +1791,7 @@ void QDVDAuthorInit::resetInitFile ()
 "      </Block>\n"
 "      <Block name=\"IMAGE_BACKGROUND\">\n"
 "        <Comment>&lt;p align=\"center\"&gt;This line of command will convert the background image&lt;BR&gt;into a MPEG2 stream in NTSC format +WIDTH+x+HEIGHT+&lt;/p&gt;</Comment>\n"
-"        <Command>jpegtopnm \"+BACKGROUND_FULL_NAME+\" | ppmtoy4m -n 1 -F30000:1001 -A10:11 -I t -L | mpeg2enc -f 8 -n n -o \"+TEMP_PATH+/+MENU_NAME+/menu.m2v\"</Command>\n"
+"        <Command>jpegtopnm \"+BACKGROUND_FULL_NAME+\" | ppmtoy4m -n 50 -r -S 420mpeg2 -F30000:1001 -A10:11 -I t -L | mpeg2enc -f 8 -n n -o \"+TEMP_PATH+/+MENU_NAME+/menu.m2v\"</Command>\n"
 "        <Command default=\"true\">jpeg2yuv -n 50 -I p -f 29.97 -j \"+BACKGROUND_FULL_NAME+\" | mpeg2enc -n n -f 8 -o \"+TEMP_PATH+/+MENU_NAME+/menu.m2v\"</Command>\n"
 "      </Block>\n"
 "      <Block name=\"EMPTY_SOUND\">\n"
@@ -1629,7 +1799,7 @@ void QDVDAuthorInit::resetInitFile ()
 "        <Command default=\"true\">arecord -f dat -twav -d 1 /dev/stdout | mp2enc -r 48000 -o \"+TEMP_PATH+/+MENU_NAME+/menu.mp2\"</Command>\n"
 "        <Command>arecord -S -M -t 1 -w /dev/stdout | mp2enc -r 48000 -o \"+TEMP_PATH+/+MENU_NAME+/menu.mp2\"</Command>\n"
 "        <Command>sox -t raw -s -w -c 2 -r 48000 /dev/zero -t wav -c 2 -r 48000 /dev/stdout trim 0 1 | mp2enc -r 48000 -o \"+TEMP_PATH+/+MENU_NAME+/menu.mp2\"</Command>\n"
-"        <Command>dd if=/dev/zero bs=4 count=1601 | toolame -b128 -s 48 /dev/stdin \"+TEMP_PATH+/+MENU_NAME+/menu.mp2\"</Command>\n"
+"        <Command>dd if=/dev/zero bs=4 count=1601 | toolame -b128 -s 48000 /dev/stdin \"+TEMP_PATH+/+MENU_NAME+/menu.mp2\"</Command>\n"
 "      </Block>\n"
 "      <Block name=\"MPLEX\">\n"
 "        <Comment>&lt;p align=\"center\"&gt;The following command will multiplex the sound file into the menu-movie.&lt;/p&gt;</Comment>\n"
@@ -1680,8 +1850,9 @@ void QDVDAuthorInit::resetInitFile ()
 "    </Burning>\n"
 "  </ExecuteInterface>\n"
 "</QDVDAuthorInitFile>\n");
-  		stream << (const char *)qsResetInitFile << "\n";
-		initFile.close();
+  		stream << qsResetInitFile << "\n";
+		initFile.flush ( );
+		initFile.close ( );
 	}
 }
 
