@@ -165,53 +165,60 @@ void KaffeinesWidget::saveInitFile ()
 	xine_config_save (pXineEngine, (const char *)qsConfigFile);
 }
 
-void KaffeinesWidget::playMRL (const QString qsMRL)
+void KaffeinesWidget::playMRL ( const QString qsMRL )
 {
-	m_qsMRL = qsMRL;
-	// Ensure the initialization is done ...
-	clearQueue();
-	appendToQueue(qsMRL);
-	slotPlay();
-	m_bPaused = false;
+  m_qsMRL = qsMRL;
+  // Ensure the initialization is done ...
+  clearQueue    ( );
+  appendToQueue ( qsMRL );
+  slotPlay      ( );
+  m_bPaused = false;
 }
 
-bool KaffeinesWidget::openMRL (const QString qsMRL)
+bool KaffeinesWidget::openMRL ( const QString qsMRL )
 {
-	appendToQueue (qsMRL);
-	slotStop ();
-	return true;
+  m_qsMRL = qsMRL;
+  appendToQueue ( qsMRL );
+  slotPlay      ( );
+  stop          ( );
+
+  return true;
 }
 
 void KaffeinesWidget::play ()
 {
-	if (isPaused())
-		slotSpeedPause ();
-	else
-		slotPlay ();
-	m_bPaused = false;
+  if ( isPaused ( ) )
+    slotSpeedPause ( );
+  else
+    slotPlay ( );
+  m_bPaused = false;
 }
 
 void KaffeinesWidget::pause()
 {
-	slotSpeedPause();
-	m_bPaused = true;
+  slotSpeedPause();
+  m_bPaused = true;
 }
 
 void KaffeinesWidget::stop ()
 {
-	slotStop();
+  m_posTimer.stop( );
+  if ( m_lengthInfoTimer.isActive ( ) ) 
+       m_lengthInfoTimer.stop ( );
+  if ( isPlaying ( ) )
+       xine_stop ( m_xineStream );
 }
 
 void KaffeinesWidget::setSpeed(float fValue)
 {
-	if (fValue > 1.0)
-		slotSpeedFaster();
-	else if (fValue == 1.0)
-		slotSpeedNormal ();
-	else if (fValue == 0.0)
-		slotSpeedPause ();
-	else if (fValue < 1.0)
-		slotSpeedSlower();
+  if (fValue > 1.0)
+    slotSpeedFaster();
+  else if (fValue == 1.0)
+    slotSpeedNormal ();
+  else if (fValue == 0.0)
+    slotSpeedPause ();
+  else if (fValue < 1.0)
+    slotSpeedSlower();
 }
 
 void KaffeinesWidget::setVolume(float fValue)
@@ -225,20 +232,20 @@ void KaffeinesWidget::setVolume(float fValue)
 
 void KaffeinesWidget::setPosition(uint iPosition)
 {
-	if (isSeekable())
-		slotSeekToPosition(iPosition);
+  if ( isSeekable ( ) )
+    slotSeekToPosition ( iPosition );
 }
 
-void KaffeinesWidget::setPositionByTime(uint iPosition)
+void KaffeinesWidget::setPositionByTime ( uint iPosition )
 {
-	QTime seekTime;
-	seekTime = seekTime.addSecs (iPosition);
-	slotSeekToTime(seekTime);
+  QTime seekTime;
+  seekTime = seekTime.addSecs ( iPosition );
+  slotSeekToTime ( seekTime );
 }
 
 float KaffeinesWidget::volume               ()
 {
-	return 0.0f;
+  return 0.0f;
 }
 
 float KaffeinesWidget::position             ()
@@ -261,10 +268,10 @@ void KaffeinesWidget::initMediaEngine ()
 
 QImage KaffeinesWidget::getScreenshot ()
 {
-	return getScreenshot (0.0f);
+	return getScreenshot ( 0.0f );
 }
 
-QImage KaffeinesWidget::getScreenshot(float fTime)
+QImage KaffeinesWidget::getScreenshot ( float fTime )
 {
 	// fTime in Seconds ...
 	QTime seekTime;
@@ -276,6 +283,22 @@ QImage KaffeinesWidget::getScreenshot(float fTime)
 	return KXineWidget::getScreenshot ();
 }
 
+bool KaffeinesWidget::setScreenshot ( long iMSecOffset )
+{
+  QTime seekTime;
+  seekTime = seekTime.addMSecs ( iMSecOffset );
+  playMRL ( m_qsMRL );
+  //slotPlay ( );
+  slotSeekToTime ( seekTime );
+  stop           ( );
+  return true;
+}
+
+bool KaffeinesWidget::setScreenshot ( QPixmap & )
+{
+  return false;
+}
+
 // Non mandatory functions. 
 void KaffeinesWidget::setAspectRatio (uint)
 {
