@@ -1,11 +1,11 @@
 /***************************************************************************
-                           kxinewidget.h - 
-		A KDE/QT API for the xine-lib. Define USE_QT_ONLY if you use QT only. 
+                           kxinewidget.h -
+		A KDE/QT API for the xine-lib. Define USE_QT_ONLY if you use QT only.
                              -------------------
     begin                : Fre Apr 18 2003
-    revision             : $Revision: 1.6 $
-    last modified        : $Date: 2004/10/07 12:16:35 $ by $Author: juergenk $
-    copyright            : (C) 2003-2004 by Jürgen Kofler
+    revision             : $Revision: 1.82 $
+    last modified        : $Date: 2006/01/13 05:04:19 $ by $Author: qdvdauthor $
+    copyright            : (C) 2003-2005 by Jürgen Kofler
     email                : kaffeine@gmx.net
  ***************************************************************************/
 
@@ -24,14 +24,14 @@
 /* define this if you want to use QT only - disables post plugin support (except visualization)! */
 #define USE_QT_ONLY 1
 
-/* Usage: 
+/* Usage:
  *
  * KXineWidget m_xine = new KXineWidget(parent);
  * m_xine->appendToQueue("the_best_song_of_the_world.mp3");
- *  
- * You should at least connect to signalXineFatal(const QString&)! 
  *
- */ 
+ * You should at least connect to signalXineFatal(const QString&)!
+ *
+ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -46,9 +46,9 @@ class QTimerEvent;
 #include <qdatetime.h>
 #include <qptrlist.h>
 #include <qwidget.h>
-#include <qthread.h>
 #include <qtimer.h>
-#include <pthread.h>
+#include <qthread.h>
+#include <qptrlist.h>
 
 #include <X11/Xlib.h>
 #include <xine.h>
@@ -57,47 +57,50 @@ class QTimerEvent;
 #include "postfilter.h"
 #else
  typedef int PostFilter; /* dummy type */
-#endif 
- 
-#define SUPPORTED_PROTOCOLS "file,http,mms,mmst,rtsp,rtp,tcp,pnm,cdda,vcd,vcdo,dvd,dvb,pvr,v4l,net,vdr"
+#endif
+
+#define SUPPORTED_PROTOCOLS "file,http,mms,mmst,rtsp,rtp,tcp,pnm,cdda,vcd,vcdo,dvd,dvb,pvr,v4l,net,vdr,smb"
 
 #define DEFAULT_TVTIME_CONFIG "tvtime:method=LinearBlend,enabled=1,pulldown=none,framerate_mode=half_top,judder_correction=0,use_progressive_frame_flag=1,chroma_filter=0,cheap_mode=1"
 
 #define DEFAULT_OSD_FONT_SIZE 18
-#define DEFAULT_OSD_DURATION  5000 
-  
+#define DEFAULT_OSD_DURATION  5000
+#define OSD_MESSAGE_LOW_PRIORITY    1
+#define OSD_MESSAGE_NORMAL_PRIORITY 2
+
 class KXineWidget : public QWidget, private QThread
 {
 
  Q_OBJECT
-   
-public: 
-  KXineWidget(QWidget *parent=0, const char *name=0, 
+
+public:
+  KXineWidget(QWidget *parent=0, const char *name=0,
   		const QString& pathToConfigFile = QString::null, const QString& pathToLogoFile = QString::null,
-		const QString& audioDriver = QString::null, const QString& videoDriver = QString::null, 
+		const QString& audioDriver = QString::null, const QString& videoDriver = QString::null,
 		bool startManual = false, bool verbose = false);
  ~KXineWidget();
- 
-  enum Speed { Normal = 0, Pause, Fast1, Fast2, Slow1, Slow2 };
- 
+
+  enum Speed { Normal = 0, Pause, Fast1, Fast2, Slow1, Slow2, Undefined };
+
   bool initXine(); /* call this only if you set startManual = true in the constructor */
   bool isXineReady() const { return m_xineReady; }
   bool isPlaying() const;
   Speed getSpeed() const { return m_currentSpeed; }
   QString getXineLog() const;
-  
+
   void setQueue(const QStringList& urls) { m_queue = urls; }
   void appendToQueue(const QString& url) { m_queue.append(url); } /* file to play; call slotPlay() to play queue... */
   void clearQueue() { m_queue.clear(); }
   bool isQueueEmpty() const { return m_queue.empty(); }
-  
-  void showOSDMessage(const QString& message, uint duration); // ms
-  
+
+  void showOSDMessage(const QString& message, uint duration = DEFAULT_OSD_DURATION /* ms */, int priority = OSD_MESSAGE_NORMAL_PRIORITY);
+
   /* stream info */
   const QString& getURL() const { return m_trackURL; }
   const QString& getTitle() const { return m_trackTitle; }
   const QString& getArtist() const { return m_trackArtist; }
   const QString& getAlbum() const { return m_trackAlbum; }
+  const QString& getTrackNumber() const { return m_trackNumber; } //may return an empty string with xine-lib 1.0
   const QString& getGenre() const { return m_trackGenre; }
   const QString& getYear() const { return m_trackYear; }
   const QString& getComment() const { return m_trackComment; }
@@ -115,11 +118,14 @@ public:
   bool hasSubtitleURL() const { return !m_trackSubtitleURL.isNull(); }
   bool hasSaveURL() const { return !m_trackSaveURL.isNull(); }
   bool isSeekable() const { return m_trackIsSeekable; }
-  
+
   uint getVolume() const; /* percent */
+  bool SoftwareMixing() const;
   QTime getPlaytime() const;
   uint getPosition() const; /* 0..65535 */
-  
+
+  void savePosition(const int pos) { (pos > 0) ? m_savedPos = pos : m_savedPos = 0; }
+
   /* plugin handling */
   QStringList getAudioDrivers() const { return m_audioDriverList; }
   QStringList getVideoDrivers() const { return m_videoDriverList; }
@@ -127,17 +133,17 @@ public:
   bool getAutoplayPluginURLS(const QString& name, QStringList& urls);
   QStringList getVisualPlugins() const;
 
-#ifndef USE_QT_ONLY  
+#ifndef USE_QT_ONLY
   void createDeinterlacePlugin(const QString& configString, QWidget* parent);
   const QString getDeinterlaceConfig() const;
   QStringList getVideoFilterNames() const;
   QStringList getAudioFilterNames() const;
   QStringList getAudioFilterConfig();
   QStringList getVideoFilterConfig();
-#endif  
+#endif
 
   QString getSupportedExtensions() const;  /* get mime types xine can play */
-  
+
   void playNextChapter() const;
   void playPreviousChapter() const;
 
@@ -151,8 +157,8 @@ public:
   QString audiocdDevice() const;
   QString vcdDevice() const;
   QString dvdDevice() const;
-  
- /* take a screenshot */                       
+
+ /* take a screenshot */
   QImage getScreenshot() const;
   void getScreenshot(uchar*& rgb32BitData, int& videoWidth, int& videoHeight, double& scaleFactor) const;
 
@@ -165,7 +171,7 @@ public:
   void stopMouseHideTimer();
 
   void globalPosChanged();  /* call this if global pos of parent was changed */
-  
+
 signals:
   void signalXineFatal(const QString& message);   /** initXine() not successfull! **/
   void signalXineError(const QString& message);
@@ -173,29 +179,30 @@ signals:
   void signalXineStatus(const QString& status);
   void signalXineReady();
   void signalXinePlaying();
-  
+
   void signalHasChapters(bool);
   void signalPlaybackFinished();
   void signalNewChannels(const QStringList& audio, const QStringList& sub, int currentAudio, int currentSub);
   void signalNewPosition(int, const QTime&);
   void signalNewPosition(int, const QString&);
   void signalNewPosition(long);
-  
+
   void signalTitleChanged();
   void signalVideoSizeChanged();
-  void signalLengthChanged(); 
+  void signalLengthChanged();
 
   void signalRightClick(const QPoint&);  /* right-click on video window */
   void signalLeftClick(const QPoint&);
   void signalMiddleClick();
   void signalDoubleClick();
-  
+  void signalSyncVolume();
+
 public slots:
   virtual void polish();
-  
+
   void slotPlay();
   void slotStop();
-  
+
   void slotSetVolume(int);
   void slotToggleMute();
   void slotSpeedPause();
@@ -224,7 +231,8 @@ public slots:
   void slotZoomOff();
   void slotToggleDeinterlace();
   void slotSetDeinterlaceConfig(const QString&);
-  
+  void slotGetInfoDelayed();
+
   /* disc drive devices */
   void slotSetAudiocdDevice(const QString&);
   void slotSetVcdDevice(const QString&);
@@ -247,8 +255,9 @@ public slots:
   void slotSetEq4k(int val);
   void slotSetEq8k(int val);
   void slotSetEq16k(int val);
+  void slotSetVolumeGain(bool gain);
 
- /* DVD Menus */ 
+ /* DVD Menus */
   void slotMenuToggle();
   void slotMenuTitle();
   void slotMenuRoot();
@@ -260,7 +269,7 @@ public slots:
   void slotDVDMenuRight();
   void slotDVDMenuUp();
   void slotDVDMenuDown();
-  void slotDVDMenuSelect();  
+  void slotDVDMenuSelect();
 
  /***** postprocess filters ****/
   void slotCreateVideoFilter(const QString& name, QWidget* parent);
@@ -270,12 +279,12 @@ public slots:
   void slotRemoveAllVideoFilters();
   void slotRemoveAllAudioFilters();
 
-  
 protected slots:
   void slotSendPosition();
   void slotEmitLengthInfo();
   void slotHideMouse();
   void slotOSDHide();
+  void slotNoRecentMessage();
 
 protected:
   void mouseMoveEvent(QMouseEvent*);
@@ -300,13 +309,15 @@ private:
   static void audioDriverChangedCallback(void* p, xine_cfg_entry_t* entry);
   static void audioMixerMethodChangedCallback(void* p, xine_cfg_entry_t* entry);
   static void showOSDMessagesChangedCallback(void* p, xine_cfg_entry_t* entry);
+  static void sizeForOSDMessagesChangedCallback(void* p, xine_cfg_entry_t* entry);
+  static void fontForOSDMessagesChangedCallback(void* p, xine_cfg_entry_t* entry);
 
   static void xineEventListener(void* p, const xine_event_t*);
-  
-protected:  
+
+protected:
   void sendXineError();
   QTime getLengthInfo();
-#ifndef USE_QT_ONLY  
+#ifndef USE_QT_ONLY
   void wireVideoFilters();
   void unwireVideoFilters();
   void wireAudioFilters();
@@ -317,7 +328,7 @@ protected:
 public:
 #ifdef USE_QT_ONLY
   static QString i18n(const char *text);
-#endif  
+#endif
   static void debugOut(QString);
   static void errorOut(QString);
   static void warningOut(QString);
@@ -325,9 +336,9 @@ public:
   static void   yuy2Toyv12(uint8_t *y, uint8_t *u, uint8_t *v, uint8_t *input, int width, int height);
   static uchar *yv12ToRgb(uint8_t *src_y, uint8_t *src_u, uint8_t *src_v, int width, int height);
 
-protected:  
+protected:
   QStringList m_queue;
-  
+
   bool m_startXineManual;
   bool m_xineReady;
   QString m_logoFile;
@@ -338,12 +349,12 @@ protected:
   QStringList m_audioDriverList;
   QStringList m_videoDriverList;
 
- /*x11*/ 
+ /*x11*/
   Window m_xineWindow;
   Display* m_xineDisplay;
   int m_xineScreen;
-  
- /*xine*/ 
+
+ /*xine*/
   x11_visual_t m_x11Visual;
   xine_t* m_xineEngine;
   xine_audio_port_t* m_audioDriver;
@@ -353,12 +364,23 @@ protected:
   xine_osd_t* m_osd;
   bool m_osdUnscaled;
   bool m_osdShow;
-  
-#ifndef USE_QT_ONLY 
+  int m_osdSize;
+  char* m_osdFont;
+  char** m_audioChoices;
+  char* m_audioInfo;
+  char** m_videoChoices;
+  char* m_videoInfo;
+  char* m_mixerInfo;
+  char* m_osdShowInfo;
+  char** m_osdSizeOptions;
+  char* m_osdSizeInfo;
+  char* m_osdFontInfo;
+
+#ifndef USE_QT_ONLY
  /*postfilter*/
   QPtrList<PostFilter> m_videoFilterList;
   bool m_videoFiltersEnabled;
-  QPtrList<PostFilter> m_audioFilterList; 
+  QPtrList<PostFilter> m_audioFilterList;
   bool m_audioFiltersEnabled;
   PostFilter* m_deinterlaceFilter;
   bool m_deinterlaceEnabled;
@@ -366,13 +388,13 @@ protected:
 #else
   xine_post_t* m_xinePost;
   xine_post_out_t* m_postAudioSource;
-  xine_post_in_t* m_postInput; 
-#endif  
-  
+  xine_post_in_t* m_postInput;
+#endif
+
   QString m_audioDriverName;
   QString m_videoDriverName;
   QString m_visualPluginName;
-  
+
   int m_videoFrameWidth;
   int m_videoFrameHeight;
   double m_videoAspect;
@@ -382,10 +404,11 @@ protected:
   Speed m_currentSpeed;
   QString m_xineMessage;
   QString m_xineError;
-  QString m_statusString; 
+  QString m_statusString;
   bool m_softwareMixer;
+  bool m_volumeGain;
   double m_displayRatio;
-  QString m_cachedCDPath, m_cachedVCDPath, m_cachedDVDPath; 
+  QString m_cachedCDPath, m_cachedVCDPath, m_cachedDVDPath;
   QSize m_newParentSize;
   int m_currentZoom;
   QStringList m_audioCh;
@@ -398,13 +421,16 @@ protected:
 
   QTimer m_posTimer;
   QTimer m_lengthInfoTimer;
+  uint m_lengthInfoTries;
   QTimer m_mouseHideTimer;
   QTimer m_osdTimer;
- 
+  QTimer m_recentMessagesTimer;
+
   QString m_trackURL;
-  QString m_trackTitle; 
-  QString m_trackArtist; 
+  QString m_trackTitle;
+  QString m_trackArtist;
   QString m_trackAlbum;
+  QString m_trackNumber;
   QString m_trackGenre;
   QString m_trackYear;
   QString m_trackComment;
@@ -416,9 +442,35 @@ protected:
   QString m_trackSubtitleURL;
   QString m_trackSaveURL;
   bool m_trackHasVideo;
-  bool m_trackHasAudio; 
+  bool m_trackHasAudio;
   bool m_trackHasChapters;
   bool m_trackIsSeekable;
+
+/*  dvb  */
+signals:
+  void stopDvb();
+
+public:
+  QString TimeShiftFilename;
+
+public slots:
+  void setDvb( const QString &pipeName, const QString &chanName, int haveVideo );
+  void setDvbCurrentNext( const QStringList &list );
+  bool openDvb();
+  bool playDvb();
+  void slotPlayTimeShift();
+  void dvbShowOSD();
+  void dvbHideOSD();
+
+private:
+  int dvbHaveVideo;
+  QTimer dvbOSDHideTimer;
+  xine_osd_t *dvbOSD;
+  QStringList dvbCurrentNext;
+  unsigned int dvbColor[256];
+  unsigned char dvbTrans[256];
+  unsigned int rgb2yuv( unsigned int R, unsigned int G, unsigned int B );
+  void initDvbPalette();
 };
 
 
