@@ -64,6 +64,8 @@ public:
 	virtual float position             ( ) = 0;
 	virtual QImage getScreenshot       ( ) = 0;
  	virtual QImage getScreenshot ( float ); // value in Seconds ...
+	virtual bool   setScreenshot ( long  ) = 0; // value in MSeconds
+	virtual bool   setScreenshot ( QPixmap & ) = 0;
 
 	// Functions handled in the MediaInterface - calss
 	const QString& getMRL();
