@@ -229,7 +229,7 @@ void MPlayerInfo::slotReadStdout ()
 //	test_print ();
 }
 
-QImage MPlayerInfo::getScreenshot(uint iSeconds)
+QImage MPlayerInfo::getScreenshot( long iMSecOffset )
 {
 	// FIXME:
 	// check out "-fixed-vo" "-aid" "-vid" "-sid" "-slang" options.
@@ -239,14 +239,14 @@ QImage MPlayerInfo::getScreenshot(uint iSeconds)
 	QImage theImage;
 	QString qsCommand, qsTempPath, m_qsScreenshotName;
 	QTime timeOffset;
-	timeOffset = timeOffset.addSecs (iSeconds);
+	timeOffset = timeOffset.addMSecs ( iMSecOffset );
 	QFileInfo fileInfo(getFileName());
 
 	qsTempPath = QString ("%1/%2").arg(m_qsTempPathName).arg(fileInfo.baseName());
 	system ((const char *)QString("mkdir -p \"%1\"").arg(qsTempPath));
 	
 	m_qsScreenshotName  = QString ("%1/00000001.jpg").arg(qsTempPath);
-	if (iSeconds != 0)	// For some reasons Mplayer produces always the first image from start
+	if (iMSecOffset != 0)	// For some reasons Mplayer produces always the first image from start
 		m_qsScreenshotName  = QString ("%1/00000002.jpg").arg(qsTempPath);
 
 	// Next we verify that the file has been created.
@@ -256,7 +256,7 @@ QImage MPlayerInfo::getScreenshot(uint iSeconds)
 	
 	// Here we generate the screenshot ...
 //	qsCommand = QString("mplayer -ao null -vo jpeg:outdir=\"%1/\" -frames 2 -quiet \"%2\" &>/dev/null").arg(qsTempPath).arg(getFileName());
-	if (iSeconds == 0)
+	if ( iMSecOffset == 0 )
 		qsCommand = QString("mplayer -ao null -vo jpeg:outdir=\"%1/\" -frames 2 -quiet \"%2\" &>/dev/null").arg(qsTempPath).arg(getFileName());
 	else
 		qsCommand = QString("mplayer -ao null -vo jpeg:outdir=\"%1/\" -ss %2 -forceidx -frames 3 -quiet \"%3\" &>/dev/null").arg(qsTempPath).arg(timeOffset.toString()).arg(getFileName());
