@@ -28,7 +28,7 @@ public:
 	virtual ~MPlayerInfo ();
 
 	// Mandatory function getScreenshot ()
-	virtual QImage getScreenshot(uint s=0);
+	virtual QImage getScreenshot ( long ms=0 );
 
 	// Non-standard functions (not implemented through MediaInfo ...)
 	virtual bool hasChapters ();
