@@ -168,9 +168,33 @@ QImage MPlayerWidget::getScreenshot ()
 	return getScreenshot (0.0f);
 }
 
-QImage MPlayerWidget::getScreenshot(float)
+QImage MPlayerWidget::getScreenshot ( float fSeconds )
 {
-	return QImage ();
+  if ( m_pMediaInfo )
+    return m_pMediaInfo->getScreenshot ( (long)(fSeconds * 1000.0) );
+  return QImage ();
+}
+
+bool MPlayerWidget::setScreenshot ( long iMSecOffset )
+{
+  // set the current image to be displayed. 
+  QImage theImage = getScreenshot ( (float) iMSecOffset / 1000.0 );
+  if ( ! theImage.isNull ( ) ) {
+    theImage = theImage.smoothScale ( width (), height (), QImage::ScaleMin );
+    QPixmap pix;
+    pix.convertFromImage ( theImage );
+    return setScreenshot ( pix );
+  }
+  return false;
+}
+ 
+bool MPlayerWidget::setScreenshot ( QPixmap &pix )
+{
+  if ( pix.isNull ( ) )
+    return false;
+  getWidget ( )->setPaletteBackgroundPixmap ( pix );
+  getWidget ( )->resize ( pix.width ( ), pix.height ( ) );
+  return true;
 }
 
 // Non mandatory functions. 
