@@ -45,14 +45,86 @@ XineInfo::~XineInfo ()
 	if (m_bOwnXineEngine)
 		xine_exit((xine_t*)m_pMediaEngine);
 }
+#include <X11/X.h>
+#include <X11/Xlib.h>
+#include <X11/Xutil.h>
+#include <X11/keysym.h>
+#include <X11/Xatom.h>
+#include <X11/Xutil.h>
+#include <X11/extensions/XShm.h>
+
+#define INPUT_MOTION (ExposureMask | ButtonPressMask | KeyPressMask | \
+                      ButtonMotionMask | StructureNotifyMask |        \
+                      PropertyChangeMask | PointerMotionMask)
+
+typedef struct {
+  uint32_t  flags;
+  uint32_t  functions;
+  uint32_t  decorations;
+  int32_t   input_mode;
+  uint32_t  status;
+} MWMHints;
+#define MWM_HINTS_DECORATIONS   (1L << 1)
+#define PROP_MWM_HINTS_ELEMENTS 5
 
 void XineInfo::createXineStream ()
 {
 //printf ("CreateXineEngine::createXineStream (1) \n");
 	if (!m_pMediaEngine)
 		return;
+	/*
+	x11_visual_t vis;
+	
+	int xpos, ypos, width, height;
+  double            res_h, res_v;
+  char             *vo_driver = "auto";
+  char             *ao_driver = "auto";
+  char             *mrl = NULL;
+  int               i;
+  Atom              XA_NO_BORDER;
+  MWMHints          mwmhints;
+  
+  Display *display = XOpenDisplay(NULL);
+  Screen  *screen  = (Screen *) XDefaultScreen(display);
+  xpos    = 0;
+  ypos    = 0;
+  width   = 320;
+  height  = 200;
+
+  // some initalization for the X11 Window we will be showing video in 
+  XLockDisplay(display);
+
+  Window window = XCreateSimpleWindow(display, XDefaultRootWindow(display),
+                                  xpos, ypos, width, height, 1, 0, 0);
+  
+  XSelectInput(display, window, INPUT_MOTION);
+
+  XA_NO_BORDER         = XInternAtom(display, "_MOTIF_WM_HINTS", False);
+  mwmhints.flags       = MWM_HINTS_DECORATIONS;
+  mwmhints.decorations = 0;
+  XChangeProperty(display, window,
+                  XA_NO_BORDER, XA_NO_BORDER, 32, PropModeReplace, (unsigned char *) &mwmhints,
+                  PROP_MWM_HINTS_ELEMENTS);
+  
+  XMapRaised(display, window);
+  
+  res_h = 200; //(DisplayWidth (display, screen) * 1000 / DisplayWidthMM (display, screen));
+  res_v = 200; //(DisplayHeight(display, screen) * 1000 / DisplayHeightMM(display, screen));
+  XSync(display, False);
+  XUnlockDisplay(display);
+
+	// filling in the xine visual struct
+	vis.display           = display;
+	vis.screen            = 0; //(Screen *)screen;
+	vis.d                 = window;
+	vis.dest_size_cb      = NULL;
+	vis.frame_output_cb   = NULL;
+	vis.user_data         = NULL;
+	double pixel_aspect   = 1.0; //res_v / res_h;	
+*/
 	// opening xine output ports
 	m_pVideoDriver = xine_open_video_driver((xine_t*)m_pMediaEngine, "none", XINE_VISUAL_TYPE_NONE, NULL);
+	//m_pVideoDriver = xine_open_video_driver((xine_t*)m_pMediaEngine, "none", XINE_VISUAL_TYPE_X11, &vis);
 	m_pAudioDriver = xine_open_audio_driver((xine_t*)m_pMediaEngine, "none", NULL);
 
 	// open a xine stream connected to these ports
@@ -67,6 +139,11 @@ void XineInfo::setXineStream (xine_stream_t *pXineStream)
 	m_pXineStream = pXineStream;
 }
 
+void XineInfo::frameOutputCb ( void * /*pUserData*/, int /*iVideoWidth*/, int /*iVideoHeight*/, double /*fVideoAspect*/, 
+							   int * /*piDestX*/, int * /*piDestY*/, int * /*piDestWidth*/, int * /*piDestHeight*/, double * /*pfDestAspect*/, int * /*piWinX*/, int * /*piWinY*/)
+{
+}
+
 void XineInfo::queryValues ()
 {
 	int iReturn, iPosStream, iPosTime, iLengthTime;
@@ -128,7 +205,9 @@ void XineInfo::queryValues ()
 */
 
 		iReturn = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_VIDEO_RATIO);
-		if (iReturn == 1)
+		m_qsRatio.sprintf ( "%4.2f:1", (double)iReturn/10000.0);
+
+/*		if (iReturn == 1)
 			m_qsRatio = QString ("1:1");
 		else if (iReturn == (int)(16.0/9.0*10000))
 			m_qsRatio = QString ("16:9");
@@ -142,6 +221,7 @@ void XineInfo::queryValues ()
 			m_qsRatio = QString ("29:9");
 		else
 			m_qsRatio = QString ("%1:1").arg((float)iReturn/10000);
+*/
 
 		iReturn = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_VIDEO_FOURCC);
 		if (iReturn)
@@ -284,16 +364,16 @@ xine_stream_t *XineInfo::getXineStream ()
 	return m_pXineStream;
 }
 
-QImage XineInfo::getScreenshot(uint iStartTime)
+QImage XineInfo::getScreenshot ( long iMSecOffset )
 {
 	xine_open(m_pXineStream, (const char *)m_qsFileName);
-	if (iStartTime == 0)
+	if (iMSecOffset == 0)
 		return getScreenshot (m_qsFileName);
 	// first we try the trick mode ... Ooops not implemented, will crash QDVDAuthor. Maybe in the future.
 	int iTricky = 0; // xine_trick_mode (m_pXineStream, XINE_TRICK_MODE_SEEK_TO_TIME, iStartTime * 1000);
 	if (iTricky == 0)	{	// Input does not support the trick mode, 
 		// so we use start/stop to get there ...
-		iTricky = xine_play (m_pXineStream, 0, iStartTime * 1000);
+		iTricky = xine_play ( m_pXineStream, 0, iMSecOffset );
 		//int iError = xine_get_error (m_pXineStream);
 		xine_stop (m_pXineStream);
 	}
