@@ -196,6 +196,7 @@ bool XineWidget::openMRL (const QString qsMRL)
 	if (xine_open(pStream, qsMRL.local8Bit())) /** pass mrl local 8Bit encoded **/
 		xine_play(pStream, 0,0);
 	slotStopPlayback();
+	m_qsMRL = qsMRL;
 
 	return true;
 }
@@ -301,6 +302,22 @@ QImage XineWidget::getScreenshot(float)
 	return screenShot;
 }
 
+bool XineWidget::setScreenshot ( long iMSecOffset )
+{
+  QTime seekTime;
+  seekTime = seekTime.addMSecs ( iMSecOffset );
+  playMRL ( m_qsMRL );
+  slotChangePositionByTime ( iMSecOffset );
+  //  xine_play(xineStream, 0, iMSecOffset );
+  slotStopPlayback ( );
+  return true;
+}
+
+bool XineWidget::setScreenshot ( QPixmap & )
+{
+  return false;
+}
+
 // Non mandatory functions. 
 void XineWidget::setAspectRatio (uint)
 {
@@ -332,9 +349,6 @@ void XineWidget::playChapter(int iHowFarFromHere)
 
 bool XineWidget::isPlaying()
 {
-	return posTimer.isActive();;
+	return posTimer.isActive();
 }
 
-
-
-
