@@ -228,13 +228,13 @@ MediaInfo *MediaCreator::createInfo(void *pVoid)
 	return pInfo;
 } 
 
-void MediaCreator::registerWithMediaScanner (QObject *pOrigObject, QString &qsFileName, QImage *pImage, int iSecondsOffset)
+void MediaCreator::registerWithMediaScanner (QObject *pOrigObject, QString &qsFileName, QImage *pImage, long iMSecondsOffset)
 {
-	// THe first action to take is a sanity check ...
+	// The first action to take is a sanity check ...
 	if ( (!pImage) || (!pOrigObject) )
 		return;
 	// First we create the ExecuteObject (Container to store the information) 
-	ExecuteJob *pNewJob = new ExecuteJob (pOrigObject, qsFileName, pImage, iSecondsOffset);
+	ExecuteJob *pNewJob = new ExecuteJob (pOrigObject, qsFileName, pImage, iMSecondsOffset);
 	
 	// Check if we need to create a new object ...
 	if (MediaCreator::pPreviewObject == NULL)
@@ -250,17 +250,23 @@ void MediaCreator::registerWithMediaScanner (QObject *pOrigObject, QString &qsFi
 
 void MediaCreator::unregisterFromMediaScanner (QObject *pObject)
 {
-	if (MediaCreator::pPreviewObject)
-		MediaCreator::pPreviewObject->remove (pObject);
+  if ( MediaCreator::pPreviewObject )
+       MediaCreator::pPreviewObject->remove ( pObject );
 }
 
-void MediaCreator::registerWithMediaScanner (QObject *pOrigObject, SourceFileInfo *pSourceFileInfo, int iSecondsOffset)
+void MediaCreator::unregisterFromMediaScanner (SourceFileInfo *pSourceFileInfo)
+{
+  if ( MediaCreator::pPreviewObject )
+       MediaCreator::pPreviewObject->remove ( pSourceFileInfo );
+}
+
+void MediaCreator::registerWithMediaScanner (QObject *pOrigObject, SourceFileInfo *pSourceFileInfo, long iMSecondsOffset, bool bUpdateAllInfo )
 {
 	// THe first action to take is a sanity check ...
 	if ( (!pSourceFileInfo) || (!pOrigObject) )
 		return;
 	// First we create the ExecuteObject (Container to store the information) 
-	ExecuteJob *pNewJob = new ExecuteJob (pOrigObject, pSourceFileInfo, iSecondsOffset);
+	ExecuteJob *pNewJob = new ExecuteJob (pOrigObject, pSourceFileInfo, iMSecondsOffset, bUpdateAllInfo );
 	
 	// Check if we need to create a new object ...
 	if (MediaCreator::pPreviewObject == NULL)
