@@ -11,9 +11,7 @@
 
 #include <qfileinfo.h>
 #include <qobject.h>
-//#include <qapplication.h>
-//#include <qmessagebox.h>
-//#include <qdir.h>
+#include <qmessagebox.h>
 
 #include "../global.h"
 #include "mediainfo.h"
@@ -123,7 +121,7 @@ QString MediaInfo::getExtensions (bool bVideo)
 {
 	QString qsExtension;
 	if (bVideo)
-		qsExtension = QString ("*.mpg *.mpeg *.avi *.mwa *.mov *.wma *.vob *.dv *.wmv *.mjpeg *.mve *.asf *.asx *.MPG *.MPEG *.AVI *.MWA *.MOV *.WMA *.VOB *.DV *.WMV *.MJPEG *.MVE *.ASF *.ASX");
+		qsExtension = QString ("*.mpg *.mpeg *.avi *.mwa *.mov *.wma *.vob *.m2v *.dv *.wmv *.mjpeg *.mve *.asf *.asx *.MPG *.MPEG *.AVI *.MWA *.MOV *.WMA *.VOB *.M2V *.DV *.WMV *.MJPEG *.MVE *.ASF *.ASX");
 	else
 		qsExtension = QString("*.wav *.mp3 *.mp2 *.mpa *.mpega *.ogg *.WAV *.MP3 *.MP2 *.MPA *.MPEGA *.OGG");
 
@@ -153,7 +151,7 @@ QString MediaInfo::getRatio ()
 
   QString qsRatio = m_qsRatio;
   int iPos = qsRatio.find ( ":" );
-  float fValue;
+  float fValue = 0.0;
 
   if ( iPos ) {
     QString qsVal1 = qsRatio.left  ( iPos );
@@ -303,4 +301,3 @@ void MediaInfo::test_print ()
 	printf ("Is Seekable : %s\n", isSeekeable () ? "true" : "false");
 }
 
-
