@@ -53,6 +53,23 @@ void MediaScanner::append(ExecuteJob *pNewJob)
 	}
 }
 
+void MediaScanner::remove ( SourceFileInfo *pSourceFileInfo )
+{
+	// Please remember that this is executed in the main thread
+	uint t;
+	ExecuteJob *pJob = NULL;
+	if ( ! setSemaphore ( true ) )
+		return;
+	for (t=0;t<m_listExecuteFifo.count();t++)	{
+		pJob = m_listExecuteFifo[t];
+		if (pJob->pSourceFileInfo == pSourceFileInfo)	{
+			pJob->pSourceFileInfo = NULL;
+			pJob->pOrigObject     = NULL;
+		}
+	}
+	setSemaphore ( false );
+}
+			
 void MediaScanner::remove (QObject *pObject)
 {
 	// Please remember that this is executed in the main thread
@@ -68,7 +85,7 @@ void MediaScanner::remove (QObject *pObject)
 	}
 	setSemaphore ( false );
 }
-			
+
 bool MediaScanner::setSemaphore ( bool bSet )
 {
 	uint iMaxWait = 0;
@@ -113,17 +130,22 @@ void MediaScanner::run()
 				qsFileName = pCurrentJob->pSourceFileInfo->qsFileName;
 				setSemaphore ( false );// unblock since the next function can take a few seconds.
 				m_pMediaInfo->setFileName (qsFileName);
-				if ( ( setSemaphore ( true ) ) && (pCurrentJob->pOrigObject) )	{
-					pCurrentJob->pSourceFileInfo->qsFormat     = m_pMediaInfo->getFormat (true);
-					pCurrentJob->pSourceFileInfo->qsResolution = m_pMediaInfo->getResolutionString ();
-					pCurrentJob->pSourceFileInfo->qsLength     = m_pMediaInfo->getLengthString ();
-					pCurrentJob->pSourceFileInfo->qsSize       = m_pMediaInfo->getSizeString();
-					pCurrentJob->pSourceFileInfo->qsRatio      = m_pMediaInfo->getRatio ();
-					pCurrentJob->pSourceFileInfo->qsFPS        = QString ("%1").arg(m_pMediaInfo->getFPS());
-					pCurrentJob->pSourceFileInfo->qsStatus     = m_pMediaInfo->getStatus();
+				if ( ( setSemaphore ( true ) ) && (pCurrentJob->pOrigObject) && ( pCurrentJob->bUpdateAllInfo ) )	{
+					pCurrentJob->pSourceFileInfo->qsVideoFormat= m_pMediaInfo->getFormat     ( true  );
+					pCurrentJob->pSourceFileInfo->qsResolution = m_pMediaInfo->getResolutionString ( );
+					pCurrentJob->pSourceFileInfo->qsLength     = m_pMediaInfo->getLengthString     ( );
+					pCurrentJob->pSourceFileInfo->qsSize       = m_pMediaInfo->getSizeString       ( );
+					pCurrentJob->pSourceFileInfo->qsRatio      = m_pMediaInfo->getRatio            ( );
+					pCurrentJob->pSourceFileInfo->qsStatus     = m_pMediaInfo->getStatus           ( );
+					pCurrentJob->pSourceFileInfo->qsFPS        = QString ("%1").arg ( m_pMediaInfo->getFPS  ( ) );
+					// And also store the audio props ...
+					pCurrentJob->pSourceFileInfo->qsBits       = QString ("%1").arg ( m_pMediaInfo->getBits ( ) );
+					pCurrentJob->pSourceFileInfo->qsAudioFormat= m_pMediaInfo->getFormat     ( false );
+					pCurrentJob->pSourceFileInfo->qsBPS        = m_pMediaInfo->getBPSString  ( false );
+					pCurrentJob->pSourceFileInfo->qsSample     = m_pMediaInfo->getSampleString     ( );
 				}
 				setSemaphore ( false );// unblock since the next function can take a few seconds.
-				theImage = m_pMediaInfo->getScreenshot (pCurrentJob->iSecondsOffset);
+				theImage = m_pMediaInfo->getScreenshot (pCurrentJob->iMSecondsOffset);
 				// Sanity check ... and copying the image over.
 				if ( ( setSemaphore ( true ) ) && (pCurrentJob->pOrigObject) )	{
 					QSize sizeButton = pCurrentJob->pSourceFileInfo->pPreview->size();
@@ -138,7 +160,7 @@ void MediaScanner::run()
 			else	{
 				m_pMediaInfo->setFileName (pCurrentJob->qsFileName);
 				setSemaphore ( false );	// unblock since the next function can take a few seconds.
-				theImage = m_pMediaInfo->getScreenshot (pCurrentJob->iSecondsOffset);
+				theImage = m_pMediaInfo->getScreenshot (pCurrentJob->iMSecondsOffset);
 				// Sanity check ...
 				if ( ( setSemaphore ( true ) ) && (pCurrentJob->pOrigObject) )	{
 					if (theImage.isNull())
@@ -200,7 +222,7 @@ void MediaScanner::run()
 				pCurrentJob->pSourceFileInfo->qsRatio      = m_pMediaInfo->getRatio ();
 				pCurrentJob->pSourceFileInfo->qsFPS        = QString ("%1").arg(m_pMediaInfo->getFPS());
 				pCurrentJob->pSourceFileInfo->qsStatus     = m_pMediaInfo->getStatus();
-				theImage = m_pMediaInfo->getScreenshot (pCurrentJob->iSecondsOffset);
+				theImage = m_pMediaInfo->getScreenshot (pCurrentJob->iMSecondsOffset);
 				// Sanity check ... and copying the image over.
 				if ( pCurrentJob->pOrigObject )	{
 					QSize sizeButton = pCurrentJob->pSourceFileInfo->pPreview->size();
@@ -214,7 +236,7 @@ void MediaScanner::run()
 			else	{
 				m_pMediaInfo->setFileName (pCurrentJob->qsFileName);
 
-//				theImage = m_pMediaInfo->getScreenshot (pCurrentJob->iSecondsOffset);
+//				theImage = m_pMediaInfo->getScreenshot (pCurrentJob->iMSecondsOffset);
 //				theImage = QImage (QPixmap::fromMimeSource( "error.jpg" ).convertToImage());
 				// Sanity check ...
 				if ( pCurrentJob->pOrigObject )	{
