@@ -27,23 +27,26 @@ class SourceFileInfo;
 class ExecuteJob 
 {
 public:
-	ExecuteJob (QObject *pTheCallingObject, QString &qsTheFileName, QImage *pTheImage, int iOffset)
+	ExecuteJob (QObject *pTheCallingObject, QString &qsTheFileName, QImage *pTheImage, long iMSecOffset)
 	{
 		qsFileName      = qsTheFileName;
 		pImage          = pTheImage;
 		pSourceFileInfo = NULL;
 		pOrigObject     = pTheCallingObject;
-		iSecondsOffset  = iOffset;
+		iMSecondsOffset = iMSecOffset;
+		bUpdateAllInfo  = true;
 	}
-	ExecuteJob (QObject *pTheCallingObject, SourceFileInfo *pSourceInfo, int iOffset)
+	ExecuteJob (QObject *pTheCallingObject, SourceFileInfo *pSourceInfo, int iMSecOffset, bool bUpdateInfo)
 	{
 		pImage          = NULL;
 		pSourceFileInfo = pSourceInfo;
 		pOrigObject     = pTheCallingObject;
-		iSecondsOffset  = iOffset;
+		iMSecondsOffset = iMSecOffset;
+		bUpdateAllInfo  = bUpdateInfo; 
 	}
 
-	int             iSecondsOffset;
+	long            iMSecondsOffset;
+	bool            bUpdateAllInfo;
 	QString         qsFileName;
 	QImage         *pImage;
 
@@ -54,13 +57,14 @@ public:
 class MediaScanner : public QThread
 {
 public:
-	MediaScanner      ();
-	bool hasFinished  ();
-	void append       (ExecuteJob *);
-	void remove       (QObject *);
-	bool setSemaphore (bool);
+	MediaScanner      ( );
+	bool hasFinished  ( );
+	void append       ( ExecuteJob * );
+	void remove       ( SourceFileInfo * );
+	void remove       ( QObject * );
+	bool setSemaphore ( bool );
 
-	virtual void run();
+	virtual void run  ( );
 
 private:
 	bool                     m_bHasFinished;
