@@ -47,7 +47,9 @@ void StartStopControl::initMe (QString qsFileName, int iThumbnailSize, int iLeng
 	QGridLayout *pLayout = new QGridLayout( m_pLabelStartStop, 1, 1, 2, 2, "pLayout2");
 	m_pStartStopSlider = new StartStopSlider ( m_pLabelStartStop );
 	m_pStartStopSlider->setMinMax (0, 1000);
-	connect (m_pStartStopSlider, SIGNAL (signalValuesChanged (int, int)), this, SLOT(slotSliderValues (int, int)));
+	connect (m_pStartStopSlider, SIGNAL (signalValuesChanged  ( int, int) ), this, SLOT(slotSliderValues ( int, int ) ) );
+	connect (m_pStartStopSlider, SIGNAL (signalStartStopPressed  ( bool ) ), this, SLOT(slotSliderPressed    ( bool ) ) );
+	connect (m_pStartStopSlider, SIGNAL (signalStartStopReleased ( bool ) ), this, SLOT(slotSliderReleased   ( bool ) ) );
 	pLayout->addWidget( m_pStartStopSlider, 0, 0 );
 	m_pLabelMovie->setFixedHeight (iThumbnailSize);
 
@@ -77,11 +79,11 @@ void StartStopControl::initMe (QString qsFileName, int iThumbnailSize, int iLeng
 	// Next we draw the line with the temp pictures, 
 	updateMovieLine ();
 	// before we go ahead and request the screenshots.
-	int iDeltaSeconds = 0;
+	long iDeltaSeconds = 0;
 	if (iNrOfImages  != 1)	// catch possible exception
-		iDeltaSeconds = (int)(iLengthMilliSeconds / (iNrOfImages) / 1000);
+		iDeltaSeconds = (long) ( iLengthMilliSeconds / (iNrOfImages) );
 	for (t=0;t<iNrOfImages;t++)
-		MediaCreator::registerWithMediaScanner (this, m_qsFileName, m_listOfScreenshots[t], iDeltaSeconds * t);
+	  MediaCreator::registerWithMediaScanner (this, m_qsFileName, m_listOfScreenshots[t], iDeltaSeconds * t);
 }
 
 void StartStopControl::showSlider (bool bShow)
@@ -111,6 +113,16 @@ void StartStopControl::setEnd (float fEnd)
 	updateMovieLine ();
 }
 
+void StartStopControl::slotSliderReleased ( bool bStart )
+{
+  emit ( signalSliderReleased ( bStart ) );
+}
+
+void StartStopControl::slotSliderPressed ( bool bStart )
+{
+  emit ( signalSliderPressed ( bStart ) );
+}
+
 void StartStopControl::slotSliderValues (int iStart, int iEnd)
 {
 	// This function is called when the user uses the sliders
@@ -249,12 +261,14 @@ void SliderHandle::mousePressEvent (QMouseEvent *pMouseEvent)
 {
 	m_bPressed = true;
 	QPushButton::mousePressEvent (pMouseEvent);
+	emit ( signalSliderPressed ( ) );
 }
 
 void SliderHandle::mouseReleaseEvent (QMouseEvent *pMouseEvent)
 {
 	m_bPressed = false;
 	QPushButton::mouseReleaseEvent (pMouseEvent);
+	emit ( signalSliderReleased ( ) );
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -277,10 +291,12 @@ StartStopSlider::StartStopSlider (QWidget *pParent, const char *pName )
 	m_iMin = 0;
 	m_iMax = 100;
 
-	connect (m_pHandleStart, SIGNAL (pressed()), this, SLOT(slotStartPressed()));
-	connect (m_pHandleEnd  , SIGNAL (pressed()), this, SLOT(slotEndPressed  ()));
-	connect (m_pHandleStart, SIGNAL (signalNewValue(int)), this, SLOT(slotNewStartValue(int)));
-	connect (m_pHandleEnd  , SIGNAL (signalNewValue(int)), this, SLOT(slotNewEndValue  (int)));
+	connect ( m_pHandleStart, SIGNAL ( signalSliderPressed ( ) ), this, SLOT ( slotStartPressed  ( ) ) );
+	connect ( m_pHandleEnd  , SIGNAL ( signalSliderPressed ( ) ), this, SLOT ( slotEndPressed    ( ) ) );
+	connect ( m_pHandleStart, SIGNAL ( signalSliderReleased( ) ), this, SLOT ( slotStartReleased ( ) ) );
+	connect ( m_pHandleEnd  , SIGNAL ( signalSliderReleased( ) ), this, SLOT ( slotEndReleased   ( ) ) );
+	connect ( m_pHandleStart, SIGNAL ( signalNewValue  ( int ) ), this, SLOT ( slotNewStartValue ( int ) ) );
+	connect ( m_pHandleEnd  , SIGNAL ( signalNewValue  ( int ) ), this, SLOT ( slotNewEndValue   ( int ) ) );
 }
 
 StartStopSlider::~StartStopSlider ()
@@ -454,14 +470,26 @@ void StartStopSlider::show ()
 // Misc functions
 void StartStopSlider::slotStartPressed ()
 {
-	// this function 'marks' the last touched Handle
-	m_pLastClicked = m_pHandleStart;
+  // this function 'marks' the last touched Handle
+  m_pLastClicked = m_pHandleStart;
+  emit ( signalStartStopPressed ( true ) );
 }
 
 void StartStopSlider::slotEndPressed ()
 {
-	// this function 'marks' the last touched Handle
-	m_pLastClicked = m_pHandleEnd;
+  // this function 'marks' the last touched Handle
+  m_pLastClicked = m_pHandleEnd;
+  emit ( signalStartStopPressed ( false ) );
+}
+
+void StartStopSlider::slotStartReleased ()
+{
+  emit ( signalStartStopReleased ( true ) );
+}
+
+void StartStopSlider::slotEndReleased ()
+{
+  emit ( signalStartStopReleased ( false ) );
 }
 
 void StartStopSlider::slotNewStartValue (int iNewValue)
