@@ -16,11 +16,12 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-//#include <sys/types.h>
+#include <unistd.h>
 #include <sys/stat.h>
 
 #include <qfile.h>
 #include <qstring.h>
+#include <qfileinfo.h>
 
 #include "qrender.h"
 #include "xml_qrender.h"
@@ -65,11 +66,35 @@ QRender::~QRender()
 	delete m_pOutputOptions;
 }
 
+QString QRender::checkForExe( QString qsExe )
+{
+	// Stolen from utils.cpp
+	QString qsExePath;
+	QFileInfo fileInfo(QString ("/tmp/%1_out.txt").arg(getlogin()));
+	// the next check is to see if we can find 
+	system ((const char *)QString ("which %1 > /tmp/%2_out.txt 2>/dev/null").arg(qsExe).arg(getlogin()));
+	fileInfo.setFile(QString("/tmp/%1_out.txt").arg(getlogin()));
+	// Okay we can not find it, so we wont bother asking the user ...
+	if (fileInfo.size() > 4)	{
+                QFile theFile   (QString ("/tmp/%1_out.txt").arg(getlogin()));
+		theFile.open    (IO_ReadOnly);
+		theFile.readLine(qsExePath, 4096);
+		theFile.close();
+		if (!qsExePath.isEmpty())	{
+			qsExePath.remove("\n");
+			return qsExePath;
+		}
+	}
+	return QString ("/bin/bash");
+}
+
 void QRender::transcode ()
 {
 	uint t;
 	QString qsFileName, qsCommand, qsConversionScript;
-	
+	qsCommand = QString ("bash");
+	QString qsExePath = checkForExe ( qsCommand );
+
 	qsFileName = m_xmlQRender.qrender().mmm.tmpdir+QString ("/ffmpeg.cfg");
 	qsConversionScript = QString ("[mpeg2video]\nvhq = 1 \nmbd = 2 \nmbqmin = 2 \nmbqmax = 4 \n");
 	generateFile (qsFileName, qsConversionScript);
@@ -77,9 +102,8 @@ void QRender::transcode ()
 	qsFileName = m_xmlQRender.qrender().mmm.tmpdir+QString ("/convert.sh");
 // 	// First we convert the background movie into the right Format ...
 	qsCommand = QString ("convert.sh %1").arg(qsFileName);
-	qsConversionScript = QString ("!/bin/sh\n\n"
-
-		"#Always do this, clean crappy avi's \n"
+	qsConversionScript = QString ("#!%1\n\n").arg (qsExePath);
+	qsConversionScript += QString ("#Always do this, clean crappy avi's \n"
 		"nice -19 mencoder -oac copy -ovc copy -ofps 25 -o output.avi $1 \n"
 		"nice -19 mplayer -ao pcm -vo null -vc dummy output.avi  \n\n"
  
