@@ -261,7 +261,6 @@ int StartMenuRender::checkStatusFile (QString qsFullPath)
 
 void StartMenuRender::renderMovieObject ()
 {
-	QTime zeroTime;
 	QFileInfo fileInfo;
 	int iStatusCheck;
 	
@@ -283,7 +282,8 @@ void StartMenuRender::renderMovieObject ()
 
 	// First we move the current status file to a backup file.
 	qsCommand = QString ("mv \"%1/%2\" \"%3/%4.prev\"").arg(qsFullPath).arg(QString (STATUS_FILE_NAME)).arg(qsFullPath).arg(QString (STATUS_FILE_NAME));
-	system (qsCommand);
+	if ( system (qsCommand) == -1 )
+		return;
 
 	QFile statusFile (qsFullPath + QString ("/") + QString (STATUS_FILE_NAME));
 	// Now we read in the status ...
@@ -303,8 +303,10 @@ void StartMenuRender::renderMovieObject ()
 	qsCommand = QString ("mencoder -oac pcm -ovc lavc -o \"%1/clean.avi\" \"%2\" 2>/dev/null").arg(qsFullPath).arg(m_pMovieObject->fileName());
 	statusStream << "[01] " << QDate::currentDate().toString() << " " << QTime::currentTime().toString() << " cmd > " << qsCommand << "\n";
 	statusFile.flush();
-	if (iStatusCheck < 1)
-		system (qsCommand);
+	if (iStatusCheck < 1)  {
+		if ( system (qsCommand) == -1 )
+			return;
+	}
 	fileInfo.setFile(qsFullPath + QString ("/clean.avi"));
 	if ( (fileInfo.exists()) || (iStatusCheck > 0) )
 		statusStream << "[02] Okay.\n";
@@ -316,8 +318,10 @@ void StartMenuRender::renderMovieObject ()
 	qsCommand = QString ("mencoder -oac pcm -ovc lavc -ss %1 -endpos %2 -o \"%3/clip.avi\" \"%4/clean.avi\" 2>/dev/null").arg(qsOffset).arg(qsDuration).arg(qsFullPath).arg(qsFullPath);
 	statusStream << "[03] " << QDate::currentDate().toString() << " " << QTime::currentTime().toString() << " cmd > " << qsCommand << "\n";
 	statusFile.flush();
-	if (iStatusCheck < 2)
-		system (qsCommand);
+	if (iStatusCheck < 2)  {
+		if ( system (qsCommand) == -1 ) 
+			return;
+	}
 	fileInfo.setFile(qsFullPath + QString ("/clip.avi"));
 	if (fileInfo.exists())
 		statusStream << "[04] Okay.\n";
@@ -329,8 +333,10 @@ void StartMenuRender::renderMovieObject ()
 	qsCommand = QString ("mplayer -ao pcm -vo null -vc dummy -aofile \"%1/clip.wav\" \"%2/clip.avi\" 2>/dev/null").arg(qsFullPath).arg(qsFullPath);
 	statusStream  << "[05] " << QDate::currentDate().toString() << " " << QTime::currentTime().toString() << " cmd > " << qsCommand << "\n";
 	statusFile.flush();
-	if (iStatusCheck < 3)
-		system (qsCommand);
+	if (iStatusCheck < 3)  {
+		if ( system (qsCommand) == -1 )
+			return;
+	}
 	fileInfo.setFile(qsFullPath + QString ("/clip.wav"));
 	if (fileInfo.exists())
 		statusStream << "[06] Okay.\n";
@@ -340,13 +346,18 @@ void StartMenuRender::renderMovieObject ()
 	// 4) extracting 300 frames from background.mwv
 	//    mplayer -ao null -vo jpeg:outdir="./snl" "snl/clip.avi"
 	qsCommand = QString ("rm \"%1/*.jpg\"").arg(qsFullPath);
-	if (iStatusCheck < 4)
-		system (qsCommand);
+	if (iStatusCheck < 4)  {
+		if ( system (qsCommand) == -1 )
+			return;
+	}
+		
 	qsCommand = QString ("mplayer -ao null -vo jpeg:outdir=\"%1\" \"%2/clip.avi\" 2>/dev/null").arg(qsFullPath).arg(qsFullPath);
 	statusStream  << "[07] " << QDate::currentDate().toString() << " " << QTime::currentTime().toString() << " cmd > " << qsCommand << "\n";
 	statusFile.flush();
-	if (iStatusCheck < 4)
-		system (qsCommand);
+	if (iStatusCheck < 4)  {
+		if ( system (qsCommand) == -1 )
+			return;
+	}
 	QDir theDir (qsFullPath);
 	theDir.setNameFilter ("*.jpg");
 	if (theDir.count() > 0)
@@ -359,8 +370,10 @@ void StartMenuRender::renderMovieObject ()
 	qsCommand = QString ("rm \"%1/clean.avi\" 2>/dev/null").arg(qsFullPath);
 	statusStream  << "[09] " << QDate::currentDate().toString() << " " << QTime::currentTime().toString() << " cmd > " << qsCommand << "\n";
 	statusFile.flush();
-	if (iStatusCheck < 5)
-		system (qsCommand);
+	if (iStatusCheck < 5)  {
+		if ( system (qsCommand) == -1 )
+			return;
+	}
 	fileInfo.setFile(qsFullPath + QString ("/clip.avi"));
 	if (fileInfo.exists())
 		statusStream << "[10] Okay.\n";
@@ -393,7 +406,8 @@ void StartMenuRender::createDirectories ()
 
 	qsFullPath = QString ("%1/%2/%3/%4").arg(Global::qsTempPath).arg(Global::qsProjectName).arg(qsMenuName). arg(m_pMovieObject->extractionPath());
 	qsCommand  = QString ("mkdir -p '%1'").arg (qsFullPath);
-	system ((const char *)qsCommand);
+	if ( system ((const char *)qsCommand) == -1 )
+		return;
 	// and now we check that the path has been created succesfully
 	theTempDir.setPath (qsFullPath);
 	if (!theTempDir.exists())	{
