@@ -18,25 +18,25 @@
 void DialogImage::initMe(void *pImg, QString &backgroundFileName)
 {
 	CXmlSlideshow::img_struct *pImage = (CXmlSlideshow::img_struct *)pImg;
-	m_pSliderRotate->setRange (-3600, 3600);
-	m_pSliderShearX->setRange (-1000, 1000);
-	m_pSliderShearY->setRange (-1000, 1000);
-	m_pSliderZoom->setRange (-1000, 1000);
-	m_pSliderRed->setRange(0, 1000);
-	m_pSliderGreen->setRange(0, 1000);
-	m_pSliderBlue->setRange(0, 1000);
+	m_pSliderRotate->setRange      (-3600, 3600);
+	m_pSliderShearX->setRange      (-1000, 1000);
+	m_pSliderShearY->setRange      (-1000, 1000);
+	m_pSliderZoom->setRange        (-1000, 1000);
+	m_pSliderRed->setRange         (0, 1000);
+	m_pSliderGreen->setRange       (0, 1000);
+	m_pSliderBlue->setRange        (0, 1000);
 	m_pSliderTransparency->setRange(0, 1000);
-	m_pSliderBrightness->setRange(-1000, 1000);
+	m_pSliderBrightness->setRange  (-1000, 1000);
 
-	m_pSliderRotate->setValue ( 0 );
-	m_pSliderShearX->setValue ( 0 );
-	m_pSliderShearY->setValue ( 0 );
-	m_pSliderZoom->setValue ( 0 );
-	m_pSliderRed->setValue ( 0 );
-	m_pSliderGreen->setValue ( 0 );
-	m_pSliderBlue->setValue ( 0 );
+	m_pSliderRotate->setValue       ( 0 );
+	m_pSliderShearX->setValue       ( 0 );
+	m_pSliderShearY->setValue       ( 0 );
+	m_pSliderZoom->setValue         ( 0 );
+	m_pSliderRed->setValue          ( 0 );
+	m_pSliderGreen->setValue        ( 0 );
+	m_pSliderBlue->setValue         ( 0 );
 	m_pSliderTransparency->setValue ( 0 );
-	m_pSliderBrightness->setValue ( 0 );
+	m_pSliderBrightness->setValue   ( 0 );
 
 	m_pLabelStatus->setText (QString (""));
 	QGridLayout *pLayout = new QGridLayout (m_pFrameImage, 1, 1, 2, 2, "m_pFrameImageLayout");
@@ -73,16 +73,15 @@ void DialogImage::initMe(void *pImg, QString &backgroundFileName)
 		pLayout->addWidget( m_pImagePreview, 0, 0 );
 	}
 	show ();
-//	m_pImagePreview->resize (m_pFrameImage->width(), m_pFrameImage->height());
 
 	// Here we init the vars ...
-	m_pImagePreview->setImage (pImage);
-	if (!backgroundFileName.isEmpty())
-		m_pImagePreview->setBackground (backgroundFileName);
-	m_pLabelStatus->setText(tr ("Zoom"));
-	m_pEditStatus->setText (QString ("1.0"));
-
 	bool bBackgroundToggleOn = false;
+	m_pImagePreview->setBackground (backgroundFileName);
+	m_pImagePreview->setImage( pImage );
+//	m_pImagePreview->setBackground (backgroundFileName, true);
+	m_pLabelStatus ->setText ( tr     ("Zoom"));
+	m_pEditStatus  ->setText ( QString ("1.0"));
+
 	if (!backgroundFileName.isEmpty())
 		bBackgroundToggleOn = true;
 
@@ -98,19 +97,20 @@ void DialogImage::initMe(void *pImg, QString &backgroundFileName)
 			m_pSliderBlue->setValue		( (int)(1000 - pManipulator->fBlue * 1000.0) );
 			m_pSliderTransparency->setValue	( (int)(pManipulator->fTransparency * 1000.0) );
 			m_pSliderBrightness->setValue	( (int)( - pManipulator->fBrightness * 1000.0) );
-			bBackgroundToggleOn = pManipulator->bShowBackground;
-			if (!pManipulator->backgroundFileName.isEmpty());
-				m_pImagePreview->setBackground (pManipulator->backgroundFileName);
+//			bBackgroundToggleOn = pManipulator->bShowBackground;
+			// Get the one stored in the structure rather then the global backgroundFileName
+//			if ( ! pManipulator->backgroundFileName.isNull() );
+//				m_pImagePreview->setBackground (pManipulator->backgroundFileName);
 		}
 	}
 	if (bBackgroundToggleOn)	{
-		m_pButtonBackground->setEnabled(false);
-		m_pCheckBackground->setChecked (false);
-	}
-	else	{
 		m_pButtonBackground->setEnabled(true);
 		m_pCheckBackground->setChecked (true);
 	}
+	else	{
+		m_pButtonBackground->setEnabled(false);
+		m_pCheckBackground->setChecked (false);
+	}
 }
 
 void DialogImage::slotShearXValueChanged(int iValue)
