@@ -81,7 +81,7 @@ void CSlideDialog::slotChooseBackground()
 void CSlideDialog::slotBackgroundToggled( bool bToggled )
 {
 	m_pButtonBackground->setEnabled(bToggled);
-	if (m_Slideshow.background.isEmpty())
+	if (bToggled && m_Slideshow.background.isEmpty())
 		slotChooseBackground();
 
 	m_pPreview->toggleBackground (bToggled);
@@ -367,15 +367,20 @@ void CSlideDialog::initMe(void *pSourceToolBar, QString qsTempPath)
 
 void CSlideDialog::previewImage(int iItem)
 {
-	CXmlSlideshow::img_struct *pImg = NULL;
-	pImg = m_Slideshow.getImg (iItem);
-	if (pImg == NULL)
-		return;
-
-	if ( m_pCheckBackground->isChecked() )
-		m_pPreview->setBackground(m_Slideshow.background, false);	// false = no refresh, done int setImage
-
-	m_pPreview->setImage (pImg);
+  CXmlSlideshow::img_struct *pImg = NULL;
+  pImg = m_Slideshow.getImg (iItem);
+  if (pImg == NULL)
+    return;
+  
+  if ( m_pCheckBackground->isChecked() )
+    m_pPreview->setBackground(m_Slideshow.background, false);	// false = no refresh, done int setImage
+  else {
+    QPixmap background ( m_pPreview->width ( ), m_pPreview->height ( ) );
+    background.fill ( QColor ( 0, 0, 0 ) );    
+    m_pPreview->setBackground(background, false); // false = no refresh, done int setImage
+  }
+  
+  m_pPreview->setImage (pImg);
 }
 
 CXmlSlideshow &CSlideDialog::createFilterSlideshow ()
