@@ -32,6 +32,8 @@ ImagePreview::ImagePreview (QWidget *pParent, const char * name, WFlags f )
 	m_bActiveCursor      = false;
 	m_bNeedToAdjustColor = false;
 	m_bShowBackground    = false;
+	m_iOriginalWidth     = -1;
+	m_iOriginalHeight    = -1;
 
 	if ( pParent )
 	  show();
@@ -128,15 +130,16 @@ void ImagePreview::setImage (QPixmap &theImage, ImageManipulator *pManipulator)
 
 void ImagePreview::setImage (CXmlSlideshow::img_struct *pImg)
 {
-        // before we change the image, we should connect the current 
-        // ImageManipulator to the current image struct.
-	getModifier ();
-	m_pImage = pImg;
-	setModifier ();	// get the additional infos for this image
-	preloadImage();
-	centerImage ();
-	if (!pImg->src.isEmpty())
-		rotate (0.0, false);
+  // before we change the image, we should connect the current 
+  // ImageManipulator to the current image struct.
+  getModifier ( );
+  m_pImage = pImg;
+  setModifier ( );	// get the additional infos for this image
+  preloadImage( );
+  centerImage ( );
+  
+  if ( ! pImg->src.isEmpty ( ) )
+    rotate ( 0.0, false );
 }
 
 CXmlSlideshow::img_struct *ImagePreview::getImage()
@@ -425,8 +428,8 @@ void ImagePreview::adjustColor()
 	QColor theColor;
 	QRgb thePix;	// QRgb defined as :  0xAARRGGBB;
 	// deep copy of the image.
-	if (m_image.isNull())
-		preloadImage();
+	if ( m_image.isNull  ( ) )
+		preloadImage ( );
 	// create empty image.
 	m_imageColored = QImage (m_image.width(), m_image.height(), m_image.depth());
 
@@ -474,6 +477,8 @@ void ImagePreview::preloadImage ()
 	if (m_pImage->src.isEmpty())
 		return;
 	m_image = QImage (m_pImage->src);
+	m_iOriginalWidth  = m_image.width  ( );
+	m_iOriginalHeight = m_image.height ( );
 //	int iWidth  = m_image.width ();
 	// adjust colors by scaling down to a manageable level.
 	if (m_bFastPreview)
@@ -565,10 +570,16 @@ void ImagePreview::setZoom (float fZoom)
 	refreshPreview();
 }
 
-void ImagePreview::setStartZoom (float fZoom)
+void ImagePreview::setStartZoom (float fZoom, bool bAdjust)
 {
-	m_fStartZoom = fZoom;
-	refreshPreview();
+  // m_image is scaled to be 
+  if ( bAdjust && m_iOriginalWidth > -1 ) // coming from ImageDialog, we ought to adjust it to original image size ratio
+    m_fStartZoom = fZoom * (double) m_iOriginalHeight / (double) height ( );
+  //    m_fStartZoom = fZoom * (double) m_iOriginalWidth / (double) width ( );
+  else
+    m_fStartZoom = fZoom;
+  //printf ( "ImagePreview::setStartZoom fZoom<%f> bAdjust<%s> startZoom<%f>\n", fZoom, bAdjust ? "true" : "false", m_fStartZoom );
+  refreshPreview();
 }
 
 void ImagePreview::setRed (float fRed)
