@@ -1,10 +1,14 @@
 /////////////////
 // Hey
 ////////////////
+#include <qdom.h>
 #include <qfile.h>
+#include <qcolor.h>
+#include <qlistview.h>
 #include <qfiledialog.h>
 #include <qmessagebox.h>
-#include <qdom.h>
+
+#include "xml_dvd.h"
 #include "xml_slideshow.h"
 
 CXmlSlideshow::CXmlSlideshow ()
@@ -430,12 +434,12 @@ bool CXmlSlideshow::img_struct::readXml (QDomElement *pDocElem)
 	ImageManipulator tmpImageManipulator;
 	while( !xmlNode.isNull() ) {
 		QDomElement searchTree = xmlNode.toElement();
+		ImageManipulator *pImageManipulator = new ImageManipulator;
 		if (searchTree.tagName() == effect.node_name)
 			bReturn = effect.readXml(&searchTree);
 		if (searchTree.tagName() == tmpImageManipulator.node_name)	{
-			ImageManipulator *pImageManipulator = new ImageManipulator;
 			pModifier = (void *)pImageManipulator;
-			bReturn = pImageManipulator->readXml(&searchTree);
+			bReturn = pImageManipulator->readProjectFile( searchTree );
 		}
 		// If there has been a problem then return false.
 		if (!bReturn)
@@ -507,7 +511,7 @@ bool CXmlSlideshow::img_struct::writeXml(QDomDocument *pDocument, QDomElement *p
 	if (fDuration > -1.0f)
 		imgNode.setAttribute( IMG_DURATION, QString ("%1").arg(fDuration) );
 	if (pModifier)
-		((ImageManipulator *)pModifier)->writeXml( pDocument, &imgNode );
+		((ImageManipulator *)pModifier)->writeProjectFile( imgNode );
 
 	pNodeElement->appendChild( imgNode );
 	return effect.writeXml(pDocument, pNodeElement);
@@ -579,14 +583,15 @@ CXmlSlideshow::time_object& CXmlSlideshow::img_struct::operator =(CXmlSlideshow:
 	ImageManipulator *pMan, *pOtherMan;
 	pMan = (ImageManipulator *)pModifier;
 	// check if we already have a modifier ...
-	if (pMan)
+	if ( pMan )
 		delete pMan;
 	pMan = NULL;
 	if (pTheOther->pModifier)	{
 		pOtherMan = (ImageManipulator *)pTheOther->pModifier;
 		//create a modifier, and copy over ...
 		pMan = new ImageManipulator;
-		pMan = pOtherMan;
+		*pMan = *pOtherMan;
+		pModifier = pMan;
 	}
 	src = pTheOther->src;
 	text = pTheOther->text;
@@ -610,71 +615,3 @@ CXmlSlideshow::time_object& CXmlSlideshow::filter_struct::operator =(CXmlSlidesh
 	return *this;
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-//
-// ImageManipulator class
-//
-////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-ImageManipulator::ImageManipulator ()
-{
-	node_name = QString ("ImageManipulator");
-
-	backgroundFileName = QString ("");
-	bShowBackground = false;
-	iStartX = 0;
-	iStartY = 0;
-	iXRes = 720;
-	iYRes = 480;
-	iTransformationMode = 0;
-	fAspectRatio = 4.0/3.0;
-	fShearX = 0.0;
-	fShearY = 0.0;
-	fZoom   = 1.0;
-	fRotate = 0.0;
-	fRed    = 1.0;
-	fGreen  = 1.0;
-	fBlue   = 1.0;
-	fBrightness   = 0.0;
-	fTransparency = 0.0;	// Opaque in the beginning ...
-}
-
-ImageManipulator::~ImageManipulator()
-{
-
-}
-
-bool ImageManipulator::readXml (QDomElement *)
-{
-
-	return false;
-}
-
-bool ImageManipulator::writeXml(QDomDocument *, QDomElement *)
-{
-	return false;
-}
-
-ImageManipulator& ImageManipulator::operator = (ImageManipulator &theOther)
-{
-	backgroundFileName  = theOther.backgroundFileName;
-	bShowBackground     = theOther.bShowBackground;
-	iStartX             = theOther.iStartX;
-	iStartY             = theOther.iStartY;
-	iXRes               = theOther.iXRes;
-	iYRes               = theOther.iYRes;
-	iTransformationMode = theOther.iTransformationMode;
-	fAspectRatio        = theOther.fAspectRatio;
-	fShearX             = theOther.fShearX;
-	fShearY             = theOther.fShearY;
-	fZoom               = theOther.fZoom;
-	fRotate             = theOther.fRotate;
-	fRed                = theOther.fRed;
-	fGreen              = theOther.fGreen;
-	fBlue               = theOther.fBlue;
-	fBrightness         = theOther.fBrightness;
-	fTransparency       = theOther.fTransparency;
-	return *this;
-}
-
-
-
