@@ -9,14 +9,15 @@
 **
 ****************************************************************************/
 
-#include <qmessagebox.h>
 #include <qfileinfo.h>
 #include <qimage.h>
 #include <qdom.h>
 #include <qdatetime.h>
 
 #include "global.h"
+#include "utils.h"
 #include "xml_dvd.h"
+#include "messagebox.h"
 #include "sourcefileentry.h"
 	 
 Subtitles::entry::entry ()
@@ -245,6 +246,7 @@ TranscodeInterface::TranscodeInterface ()
 	iStartingAt   = 0;
 	iEndingAt     = 0;
 	bTranscoding  = false;
+	bRemuxOnly    = false; 
 }
 
 TranscodeInterface::~TranscodeInterface ()
@@ -267,22 +269,25 @@ TranscodeInterface & TranscodeInterface::operator = (TranscodeInterface &theOthe
 	iStartingAt   = theOther.iStartingAt;
 	iEndingAt     = theOther.iEndingAt;
 	bTranscoding  = theOther.bTranscoding;
+	bRemuxOnly    = theOther.bRemuxOnly;
+	qsTempFile    = theOther.qsTempFile;
 	return *this;
 }
 
 bool TranscodeInterface::operator == (const TranscodeInterface &theOther)
 {
-	if ( 	( qsVideoFormat == theOther.qsVideoFormat) && 
-		( qsVideoType   == theOther.qsVideoType ) &&
-		( qsResolution  == theOther.qsResolution ) &&
+	if ( 	( qsVideoFormat == theOther.qsVideoFormat ) && 
+		( qsVideoType   == theOther.qsVideoType   ) &&
+		( qsResolution  == theOther.qsResolution  ) &&
 		( iVideoBitrate == theOther.iVideoBitrate ) &&
-		( fFrameRate    == theOther.fFrameRate ) &&
-		( qsRatio       == theOther.qsRatio ) &&
+		( fFrameRate    == theOther.fFrameRate    ) &&
+		( qsRatio       == theOther.qsRatio       ) &&
 		( qsAudioFormat == theOther.qsAudioFormat ) &&
-		( qsAudioType   == theOther.qsAudioType ) &&
+		( qsAudioType   == theOther.qsAudioType   ) &&
 		( iAudioBitrate == theOther.iAudioBitrate ) &&
-		( iSample       == theOther.iSample ) &&
-		( qsTempFile    == theOther.qsTempFile ) )
+		( iSample       == theOther.iSample       ) &&
+		( bRemuxOnly    == theOther.bRemuxOnly    ) &&
+		( qsTempFile    == theOther.qsTempFile    ) )
 		// The following can be different but the transcoding will still output the same Format.
 //		( iEndingAt - iStartingAt == theOther.iEndingAt - theOther.iStartingAt ) )
 		return true;
@@ -380,12 +385,14 @@ bool TranscodeInterface::writeProjectFile (QDomElement &theElement)
 
 SourceFileInfo::SourceFileInfo ()
 {
-	pPreview    = NULL;
+	pPreview       = NULL;
+	bAutotranscode = true;
 	pTranscodeInterface = NULL;
-	pSubtitles  = NULL;
-	bUpdateInfo = false;
-	iPause      =  0;
-	iTitleset   = -1;
+	pSubtitles     = NULL;
+	bUpdateInfo    = false;
+	iPause         =  0;
+	iMSecPreview   =  0;
+	iTitleset      = -1;
 }
 
 SourceFileInfo::~SourceFileInfo ()
@@ -403,13 +410,19 @@ QString SourceFileInfo::getFileName ()
 {
   if ( pSubtitles && ( ! pSubtitles->qsTempFile.isEmpty () ) )
     return pSubtitles->qsTempFile;
-  if ( pTranscodeInterface && ( ! pTranscodeInterface->qsTempFile.isEmpty () ) )
-    return pTranscodeInterface->qsTempFile;
+  if ( pTranscodeInterface ) {
+    if ( ! pTranscodeInterface->qsTempFile.isEmpty () )
+      return pTranscodeInterface->qsTempFile;
+    else {
+      // nothing in so we should create the file name
+      Utils     theUtils;
+      QFileInfo fileInfo ( qsFileName );
+      return QString ( "%1/%2.mpeg2" ).arg ( theUtils.getTempPath ( fileInfo.baseName () ) ).arg(fileInfo.baseName () );
+    }
+  }
   return qsFileName;
 }
 
-#include "log.h"
-#include "global.h"
 SourceFileEntry::SourceFileEntry ()
 {
 	iTitleset     = -1;
@@ -418,7 +431,6 @@ SourceFileEntry::SourceFileEntry ()
 	bIsSlideshow  = false;
 	bSoundSource  = false;
 	sizeThumbnail = QSize (150, 150);
-    iLOG ("<%010p> is beeing created", this );
 }
 
 SourceFileEntry::~SourceFileEntry()
@@ -444,13 +456,12 @@ bool SourceFileEntry::readProjectFile  (QDomNode &xmlNode)
 	qsPost = a.value();
 	qsAttribute = theElement.attributeNode ( SOURCE_OBJECT_IS_SOUND_SOURCE ).value();
 	bSoundSource = false;
+	if ( (!qsAttribute.isEmpty ()) && (qsAttribute == QString ("true")) )
+	  bSoundSource = true;
 	qsAttribute = theElement.attributeNode ( SOURCE_OBJECT_PAUSE ).value();
 	if (!qsAttribute.isEmpty ())
 	  iPause = qsAttribute.toInt();
 
-	if ( (!qsAttribute.isEmpty ()) && (qsAttribute == QString ("true")) )
-			bSoundSource = true;
-
 	QDomNode sourceNode = theElement.firstChild();
 	while (!sourceNode.isNull() )	{
 		theElement = sourceNode.toElement();
@@ -475,9 +486,12 @@ bool SourceFileEntry::readProjectFile  (QDomNode &xmlNode)
 			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_LENGTH).value();
 			if (!qsAttribute.isEmpty ())
 				pFileInfos->qsLength = qsAttribute;
-			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_FORMAT).value();
+			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_VIDEO_FORMAT).value();
 			if (!qsAttribute.isEmpty ())
-				pFileInfos->qsFormat = qsAttribute;
+				pFileInfos->qsVideoFormat = qsAttribute;
+			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_AUDIO_FORMAT).value();
+			if (!qsAttribute.isEmpty ())
+				pFileInfos->qsAudioFormat = qsAttribute;
 			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_STATUS).value();
 			if (!qsAttribute.isEmpty ())
 				pFileInfos->qsStatus = qsAttribute;
@@ -496,6 +510,13 @@ bool SourceFileEntry::readProjectFile  (QDomNode &xmlNode)
 			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_TITLESET).value();
 			if (!qsAttribute.isEmpty ())
 			  pFileInfos->iTitleset = qsAttribute.toInt();
+			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_AUTOTRANSCODE).value();
+			pFileInfos->bAutotranscode = true;
+			if (!qsAttribute.isEmpty ())
+			  pFileInfos->bAutotranscode = ( qsAttribute == QString ("true") );
+			qsAttribute = theElement.attributeNode ( SOURCE_OBJECT_MSEC_OFFSET ).value ( );
+			if (!qsAttribute.isEmpty ( ) )
+			  pFileInfos->iMSecPreview = qsAttribute.toInt ( );
 
 			infoNode = theElement.firstChild ();
 			while (!infoNode.isNull())	{
@@ -553,7 +574,7 @@ bool SourceFileEntry::writeProjectFile (QDomElement &theElement, bool bAutosave)
 	// This check means that the slideshow has not yet been finished, thus we should not bother to
 	// store this record since the mpeg does probably not exist.
 	if (bIsSlideshow && bAutosave)	{
-		QMessageBox::warning (NULL,QObject::tr("Warning"), QObject::tr ("Warning, the slideshow \n%1\nis not finished.\nThe SourceFileEntry will not be stored.").arg(qsDisplayName), QMessageBox::Ok, QMessageBox::NoButton);
+		MessageBox::warning (NULL,QObject::tr("Warning"), QObject::tr ("Warning, the slideshow \n%1\nis not finished.\nThe SourceFileEntry will not be stored.").arg(qsDisplayName), QMessageBox::Ok, QMessageBox::NoButton);
 		return true;
 	}
 	uint t;
@@ -587,8 +608,10 @@ bool SourceFileEntry::writeProjectFile (QDomElement &theElement, bool bAutosave)
 				infoElement.setAttribute( SOURCE_OBJECT_RATIO, listFileInfos[t]->qsRatio );
 			if (!listFileInfos[t]->qsLength.isNull())
 				infoElement.setAttribute( SOURCE_OBJECT_LENGTH, listFileInfos[t]->qsLength );
-			if (!listFileInfos[t]->qsFormat.isNull())
-				infoElement.setAttribute( SOURCE_OBJECT_FORMAT, listFileInfos[t]->qsFormat );
+			if (!listFileInfos[t]->qsVideoFormat.isNull())
+				infoElement.setAttribute( SOURCE_OBJECT_VIDEO_FORMAT, listFileInfos[t]->qsVideoFormat );
+			if (!listFileInfos[t]->qsAudioFormat.isNull())
+				infoElement.setAttribute( SOURCE_OBJECT_AUDIO_FORMAT, listFileInfos[t]->qsAudioFormat );
 			if (!listFileInfos[t]->qsStatus.isNull())
 				infoElement.setAttribute( SOURCE_OBJECT_STATUS, listFileInfos[t]->qsStatus );
 			if (!listFileInfos[t]->qsBits.isNull())
@@ -601,6 +624,10 @@ bool SourceFileEntry::writeProjectFile (QDomElement &theElement, bool bAutosave)
 			        infoElement.setAttribute( SOURCE_OBJECT_PAUSE, QString ("%1").arg(listFileInfos[t]->iPause) );
 			if (!listFileInfos[t]->iTitleset != -1 )
 			        infoElement.setAttribute( SOURCE_OBJECT_TITLESET, QString ("%1").arg(listFileInfos[t]->iTitleset) );
+			if ( listFileInfos[t]->bAutotranscode == false )
+			        infoElement.setAttribute( SOURCE_OBJECT_AUTOTRANSCODE, "false" );
+			if (!listFileInfos[t]->iMSecPreview !=-1 )
+			        infoElement.setAttribute( SOURCE_OBJECT_MSEC_OFFSET, QString ("%1").arg(listFileInfos[t]->iMSecPreview) );
 			// Here we create another level in the XML tree for name and chapter ...
 				// First the file name
 				fileElement = xmlDoc.createElement( SOURCE_OBJECT_FILE_NAME );
@@ -650,6 +677,27 @@ bool SourceFileEntry::writeProjectFile (QDomElement &theElement, bool bAutosave)
 	return true;
 }
 
+SourceFileEntry *SourceFileEntry::flatClone ()
+{
+  // Clones this SourceFileEntries without the deep copy of the 
+  // SourceFileInfos.
+  SourceFileEntry *pClone = new SourceFileEntry;
+
+  pClone->listFileInfos = listFileInfos;
+  pClone->qsDisplayName = qsDisplayName;
+  pClone->listChapters  = listChapters;
+  pClone->bSoundSource  = bSoundSource;
+  pClone->bIsSlideshow  = bIsSlideshow;
+  pClone->iJumpStart    = iJumpStart;
+  pClone->iTitleset     = iTitleset;
+  pClone->iTitle        = iTitle;
+  pClone->qsPre         = qsPre;
+  pClone->qsPost        = qsPost;
+  pClone->iPause        = iPause;  
+  
+  return pClone;
+}
+
 SourceFileEntry & SourceFileEntry::operator = (SourceFileEntry &theOther)
 {
 	uint t;
@@ -685,22 +733,25 @@ SourceFileEntry & SourceFileEntry::operator = (SourceFileEntry &theOther)
 
 SourceFileInfo & SourceFileInfo::operator = (SourceFileInfo &theOther)
 {
-	qsFileName   = theOther.qsFileName;
-	qsSize       = theOther.qsSize;
-	qsResolution = theOther.qsResolution;
-	qsFPS        = theOther.qsFPS;
-	qsRatio      = theOther.qsRatio;
-	qsLength     = theOther.qsLength;
-	qsFormat     = theOther.qsFormat;
-	qsStatus     = theOther.qsStatus;
-	qsBits       = theOther.qsBits;
-	qsSample     = theOther.qsSample;
-	qsBPS        = theOther.qsBPS;
-	listChapters = theOther.listChapters;
-	qsPreCommand = theOther.qsPreCommand;
-	qsPostCommand= theOther.qsPostCommand;
-	iPause       = theOther.iPause;
-	iTitleset    = theOther.iTitleset;
+	qsFileName     = theOther.qsFileName;
+	qsSize         = theOther.qsSize;
+	qsResolution   = theOther.qsResolution;
+	qsFPS          = theOther.qsFPS;
+	qsRatio        = theOther.qsRatio;
+	qsLength       = theOther.qsLength;
+	qsAudioFormat  = theOther.qsAudioFormat;
+	qsVideoFormat  = theOther.qsVideoFormat;
+	qsStatus       = theOther.qsStatus;
+	qsBits         = theOther.qsBits;
+	qsSample       = theOther.qsSample;
+	qsBPS          = theOther.qsBPS;
+	listChapters   = theOther.listChapters;
+	qsPreCommand   = theOther.qsPreCommand;
+	qsPostCommand  = theOther.qsPostCommand;
+	iPause         = theOther.iPause;
+	iMSecPreview   = theOther.iMSecPreview;  
+	iTitleset      = theOther.iTitleset;
+	bAutotranscode = theOther.bAutotranscode;
 	if (theOther.pTranscodeInterface)	{
 		if (!pTranscodeInterface)
 			pTranscodeInterface = new TranscodeInterface ();
