@@ -27,7 +27,6 @@
 #include <qapplication.h>
 #include <qmainwindow.h>
 #include <qfiledialog.h>
-#include <qmessagebox.h>
 #include <qpushbutton.h>
 #include <qpopupmenu.h>
 #include <qlistview.h>
@@ -45,7 +44,9 @@
 #include "listviewitemmedia.h"
 #include "dvdmenuundoobject.h"
 #include "menupreview.h"
+#include "messagebox.h"
 #include "dialogmovie.h"
+#include "filepreviewdialog.h"
 
 #include "qplayer/mediainfo.h"
 #include "qplayer/mediacreator.h"
@@ -84,13 +85,13 @@ SourceToolBar::SourceToolBar (const QString &qsLabel, QMainWindow *pMainWindow,
 	m_pSourceWidget->m_pListViewVideoSources->clear ();
 	m_pSourceWidget->m_pListViewAudioSources->clear ();
 
-	connect( m_pListViewAllSources, SIGNAL( doubleClicked ( QListViewItem *, const QPoint &, int )), this, SLOT (slotDoubleClickedOnVideoList(QListViewItem *, const QPoint &, int)) );
-	connect( m_pListViewAllSources, SIGNAL( rightButtonClicked ( QListViewItem *, const QPoint &, int )), this, SLOT (slotRightClickedOnVideoList (QListViewItem *, const QPoint &, int)) );
-	connect( m_pListViewAllSources, SIGNAL( clicked ( QListViewItem *, const QPoint &, int )), this, SLOT (slotClickedOnVideoList      (QListViewItem *, const QPoint &, int)) );
-	connect (m_pListViewAllSources, SIGNAL(signalRemoveEntry (SourceFileEntry *)), this, SLOT(slotRemoveEntry (SourceFileEntry *)));
+	connect( m_pListViewAllSources, SIGNAL( doubleClicked ( QListViewItem *, const QPoint &, int ) ), this, SLOT (slotDoubleClickedOnVideoList(QListViewItem *, const QPoint &, int) ) );
+	connect( m_pListViewAllSources, SIGNAL( rightButtonClicked ( QListViewItem *, const QPoint &, int ) ), this, SLOT (slotRightClickedOnVideoList (QListViewItem *, const QPoint &, int) ) );
+	connect( m_pListViewAllSources, SIGNAL( clicked ( QListViewItem *, const QPoint &, int ) ), this, SLOT (slotClickedOnVideoList      (QListViewItem *, const QPoint &, int) ) );
+	connect( m_pListViewAllSources, SIGNAL( signalRemoveEntry ( SourceFileEntry * ) ), this, SLOT(slotRemoveEntry (SourceFileEntry *) ) );
 
-	connect ( m_pSourceWidget->m_pButtonAddMovie, SIGNAL(clicked()), this, SLOT(slotAddMovie()));
-	connect ( m_pSourceWidget->m_pButtonAddSlide, SIGNAL(clicked()), this, SLOT(slotAddSlideshow()));
+	connect ( m_pSourceWidget->m_pButtonAddMovie,  SIGNAL( clicked ( ) ), this, SLOT ( slotAddMovie     ( ) ) );
+	connect ( m_pSourceWidget->m_pButtonAddSlide,  SIGNAL( clicked ( ) ), this, SLOT ( slotAddSlideshow ( ) ) );
 
 //	connect( m_pSourceWidget->m_pListViewVideoSources, SIGNAL( mouseButtonClicked(int,QListBoxItem*,const QPoint&)), this, SLOT(slotClickedOnVideoList(int,QListBoxItem*,const QPoint&) ) );
 //	connect( m_pSourceWidget->m_pListViewAudioSources, SIGNAL( mouseButtonClicked(int,QListBoxItem*,const QPoint&)), this, SLOT(slotClickedOnVideoList(int,QListBoxItem*,const QPoint&) ) );
@@ -212,13 +213,13 @@ SourceFileEntry *SourceToolBar::getCurrentSourceFileEntry()
 */
 void SourceToolBar::slotDoubleClickedOnVideoList(QListViewItem *pItem, const QPoint &, int)
 {
-	// First we check if the item is valid ...
-	if (pItem == NULL)	{
-		slotAddMovie ();
-		return;
-	}
-	if (m_listSourceFileEntries.count() > 0)
-		slotEditMovie    ();
+  // First we check if the item is valid ...
+  if (pItem == NULL)	{
+    slotAddMovie ( );
+    return;
+  }
+  if (m_listSourceFileEntries.count() > 0)
+    slotEditMovie ( );
 }
 
 void SourceToolBar::slotRightClickedOnVideoList (QListViewItem *pItem, const QPoint &thePoint, int)
@@ -272,89 +273,110 @@ void SourceToolBar::slotClickedOnVideoList(QListViewItem *pItem, const QPoint &t
 	}
 }
 
+void SourceToolBar::slotSetThumbnail ( long iMSecOffset )
+{
+  // The user wants to set the current frame as the thumbnail instead of frame 0.
+  ListViewItemMedia *pItem = (ListViewItemMedia *)m_pListViewAllSources->currentItem();
+  if ( ! pItem )
+    return;
+  SourceFileInfo *pSourceFileInfo = pItem->sourceFileInfo ( );
+  if ( pSourceFileInfo )  { // create new thumbnail ...
+    pSourceFileInfo->iMSecPreview = iMSecOffset;
+    MediaCreator::registerWithMediaScanner (this, pSourceFileInfo, iMSecOffset, false);
+  }
+}
+
 void SourceToolBar::slotTranscodeAll()
 {
-	uint t;
-	bool bGood = true;
-	// Called when the user clicks on the SourceFileEntry - header.
-	// This function will transcode all associated SourceFiles into the same format.
-	SourceFileEntry *pSourceFileEntry = NULL;
-	SourceFileInfo  *pSourceFileInfo  = NULL;
-	SourceFileInfo  *pFirstFileInfo   = NULL;
-	QListViewItem *pItem = m_pListViewAllSources->currentItem (); //selectedItem (); // currentItem ();
-	if ( ! pItem ) 
-		return;
-	for (t=0;t<m_listSourceFileEntries.count();t++)	{
-		if (pItem->text(SOURCE_FILE_ENTRY_NAME) == m_listSourceFileEntries[t]->qsDisplayName)	{
-			pSourceFileEntry = m_listSourceFileEntries[t];
-			break;
-		}
-	}
-	if ( ! pSourceFileEntry )
-		return;
-
-	// Okay we only want to convert if the FileInfos have the same transcoding information (Either none, or all values the same.
-	pFirstFileInfo = pSourceFileEntry->listFileInfos[0];
-	
-	for (t=0;t<pSourceFileEntry->listFileInfos.count();t++)	{
-		pSourceFileInfo = pSourceFileEntry->listFileInfos[t];
-		if ( pFirstFileInfo->pTranscodeInterface)	{
-			if ( ! pSourceFileInfo )
-				bGood = false;
-			if ( (pSourceFileInfo->pTranscodeInterface) && (pFirstFileInfo->pTranscodeInterface) && 
-			   ( *pSourceFileInfo->pTranscodeInterface  != *pFirstFileInfo->pTranscodeInterface ) )
-				bGood = false;
-			else if ( ((   pSourceFileInfo->pTranscodeInterface) && ( ! pFirstFileInfo->pTranscodeInterface)) || 
-				( (( ! pSourceFileInfo->pTranscodeInterface) && (   pFirstFileInfo->pTranscodeInterface)) ))
-				bGood = false;
-		}
-	}
-	if ( ! bGood )
-		return;
-	
-	// Here we open the MovieDialog.
-	DialogMovie theDialog (this);
-	theDialog.initMe (pSourceFileEntry);
-	if (theDialog.exec () == QDialog::Rejected)
-		return;
-
-	// Check if there was a transcodeInterface created by the dialog.
-	if (theDialog.sourceFileInfo()->pTranscodeInterface)	{
-		for (t=0;t<pSourceFileEntry->listFileInfos.count();t++)	{
-			pSourceFileInfo = pSourceFileEntry->listFileInfos[t];
-			if ( ! pSourceFileInfo->pTranscodeInterface )
-			       pSourceFileInfo->pTranscodeInterface = new TranscodeInterface;
-			*pSourceFileInfo->pTranscodeInterface = *theDialog.sourceFileInfo()->pTranscodeInterface;
-		}
-	}
-	else	{	// If there is none then remove all transcodeInterfaces from the files.
-		for (t=0;t<pSourceFileEntry->listFileInfos.count();t++)	{
-			pSourceFileInfo = pSourceFileEntry->listFileInfos[t];
-			if ( pSourceFileInfo->pTranscodeInterface )	{
-				delete pSourceFileInfo->pTranscodeInterface;
-				pSourceFileInfo->pTranscodeInterface = NULL;
-			}
-		}
-	}
-	pSourceFileEntry->qsPre  = theDialog.m_pComboPreCommand->currentText  ( );
-	pSourceFileEntry->qsPost = theDialog.m_pComboPostCommand->currentText ( );
+  uint t;
+  QFileInfo fileInfo;
+  // Called when the user clicks on the SourceFileEntry - header.
+  // This function will transcode all associated SourceFiles into the same format.
+  SourceFileEntry *pSourceFileEntry = NULL;
+  SourceFileInfo  *pSourceFileInfo  = NULL;
+  SourceFileInfo  *pFirstFileInfo   = NULL;
+  QListViewItem   *pItem = m_pListViewAllSources->currentItem ();
+  if ( ! pItem ) 
+    return;
+  for (t=0;t<m_listSourceFileEntries.count();t++)	{
+    if (pItem->text(SOURCE_FILE_ENTRY_NAME) == m_listSourceFileEntries[t]->qsDisplayName)	{
+      pSourceFileEntry = m_listSourceFileEntries[t];
+      break;
+    }
+  }
+  
+  if ( ! pSourceFileEntry )
+    return; // Could not find the currently selected SourceFileEntry
+  
+  // Okay we only want to convert if the FileInfos have the same transcoding information (Either none, or all values the same.
+  pFirstFileInfo = pSourceFileEntry->listFileInfos[0];
+  
+  for (t=0;t<pSourceFileEntry->listFileInfos.count();t++)	{
+    pSourceFileInfo = pSourceFileEntry->listFileInfos[t];
+    if ( pFirstFileInfo->pTranscodeInterface )	{
+      if ( ! pSourceFileInfo )
+	return;
+      if ( ! pSourceFileInfo->pTranscodeInterface )
+	return;
+      else if ( *pSourceFileInfo->pTranscodeInterface  != *pFirstFileInfo->pTranscodeInterface )
+	return;
+    }
+    else if ( pSourceFileInfo && pSourceFileInfo->pTranscodeInterface )
+      return;
+  }
+  
+  // Here we open the MovieDialog.
+  Utils theUtils;
+  DialogMovie theDialog (this);
+  theDialog.initMe (pSourceFileEntry);
+  if (theDialog.exec () == QDialog::Rejected)
+    return;
+  
+  // Check if there was a transcodeInterface created by the dialog.
+  if (theDialog.sourceFileInfo()->pTranscodeInterface)	{
+    for (t=0;t<pSourceFileEntry->listFileInfos.count();t++)	{
+      pSourceFileInfo = pSourceFileEntry->listFileInfos[t];
+      if ( ! pSourceFileInfo->pTranscodeInterface )
+	pSourceFileInfo->pTranscodeInterface = new TranscodeInterface;
+      *pSourceFileInfo->pTranscodeInterface = *theDialog.sourceFileInfo()->pTranscodeInterface;
+      fileInfo.setFile ( pSourceFileInfo->qsFileName );
+      pSourceFileInfo->pTranscodeInterface->qsTempFile = QString ( "%1/%2.mpeg2" ).arg (theUtils.getTempPath ( fileInfo.baseName () ) ).arg(fileInfo.baseName () );
+      updateListViewItem ( pSourceFileInfo );
+    }
+  }
+  else	{	// If there is none then remove all transcodeInterfaces from the files.
+    for (t=0;t<pSourceFileEntry->listFileInfos.count();t++)	{
+      pSourceFileInfo = pSourceFileEntry->listFileInfos[t];
+      if ( pSourceFileInfo->pTranscodeInterface )	{
+	delete pSourceFileInfo->pTranscodeInterface;
+	pSourceFileInfo->pTranscodeInterface = NULL;
+	updateListViewItem ( pSourceFileInfo );
+      }
+    }
+  }
+  pSourceFileEntry->qsPre  = theDialog.m_pComboPreCommand->currentText  ( );
+  pSourceFileEntry->qsPost = theDialog.m_pComboPostCommand->currentText ( );
+  updateEntryHeader ( pSourceFileEntry );
 }
 
 // This is without background task to get the info ...
 void SourceToolBar::slotAddMovie()
 {
-	if (!m_pDVDAuthor->checkForNewProject ())
-		return;
-	// Some one clicked the "Add Movie" button.
-	QString qsFilter = m_pDVDAuthor->getMovieFilter();
-	QStringList listAddMovies = QFileDialog::getOpenFileNames (tr("Movie Files (")+qsFilter+QString (")"), Global::qsCurrentPath, this, tr("Open file dialog"), tr ("Add To Project ..."));
-	// I tried to get the sorting of the names out of here but
-	// detailViewSelectionChanged and listBoxSelectionChanged
-	// are not flexible enough to handle this (yet).
-	if (listAddMovies.count() < 1)
-		return;
-
-	addMovieList (listAddMovies);
+  if (!m_pDVDAuthor->checkForNewProject ( ) )
+    return;
+  // Some one clicked the "Add Movie" button.
+  QString qsMovieFilter        = m_pDVDAuthor->getMovieFilter ( );
+  void   *pExistingMediaEngine = getMediaEngine               ( );
+  
+  QStringList listAddMovies = FilePreviewDialog::getOpenFileNames ( pExistingMediaEngine, Global::qsCurrentPath, QString ("Movies ( ") + qsMovieFilter + QString (" );;All ( * )"));
+  //QStringList listAddMovies = QFileDialog::getOpenFileNames (tr("Movie Files (")+qsFilter+QString (")"), Global::qsCurrentPath, this, tr("Open file dialog"), tr ("Add To Project ..."));
+  // I tried to get the sorting of the names out of here but
+  // detailViewSelectionChanged and listBoxSelectionChanged
+  // are not flexible enough to handle this (yet).
+  if (listAddMovies.count() < 1)
+    return;
+  
+  addMovieList (listAddMovies);
 }
 
 void SourceToolBar::addMovieList (QStringList &listAddMovies, QString *pTitle)
@@ -377,8 +399,7 @@ void SourceToolBar::addMovieList (QStringList &listAddMovies, QString *pTitle)
 		pInfo->pPreview = new QImage (QImage().fromMimeSource( "please_wait.jpg" ));
 		*pInfo->pPreview = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
 		// and then register to obtain the info in the background.
-		MediaCreator::registerWithMediaScanner (this, pInfo);
-
+		MediaCreator::registerWithMediaScanner ( this, pInfo );
 		pEntry->listFileInfos.append(pInfo);
 	}
 	// Check if there is something in the Entry left to be added to the sourceToolbar.
@@ -387,7 +408,7 @@ void SourceToolBar::addMovieList (QStringList &listAddMovies, QString *pTitle)
 		return;
 	}
 
-	if (pTitle)	{	// If a title has been 
+	if (pTitle)	{	// If a title has been provided
 		pEntry->qsDisplayName = *pTitle;
 	}
 	else if (listAddMovies.count () > 1)	{
@@ -403,55 +424,201 @@ void SourceToolBar::addMovieList (QStringList &listAddMovies, QString *pTitle)
 	QApplication::restoreOverrideCursor ();
 }
 
+bool SourceToolBar::checkRightFileFormat ( SourceFileInfo *pInfo )
+{
+  Utils     theUtil;
+  // this function will check if we have a VOB stream.
+  // if not, if we have a Mpeg2 stream
+  // if not the set transcode parameters for this SourceFileInfo - object.
+
+  // If we have a VOB - stream we can safely return ...
+  // Note, we assume VOBUs == right resolution. Why else would you have a VOB stream ?
+  if ( theUtil.hasVobus ( pInfo->qsFileName ) ) 
+    return true;
+
+  // If the user selected not to transcode this file, so be it.
+  if ( ! pInfo->bAutotranscode )
+    return true;
+
+  // Also if there is already a TranscodeInterface defined, then keep our hands off !!!
+  if ( pInfo->pTranscodeInterface ) 
+    return true;
+  
+  QFileInfo fileInfo ( pInfo->qsFileName );
+  int       iWidth, iHeight;
+  // Everything else needs to be transcoded !!!
+  TranscodeInterface *pTranscode = new TranscodeInterface;
+  pInfo->pTranscodeInterface = pTranscode;
+  pTranscode->qsTempFile     = QString ( "%1/%2.mpeg2" ).arg ( theUtil.getTempPath ( fileInfo.baseName () ) ).arg(fileInfo.baseName () );
+
+  iWidth  = theUtil.getWHFromResolution ( pInfo->qsResolution, true  );
+  iHeight = theUtil.getWHFromResolution ( pInfo->qsResolution, false );
+  if ( theUtil.getFormat ( iWidth, iHeight ) != FORMAT_NONE ) {
+    pTranscode->bRemuxOnly = true;
+    return true;
+  }
+
+  //  if ( theUtil.isMpeg2 ( pInfo->qsFileName ) ) {
+    // Mpeg 2 stream detected. Lets check resolution.
+    QString qsFormat          = "ntsc";
+    pTranscode->fFrameRate    = 29.97;
+    pTranscode->qsResolution  = "720x480"; 
+    if ( (pInfo->qsVideoFormat == "pal") || (pInfo->qsVideoFormat == "PAL") ) {
+      qsFormat                = "pal";
+      pTranscode->fFrameRate  = 25.0;
+      pTranscode->qsResolution= "720x576"; 
+    }
+    
+    pTranscode->qsVideoFormat = qsFormat;
+    pTranscode->qsVideoType   = "mpeg2";
+    pTranscode->iVideoBitrate = 6600000;
+    pTranscode->qsRatio       = pInfo->qsRatio;
+    pTranscode->qsAudioFormat = "mp2"; //pInfo->;
+    pTranscode->qsAudioType   = "stereo";
+    pTranscode->iAudioBitrate = 128*1024; // 128kbps
+    pTranscode->iSample       = 48000;
+    pTranscode->bTranscoding  = false;
+    return true;
+    //  }
+
+  return false;
+}
+
 void SourceToolBar::timerEvent(QTimerEvent *pTimerEvent)
 {
-	// Called after the background thread has generated the preview ...
-	uint t, i;
-	SourceFileEntry *pEntry = NULL;
-	SourceFileInfo  *pInfo  = NULL;
+  // Called after the background thread has generated the preview ...
+  uint t, i;
+  SourceFileEntry *pEntry = NULL;
+  SourceFileInfo  *pInfo  = NULL;
+  
+  switch ( pTimerEvent->timerId() )	{
+  case MEDIASCANNER_EVENT:
+    m_mutexThumbnails.lock ();
+    // We could simply call this function but it would be a brute force approach as the whole tree would get rebuild.
+    //refreshToolBarEntries ();
+    // So rather we check all SourceFileInfo's for the flag bUpdateImage and do so singularily.
+    for (t=0;t<m_listSourceFileEntries.count();t++)	{
+      pEntry = m_listSourceFileEntries[t];
+      for (i=0;i<pEntry->listFileInfos.count();i++)	{
+	// Okay found the SourceFileInfo now we need the ListViewItemMedia - object for this Info.
+	pInfo = pEntry->listFileInfos[i];
+	if (pInfo->bUpdateInfo)	{
+	  // next we check if the file is an VOB stream, Mpeg2 stream or any other ...
+	  checkRightFileFormat ( pInfo );
 
-	switch ( pTimerEvent->timerId() )	{
-	case MEDIASCANNER_EVENT:
-	        m_mutexThumbnails.lock ();
-		// We could simply call this function but it would be a brute force approach as the whole tree would get rebuild.
-		//refreshToolBarEntries ();
-		// So rather we check all SourceFIleInfo's for the flag bUpdateImage and do so singularily.
-		for (t=0;t<m_listSourceFileEntries.count();t++)	{
-			pEntry = m_listSourceFileEntries[t];
-			for (i=0;i<pEntry->listFileInfos.count();i++)	{
-				// Okay found the SourceFileInfo no we need the ListViewItemMedia - object for this Info.
-				pInfo = pEntry->listFileInfos[i];
-				if (pInfo->bUpdateInfo)	{
-					ListViewItemMedia *pChild = (ListViewItemMedia *)m_pListViewAllSources->firstChild ();
-					while (pChild)	{
-						// Got it and it fits ...
-						pChild->replaceInfo(pInfo);
-						pChild = (ListViewItemMedia *)pChild->nextSibling();
-					}
-					// Oh and the ListViewVideoSources should also be updated ...
-					QListViewItem *pItem = m_pSourceWidget->m_pListViewVideoSources->firstChild ();
-					while (pItem)	{
-						if (pItem->text (7) == pInfo->qsFileName)	{
-							pItem->setText (0, pInfo->qsFormat);
-							pItem->setText (1, pInfo->qsResolution);
-							pItem->setText (2, pInfo->qsLength);
-							pItem->setText (3, pInfo->qsSize);
-							pItem->setText (4, pInfo->qsRatio);
-							pItem->setText (5, pInfo->qsFPS);
-							pItem->setText (6, pInfo->qsStatus);
-						}
-						pItem = pItem->nextSibling();
-					}
-					pInfo->bUpdateInfo = false;
-					m_pDVDAuthor->slotCalculateSize();
-					m_mutexThumbnails.unlock ();
-					return;
-				}
-			}
-		}
-		m_mutexThumbnails.unlock ();
-	break;
+	  ListViewItemMedia *pChild = (ListViewItemMedia *)m_pListViewAllSources->firstChild ();
+	  while (pChild)	{
+	    // Got it and it fits ...
+	    pChild->replaceInfo(pInfo);
+	    pChild = (ListViewItemMedia *)pChild->nextSibling();
+	  }
+	  // Oh and the ListViewVideoSources should also be updated ...
+	  QListViewItem *pItem = m_pSourceWidget->m_pListViewVideoSources->firstChild ();
+	  while (pItem)	{
+	    if (pItem->text (MOVIE_FILE_NAME_INDEX) == pInfo->qsFileName)	{
+	      pItem->setText (0, pInfo->qsVideoFormat);
+	      pItem->setText (1, pInfo->qsResolution);
+	      pItem->setText (2, pInfo->qsLength);
+	      pItem->setText (3, pInfo->qsSize);
+	      pItem->setText (4, pInfo->qsRatio);
+	      pItem->setText (5, pInfo->qsFPS);
+	      pItem->setText (6, pInfo->qsStatus);
+	    }
+	    pItem = pItem->nextSibling();
+	  }
+	  pInfo->bUpdateInfo = false;
+	  m_pDVDAuthor->slotCalculateSize();
+	  updateEntryHeader ( pEntry );
+	  m_mutexThumbnails.unlock ();
+	  return;
 	}
+      }
+    }
+    m_mutexThumbnails.unlock ();
+    break;
+  }
+}
+
+void SourceToolBar::updateEntryHeader ( SourceFileEntry *pEntry )
+{
+  uint t, i;
+  QString qsFormat ("--");
+  SourceFileInfo *pInfo;
+  QListViewItem  *pItem;
+  // Oh and the ListViewVideoSources should also be updated ...
+  for (t=0;t<pEntry->listFileInfos.count();t++)	{
+    // Okay found the SourceFileInfo now we need the ListViewItemMedia - object for this Info.
+    pInfo = pEntry->listFileInfos[t];
+    pItem = m_pListViewAllSources->firstChild ();
+    while ( pItem )	{
+      if  ( pItem->text ( 1 ) == pEntry->qsDisplayName ) {
+	// Okay, we found the Item that belongs to this SourceFileEntry
+	if ( pEntry->listFileInfos.count () > 0 )
+	  qsFormat = pEntry->listFileInfos[0]->qsVideoFormat;
+	for (i=1;i<pEntry->listFileInfos.count();i++)	{
+	  if ( pEntry->listFileInfos[i]->qsVideoFormat != qsFormat ) {
+	    qsFormat = "Mixed";
+	    break; // out of the inner for - loop
+	  }
+	}
+	pItem->setText ( 0, qsFormat );
+	return;
+      }
+      pItem = pItem->nextSibling();
+    }
+  }
+}
+
+void SourceToolBar::updateListViewItem ( SourceFileInfo *pInfo )
+{
+  ListViewItemMedia *pItem, *pSubItem;
+  // Okay found the SourceFileInfo now we need the ListViewItemMedia - object for this Info.
+  pItem = (ListViewItemMedia *)m_pListViewAllSources->firstChild ();
+  while ( pItem )	{
+    pSubItem = (ListViewItemMedia *)pItem->firstChild ();
+    while ( pSubItem ) {
+      if  ( pSubItem->sourceFileInfo () == pInfo ) {
+	pSubItem->updateItem ( );
+	m_pListViewAllSources->repaintItem ( pSubItem );
+	pSubItem = NULL;
+      }
+      else
+	pSubItem = (ListViewItemMedia *)pSubItem->nextSibling();
+    }
+    pItem = (ListViewItemMedia *)pItem->nextSibling();
+  }
+
+  QListViewItem *pVideoItem = m_pSourceWidget->m_pListViewVideoSources->firstChild ();
+  while ( pVideoItem ) {
+    if  ( pVideoItem->text( MOVIE_FILE_NAME_INDEX ) == pInfo->qsFileName ) {
+      pVideoItem->setText (0, pInfo->qsVideoFormat);
+      pVideoItem->setText (1, pInfo->qsResolution);
+      pVideoItem->setText (2, pInfo->qsLength);
+      pVideoItem->setText (3, pInfo->qsSize);
+      pVideoItem->setText (4, pInfo->qsRatio);
+      pVideoItem->setText (5, pInfo->qsFPS);
+      pVideoItem->setText (6, pInfo->qsStatus);
+      pVideoItem = NULL;
+    }
+    else
+      pVideoItem = pVideoItem->nextSibling ();
+  }
+
+  QListViewItem *pAudioItem = m_pSourceWidget->m_pListViewAudioSources->firstChild ();
+  while ( pAudioItem ) {
+    if  ( pAudioItem->text( AUDIO_FILE_NAME_INDEX ) == pInfo->qsFileName ) {
+      pAudioItem->setText (0, pInfo->qsAudioFormat);
+      pAudioItem->setText (1, pInfo->qsLength);
+      pAudioItem->setText (2, pInfo->qsBits);
+      pAudioItem->setText (3, pInfo->qsSample);
+      pAudioItem->setText (4, pInfo->qsBPS);
+      pAudioItem->setText (5, pInfo->qsSize);
+      pAudioItem->setText (6, pInfo->qsStatus);
+      pAudioItem = NULL;
+    }
+    else
+      pAudioItem = pAudioItem->nextSibling ();
+  }
 }
 
 int SourceToolBar::getFreeSourceSlot ()
@@ -485,57 +652,56 @@ int SourceToolBar::getFreeSourceSlot ()
 
 void SourceToolBar::addMovie (SourceFileEntry *pEntry)
 {
-	uint t;
-	QColor statusColor (COLOR_MOVIE_FILES_OK);
-
-	SourceFileInfo *pInfo;
-	for (t=0;t<pEntry->listFileInfos.count();t++)	{
-		pInfo = pEntry->listFileInfos[t];
-		// Here we check that ALL sources are ok
-		if (pInfo->qsStatus != QString ("Ok"))
-			statusColor = QColor(COLOR_MOVIE_FILES_BAD);
-
-		new QListViewItem (m_pSourceWidget->m_pListViewVideoSources, pInfo->qsFormat,
-			pInfo->qsResolution, pInfo->qsLength, pInfo->qsSize, pInfo->qsRatio,
-			pInfo->qsFPS, pInfo->qsStatus, pInfo->qsFileName);
-	}
-	new ListViewItemMedia (m_pListViewAllSources, pEntry, statusColor);
+  uint t;
+  QColor statusColor (COLOR_MOVIE_FILES_OK);
+  
+  SourceFileInfo *pInfo;
+  for (t=0;t<pEntry->listFileInfos.count();t++)	{
+    pInfo = pEntry->listFileInfos[t];
+    // Here we check that ALL sources are ok
+    if (pInfo->qsStatus != QString ("Ok"))
+      statusColor = QColor(COLOR_MOVIE_FILES_BAD);
+    
+    new QListViewItem (m_pSourceWidget->m_pListViewVideoSources, pInfo->qsVideoFormat,
+		       pInfo->qsResolution, pInfo->qsLength, pInfo->qsSize, pInfo->qsRatio,
+		       pInfo->qsFPS, pInfo->qsStatus, pInfo->qsFileName);
+  }
+  new ListViewItemMedia (m_pListViewAllSources, pEntry, statusColor);
 }
 
 void SourceToolBar::appendSourceFileEntry(SourceFileEntry *pEntry)
 {
-	// This function is called when loading from an XML-project file ???
-	m_listSourceFileEntries.append(pEntry);
-	QColor statusColor (COLOR_MOVIE_FILES_BAD);
-	// Here we set the preview size ...
-	pEntry->sizeThumbnail = m_pDVDAuthor->getDragNDropContainer()->sizeThumbnail;
-	if (!pEntry->bSoundSource)	{	// Here we handle a Movie SourceFileEntry ...
-		for (uint t=0;t<pEntry->listFileInfos.count();t++)	{
-			SourceFileInfo *pInfo = pEntry->listFileInfos[t];
-			// Add the plaeas - wait image
-			pInfo->pPreview = new QImage (QImage().fromMimeSource( "please_wait.jpg" ));
-			// and the request the preview from a background thread.
-			MediaCreator::registerWithMediaScanner (this, pInfo);
-			*pInfo->pPreview = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
-			// And show what we have thus far.
-			new QListViewItem (m_pSourceWidget->m_pListViewVideoSources, pInfo->qsFormat, pInfo->qsResolution, pInfo->qsLength,  pInfo->qsSize, pInfo->qsRatio, pInfo->qsFPS, pInfo->qsStatus, pInfo->qsFileName);
-		}
-	}
-	else	{	// And here we have a Sound SourceFileEntry
-		statusColor = QColor (COLOR_SOUND_FILES_OK);
-
-		for (uint t=0;t<pEntry->listFileInfos.count();t++)	{
-			SourceFileInfo *pInfo = pEntry->listFileInfos[t];
-			if (pInfo->qsStatus != QString ("Ok"))
-				statusColor = QColor (COLOR_SOUND_FILES_BAD);
-
-			pInfo->pPreview = new QImage (QImage().fromMimeSource( "sound_file.jpg" ));
-			*pInfo->pPreview = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
-			new QListViewItem (m_pSourceWidget->m_pListViewAudioSources, pInfo->qsFormat, pInfo->qsLength, pInfo->qsBits, pInfo->qsSample, pInfo->qsBPS, pInfo->qsSize, pInfo->qsStatus, pInfo->qsFileName);
-		}
-	}
-//	makeScreenshots (pEntry);
-	new ListViewItemMedia (m_pListViewAllSources, pEntry, statusColor);
+  // This function is called when loading from an XML-project file ???
+  m_listSourceFileEntries.append(pEntry);
+  QColor statusColor (COLOR_MOVIE_FILES_BAD);
+  // Here we set the preview size ...
+  pEntry->sizeThumbnail = m_pDVDAuthor->getDragNDropContainer()->sizeThumbnail;
+  if (!pEntry->bSoundSource)	{	// Here we handle a Movie SourceFileEntry ...
+    for (uint t=0;t<pEntry->listFileInfos.count();t++)	{
+      SourceFileInfo *pInfo = pEntry->listFileInfos[t];
+      // Add the plaeas - wait image
+      pInfo->pPreview = new QImage (QImage().fromMimeSource( "please_wait.jpg" ));
+      // and the request the preview from a background thread.
+      MediaCreator::registerWithMediaScanner (this, pInfo, pInfo->iMSecPreview, false);
+      *pInfo->pPreview = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
+      // And show what we have thus far.
+      new QListViewItem (m_pSourceWidget->m_pListViewVideoSources, pInfo->qsVideoFormat, pInfo->qsResolution, pInfo->qsLength,  pInfo->qsSize, pInfo->qsRatio, pInfo->qsFPS, pInfo->qsStatus, pInfo->qsFileName);
+    }
+  }
+  else	{	// And here we have a Sound SourceFileEntry
+    statusColor = QColor (COLOR_SOUND_FILES_OK);
+    
+    for (uint t=0;t<pEntry->listFileInfos.count();t++)	{
+      SourceFileInfo *pInfo = pEntry->listFileInfos[t];
+      if (pInfo->qsStatus != QString ("Ok"))
+	statusColor = QColor (COLOR_SOUND_FILES_BAD);
+      
+       pInfo->pPreview = new QImage (QImage().fromMimeSource( "sound_file.jpg" ));
+      *pInfo->pPreview = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
+      new QListViewItem (m_pSourceWidget->m_pListViewAudioSources, pInfo->qsAudioFormat, pInfo->qsLength, pInfo->qsBits, pInfo->qsSample, pInfo->qsBPS, pInfo->qsSize, pInfo->qsStatus, pInfo->qsFileName);
+    }
+  }
+  new ListViewItemMedia (m_pListViewAllSources, pEntry, statusColor);
 }
 
 void SourceToolBar::slotRemoveEntry(SourceFileEntry *pEntry)
@@ -584,16 +750,16 @@ void SourceToolBar::addSound (QStringList &listSoundNames)
 		// Lets create a new SoourceFileEntry for this sound file ...
 		pInfo = new SourceFileInfo;
 
-		pInfo->qsSize     = pMediaInfo->getSizeString();
-		pInfo->qsBits     = QString ("%1").arg(pMediaInfo->getBits());
-		pInfo->qsSample   = pMediaInfo->getSampleString ();
-		pInfo->qsBPS      = pMediaInfo->getBPSString (false);
-		pInfo->qsLength   = pMediaInfo->getLengthString ();
-		pInfo->qsFormat   = pMediaInfo->getFormat (false);
-		pInfo->qsStatus   = pMediaInfo->getStatus();
-		pInfo->qsFileName = listSoundNames[t];
-		pInfo->pPreview   = new QImage (QImage().fromMimeSource( "sound_file.jpg" ));
-		*pInfo->pPreview  = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
+		pInfo->qsSize        = pMediaInfo->getSizeString();
+		pInfo->qsBits        = QString ("%1").arg(pMediaInfo->getBits());
+		pInfo->qsSample      = pMediaInfo->getSampleString ();
+		pInfo->qsBPS         = pMediaInfo->getBPSString (false);
+		pInfo->qsLength      = pMediaInfo->getLengthString ();
+		pInfo->qsAudioFormat = pMediaInfo->getFormat (false);
+		pInfo->qsStatus      = pMediaInfo->getStatus();
+		pInfo->qsFileName    = listSoundNames[t];
+		pInfo->pPreview      = new QImage (QImage().fromMimeSource( "sound_file.jpg" ));
+		*pInfo->pPreview     = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
 
 		if (pInfo->qsStatus != QString ("Ok"))
 			statusColor = QColor (COLOR_SOUND_FILES_BAD);
@@ -609,11 +775,13 @@ void SourceToolBar::addSound (QStringList &listSoundNames)
 	m_listSourceFileEntries.append(pEntry);
 
 	// this new sound is assigned to the current DVDMenu's Preview. PHew what a long list to get there ...
-	m_pDVDAuthor->getCurrentSubMenu()->getMenuPreview()->undoBuffer()->push (new DVDMenuUndoObject(DVDMenuUndoObject::NEW_AUDIO, pEntry ));	// And finally we add it to the list ...
+	DVDMenu *pCurrentSubMenu = m_pDVDAuthor->getCurrentSubMenu();
+	if ( pCurrentSubMenu )
+	  pCurrentSubMenu->getMenuPreview()->undoBuffer()->push (new DVDMenuUndoObject(DVDMenuUndoObject::NEW_AUDIO, pEntry ));	// And finally we add it to the list ...
 	new ListViewItemMedia (m_pListViewAllSources, pEntry, statusColor);
 
 	// And further on to the m_pListViewVideoSources ...
-	new QListViewItem (m_pSourceWidget->m_pListViewAudioSources, pInfo->qsFormat, pInfo->qsLength, pInfo->qsBits, pInfo->qsSample, pInfo->qsBPS, pInfo->qsSize,  pInfo->qsStatus, pInfo->qsFileName);
+	new QListViewItem (m_pSourceWidget->m_pListViewAudioSources, pInfo->qsAudioFormat, pInfo->qsLength, pInfo->qsBits, pInfo->qsSample, pInfo->qsBPS, pInfo->qsSize,  pInfo->qsStatus, pInfo->qsFileName);
 	delete pMediaInfo;
 }
 
@@ -643,8 +811,13 @@ void SourceToolBar::slotEditMovie()
 	if (pSourceFileInfo)	{
 		DialogMovie *pDialog = new DialogMovie (this);
 		pDialog->initMe (pSourceFileInfo, getMediaEngine(), m_pDVDAuthor->getDragNDropContainer()->sizeThumbnail.width());
-		if (pDialog->exec () == QDialog::Accepted)
+		connect ( pDialog, SIGNAL ( signalSetThumbnail ( long ) ), this, SLOT ( slotSetThumbnail ( long ) ) );
+		if (pDialog->exec () == QDialog::Accepted) {
 			*pSourceFileInfo = *pDialog->sourceFileInfo();
+			// next is to update the entries if neccesary ...
+			updateListViewItem ( pSourceFileInfo );
+		}
+		disconnect ( pDialog, SIGNAL ( signalSetThumbnail ( long ) ), this, SLOT ( slotSetThumbnail ( long ) ) );
 		delete pDialog;
 		return;
 	}
@@ -692,46 +865,46 @@ void SourceToolBar::slotEditMovie()
 
 void SourceToolBar::refreshToolBarEntries()
 {
-	uint t, i;
-	QColor statusColor;
-	SourceFileEntry *pEntry;
-	SourceFileInfo *pInfo;
-	// This function will remove all entries from all listBox objects and re-create all information from
-	// The current m_listSourceFileEntries.
-	m_pListViewAllSources  ->clear ();
-	m_pSourceWidget->m_pListViewVideoSources->clear ();
-	m_pSourceWidget->m_pListViewAudioSources->clear ();
-	for (t=0;t<m_listSourceFileEntries.count();t++)	{
-		pEntry = m_listSourceFileEntries[t];
-		// Okay here we decide if we have a Movie or sound stream ...
-//		if (pEntry->listFileInfos[0]->qsSample.isEmpty())	{
-		if (!pEntry->bSoundSource)	{
-			statusColor = QColor(COLOR_MOVIE_FILES_OK);
-			for (i=0;i<pEntry->listFileInfos.count();i++)	{
-				pInfo = pEntry->listFileInfos[i];
-				// Here we check that ALL sources are ok
-				if (pInfo->qsStatus != QString ("Ok"))
-					statusColor = QColor(COLOR_MOVIE_FILES_BAD);
-
-				new QListViewItem (m_pSourceWidget->m_pListViewVideoSources, pInfo->qsFormat,
-					pInfo->qsResolution, pInfo->qsLength, pInfo->qsSize, pInfo->qsRatio,
-					pInfo->qsFPS, pInfo->qsStatus, pInfo->qsFileName);
-			}
-		}
-		else 	{
-			statusColor = QColor (COLOR_SOUND_FILES_OK);
-			for (i=0;i<pEntry->listFileInfos.count();i++)	{
-				pInfo = pEntry->listFileInfos[i];
-				if (pInfo->qsStatus != QString ("Ok"))
-					statusColor = QColor (COLOR_SOUND_FILES_BAD);
-
-				new QListViewItem (m_pSourceWidget->m_pListViewAudioSources, pInfo->qsFormat,
-					pInfo->qsLength, pInfo->qsBits, pInfo->qsSample, pInfo->qsBPS,
-					pInfo->qsSize,  pInfo->qsStatus, pInfo->qsFileName);
-			}
-		}
-		new ListViewItemMedia (m_pListViewAllSources, pEntry, statusColor);
-	}
+  uint t, i;
+  QColor statusColor;
+  SourceFileEntry *pEntry;
+  SourceFileInfo *pInfo;
+  // This function will remove all entries from all listBox objects and re-create all information from
+  // The current m_listSourceFileEntries.
+  m_pListViewAllSources  ->clear ();
+  m_pSourceWidget->m_pListViewVideoSources->clear ();
+  m_pSourceWidget->m_pListViewAudioSources->clear ();
+  for (t=0;t<m_listSourceFileEntries.count();t++)	{
+    pEntry = m_listSourceFileEntries[t];
+    // Okay here we decide if we have a Movie or sound stream ...
+    //		if (pEntry->listFileInfos[0]->qsSample.isEmpty())	{
+    if (!pEntry->bSoundSource)	{
+      statusColor = QColor(COLOR_MOVIE_FILES_OK);
+      for (i=0;i<pEntry->listFileInfos.count();i++)	{
+	pInfo = pEntry->listFileInfos[i];
+	// Here we check that ALL sources are ok
+	if (pInfo->qsStatus != QString ("Ok"))
+	  statusColor = QColor(COLOR_MOVIE_FILES_BAD);
+	  
+	  new QListViewItem (m_pSourceWidget->m_pListViewVideoSources, pInfo->qsVideoFormat,
+			     pInfo->qsResolution, pInfo->qsLength, pInfo->qsSize, pInfo->qsRatio,
+			     pInfo->qsFPS, pInfo->qsStatus, pInfo->qsFileName);
+      }
+    }
+    else 	{
+      statusColor = QColor (COLOR_SOUND_FILES_OK);
+      for (i=0;i<pEntry->listFileInfos.count();i++)	{
+	pInfo = pEntry->listFileInfos[i];
+	if (pInfo->qsStatus != QString ("Ok"))
+	  statusColor = QColor (COLOR_SOUND_FILES_BAD);
+	
+	new QListViewItem (m_pSourceWidget->m_pListViewAudioSources, pInfo->qsAudioFormat,
+			   pInfo->qsLength, pInfo->qsBits, pInfo->qsSample, pInfo->qsBPS,
+			   pInfo->qsSize,  pInfo->qsStatus, pInfo->qsFileName);
+      }
+    }
+    new ListViewItemMedia (m_pListViewAllSources, pEntry, statusColor);
+  }
 }
 
 void SourceToolBar::slotDeleteSource()
@@ -753,7 +926,7 @@ void SourceToolBar::slotDeleteSource()
 	if ( (!pSourceFileEntry->bSoundSource) && (m_pDVDAuthor) )	{
 		// Okay we should politely check if this source is in use by a button.
 		if (m_pDVDAuthor->isSourceEntryUsed(qsCurrentText))	{
-			if (QMessageBox::warning (NULL, tr ("Warning, This source is in use."),
+			if (MessageBox::warning (NULL, tr ("Warning, This source is in use."),
 				tr ("This Source is in use.\nDo you realy want to delete this source ?\n"), 
 				QMessageBox::Yes, QMessageBox::No) == QMessageBox::No)
 					return;
@@ -783,7 +956,8 @@ void SourceToolBar::removeEntry (QString &qsEntry, bool bSourceOnly)
 			pSourceFileInfo = pSourceFileEntry->listFileInfos[t];
 			fileInfo.setFile (pSourceFileInfo->qsFileName);
 			if (fileInfo.fileName() == qsEntry)	{
-				pSourceFileEntry->listFileInfos.remove (pSourceFileInfo);
+				pSourceFileEntry->listFileInfos.remove   ( pSourceFileInfo );
+				MediaCreator::unregisterFromMediaScanner ( pSourceFileInfo );
 				delete pSourceFileInfo;
 				refreshToolBarEntries ();
 				// Check if we have just removed the last source from this entry.
@@ -791,6 +965,7 @@ void SourceToolBar::removeEntry (QString &qsEntry, bool bSourceOnly)
 					// in which case we want to alos delete the header ...
 					removeEntry (pSourceFileEntry, bSourceOnly);
 					delete pSourceFileEntry;
+					return;
 				}
 			}
 		}
@@ -805,6 +980,11 @@ void SourceToolBar::removeEntry (SourceFileEntry *pSourceFileEntry, bool bSource
 	if (!pSourceFileEntry)
 		return;
 	m_listSourceFileEntries.remove (pSourceFileEntry);
+
+	// The first thing we should ensure is that we are not registered with the MediaScanner, which could crash QDVDAuthor
+	for (t=0;t<pSourceFileEntry->listFileInfos.count();t++)
+	  MediaCreator::unregisterFromMediaScanner ( pSourceFileEntry->listFileInfos[t] );
+
 	// Next we remove the entry from the AllSources - Tab
 	QValueList<QListViewItem *> listDelItems;
 	QListViewItem *pItem = m_pListViewAllSources->firstChild();
@@ -889,7 +1069,8 @@ void SourceToolBar::slotPlayMovie()
 	}
 	// Here we execute the external QXine video viewer application ...
 	qsCommand += QString (" &");
-	system ((const char *)qsCommand);
+	if ( system ((const char *)qsCommand) == -1)
+		return;
 }
 
 // the following two functions are called from CSlideDialog, if avail ...
@@ -957,7 +1138,7 @@ void SourceToolBar::slotSlideshowDone(QString qsSlideshowName, QString qsFileNam
 			fileInfo.setFile ( qsFileName );
 			qsFileName = QString ("%1/%2.xml").arg(fileInfo.dirPath( TRUE )).arg(fileInfo.baseName ());
 			importChapters ( qsFileName, pInfo );
-			new QListViewItem (m_pSourceWidget->m_pListViewVideoSources, pInfo->qsFormat,
+			new QListViewItem (m_pSourceWidget->m_pListViewVideoSources, pInfo->qsVideoFormat,
 				pInfo->qsResolution, pInfo->qsLength, pInfo->qsSize, pInfo->qsRatio,
 				pInfo->qsFPS, pInfo->qsStatus, pInfo->qsFileName);
 			MediaCreator::registerWithMediaScanner (this, pInfo);
