@@ -11,6 +11,7 @@
 #include <qmainwindow.h>
 #include <qlistview.h>
 
+#include "dvdmenu.h"
 #include "menupreview.h"
 #include "menuobject.h"
 #include "structuretoolbar.h"
@@ -79,8 +80,23 @@ void StructureToolBar::slotRightClickedOnTitleset (QListViewItem *, const QPoint
 
 void StructureItem::createContextMenu    ( QPoint p )
 {
+  QString qsText  = text ( 1 );
+  bool bIntro     = false;
+  bool bSoundFile = false;
+  if ( text ( 0 ).find ( "Intro file" ) > -1 )
+    bIntro = true;
+  else if ( text ( 0 ).find ( "Sound file" ) > -1 )
+    bSoundFile = true;
+
   if ( m_pMenuObject )
-    m_pMenuObject->createContextMenu( p );
+    m_pMenuObject->createContextMenu  ( p );    
   else if ( m_pMenuPreview )
     m_pMenuPreview->createContextMenu ( p );
+  else if ( m_pDVDMenu ) {
+    if ( bSoundFile )
+      m_pDVDMenu->createSoundMenu ( p, qsText );
+    else
+      m_pDVDMenu->createIntroExtroMenu  ( p, bIntro, qsText );
+  }
 }
+
