@@ -21,13 +21,13 @@
 #include <qtabwidget.h>
 #include <qdragobject.h>
 #include <qpushbutton.h>
-#include <qmessagebox.h>
 #include <qcolordialog.h>
 #include <qfontdatabase.h>
 
 #include "global.h"
 #include "importsrt.h"
 #include "exportsrt.h"
+#include "messagebox.h"
 #include "qdvdauthor.h"
 #include "subtitlesgui.h"
 #include "listviewmedia.h"
@@ -562,7 +562,7 @@ void SubtitlesGui::slotImport ()
 void SubtitlesGui::slotClear ()
 {
   if ( m_pTableSubtitles->numRows () > 10 ) 
-    if ( QMessageBox::warning ( NULL, tr("Attention:"), tr("Are you sure you want to delete all subtitles ?"), QMessageBox::Yes, QMessageBox::No ) == QMessageBox::No )
+    if ( MessageBox::warning ( NULL, tr("Attention:"), tr("Are you sure you want to delete all subtitles ?"), QMessageBox::Yes, QMessageBox::No ) == QMessageBox::No )
       return;
 
   if ( m_pSourceFileInfo && m_pSourceFileInfo->pSubtitles ) {
@@ -897,7 +897,7 @@ QFont &SubtitlesGui::getFont ()
   return m_qfFont;
 }
 
-void SubtitlesGui::setBackgroundColor (QColor &newColor)
+void SubtitlesGui::setBackgroundColor  ( const QColor &newColor )
 {
   // Check if the user pressed cancel ...
   if (!newColor.isValid())
@@ -924,12 +924,12 @@ void SubtitlesGui::insertDraggedObject ( QDropEvent *pDropEvent, QImage &theImag
     ListViewMedia   *pListViewMedia   = (ListViewMedia *)pDropEvent->source();
     SourceFileEntry *pSourceFileEntry = pListViewMedia->draggingSourceFileEntry();
     SourceFileInfo  *pSourceFileInfo  = pListViewMedia->draggingSourceFileInfo();
-    if ( pSourceFileEntry->bSoundSource )  {	// No adding of a sound source !
-      QMessageBox::warning (NULL, tr("Can not add."), tr ("This is a sound source.\nI can currently not add this type of source.\n"), QMessageBox::Ok, QMessageBox::NoButton);
+    if ( pSourceFileEntry && pSourceFileEntry->bSoundSource )  {	// No adding of a sound source !
+      MessageBox::warning (NULL, tr("Can not add."), tr ("This is a sound source.\nI can currently not add this type of source.\n"), QMessageBox::Ok, QMessageBox::NoButton);
       return;
     }
-    if ( pSourceFileEntry->bIsSlideshow )	{
-      QMessageBox::warning (NULL, tr("Can not add."), tr ("The slideshow is still beeing created.\nI can not add it at this moment.\n"), QMessageBox::Ok, QMessageBox::NoButton);
+    if ( pSourceFileEntry && pSourceFileEntry->bIsSlideshow )	{
+      MessageBox::warning (NULL, tr("Can not add."), tr ("The slideshow is still beeing created.\nI can not add it at this moment.\n"), QMessageBox::Ok, QMessageBox::NoButton);
       return;
     }
     if ( ( ! pSourceFileInfo ) && ( pSourceFileEntry ) ) // Okay here we split between adding one button
@@ -1053,7 +1053,7 @@ Subtitles *SubtitlesGui::getSubtitles ( bool bCreateNew )
 void SubtitlesGui::initNewSourceFileInfo ()
 {
   if ( m_pSourceFileInfo &&  m_pSourceFileInfo->pSubtitles && m_pSubtitles ) {
-    if (QMessageBox::warning (NULL, QObject::tr("What should I keep ?"), 
+    if (MessageBox::warning (NULL, QObject::tr("What should I keep ?"), 
           QObject::tr ("I detected that there are already Subtitle in the Dialog and in the Source.\n\nShould I delete the Subtitles in the Dialog ?\n"), 
 	  QMessageBox::Yes, QMessageBox::No) == QMessageBox::No )
 	    return; // Note at this point table and Subtitles-object are in sync
