@@ -71,10 +71,12 @@ public:
 	{
 		 DropZone ();
 	public:
-		 DropZone (int, QString, QRect);
+		 enum { IgnoreObject, ImageObject, MovieObject, TextObject, FrameObject };
+		 DropZone (int, QString, QRect, QString);
  		~DropZone ();
 
 		int      iNumber;	// Counter, of which DropZone we have ... E.g. 1
+		int      iType;         // MovieObject, TextObject, FrameObject or ImageObject
 		bool     bMovie;	// Is this a movie Source ?
 		QString  qsText;	// E.g "Movie 1" used for ???
 		QRect    rect;
@@ -85,29 +87,32 @@ public:
 	 TemplateWizard( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
 	~TemplateWizard();
 
-	void initMe             (QDVDAuthor *);
-	void droppedSomething   (QDropEvent *);
-	DVDMenu *getMenu        ();
+	void initMe             ( QDVDAuthor * );
+	void droppedSomething   ( QDropEvent * );
+	void showDialog         ( );
+	DVDMenu *getMenu        ( );
 
 protected:
 	void initTab (QString, QIconView * );
-	void initPreview                  ();
-	void initDragList                 ();
-	void refreshBackground            ();
-	void refreshComboMenu             ();
-	QString getSourceEntryName (QString);
-	QString readProjectFile (QString, bool);
+	void initPreview                  ( );
+	void initDragList                 ( );
+	void refreshBackground            ( );
+	void refreshComboMenu             ( );
+	QString getSourceEntryName( QString );
+	QString readProjectFile ( QString, bool );
 
 protected slots:
 	virtual void slotTemplateClicked   (QMouseEvent   *);
 	virtual void slotListBoxClicked    (QListBoxItem  *);
 	virtual void slotIconViewClicked   (QIconViewItem *);
 	virtual void slotTargetMenuChanged (const QString &);
-	virtual void slotPlaybackFinished  ();
-	virtual void next   ();
-	virtual void reject ();
-	virtual void accept ();
-	virtual void hide   ();
+	virtual void slotPlaybackFinished  ( );
+	virtual void slotTemplateDetails   ( );
+	virtual void next     ( );
+	virtual void reject   ( );
+	virtual void accept   ( );
+	virtual void hide     ( );
+	virtual void slotHelp ( );
     
 private:
 	QDVDAuthor              *m_pDVDAuthor;
@@ -116,12 +121,20 @@ private:
 	MediaInterface          *m_pMediaInterface;
 	ListBoxToolTip          *m_pListBoxToolTip;
 	bool                     m_bDontRestart;
+	bool                     m_bLocalTemplate;
 
 	QValueList<DVDMenu *>    m_listDVDMenus;
 	QString                  m_qsPathName;
 	QValueList<DropZone *>   m_listDropZones;
 	QString                  m_qsXMLDVDMenu;
 	QString                  m_qsCurrentTemplate;
+	QString                  m_qsTemplateVersion;
+	QString                  m_qsTemplateAuthor;
+	QString                  m_qsTemplateContact;
+	QString                  m_qsTemplateHeader;
+	QString                  m_qsTemplateDescription;
+	QString                  m_qsTemplateComment;
+
 	float                    m_fScale;
 	QStringList              m_listSourceFileDescriptions;
 };
