@@ -1,12 +1,9 @@
 /****************************************************************************
-** ImagePreview class
+** TextObject class
 **
 ** Created: Tue Feb 02 22:06:51 2004
 **      by: Varol Okan using Kate
 **
-** This class is the encapsulation of the ImagePreview from the FileSelection
-** Dialog.
-** It is also used in the ImageDialog.
 **
 ****************************************************************************/
 
@@ -16,8 +13,8 @@
 #include <qpainter.h>
 #include <qpopupmenu.h>
 #include <qwmatrix.h>
-#include <qmessagebox.h>
 
+#include "messagebox.h"
 #include "global.h"
 #include "xml_dvd.h"
 #include "dialogtextfont.h"
@@ -92,14 +89,14 @@ void TextObject::replaceColor (QColor theColor, QColor oldColor)
 		setBackgroundColor (theColor);
 }
 
-void TextObject::setForegroundColor (QColor &theColor)
+void TextObject::setForegroundColor ( const QColor &theColor)
 {
-	m_colorForeground = theColor;
+  m_colorForeground = theColor;
 }
 
-void TextObject::setBackgroundColor (QColor &theColor)
+void TextObject::setBackgroundColor ( const QColor &theColor)
 {
-	m_colorBackground = theColor;
+  m_colorBackground = theColor;
 }
 
 QColor &TextObject::getForegroundColor ()
@@ -114,6 +111,8 @@ QColor &TextObject::getBackgroundColor ()
 
 void TextObject::drawSemiTransparent (QPainter *pPainter)
 {
+        if ( m_pShadow && ! m_bDrawRect )
+	     m_pShadow->drawContents ( pPainter );
 	QWMatrix theMatrix;
 	QRect dummyRect, theRect;
 	int iFlags, x, y;
@@ -224,7 +223,10 @@ void TextObject::drawContents (QPainter *painter)
 	if (modifiers()->fTransparency == 1.0)
 		return;
 	else if ( (modifiers()->fTransparency != 0.0) && ( ! m_bDrawRect) )
-		return drawSemiTransparent (painter);
+		return drawSemiTransparent ( painter );
+
+        if ( m_pShadow && ! m_bDrawRect )
+	     m_pShadow->drawContents ( painter );
 	// Here we calculate the center point of gravity (rotation)
 	QPoint centerPos;
 	centerPos.setX (rect().x() + (int)(rect().width () / 2.0));
@@ -251,8 +253,10 @@ void TextObject::drawContents (QPainter *painter)
 	
 	// Here we get the rect that encompasses the button for this object.
 	m_boundingRect = theMatrix.mapRect(theRect);
-	if (m_bDrawRect)
-		painter->drawRect(m_boundingRect);
+	if (m_bDrawRect) {
+	  drawActiveFrame ( painter );
+	  //painter->drawRect(m_boundingRect);
+	}
 	//  then we actually set the world matrix 
 	painter->setWorldMatrix(theMatrix);
 
@@ -271,7 +275,7 @@ void TextObject::drawContents (QPainter *painter)
 	m_Font.setStyleStrategy ((QFont::StyleStrategy)m_iStyleStrategy);
 	painter->setFont(m_Font);
 	QRect boundingRect;
-
+	bool bUpdateAgain = false;
 	// Okay, I abused a QPoint class to hold some other infos ... so what ???
 	int iFlags = Qt::DontClip|Qt::WordBreak|m_ptTextAlign.x()|m_ptTextAlign.y();
 
@@ -282,11 +286,16 @@ void TextObject::drawContents (QPainter *painter)
 	// Here we expand the rectangle if needs be, and update again, to re-draw.
 	if (m_rect.width() < boundingRect.width())	{
 		m_rect.setWidth  (boundingRect.width());
-		m_pParent->update ();
+		bUpdateAgain = true;
 	}
 	if (m_rect.height() < boundingRect.height())	{
 		m_rect.setHeight (boundingRect.height());
-		m_pParent->update ();
+		bUpdateAgain = true;
+	}
+
+	if ( bUpdateAgain ) {
+	  m_pParent->update ( );
+	  updateShadow      ( );
 	}
 
 	// Here we re-set the world matrix and translate the newly drawn ... thing ...
@@ -387,13 +396,14 @@ bool TextObject::createContextMenu (QPoint globalPos)
 	if (m_pContextMenu)
 		delete m_pContextMenu;
 	m_pContextMenu = new QPopupMenu(m_pParent);
-	m_pContextMenu->insertItem ( tr ("Edit ...")  , this,  SLOT(slotEdit()));
-	m_pContextMenu->insertItem ( tr ("Matrix ..."), this,  SLOT(slotMatrix()));
-	m_pContextMenu->insertItem ( tr ("Delete")    , this,  SLOT(slotDelete()));
+	m_pContextMenu->insertItem ( tr ("Edit ...")  , this,  SLOT(slotEdit      ( ) ) );
+	m_pContextMenu->insertItem ( tr ("Matrix ..."), this,  SLOT(slotMatrix    ( ) ) );
+	m_pContextMenu->insertItem ( tr ("Delete")    , this,  SLOT(slotDelete    ( ) ) );
 	m_pContextMenu->insertSeparator();
-	m_pContextMenu->insertItem ( tr ("Add Frame"), this,   SLOT(slotAddFrame()));
-	m_pContextMenu->insertItem ( tr ("Add Image"), this,   SLOT(slotAddImage()));
-	m_pContextMenu->insertItem ( tr ("Add Movie"), this,   SLOT(slotAddMovie()));
+	m_pContextMenu->insertItem ( tr ("Add Shadow"),this,   SLOT(slotAddShadow ( ) ) );
+	m_pContextMenu->insertItem ( tr ("Add Frame"), this,   SLOT(slotAddFrame  ( ) ) );
+	m_pContextMenu->insertItem ( tr ("Add Image"), this,   SLOT(slotAddImage  ( ) ) );
+	m_pContextMenu->insertItem ( tr ("Add Movie"), this,   SLOT(slotAddMovie  ( ) ) );
 	m_pContextMenu->insertSeparator();
 	m_pContextMenu->insertItem ( tr ("Define as Button") , this, SLOT(slotDefineAsButton()));
 	// Blocking call
@@ -430,6 +440,8 @@ void TextObject::createStructure (QListViewItem *pParentItem)
 		new StructureItem(this, pModifierItem, tr ("Rotate"),
 			QString ("%1 deg").arg(m_modifiers.fRotate));
 	}
+	if ( m_pShadow )
+	     m_pShadow->createStructure ( pButtonItem );
 
 	if (m_colorBackground == QColor (TRANSPARENT_COLOR))
 	  new StructureItem(this, pButtonItem, tr ("Background"), tr ("Transparent"));
@@ -451,25 +463,6 @@ void TextObject::createStructure (QListViewItem *pParentItem)
 		arg(rect().x()).arg(rect().y()).arg(rect().width()).arg(rect().height()));
 }
 
-bool TextObject::mouseMoveEvent (QMouseEvent *pEvent)
-{
-	// This will move the textObject around and around and around we go ...
-	QRect theRect = rect();
-	int iX, iY, iWidth, iHeight;
-	iWidth  = rect().width ();
-	iHeight = rect().height();
-	iX = rect().x() - (m_currentMousePos.x() - pEvent->pos().x());
-	iY = rect().y() - (m_currentMousePos.y() - pEvent->pos().y());
-	theRect.setX(iX);
-	theRect.setY(iY);
-	theRect.setWidth(iWidth);
-	theRect.setHeight(iHeight);
-
-	setRect(theRect);
-	m_currentMousePos = pEvent->pos();
-	return false;
-}
-
 bool TextObject::mousePressEvent (QMouseEvent *pEvent)
 {
 	m_currentMousePos = pEvent->pos();
@@ -574,9 +567,10 @@ bool TextObject::mouseDoubleClickEvent (QMouseEvent *)
 	else
 		setRect(fontDialog.getRect());
 
-	m_pParent->update ();
-	emit (signalUpdatePixmap());
-	emit (signalUpdateStructure());
+	m_pParent->update ( );
+	updateShadow      ( );
+	emit (signalUpdatePixmap    ( ) );
+	emit (signalUpdateStructure ( ) );
 	return false;
 }
 
@@ -594,19 +588,19 @@ void TextObject::slotMatrix()
 
 void TextObject::slotAddFrame ()
 {
-	QMessageBox::warning (NULL, tr ("Not Implemented yet."), tr ("Not Implemented yet."),
+	MessageBox::warning (NULL, tr ("Not Implemented yet."), tr ("Not Implemented yet."),
 		QMessageBox::Ok ,  QMessageBox::Cancel);
 }
 
 void TextObject::slotAddImage ()
 {
-	QMessageBox::warning (NULL, tr ("Not Implemented yet."), tr ("Not Implemented yet."),
+	MessageBox::warning (NULL, tr ("Not Implemented yet."), tr ("Not Implemented yet."),
 		QMessageBox::Ok ,  QMessageBox::Cancel);
 }
 
 void TextObject::slotAddMovie ()
 {
-	QMessageBox::warning (NULL, tr ("Not Implemented yet."), tr ("Not Implemented yet."),
+	MessageBox::warning (NULL, tr ("Not Implemented yet."), tr ("Not Implemented yet."),
 		QMessageBox::Ok ,  QMessageBox::Cancel);
 }
 
@@ -633,6 +627,11 @@ MenuObject *TextObject::clone()
 	pNewObject->setRect(rect());
 	pNewObject->setModifiers(*modifiers());
 
+	MenuObject *pShadow = shadow ( );
+	if ( pShadow )
+	     pShadow = pShadow->clone ( pNewObject );
+	pNewObject->setShadow         (  pShadow   );
+
 	return pNewObject;
 }
 
