@@ -11,14 +11,20 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#include <qmessagebox.h>
 #include <qfileinfo.h>
 #include <qimage.h>
 #include <qfile.h>
 #include <qdir.h>
 
+#include <qstylefactory.h>
+#include <qapplication.h>
+#include <qmetaobject.h>
+#include <qstyle.h>
+
 #include "global.h"
 #include "utils.h"
+#include "messagebox.h"
+
 
 Utils::Utils()
 {
@@ -30,6 +36,24 @@ Utils::~Utils ()
 
 }
 
+QString Utils::currentStyleName ( )
+{
+  QStringList list = QStyleFactory::keys();
+  list.sort();
+
+  for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it ) {
+    QString styleName = *it;
+    QStyle *candidate = QStyleFactory::create(styleName);
+    Q_ASSERT(candidate);
+    if (candidate->metaObject()->className() == QApplication::style().metaObject()->className()) {
+      delete candidate;
+      return styleName;
+    }
+    delete candidate;
+  }
+  return QString("Default");
+}
+
 QString Utils::formatChapter (QString qsInput)
 {
 	char cBuffer[20];
@@ -181,6 +205,28 @@ QString Utils::getVideoFormat (int iWidth, int iHeight)
 	return qsFormat;
 }
 
+int Utils::getFormat (int iWidth, int iHeight)
+{
+	int iFormat = FORMAT_NONE;
+	if ((iWidth == 720) && (iHeight == 480) )
+		iFormat = FORMAT_NTSC1;
+	else if  ((iWidth == 704) && (iHeight == 480) )
+		iFormat = FORMAT_NTSC2;
+	else if  ((iWidth == 352) && (iHeight == 480) )
+		iFormat = FORMAT_NTSC3;
+	else if  ((iWidth == 352) && (iHeight == 240) )
+		iFormat = FORMAT_NTSC4;
+	else if  ((iWidth == 720) && (iHeight == 576) )
+		iFormat = FORMAT_PAL1;
+	else if ((iWidth == 704) && (iHeight == 576) )
+		iFormat = FORMAT_PAL2;
+	else if  ((iWidth == 352) && (iHeight == 576) )
+		iFormat = FORMAT_PAL3;
+	else if  ((iWidth == 352) && (iHeight == 288) )
+		iFormat = FORMAT_PAL4;
+	return iFormat;
+}
+
 QString Utils::iso639 (QString qsCode, bool bReverse)
 {
 	// This function will return the Country name of the found two-letter - code
@@ -235,7 +281,8 @@ QString Utils::checkForExe( QString qsExe )
 	QString qsExePath;
 	QFileInfo fileInfo(QString ("%1/%2_out.txt").arg(Global::qsTempPath).arg(getlogin()));
 	// the next check is to see if we can find 
-	system ((const char *)QString ("which %1 > %2/%3_out.txt 2>/dev/null").arg(qsExe).arg(Global::qsTempPath).arg(getlogin()));
+	if ( system ((const char *)QString ("which %1 > %2/%3_out.txt 2>/dev/null").arg(qsExe).arg(Global::qsTempPath).arg(getlogin())) == -1)
+		return QString ();
 	fileInfo.setFile(QString("%1/%2_out.txt").arg(Global::qsTempPath).arg(getlogin()));
 	// Okay we can not find it, so we wont bother asking the user ...
 	if (fileInfo.size() > 4)	{
@@ -357,7 +404,7 @@ QString Utils::getTempFile (QString qsOrigFileName)
 	if (!tempDir.exists())
 		tempDir.mkdir (qsTempDir);
 	if (!tempDir.exists())	{
-		QMessageBox::warning ( NULL, QObject::tr ("Could not create temp directory"),
+		MessageBox::warning ( NULL, QObject::tr ("Could not create temp directory"),
 		QObject::tr ("Failed to create temp directory\n"
 			"%1").arg (qsTempDir),
 			QMessageBox::Ok, QMessageBox::NoButton);
@@ -371,6 +418,22 @@ QString Utils::getTempFile (QString qsOrigFileName)
 	return qsTempDir;
 }
 
+// creates a path under the temp dir ...
+QString Utils::getTempPath ( QString qsInputPath )
+{
+  QString qsPath = getTempFile ( qsInputPath );
+  QDir tempDir ( qsPath );
+  if ( ! tempDir.exists ( ) )
+    tempDir.mkdir ( qsPath );
+  if ( ! tempDir.exists ( ) )  {
+    MessageBox::warning ( NULL, QObject::tr ("Could not create temp directory"),
+       QObject::tr ("Failed to create temp directory\n%1").arg ( qsPath ), 
+       QMessageBox::Ok, QMessageBox::NoButton);
+    return Global::qsTempPath + QString ("/");
+  }
+  return qsPath;
+}
+
 QString Utils::getUniqueTempFile (QString qsOrigFileName)
 {
 	uint t = 0;
@@ -484,24 +547,24 @@ bool Utils::recRmdir( const QString &dirName, const char *pExcludeFiles ) const
 	return dir.rmdir(dirN); // delete empty dir and return if (now empty) dir-removing was successfull
 }
 
-int Utils::getMsFromString(QString qsInput)
+long Utils::getMsFromString(QString qsInput)
 {
-	
-	uint iHours, iMinutes, iSeconds, iMilliSeconds, iStepper;
-	float fSeconds=0.0;
-	iStepper=0;
-	// 00:00:00.000
-	iHours = iMinutes = iSeconds = iMilliSeconds = 0;
-	QStringList listParts = QStringList::split (":", qsInput);
-	if (listParts.count() > 3)
-		return 0;
-	if (listParts.count() > 2)
-		iHours = listParts[iStepper++].toInt();
-	if (listParts.count() > 1)
-		iMinutes = listParts[iStepper++].toInt();
-	if (listParts.count() > 0)
-		fSeconds = listParts[iStepper++].toFloat();
-	iMilliSeconds = (uint)(1000*fSeconds) + 60*1000*iMinutes + 60*60*1000*iHours;
+  long iMilliSeconds;
+  uint iHours, iMinutes, iSeconds, iStepper;
+  float fSeconds=0.0;
+  iStepper=0;
+  // 00:00:00.000
+  iHours = iMinutes = iSeconds = iMilliSeconds = 0;
+  QStringList listParts = QStringList::split (":", qsInput);
+  if (listParts.count() > 3)
+    return 0;
+  if (listParts.count() > 2)
+    iHours = listParts[iStepper++].toInt();
+  if (listParts.count() > 1)
+    iMinutes = listParts[iStepper++].toInt();
+  if (listParts.count() > 0)
+    fSeconds = listParts[iStepper++].toFloat();
+  iMilliSeconds = (uint)(1000*fSeconds) + 60*1000*iMinutes + 60*60*1000*iHours;
 // 	uint iHours, iMinutes, iSeconds, iMilliSeconds;
 // 	QTime length;
 // 	
@@ -514,10 +577,10 @@ int Utils::getMsFromString(QString qsInput)
 // 	length= QTime::fromString(qsInput);
 // 	iHours = 
 	
-	return iMilliSeconds;
+  return iMilliSeconds;
 }
 
-QString Utils::getStringFromMs(int iInput)
+QString Utils::getStringFromMs ( long iInput )
 {
 	uint iHours, iMinutes, iSeconds;
         double fMilliSeconds=0.0;
@@ -575,3 +638,95 @@ int Utils::getWHFromResolution ( QString qsResolution, bool bWidth )
   qsHeight = qsResolution.right(iXPos);
   return qsHeight.toInt ();
 }
+
+bool Utils::isMpeg2 ( QString qsFileName )
+{
+  unsigned char Mpeg2Header[4] = {0x00, 0x00, 0x01, 0xba };
+  int t, iByte;
+  unsigned char c;
+  QFile theFile ( qsFileName );
+
+  if ( ! theFile.exists () )
+    return false;
+
+  if ( ! theFile.open ( IO_ReadOnly ) )
+    return false;
+
+  for (t=0;t<4;t++) {
+    iByte = theFile.getch ();
+    if ( iByte == -1 ) {
+      theFile.close ();
+      return false;
+    }
+    c = (unsigned char) iByte;
+    if ( Mpeg2Header[t] != c )
+      return false;
+  }
+  theFile.close ();
+
+  // Okay getting here means the first 4 bytes are mpeg2 header compliant ... Greeeeeat !!!
+  return true;
+}
+
+bool Utils::hasVobus ( QString qsFileName )
+{
+  // VOB is a special subset of the Mpeg2 standard. I stole this test version from DVDStyler's MPEG.cpp - file.
+  // A great thank you goes to Alex Thuering for his great effort to advance DVDStyler. 
+  // But Ya'll know 'Q'DVD-Author is much better ;o) 
+
+  /*
+    Navigation packets are PES packets with a stream id 0xbf, i.e.
+    private stream 2.  It's made up of PCI, Presentation Control Information
+    and DSI, Data Search Information.
+    
+    details: www.mpucoder.com
+   */
+  
+  unsigned char PCI_PACK[] = { 0x00, 0x00, 0x01, 0xBF, 0x03, 0xD4 };
+  unsigned char DSI_PACK[] = { 0x00, 0x00, 0x01, 0xBF, 0x03, 0xFA };
+  
+  QFile theFile ( qsFileName );
+  if ( ! theFile.open ( IO_ReadOnly ) )
+    return false;
+  
+  const long MAX_LENGTH=16384; // only looking at 1st 16KB - enough to contain nav packs
+  unsigned char buffer[MAX_LENGTH];
+  
+  // skip zeroes at start of file
+  int zeroCnt = 0;
+  char c;
+  while ( (c = (char)theFile.getch ( ) ) == 0)
+    zeroCnt++;
+  
+  if (zeroCnt < 2 || c != 1)
+    return false;
+  
+  buffer[0] = buffer[1] = 0; buffer[2] = 1;
+  int iRead = theFile.readBlock ( (char *)(buffer+3), MAX_LENGTH-3);
+  
+  bool valid_pci = false;
+  bool valid_dsi = false;
+  for (int i=0; i<iRead-(int)sizeof(PCI_PACK); i++)
+    {
+      int j;
+      for (j=0; j<(int)sizeof(PCI_PACK); j++)
+	{
+	  if(buffer[i+j] != PCI_PACK[j])
+	    break;
+	  else if (j == sizeof(PCI_PACK)-1)
+	    valid_pci=true;
+	}
+      for (j=0; j<(int)sizeof(DSI_PACK); j++)
+      {
+	if(buffer[i+j] != DSI_PACK[j])
+	  break;
+	else if (j == sizeof(DSI_PACK)-1)
+	  valid_dsi=true;
+      }
+      
+      if (valid_pci && valid_dsi)
+	return true;
+    }
+  
+  return false;
+}
