@@ -12,15 +12,22 @@
 
 // The following version number is used for the xml - ProjectFile
 #define QDVDAUTHOR_VERSION                     "XMLVersion"
-#define QDVDAUTHOR_VERSION_NUMBER              "0.1.0"
+#define QDVDAUTHOR_VERSION_NUMBER              "0.1.2"
 
 // Here we goof around with the Templates
 // Nodes
+#define TEMPLATE_VERSION_NUMBER                1.2
 #define TEMPLATE_DOCTYPE                       "QDVDAuthor"
 #define XML_TEMPLATE                           "QDVDTemplate"
 #define TEMPLATE_DATA                          "DVDTemplateData"
+#define TEMPLATE_VERSION                       "XMLVersion"
+#define TEMPLATE_AUTHOR                        "Author"
+#define TEMPLATE_CONTACT                       "Contact"
+#define TEMPLATE_HEADER                        "Header"
 #define TEMPLATE_DESCRIPTION                   "TemplateDescription"
+#define TEMPLATE_COMMENT                       "TemplateComment"
 #define TEMPLATE_DROPZONE                      "DropZone"
+
 // Tags
 #define TEMPLATE_NAME                          "TemplateName"
 #define TEMPLATE_DROPZONE_X                    "X"
@@ -28,6 +35,7 @@
 #define TEMPLATE_DROPZONE_WIDTH                "Width"
 #define TEMPLATE_DROPZONE_HEIGHT               "Height"
 #define TEMPLATE_DROPZONE_NUMBER               "Number"
+#define TEMPLATE_DROPZONE_TYPE                 "Type"
 
 // Here are the defines for qdvdauthor.
 #define DVDAUTHOR                               "DVDAuthor"
@@ -49,7 +57,7 @@
 #define MENU_EXTRO                              "MenuExtro"
 #define MENU_SOUND                              "MenuSound"
 #define MENU_MOVIE                              "MenuMovie"
-#define MENU_BACKGROUND                         "MenuBackround"
+#define MENU_BACKGROUND                         "MenuBackground"
 #define MENU_OFFSET                             "MenuOffset"
 #define MENU_DURATION                           "MenuDuration"
 #define MENU_ANIMATION                          "MenuAnimation"
@@ -92,6 +100,14 @@
 #define FRAME_OBJECT_STYLE                      "Style"
 #define FRAME_OBJECT_JOIN                       "Join"
 
+// ShadowObject - class
+#define SHADOW_OBJECT                           "ShadowObject"
+#define SHADOW_OBJECT_COLOR                     "Color"
+#define SHADOW_OBJECT_TRANSPARENCY              "Transparency"
+#define SHADOW_OBJECT_DISTANCE                  "Distance"
+#define SHADOW_OBJECT_BLUR_RADIUS               "BlurRadius"
+#define SHADOW_OBJECT_SUN_ANGLE                 "SunAngle"
+
 // The TextObject - class
 #define TEXT_OBJECT                             "TextObject"
 #define TEXT_OBJECT_TEXT                        "Text"
@@ -110,6 +126,7 @@
 #define MOVIE_OBJECT_FILE_NAME                  "FileName"
 #define MOVIE_OBJECT_OFFSET                     "Offset"
 #define MOVIE_OBJECT_DURATION                   "Duration"
+#define MOVIE_OBJECT_MSEC_PREVIEW               "MSecPreview"
 #define MOVIE_OBJECT_SIZE                       "Size"
 
 // The ObjectCollection - class
@@ -142,15 +159,18 @@
 #define SOURCE_OBJECT_FPS                       "FPS"
 #define SOURCE_OBJECT_RATIO                     "Ratio"
 #define SOURCE_OBJECT_LENGTH                    "Length"
-#define SOURCE_OBJECT_FORMAT                    "Format"
+#define SOURCE_OBJECT_VIDEO_FORMAT              "Format"
+#define SOURCE_OBJECT_AUDIO_FORMAT              "AudioFormat"
 #define SOURCE_OBJECT_STATUS                    "Status"
 #define SOURCE_OBJECT_BITS                      "Bits"
 #define SOURCE_OBJECT_SAMPLE                    "Sample"
 #define SOURCE_OBJECT_BPS                       "BPS"
 #define SOURCE_OBJECT_PAUSE                     "Pause"
+#define SOURCE_OBJECT_MSEC_OFFSET               "MSecPreview"
 #define SOURCE_OBJECT_TITLESET                  "Titleset"
 #define SOURCE_OBJECT_PROPERTIES                "Properties"
 #define SOURCE_OBJECT_TRANSCODE                 "TranscodeInterface"
+#define SOURCE_OBJECT_AUTOTRANSCODE             "AutoTranscode"
 #define SOURCE_OBJECT_SUBTITLES                 "Subtitles"
 
 #define SOURCE_PROPERTIES_POST                  "PostCommands"
