@@ -4,8 +4,8 @@
 #include "../bugs_workaround.h"
 #include "global.h"
 #include "xml_dvdauthor.h"
+#include "messagebox.h"
 
-#include <qmessagebox.h>
 #include <qfiledialog.h>
 #include <qfile.h>
 #include <qstring.h>
@@ -59,7 +59,7 @@ bool CXmlDVDAuthor::readXml (QString &fileName )
 	if (!xmlDoc.setContent (&projectFile))	{
 		// Error handling ...
 		projectFile.close();
-		int iReturn = QMessageBox::warning ( NULL, QObject::tr ("xml project file seems to be defective."),
+		int iReturn = MessageBox::warning ( NULL, QObject::tr ("xml project file seems to be defective."),
 			QObject::tr ("Do you want to try to load another project file ?"),
 			QMessageBox::Yes, QMessageBox::No);
 		if (iReturn == QMessageBox::Yes)
@@ -362,6 +362,7 @@ bool CXmlDVDAuthor::vob_struct::readXml(QDomElement *pNodeElement)
 	chapters = a.value();
 	a = pNodeElement->attributeNode ( VOB_PAUSE );
 	pause = a.value();
+
 	// And now read in all remaining nodes and handle them accordingly.
 	QDomNode xmlNode = pNodeElement->firstChild();
 	// And only one menus entry is allowed ...
@@ -964,7 +965,7 @@ bool CXmlSpumux::readXml ( QString &fileName )
   if (!xmlDoc.setContent (&projectFile))	{
     // Error handling ...
     projectFile.close();
-    int iReturn = QMessageBox::warning ( NULL, QObject::tr ("xml spumux file seems to be defective."),
+    int iReturn = MessageBox::warning ( NULL, QObject::tr ("xml spumux file seems to be defective."),
 					 QObject::tr ("Do you want to try to load another project file ?"),
 					 QMessageBox::Yes, QMessageBox::No);
     if (iReturn == QMessageBox::Yes)
