@@ -556,11 +556,17 @@ void AnimationAttribute::append (long iFrame, QString qsValue)
 		m_arrayStrings[iFrame] = qsValue;
 }
 
-
+#include <qregexp.h>
 int main( int, char ** )
 {
-    loadAnimationData ("test.anim");
-    
+//    loadAnimationData ("test.anim");
+  	QRegExp rx ( "<[^>]*>"); //"s/</p>/HHH/g" );
+	QString qsFick, qsFuck ( "<p align=\"center\">FUCK THIS</p>" );
+
+	qsFick = qsFuck.remove ( rx );
+
+	printf ( "%s  -  %s\n", qsFuck.ascii ( ), qsFick.ascii ( ) ) ;
+  
     return 0;
 }
 
